@@ -40,29 +40,26 @@ namespace unocontrols {
     /* First get all interfaces from container with right type.*/                                                                   \
     OInterfaceContainerHelper* pContainer = m_aListenerHolder.getContainer( cppu::UnoType<INTERFACE>::get() );  \
     /* Do the follow only, if elements in container exist.*/                                                                        \
-    if( pContainer != nullptr )                                                                                                        \
-    {                                                                                                                               \
-        OInterfaceIteratorHelper aIterator( *pContainer );                                                                          \
-        EVENTTYP aLocalEvent = EVENT;                                                                                               \
-        /* Remark: The control is the event source not the peer.*/                                                                  \
-        /*         We must change the source of the event.      */                                                                  \
-        aLocalEvent.Source = m_xControl;                                                                                           \
-        /* Is the control not destroyed? */                                                                                         \
-        if( aLocalEvent.Source.is() )                                                                                               \
-        {                                                                                                                           \
-            if( aIterator.hasMoreElements() )                                                                                       \
-            {                                                                                                                       \
-                INTERFACE * pListener = static_cast<INTERFACE *>(aIterator.next());                                                 \
-                try                                                                                                                 \
-                {                                                                                                                   \
-                    pListener->METHOD( aLocalEvent );                                                                               \
-                }                                                                                                                   \
-                catch(const RuntimeException& )                                                                                     \
-                {                                                                                                                   \
-                    /* Ignore all system exceptions from the listener! */                                                           \
-                }                                                                                                                   \
-            }                                                                                                                       \
-        }                                                                                                                           \
+    if( !pContainer )                                                                                                        \
+        return;                                                                                                                               \
+    OInterfaceIteratorHelper aIterator( *pContainer );                                                                          \
+    EVENTTYP aLocalEvent = EVENT;                                                                                               \
+    /* Remark: The control is the event source not the peer.*/                                                                  \
+    /*         We must change the source of the event.      */                                                                  \
+    aLocalEvent.Source = m_xControl;                                                                                           \
+    /* Is the control not destroyed? */                                                                                         \
+    if( !aLocalEvent.Source )                                                                                               \
+        return;                                                                                                                           \
+    if( !aIterator.hasMoreElements() )                                                                                       \
+        return;                                                                                                             \
+    INTERFACE * pListener = static_cast<INTERFACE *>(aIterator.next());                                                 \
+    try                                                                                                                 \
+    {                                                                                                                   \
+        pListener->METHOD( aLocalEvent );                                                                               \
+    }                                                                                                                   \
+    catch(const RuntimeException& )                                                                                     \
+    {                                                                                                                   \
+        /* Ignore all system exceptions from the listener! */                                                           \
     }
 
 //  construct/destruct
@@ -128,7 +125,7 @@ Any SAL_CALL OMRCListenerMultiplexerHelper::queryInterface( const Type& rType )
 
 //  XInterface
 
-void SAL_CALL OMRCListenerMultiplexerHelper::acquire() throw()
+void SAL_CALL OMRCListenerMultiplexerHelper::acquire() noexcept
 {
     // Attention:
     //  Don't use mutex or guard in this method!!! Is a method of XInterface.
@@ -139,7 +136,7 @@ void SAL_CALL OMRCListenerMultiplexerHelper::acquire() throw()
 
 //  XInterface
 
-void SAL_CALL OMRCListenerMultiplexerHelper::release() throw()
+void SAL_CALL OMRCListenerMultiplexerHelper::release() noexcept
 {
     // Attention:
     //  Don't use mutex or guard in this method!!! Is a method of XInterface.
