@@ -125,7 +125,7 @@ public:
     Mutex maMutex;
 };
 
-class AnimationNode : public AnimationNodeBase
+class AnimationNode final : public AnimationNodeBase
 {
 public:
     explicit AnimationNode(sal_Int16 nNodeType);
@@ -133,8 +133,8 @@ public:
 
     // XInterface
     virtual Any SAL_CALL queryInterface( const Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XTypeProvider
     virtual Sequence< Type > SAL_CALL getTypes() override;
@@ -254,6 +254,10 @@ public:
     virtual void SAL_CALL setSource( const Any& _source ) override;
     virtual double SAL_CALL getVolume() override;
     virtual void SAL_CALL setVolume( double _volume ) override;
+    sal_Bool SAL_CALL getHideDuringShow() override;
+    void SAL_CALL setHideDuringShow(sal_Bool bHideDuringShow) override;
+    sal_Bool SAL_CALL getNarration() override;
+    void SAL_CALL setNarration(sal_Bool bNarration) override;
 
 
     // XCommand - the following two shadowed by animate, unfortunately
@@ -297,7 +301,7 @@ public:
 private:
     OInterfaceContainerHelper2   maChangeListener;
 
-    static void initTypeProvider( sal_Int16 nNodeType ) throw();
+    static void initTypeProvider( sal_Int16 nNodeType ) noexcept;
 
     const sal_Int16 mnNodeType;
 
@@ -347,6 +351,8 @@ private:
 
     // XAudio
     double mfVolume;
+    bool mbHideDuringShow;
+    bool mbNarration;
 
     // XCommand
     sal_Int16 mnCommand;
@@ -434,6 +440,8 @@ AnimationNode::AnimationNode( sal_Int16 nNodeType )
     mbMode(true),
     mnFadeColor(0),
     mfVolume(1.0),
+    mbHideDuringShow(false),
+    mbNarration(false),
     mnCommand(0),
     mnIterateType( css::presentation::ShapeAnimationSubType::AS_WHOLE ),
     mfIterateInterval(0.0)
@@ -504,6 +512,8 @@ AnimationNode::AnimationNode( const AnimationNode& rNode )
 
     // XAudio
     mfVolume( rNode.mfVolume ),
+    mbHideDuringShow(rNode.mbHideDuringShow),
+    mbNarration(rNode.mbNarration),
 
     // XCommand
     mnCommand( rNode.mnCommand ),
@@ -732,7 +742,7 @@ Any SAL_CALL AnimationNode::queryInterface( const Type& aType )
 }
 
 
-void AnimationNode::initTypeProvider( sal_Int16 nNodeType ) throw()
+void AnimationNode::initTypeProvider( sal_Int16 nNodeType ) noexcept
 {
     ::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
 
@@ -827,14 +837,14 @@ Sequence< sal_Int8 > AnimationNode::getImplementationId()
 
 
 // XInterface
-void SAL_CALL AnimationNode::acquire(  ) throw ()
+void SAL_CALL AnimationNode::acquire(  ) noexcept
 {
     OWeakObject::acquire();
 }
 
 
 // XInterface
-void SAL_CALL AnimationNode::release(  ) throw ()
+void SAL_CALL AnimationNode::release(  ) noexcept
 {
     OWeakObject::release();
 }
@@ -1807,6 +1817,37 @@ void SAL_CALL AnimationNode::setVolume( double _volume )
     }
 }
 
+sal_Bool SAL_CALL AnimationNode::getHideDuringShow()
+{
+    osl::Guard<osl::Mutex> aGuard(maMutex);
+    return mbHideDuringShow;
+}
+
+void SAL_CALL AnimationNode::setHideDuringShow(sal_Bool bHideDuringShow)
+{
+    osl::Guard<osl::Mutex> aGuard(maMutex);
+    if (static_cast<bool>(bHideDuringShow) != mbHideDuringShow)
+    {
+        mbHideDuringShow = bHideDuringShow;
+        fireChangeListener();
+    }
+}
+
+sal_Bool SAL_CALL AnimationNode::getNarration()
+{
+    osl::Guard<osl::Mutex> aGuard(maMutex);
+    return mbNarration;
+}
+
+void SAL_CALL AnimationNode::setNarration(sal_Bool bNarration)
+{
+    osl::Guard<osl::Mutex> aGuard(maMutex);
+    if (static_cast<bool>(bNarration) != mbNarration)
+    {
+        mbNarration = bNarration;
+        fireChangeListener();
+    }
+}
 
 // XCommand
 sal_Int16 SAL_CALL AnimationNode::getCommand()
@@ -1875,7 +1916,7 @@ Reference< XAnimationNode > SAL_CALL AnimationNode::insertBefore( const Referenc
     Guard< Mutex > aGuard( maMutex );
 
     if( !newChild.is() || !refChild.is() )
-        throw IllegalArgumentException();
+        throw IllegalArgumentException("no child", static_cast<cppu::OWeakObject*>(this), -1);
 
     if( std::find(maChildren.begin(), maChildren.end(), newChild) != maChildren.end() )
         throw ElementExistException();
@@ -1899,7 +1940,7 @@ Reference< XAnimationNode > SAL_CALL AnimationNode::insertAfter( const Reference
     Guard< Mutex > aGuard( maMutex );
 
     if( !newChild.is() || !refChild.is() )
-        throw IllegalArgumentException();
+        throw IllegalArgumentException("no child", static_cast<cppu::OWeakObject*>(this), -1);
 
     if( std::find(maChildren.begin(), maChildren.end(), newChild) != maChildren.end() )
         throw ElementExistException();
@@ -1927,7 +1968,7 @@ Reference< XAnimationNode > SAL_CALL AnimationNode::replaceChild( const Referenc
     Guard< Mutex > aGuard( maMutex );
 
     if( !newChild.is() || !oldChild.is() )
-        throw IllegalArgumentException();
+        throw IllegalArgumentException("no child", static_cast<cppu::OWeakObject*>(this), -1);
 
     if( std::find(maChildren.begin(), maChildren.end(), newChild) != maChildren.end() )
         throw ElementExistException();
@@ -1953,7 +1994,7 @@ Reference< XAnimationNode > SAL_CALL AnimationNode::removeChild( const Reference
     Guard< Mutex > aGuard( maMutex );
 
     if( !oldChild.is() )
-        throw IllegalArgumentException();
+        throw IllegalArgumentException("no child", static_cast<cppu::OWeakObject*>(this), 1);
 
     auto old = std::find(maChildren.begin(), maChildren.end(), oldChild);
     if( old == maChildren.end() )
@@ -1973,7 +2014,7 @@ Reference< XAnimationNode > SAL_CALL AnimationNode::appendChild( const Reference
     Guard< Mutex > aGuard( maMutex );
 
     if( !newChild.is() )
-        throw IllegalArgumentException();
+        throw IllegalArgumentException("no child", static_cast<cppu::OWeakObject*>(this), 1);
 
     if( std::find(maChildren.begin(), maChildren.end(), newChild) != maChildren.end() )
         throw ElementExistException();
@@ -1982,7 +2023,7 @@ Reference< XAnimationNode > SAL_CALL AnimationNode::appendChild( const Reference
     Reference< XInterface > xChild( newChild );
 
     if( xThis == xChild )
-        throw IllegalArgumentException();
+        throw IllegalArgumentException("cannot append self", static_cast<cppu::OWeakObject*>(this), -1);
 
     maChildren.push_back( newChild );
 
@@ -2060,14 +2101,10 @@ void SAL_CALL AnimationNode::removeChangesListener( const Reference< XChangesLis
     }
 }
 
-namespace
-{
-    class theAnimationNodeUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theAnimationNodeUnoTunnelId > {};
-}
-
 const css::uno::Sequence< sal_Int8 > & AnimationNode::getUnoTunnelId()
 {
-    return theAnimationNodeUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theAnimationNodeUnoTunnelId;
+    return theAnimationNodeUnoTunnelId.getSeq();
 }
 
 
