@@ -20,6 +20,7 @@
 #include <config_features.h>
 
 #include <math.h>
+#include <string_view>
 
 #include <o3tl/float_int_conversion.hxx>
 #include <tools/debug.hxx>
@@ -246,7 +247,7 @@ SbxValue* SbxValue::TheRealValue( bool bObjInObjError ) const
                     if( pDimArray )
                         p = pDimArray->Get( pPar );
                     else
-                        p = pArray->Get32( pPar->Get32( 1 )->GetInteger() );
+                        p = pArray->Get(pPar->Get(1)->GetInteger());
                     break;
                 }
             }
@@ -1382,11 +1383,14 @@ bool SbxValue::LoadData( SvStream& r, sal_uInt16 )
                     aData.pObj = nullptr;
                     break;
                 case 1:
-                    aData.pObj = SbxBase::Load( r );
+                {
+                    auto ref = SbxBase::Load( r );
+                    aData.pObj = ref.get();
                     // if necessary increment Ref-Count
                     if (aData.pObj)
                         aData.pObj->AddFirstRef();
                     return ( aData.pObj != nullptr );
+                }
                 case 2:
                     aData.pObj = this;
                     break;
@@ -1499,7 +1503,7 @@ bool SbxValue::LoadData( SvStream& r, sal_uInt16 )
                 }
                 else
                 {
-                    write_uInt16_lenPrefixed_uInt8s_FromOUString(r, OUString(), RTL_TEXTENCODING_ASCII_US);
+                    write_uInt16_lenPrefixed_uInt8s_FromOUString(r, std::u16string_view(), RTL_TEXTENCODING_ASCII_US);
             }
             break;
             case SbxERROR:
