@@ -53,7 +53,7 @@ namespace vclcanvas
         CanvasHelper::init( rDevice,
                             mpBackBuffer,
                             false,
-                            rBitmap.IsTransparent() );
+                            rBitmap.IsAlpha() );
     }
 
     void CanvasBitmapHelper::disposing()
@@ -148,7 +148,7 @@ namespace vclcanvas
         pRes[ 0 ] = aColor.GetRed();
         pRes[ 1 ] = aColor.GetGreen();
         pRes[ 2 ] = aColor.GetBlue();
-        pRes[ 3 ] = aColor.GetTransparency();
+        pRes[ 3 ] = 255 - aColor.GetAlpha();
 
         return aRes;
     }
