@@ -22,6 +22,7 @@
 #include <rtl/ustrbuf.hxx>
 
 #include <fstream>
+#include <string_view>
 
 #if defined(X86)
 #define INT_EPS     2.1
@@ -50,7 +51,7 @@
     else \
         { \
             OString sTestFileName = OUStringToOString(getTestFileName(), RTL_TEXTENCODING_UTF8); \
-            CPPUNIT_ASSERT_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), readExpected(#aActual), OUString(OUString::number(aActual))); \
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), readExpected(u ## #aActual), OUString(OUString::number(aActual))); \
         }
 
 #define CPPUNIT_DUMP_ASSERT_DOUBLES_EQUAL(aActual, EPS_) \
@@ -59,7 +60,7 @@
         else \
         { \
             OString sTestFileName = OUStringToOString(getTestFileName(), RTL_TEXTENCODING_UTF8); \
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), readExpectedDouble(#aActual), aActual, EPS_); \
+            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), readExpectedDouble(u ## #aActual), aActual, EPS_); \
         }
 
 #define CPPUNIT_DUMP_ASSERT_STRINGS_EQUAL(aActual) \
@@ -68,7 +69,7 @@
     else \
     { \
         OString sTestFileName = OUStringToOString(getTestFileName(), RTL_TEXTENCODING_UTF8); \
-        CPPUNIT_ASSERT_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), readExpected(#aActual), aActual.trim()); \
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), readExpected(u ## #aActual), aActual.trim()); \
     }
 
 #define CPPUNIT_DUMP_ASSERT_TRANSFORMATIONS_EQUAL(aActual, EPS_) \
@@ -77,21 +78,14 @@
     else \
     { \
         OUString expectedTransform; \
-        if (!readAndCheckTransformation (aActual, #aActual, EPS_, expectedTransform)) \
+        if (!readAndCheckTransformation (aActual, u ## #aActual, EPS_, expectedTransform)) \
         { \
             OString sTestFileName = OUStringToOString(getTestFileName(), RTL_TEXTENCODING_UTF8); \
             CPPUNIT_ASSERT_EQUAL_MESSAGE(OString("Failing test file is: " + sTestFileName).getStr(), expectedTransform, transformationToOneLineString(aActual)); \
         } \
     }
 
-#define CPPUNIT_DUMP_ASSERT_NOTE(Note) \
-    if(isInDumpMode()) \
-        writeNote(Note); \
-    else \
-        readNote(Note);\
-
-
-class Chart2DumpTest : public ChartTest, public XmlTestTools
+class Chart2DumpTest : public ChartTest
 {
 protected:
     Chart2DumpTest(bool bDumpMode)
@@ -103,6 +97,13 @@ protected:
     {
     }
 
+    void CPPUNIT_DUMP_ASSERT_NOTE(OUString const & Note) {
+        if(isInDumpMode())
+            writeNote(Note);
+        else
+            readNote(Note);
+    }
+
     bool isInDumpMode () const {return m_bDumpMode;}
 
     virtual OUString getTestName() { return OUString(); }
@@ -124,7 +125,7 @@ protected:
         {
             if (m_aReferenceFile.is_open())
                 m_aReferenceFile.close();
-            OString sReferenceFile = OUStringToOString(m_directories.getPathFromSrc(getReferenceDirName()) + sFileName, RTL_TEXTENCODING_UTF8);
+            OString sReferenceFile = OUStringToOString(OUString(m_directories.getPathFromSrc(getReferenceDirName()) + sFileName), RTL_TEXTENCODING_UTF8);
             m_aReferenceFile.open(sReferenceFile.getStr(), std::ios_base::in);
             CPPUNIT_ASSERT_MESSAGE(OString("Can't open reference file: " + sReferenceFile).getStr(), m_aReferenceFile.is_open());
         }
@@ -132,7 +133,7 @@ protected:
         {
             if (m_aDumpFile.is_open())
                 m_aDumpFile.close();
-            OString sDumpFile = OUStringToOString(m_directories.getPathFromSrc(getReferenceDirName()) + sFileName, RTL_TEXTENCODING_UTF8);
+            OString sDumpFile = OUStringToOString(OUString(m_directories.getPathFromSrc(getReferenceDirName()) + sFileName), RTL_TEXTENCODING_UTF8);
             m_aDumpFile.open(sDumpFile.getStr(), std::ios_base::out | std::ofstream::binary | std::ofstream::trunc);
             CPPUNIT_ASSERT_MESSAGE(OString("Can't open dump file: " + sDumpFile).getStr(), m_aDumpFile.is_open());
         }
@@ -143,7 +144,7 @@ protected:
         CPPUNIT_FAIL("verify method must be overridden");
     }
 
-    OUString readExpected(const OUString& sCheck)
+    OUString readExpected(std::u16string_view sCheck)
     {
         assert(!m_bDumpMode);
         assert(m_aReferenceFile.is_open());
@@ -152,7 +153,7 @@ protected:
         OString sAssertMessage =
             "The reference file does not contain the right content. Maybe it needs an update:"
             + OUStringToOString(m_sTestFileName, RTL_TEXTENCODING_UTF8);
-        CPPUNIT_ASSERT_EQUAL_MESSAGE(sAssertMessage.getStr(), OUString("// " + sCheck), OUString(sTemp.data(), sTemp.length(), RTL_TEXTENCODING_UTF8));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(sAssertMessage.getStr(), OUString(OUString::Concat("// ") + sCheck), OUString(sTemp.data(), sTemp.length(), RTL_TEXTENCODING_UTF8));
         getline(m_aReferenceFile, sTemp);
         return OUString(sTemp.data(), sTemp.length(), RTL_TEXTENCODING_UTF8);
     }
@@ -165,7 +166,7 @@ protected:
         m_aDumpFile << sActualValue.trim() << "\n";      // Write out the checked value, will be used as reference later
     }
 
-    void readNote(const OUString& sNote)
+    void readNote(std::u16string_view sNote)
     {
         assert(!m_bDumpMode);
         assert(m_aReferenceFile.is_open());
@@ -174,7 +175,7 @@ protected:
         OString sAssertMessage =
             "The reference file does not contain the right content. Maybe it needs an update:"
             + OUStringToOString(m_sTestFileName, RTL_TEXTENCODING_UTF8);
-        CPPUNIT_ASSERT_EQUAL_MESSAGE(sAssertMessage.getStr(), OUString("/// " + sNote), OUString(sTemp.data(), sTemp.length(), RTL_TEXTENCODING_UTF8));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(sAssertMessage.getStr(), OUString(OUString::Concat("/// ") + sNote), OUString(sTemp.data(), sTemp.length(), RTL_TEXTENCODING_UTF8));
     }
 
     void writeNote(const OUString& sNote)
@@ -184,7 +185,7 @@ protected:
         m_aDumpFile << "/// " << sNote << "\n";
     }
 
-    double readExpectedDouble(const OUString& sCheck)
+    double readExpectedDouble(std::u16string_view sCheck)
     {
         OUString sExpected = readExpected(sCheck);
         return sExpected.toDouble();
@@ -195,7 +196,7 @@ protected:
         writeActual(transformationToOneLineString(rTransform), sCheck);
     }
 
-    bool readAndCheckTransformation(const drawing::HomogenMatrix3& rTransform, const OUString& sCheck, const double fEPS, OUString& rExpectedTransform)
+    bool readAndCheckTransformation(const drawing::HomogenMatrix3& rTransform, std::u16string_view sCheck, const double fEPS, OUString& rExpectedTransform)
     {
         rExpectedTransform = readExpected(sCheck); // Reference transformation string
 
@@ -229,7 +230,7 @@ protected:
         OUStringBuffer aBuffer;
         for (const OUString& seqItem : rSeq)
         {
-            aBuffer.append(seqItem).append(";");
+            aBuffer.append(seqItem + ";");
         }
         return aBuffer.makeStringAndClear();
     }
@@ -239,7 +240,7 @@ protected:
         OUStringBuffer aBuffer;
         for (const double& vectorItem : rVector)
         {
-            aBuffer.append(OUString::number(vectorItem)).append(";");
+            aBuffer.append(OUString::number(vectorItem) + ";");
         }
         return aBuffer.makeStringAndClear();
     }
@@ -343,19 +344,19 @@ DECLARE_DUMP_TEST(ChartDataTest, Chart2DumpTest, false)
         // Check source ranges
         for (size_t nIndex = 0; nIndex < aDataSeriesYValues.size(); ++nIndex)
         {
-            Reference< chart2::data::XDataSequence > xDataSeq = getDataSequenceFromDocByRole(xChartDoc2, "values-x", nIndex);
+            Reference< chart2::data::XDataSequence > xDataSeq = getDataSequenceFromDocByRole(xChartDoc2, u"values-x", nIndex);
             if (xDataSeq.is())
             {
                 OUString aXValuesSourceRange = xDataSeq->getSourceRangeRepresentation();
                 CPPUNIT_DUMP_ASSERT_STRINGS_EQUAL(aXValuesSourceRange);
             }
-            xDataSeq.set(getDataSequenceFromDocByRole(xChartDoc2, "values-y", nIndex));
+            xDataSeq.set(getDataSequenceFromDocByRole(xChartDoc2, u"values-y", nIndex));
             if (xDataSeq.is())
             {
                 OUString aYValuesSourceRange = xDataSeq->getSourceRangeRepresentation();
                 CPPUNIT_DUMP_ASSERT_STRINGS_EQUAL(aYValuesSourceRange);
             }
-            xDataSeq.set(getDataSequenceFromDocByRole(xChartDoc2, "categories", nIndex));
+            xDataSeq.set(getDataSequenceFromDocByRole(xChartDoc2, u"categories", nIndex));
             if (xDataSeq.is())
             {
                 OUString aCategoriesSourceRange = xDataSeq->getSourceRangeRepresentation();
