@@ -14,12 +14,11 @@
 
 #include <test/xmldiff.hxx>
 #include <test/xmltesttools.hxx>
-#include <vcl/outdev.hxx>
-#include <vcl/svapp.hxx>
 
 #include <fstream>
+#include <string_view>
 
-class Chart2XShapeTest : public ChartTest, public XmlTestTools
+class Chart2XShapeTest : public ChartTest
 {
 public:
     void testFdo75075();
@@ -44,14 +43,14 @@ public:
     CPPUNIT_TEST_SUITE_END();
 
 private:
-    void compareAgainstReference(const OUString& rReferenceFile, bool bCreateReference = false);
+    void compareAgainstReference(std::u16string_view rReferenceFile, bool bCreateReference = false);
     OUString getXShapeDumpString();
     xmlDocUniquePtr getXShapeDumpXmlDoc();
 };
 
 namespace
 {
-bool checkDumpAgainstFile(const OUString& rDump, const OUString& aFilePath)
+bool checkDumpAgainstFile(const OUString& rDump, std::u16string_view aFilePath)
 {
     OString aOFile = OUStringToOString(aFilePath, RTL_TEXTENCODING_UTF8);
 
@@ -77,13 +76,13 @@ xmlDocUniquePtr Chart2XShapeTest::getXShapeDumpXmlDoc()
     return xmlDocUniquePtr(xmlParseDoc(reinterpret_cast<const xmlChar*>(aXmlDump.getStr())));
 }
 
-void Chart2XShapeTest::compareAgainstReference(const OUString& rReferenceFile,
+void Chart2XShapeTest::compareAgainstReference(std::u16string_view rReferenceFile,
                                                bool bCreateReference)
 {
     OUString aDump = getXShapeDumpString();
 
-    OUString aReference
-        = m_directories.getPathFromSrc("/chart2/qa/extras/xshape/data/reference/") + rReferenceFile;
+    OUString aReference = m_directories.getPathFromSrc(u"/chart2/qa/extras/xshape/data/reference/")
+                          + rReferenceFile;
     if (bCreateReference)
     {
         OString aOFile = OUStringToOString(aReference, RTL_TEXTENCODING_UTF8);
@@ -117,52 +116,48 @@ void Chart2XShapeTest::testPieChartLabels1()
 {
     // FIXME: the DPI check should be removed when either (1) the test is fixed to work with
     // non-default DPI; or (2) unit tests on Windows are made to use svp VCL plugin.
-    if (Application::GetDefaultDevice()->GetDPIX() != 96
-        || Application::GetDefaultDevice()->GetDPIY() != 96)
+    if (!IsDefaultDPI())
         return;
 
     // inside placement for the best fit case
-    load("chart2/qa/extras/xshape/data/xlsx/", "tdf90839-1.xlsx");
-    compareAgainstReference("tdf90839-1.xml");
+    load(u"chart2/qa/extras/xshape/data/xlsx/", "tdf90839-1.xlsx");
+    compareAgainstReference(u"tdf90839-1.xml");
 }
 
 void Chart2XShapeTest::testPieChartLabels2()
 {
     // FIXME: the DPI check should be removed when either (1) the test is fixed to work with
     // non-default DPI; or (2) unit tests on Windows are made to use svp VCL plugin.
-    if (Application::GetDefaultDevice()->GetDPIX() != 96
-        || Application::GetDefaultDevice()->GetDPIY() != 96)
+    if (!IsDefaultDPI())
         return;
 
     // text wrap: wrap all text labels except one
-    load("chart2/qa/extras/xshape/data/xlsx/", "tdf90839-2.xlsx");
-    compareAgainstReference("tdf90839-2.xml");
+    load(u"chart2/qa/extras/xshape/data/xlsx/", "tdf90839-2.xlsx");
+    compareAgainstReference(u"tdf90839-2.xml");
 }
 
 void Chart2XShapeTest::testPieChartLabels3()
 {
     // FIXME: the DPI check should be removed when either (1) the test is fixed to work with
     // non-default DPI; or (2) unit tests on Windows are made to use svp VCL plugin.
-    if (Application::GetDefaultDevice()->GetDPIX() != 96
-        || Application::GetDefaultDevice()->GetDPIY() != 96)
+    if (!IsDefaultDPI())
         return;
 
     // text wrap: wrap no text label except one
-    load("chart2/qa/extras/xshape/data/xlsx/", "tdf90839-3.xlsx");
-    compareAgainstReference("tdf90839-3.xml");
+    load(u"chart2/qa/extras/xshape/data/xlsx/", "tdf90839-3.xlsx");
+    compareAgainstReference(u"tdf90839-3.xml");
 }
 
 void Chart2XShapeTest::testPieChartLabels4()
 {
     // FIXME: the DPI check should be removed when either (1) the test is fixed to work with
     // non-default DPI; or (2) unit tests on Windows are made to use svp VCL plugin.
-    if (Application::GetDefaultDevice()->GetDPIX() != 96
-        || Application::GetDefaultDevice()->GetDPIY() != 96)
+    if (!IsDefaultDPI())
         return;
 
     // data value and percent value are centered horizontally
-    load("chart2/qa/extras/xshape/data/ods/", "tdf90839-4.ods");
-    compareAgainstReference("tdf90839-4.xml");
+    load(u"chart2/qa/extras/xshape/data/ods/", "tdf90839-4.ods");
+    compareAgainstReference(u"tdf90839-4.xml");
 }
 
 void Chart2XShapeTest::testTdf76649TrendLineBug()
@@ -170,7 +165,7 @@ void Chart2XShapeTest::testTdf76649TrendLineBug()
     // This bug prevents that the trendline (regression curve) is drawn
     // if the first cell is empty. See tdf#76649 for details.
 
-    load("chart2/qa/extras/xshape/data/ods/", "tdf76649_TrendLineBug.ods");
+    load(u"chart2/qa/extras/xshape/data/ods/", "tdf76649_TrendLineBug.ods");
 
     xmlDocUniquePtr pXmlDoc = getXShapeDumpXmlDoc();
 
@@ -181,7 +176,7 @@ void Chart2XShapeTest::testTdf76649TrendLineBug()
 
 void Chart2XShapeTest::testTdf88154LabelRotatedLayout()
 {
-    load("chart2/qa/extras/xshape/data/pptx/", "tdf88154_LabelRotatedLayout.pptx");
+    load(u"chart2/qa/extras/xshape/data/pptx/", "tdf88154_LabelRotatedLayout.pptx");
     uno::Reference<chart::XChartDocument> xChartDoc = getChartDocFromDrawImpress(0, 6);
     uno::Reference<qa::XDumper> xDumper(xChartDoc, UNO_QUERY_THROW);
     OUString rDump = xDumper->dump();
