@@ -237,7 +237,7 @@ bool AccessibleBase::ImplUpdateChildren()
             aAccInfo.m_aOID = childToAdd;
             if ( childToAdd.isAutoGeneratedObject() )
             {
-                AddChild( ChartElementFactory::CreateChartElement( aAccInfo ) );
+                AddChild( ChartElementFactory::CreateChartElement( aAccInfo ).get() );
             }
             else if ( childToAdd.isAdditionalShape() )
             {
@@ -427,7 +427,7 @@ void SAL_CALL AccessibleBase::disposing()
         m_aAccInfo.m_pParent = nullptr;
 
         // attach new empty state set helper to member reference
-        ::utl::AccessibleStateSetHelper * pHelper = new ::utl::AccessibleStateSetHelper();
+        rtl::Reference<::utl::AccessibleStateSetHelper> pHelper = new ::utl::AccessibleStateSetHelper();
         pHelper->AddState(AccessibleStateType::DEFUNC);
         // release old helper and attach new one
         m_xStateSetHelper = pHelper;
@@ -565,7 +565,7 @@ Reference< XAccessibleStateSet > SAL_CALL AccessibleBase::getAccessibleStateSet(
         m_bStateSetInitialized = true;
     }
 
-    return m_xStateSetHelper.get();
+    return m_xStateSetHelper;
 }
 
 lang::Locale SAL_CALL AccessibleBase::getLocale()
