@@ -256,7 +256,7 @@ SfxItemSet DrawViewWrapper::getPositionAndSizeItemSetFromMarkedObject() const
     SfxItemSet aFullSet(
         GetModel()->GetItemPool(),
         svl::Items<
-            SDRATTR_ECKENRADIUS, SDRATTR_ECKENRADIUS,
+            SDRATTR_CORNER_RADIUS, SDRATTR_CORNER_RADIUS,
             SID_ATTR_TRANSFORM_POS_X, SID_ATTR_TRANSFORM_ANGLE,
             SID_ATTR_TRANSFORM_PROTECT_POS, SID_ATTR_TRANSFORM_AUTOHEIGHT,
             SID_ATTR_METRIC, SID_ATTR_METRIC>{});
@@ -345,9 +345,7 @@ SdrObject* DrawViewWrapper::getSdrObject( const uno::Reference<
     uno::Reference< lang::XTypeProvider > xTypeProvider( xShape, uno::UNO_QUERY );
     if(xTypeProvider.is())
     {
-        SvxShape* pSvxShape = comphelper::getUnoTunnelImplementation<SvxShape>(xShape);
-        if(pSvxShape)
-            pRet = pSvxShape->GetSdrObject();
+        pRet = SdrObject::getSdrObjectFromXShape(xShape);
     }
     return pRet;
 }
