@@ -324,10 +324,10 @@ wrapper::ItemConverter* createItemConverter(
     return pItemConverter;
 }
 
-OUString lcl_getTitleCIDForCommand( const OString& rDispatchCommand, const uno::Reference< frame::XModel > & xChartModel )
+OUString lcl_getTitleCIDForCommand( std::string_view rDispatchCommand, const uno::Reference< frame::XModel > & xChartModel )
 {
     if( rDispatchCommand == "AllTitles")
-        return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_TITLE, "ALLELEMENTS" );
+        return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_TITLE, u"ALLELEMENTS" );
 
     TitleHelper::eTitleType nTitleType( TitleHelper::MAIN_TITLE );
     if( rDispatchCommand == "SubTitle" )
@@ -347,10 +347,10 @@ OUString lcl_getTitleCIDForCommand( const OString& rDispatchCommand, const uno::
     return ObjectIdentifier::createClassifiedIdentifierForObject( xTitle, xChartModel );
 }
 
-OUString lcl_getAxisCIDForCommand( const OString& rDispatchCommand, const uno::Reference< frame::XModel >& xChartModel )
+OUString lcl_getAxisCIDForCommand( std::string_view rDispatchCommand, const uno::Reference< frame::XModel >& xChartModel )
 {
     if( rDispatchCommand == "DiagramAxisAll")
-        return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_AXIS, "ALLELEMENTS" );
+        return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_AXIS, u"ALLELEMENTS" );
 
     sal_Int32   nDimensionIndex=0;
     bool        bMainAxis=true;
@@ -380,12 +380,12 @@ OUString lcl_getAxisCIDForCommand( const OString& rDispatchCommand, const uno::R
     return ObjectIdentifier::createClassifiedIdentifierForObject( xAxis, xChartModel );
 }
 
-OUString lcl_getGridCIDForCommand( const OString& rDispatchCommand, const uno::Reference< frame::XModel >& xChartModel )
+OUString lcl_getGridCIDForCommand( std::string_view rDispatchCommand, const uno::Reference< frame::XModel >& xChartModel )
 {
     uno::Reference< XDiagram > xDiagram( ChartModelHelper::findDiagram( xChartModel ) );
 
     if( rDispatchCommand == "DiagramGridAll")
-        return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_GRID, "ALLELEMENTS" );
+        return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_GRID, u"ALLELEMENTS" );
 
     sal_Int32   nDimensionIndex=0;
     bool        bMainGrid=true;
@@ -429,10 +429,10 @@ OUString lcl_getErrorCIDForCommand( const ObjectType eDispatchType, const Object
     if( eSelectedType == eDispatchType )
         return rSelectedCID;
 
-    return ObjectIdentifier::createClassifiedIdentifierWithParent( eDispatchType, OUString(), rSelectedCID );
+    return ObjectIdentifier::createClassifiedIdentifierWithParent( eDispatchType, u"", rSelectedCID );
 }
 
-OUString lcl_getObjectCIDForCommand( const OString& rDispatchCommand, const uno::Reference< XChartDocument > & xChartDocument, const OUString& rSelectedCID )
+OUString lcl_getObjectCIDForCommand( std::string_view rDispatchCommand, const uno::Reference< XChartDocument > & xChartDocument, const OUString& rSelectedCID )
 {
     ObjectType eObjectType = OBJECTTYPE_UNKNOWN;
 
@@ -520,7 +520,7 @@ OUString lcl_getObjectCIDForCommand( const OString& rDispatchCommand, const uno:
             return rSelectedCID;
         else
             return ObjectIdentifier::createClassifiedIdentifierWithParent(
-                OBJECTTYPE_DATA_LABELS, OUString(), rSelectedCID );
+                OBJECTTYPE_DATA_LABELS, u"", rSelectedCID );
     }
     //data labels
     else if( rDispatchCommand == "FormatDataLabel" )
@@ -536,7 +536,7 @@ OUString lcl_getObjectCIDForCommand( const OString& rDispatchCommand, const uno:
                 OUString aChildParticle( ObjectIdentifier::getStringForType( OBJECTTYPE_DATA_LABELS ) + "=" );
                 OUString aLabelsCID = ObjectIdentifier::createClassifiedIdentifierForParticles( aSeriesParticle, aChildParticle );
                 OUString aLabelCID_Stub = ObjectIdentifier::createClassifiedIdentifierWithParent(
-                    OBJECTTYPE_DATA_LABEL, OUString(), aLabelsCID );
+                    OBJECTTYPE_DATA_LABEL, u"", aLabelsCID );
 
                 return ObjectIdentifier::createPointCID( aLabelCID_Stub, nPointIndex );
             }
@@ -631,7 +631,7 @@ OUString lcl_getObjectCIDForCommand( const OString& rDispatchCommand, const uno:
         if( eSelectedType == OBJECTTYPE_DATA_STOCK_LOSS )
             return rSelectedCID;
         else
-            return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DATA_STOCK_LOSS, OUString());
+            return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DATA_STOCK_LOSS, u"");
     }
     // stock gain
     else if( rDispatchCommand == "FormatStockGain" )
@@ -639,18 +639,18 @@ OUString lcl_getObjectCIDForCommand( const OString& rDispatchCommand, const uno:
         if( eSelectedType == OBJECTTYPE_DATA_STOCK_GAIN )
             return rSelectedCID;
         else
-            return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DATA_STOCK_GAIN, OUString() );
+            return ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DATA_STOCK_GAIN, u"" );
     }
 
     return ObjectIdentifier::createClassifiedIdentifier(
         eObjectType,
-        OUString() ); // aParticleID
+        u"" ); // aParticleID
 }
 
 }
 // anonymous namespace
 
-void ChartController::executeDispatch_FormatObject(const OUString& rDispatchCommand)
+void ChartController::executeDispatch_FormatObject(std::u16string_view rDispatchCommand)
 {
     uno::Reference< XChartDocument > xChartDocument( getModel(), uno::UNO_QUERY );
     OString aCommand( OUStringToOString( rDispatchCommand, RTL_TEXTENCODING_ASCII_US ) );
@@ -682,7 +682,7 @@ OUString lcl_getFormatCIDforSelectedCID( const OUString& rSelectedCID )
 
     // treat diagram as wall
     if( eObjectType==OBJECTTYPE_DIAGRAM )
-        aFormatCID  = ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM_WALL, OUString() );
+        aFormatCID  = ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_DIAGRAM_WALL, u"" );
 
     return aFormatCID;
 }
