@@ -279,7 +279,7 @@ void SAL_CALL ChartController::setPosSize(
     //a correct work area is at least necessary for correct values in the position and  size dialog and for dragging area
     if(m_pDrawViewWrapper)
     {
-        tools::Rectangle aRect(Point(0,0), pChartWindow->GetOutputSize());
+        tools::Rectangle aRect(Point(0,0), pChartWindow->GetOutDev()->GetOutputSize());
         m_pDrawViewWrapper->SetWorkArea( aRect );
     }
     pChartWindow->Invalidate();
@@ -600,7 +600,7 @@ void ChartController::execute_MouseButtonDown( const MouseEvent& rMEvt )
              // #i12587# support for shapes in chart
              ( rMEvt.IsRight() && pDrawViewWrapper->PickAnything( rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt ) == SdrHitKind::MarkedObject ) )
         {
-            pDrawViewWrapper->MouseButtonDown(rMEvt, pChartWindow);
+            pDrawViewWrapper->MouseButtonDown(rMEvt, pChartWindow->GetOutDev());
             return;
         }
         else
@@ -725,7 +725,7 @@ void ChartController::execute_MouseMove( const MouseEvent& rMEvt )
 
     if( m_pDrawViewWrapper->IsTextEdit() )
     {
-        if( m_pDrawViewWrapper->MouseMove(rMEvt,pChartWindow) )
+        if( m_pDrawViewWrapper->MouseMove(rMEvt,pChartWindow->GetOutDev()) )
             return;
     }
 
@@ -771,7 +771,7 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
 
         if(pDrawViewWrapper->IsTextEdit())
         {
-            if( pDrawViewWrapper->MouseButtonUp(rMEvt,pChartWindow) )
+            if( pDrawViewWrapper->MouseButtonUp(rMEvt,pChartWindow->GetOutDev()) )
                 return;
         }
 
@@ -863,7 +863,8 @@ void ChartController::execute_MouseButtonUp( const MouseEvent& rMEvt )
                             m_xUndoManager );
 
                         bool bChanged = false;
-                        ChartModel* pModel = dynamic_cast<ChartModel*>(getModel().get());
+                        css::uno::Reference< css::frame::XModel > xModel = getModel();
+                        ChartModel* pModel = dynamic_cast<ChartModel*>(xModel.get());
                         assert(pModel);
                         if ( eObjectType == OBJECTTYPE_LEGEND )
                             bChanged = DiagramHelper::switchDiagramPositioningToExcludingPositioning( *pModel, false , true );
@@ -1288,19 +1289,19 @@ void ChartController::execute_Command( const CommandEvent& rCEvt )
         {
             if (SfxViewShell* pViewShell = SfxViewShell::Current())
             {
-                PopupMenu* pPopupMenu = static_cast<PopupMenu*>(comphelper::getUnoTunnelImplementation<VCLXMenu>(xPopupMenu)->GetMenu());
                 ControllerCommandDispatch* pCommandDispatch = dynamic_cast<ControllerCommandDispatch*>(m_aDispatchContainer.getChartDispatcher().get());
-                if(pCommandDispatch)
+                if (pCommandDispatch)
                 {
-                    for (sal_uInt16 nPos = 0; nPos < pPopupMenu->GetItemCount(); nPos++)
+                    for (int nPos = 0, nCount = xPopupMenu->getItemCount(); nPos < nCount; ++nPos)
                     {
-                        const sal_uInt16 nItemId = pPopupMenu->GetItemId(nPos);
-                        OUString aCommandURL = pPopupMenu->GetItemCommand(nItemId);
-                        if(!pCommandDispatch->commandAvailable(aCommandURL))
-                            pPopupMenu->EnableItem(nItemId, false);
+                        auto nItemId = xPopupMenu->getItemId(nPos);
+                        OUString aCommandURL = xPopupMenu->getCommand(nItemId);
+                        if (!pCommandDispatch->commandAvailable(aCommandURL))
+                            xPopupMenu->enableItem(nItemId, false);
                     }
                 }
 
+                Menu* pPopupMenu = comphelper::getUnoTunnelImplementation<VCLXMenu>(xPopupMenu)->GetMenu();
                 boost::property_tree::ptree aMenu = SfxDispatcher::fillPopupMenu(pPopupMenu);
                 boost::property_tree::ptree aRoot;
                 aRoot.add_child("menu", aMenu);
@@ -1924,7 +1925,7 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
         if( m_pDrawViewWrapper->IsTextEditHit( aMousePos ) )
         {
             pChartWindow->SetPointer( m_pDrawViewWrapper->GetPreferredPointer(
-                aMousePos, pChartWindow, nModifier, bLeftDown ) );
+                aMousePos, pChartWindow->GetOutDev(), nModifier, bLeftDown ) );
             return;
         }
     }
@@ -1940,7 +1941,7 @@ void ChartController::impl_SetMousePointer( const MouseEvent & rEvent )
     if( pHitSelectionHdl )
     {
         PointerStyle aPointer = m_pDrawViewWrapper->GetPreferredPointer(
-            aMousePos, pChartWindow, nModifier, bLeftDown );
+            aMousePos, pChartWindow->GetOutDev(), nModifier, bLeftDown );
         bool bForceArrowPointer = false;
 
         ObjectIdentifier aOID( m_aSelection.getSelectedOID() );
@@ -2090,7 +2091,8 @@ void ChartController::sendPopupRequest(OUString const & rCID, tools::Rectangle a
 
     OUString sPivotTableName = xPivotTableDataProvider->getPivotTableName();
 
-    PopupRequest* pPopupRequest = dynamic_cast<PopupRequest*>(pChartModel->getPopupRequest().get());
+    css::uno::Reference<css::awt::XRequestCallback> xPopupRequest = pChartModel->getPopupRequest();
+    PopupRequest* pPopupRequest = dynamic_cast<PopupRequest*>(xPopupRequest.get());
     if (!pPopupRequest)
         return;
 
