@@ -56,6 +56,7 @@
 #include <sal/log.hxx>
 #include <svl/zforlist.hxx>
 #include <tools/diagnose_ex.h>
+#include <libxml/xmlwriter.h>
 
 using ::com::sun::star::uno::Sequence;
 using ::com::sun::star::uno::Reference;
@@ -68,10 +69,10 @@ using namespace ::chart::CloneHelper;
 
 namespace
 {
-const OUString lcl_aGDIMetaFileMIMEType(
-    "application/x-openoffice-gdimetafile;windows_formatname=\"GDIMetaFile\"");
-const OUString lcl_aGDIMetaFileMIMETypeHighContrast(
-    "application/x-openoffice-highcontrast-gdimetafile;windows_formatname=\"GDIMetaFile\"");
+constexpr OUStringLiteral lcl_aGDIMetaFileMIMEType(
+    u"application/x-openoffice-gdimetafile;windows_formatname=\"GDIMetaFile\"");
+constexpr OUStringLiteral lcl_aGDIMetaFileMIMETypeHighContrast(
+    u"application/x-openoffice-highcontrast-gdimetafile;windows_formatname=\"GDIMetaFile\"");
 
 } // anonymous namespace
 
@@ -282,10 +283,10 @@ void ChartModel::impl_adjustAdditionalShapesPositionAndSize( const awt::Size& aV
                 double fWidth = static_cast< double >( aVisualAreaSize.Width ) / m_aVisualAreaSize.Width;
                 double fHeight = static_cast< double >( aVisualAreaSize.Height ) / m_aVisualAreaSize.Height;
 
-                aPos.X = static_cast< long >( aPos.X * fWidth );
-                aPos.Y = static_cast< long >( aPos.Y * fHeight );
-                aSize.Width = static_cast< long >( aSize.Width * fWidth );
-                aSize.Height = static_cast< long >( aSize.Height * fHeight );
+                aPos.X = static_cast< tools::Long >( aPos.X * fWidth );
+                aPos.Y = static_cast< tools::Long >( aPos.Y * fHeight );
+                aSize.Width = static_cast< tools::Long >( aSize.Width * fWidth );
+                aSize.Height = static_cast< tools::Long >( aSize.Height * fHeight );
 
                 xShape->setPosition( aPos );
                 xShape->setSize( aSize );
@@ -656,7 +657,7 @@ Reference< document::XUndoManager > SAL_CALL ChartModel::getUndoManager(  )
     ::osl::MutexGuard aGuard( m_aModelMutex );
     if ( !m_pUndoManager.is() )
         m_pUndoManager.set( new UndoManager( *this, m_aModelMutex ) );
-    return m_pUndoManager.get();
+    return m_pUndoManager;
 }
 
 // chart2::XChartDocument
@@ -738,6 +739,19 @@ void ChartModel::removeDataProviders()
         m_xDataProvider.clear();
 }
 
+void ChartModel::dumpAsXml(xmlTextWriterPtr pWriter) const
+{
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("ChartModel"));
+    (void)xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("ptr"), "%p", this);
+
+    if (mxChartView.is())
+    {
+        mxChartView->dumpAsXml(pWriter);
+    }
+
+    (void)xmlTextWriterEndElement(pWriter);
+}
+
 sal_Bool SAL_CALL ChartModel::hasInternalDataProvider()
 {
     return m_xDataProvider.is() && m_xInternalDataProvider.is();
@@ -1066,13 +1080,9 @@ uno::Any SAL_CALL ChartModel::getTransferData( const datatransfer::DataFlavor& a
 
 Sequence< datatransfer::DataFlavor > SAL_CALL ChartModel::getTransferDataFlavors()
 {
-    uno::Sequence< datatransfer::DataFlavor > aRet(1);
-
-    aRet[0] = datatransfer::DataFlavor( lcl_aGDIMetaFileMIMETypeHighContrast,
+    return { datatransfer::DataFlavor( lcl_aGDIMetaFileMIMETypeHighContrast,
         "GDIMetaFile",
-        cppu::UnoType<uno::Sequence< sal_Int8 >>::get() );
-
-    return aRet;
+        cppu::UnoType<uno::Sequence< sal_Int8 >>::get() ) };
 }
 
 sal_Bool SAL_CALL ChartModel::isDataFlavorSupported( const datatransfer::DataFlavor& aFlavor )
