@@ -277,10 +277,11 @@ void VDataSeries::doSortByXValues()
     sal_Int32 nPointIndex = 0;
     for( nPointIndex=0; nPointIndex < m_nPointCount; nPointIndex++ )
     {
-        std::vector< double > aSinglePoint;
-        aSinglePoint.push_back( (nPointIndex < m_aValues_X.Doubles.getLength()) ? m_aValues_X.Doubles[nPointIndex] : fNan );
-        aSinglePoint.push_back( (nPointIndex < m_aValues_Y.Doubles.getLength()) ? m_aValues_Y.Doubles[nPointIndex] : fNan );
-        aTmp.push_back( aSinglePoint );
+        aTmp.push_back(
+                        { ((nPointIndex < m_aValues_X.Doubles.getLength()) ? m_aValues_X.Doubles[nPointIndex] : fNan),
+                          ((nPointIndex < m_aValues_Y.Doubles.getLength()) ? m_aValues_Y.Doubles[nPointIndex] : fNan)
+                        }
+                      );
     }
 
     //do sort
@@ -353,7 +354,7 @@ void VDataSeries::setParticle( const OUString& rSeriesParticle )
     m_aPointCID_Stub = ObjectIdentifier::createSeriesSubObjectStub( OBJECTTYPE_DATA_POINT, m_aSeriesParticle );
 
     m_aLabelCID_Stub = ObjectIdentifier::createClassifiedIdentifierWithParent(
-                        OBJECTTYPE_DATA_LABEL, OUString(), getLabelsCID() );
+                        OBJECTTYPE_DATA_LABEL, u"", getLabelsCID() );
 }
 OUString VDataSeries::getErrorBarsCID(bool bYError) const
 {
@@ -570,21 +571,21 @@ sal_Int32 VDataSeries::getExplicitNumberFormat( sal_Int32 nPointIndex, bool bFor
         xPointProp->getPropertyValue(aPropName) >>= nNumberFormat;
     return nNumberFormat;
 }
-void VDataSeries::setRoleOfSequenceForDataLabelNumberFormatDetection( const OUString& rRole )
+void VDataSeries::setRoleOfSequenceForDataLabelNumberFormatDetection( std::u16string_view rRole )
 {
-    if (rRole == "values-y")
+    if (rRole == u"values-y")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_Y;
-    else if (rRole == "values-size")
+    else if (rRole == u"values-size")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_Bubble_Size;
-    else if (rRole == "values-min")
+    else if (rRole == u"values-min")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_Y_Min;
-    else if (rRole == "values-max")
+    else if (rRole == u"values-max")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_Y_Max;
-    else if (rRole == "values-first")
+    else if (rRole == u"values-first")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_Y_First;
-    else if (rRole == "values-last")
+    else if (rRole == u"values-last")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_Y_Last;
-    else if (rRole == "values-x")
+    else if (rRole == u"values-x")
         m_pValueSequenceForDataLabelNumberFormatDetection = &m_aValues_X;
 }
 sal_Int32 VDataSeries::detectNumberFormatKey( sal_Int32 index ) const
@@ -771,7 +772,7 @@ double VDataSeries::getXMeanValue() const
 {
     if( std::isnan( m_fXMeanValue ) )
     {
-        uno::Reference< XRegressionCurveCalculator > xCalculator( RegressionCurveHelper::createRegressionCurveCalculatorByServiceName( "com.sun.star.chart2.MeanValueRegressionCurve" ) );
+        uno::Reference< XRegressionCurveCalculator > xCalculator( RegressionCurveHelper::createRegressionCurveCalculatorByServiceName( u"com.sun.star.chart2.MeanValueRegressionCurve" ) );
         uno::Sequence< double > aXValuesDummy;
         xCalculator->recalculateRegression( aXValuesDummy, getAllX() );
         m_fXMeanValue = xCalculator->getCurveValue( 1.0 );
@@ -784,7 +785,7 @@ double VDataSeries::getYMeanValue() const
     if( std::isnan( m_fYMeanValue ) )
     {
         uno::Reference< XRegressionCurveCalculator > xCalculator(
-            RegressionCurveHelper::createRegressionCurveCalculatorByServiceName("com.sun.star.chart2.MeanValueRegressionCurve"));
+            RegressionCurveHelper::createRegressionCurveCalculatorByServiceName(u"com.sun.star.chart2.MeanValueRegressionCurve"));
         uno::Sequence< double > aXValuesDummy;
         xCalculator->recalculateRegression( aXValuesDummy, getAllY() );
         m_fYMeanValue = xCalculator->getCurveValue( 1.0 );
@@ -995,7 +996,7 @@ DataPointLabel* VDataSeries::getDataPointLabelIfLabel( sal_Int32 index ) const
 {
     DataPointLabel* pLabel = getDataPointLabel( index );
     if( !pLabel || (!pLabel->ShowNumber && !pLabel->ShowNumberInPercent
-        && !pLabel->ShowCategoryName && !pLabel->ShowCustomLabel ) )
+        && !pLabel->ShowCategoryName && !pLabel->ShowCustomLabel && !pLabel->ShowSeriesName ) )
         return nullptr;
     return pLabel;
 }
@@ -1125,13 +1126,13 @@ double VDataSeries::getValueByProperty( sal_Int32 nIndex, const OUString& rPropN
         if(rPropName.endsWith("Color"))
         {
             //optimized interpolation for color values
-            Color aColor(static_cast<sal_uInt32>(fValue));
-            Color aOldColor(static_cast<sal_uInt32>(fOldValue));
+            Color aColor(ColorTransparency, static_cast<sal_uInt32>(fValue));
+            Color aOldColor(ColorTransparency, static_cast<sal_uInt32>(fOldValue));
             sal_uInt8 r = aOldColor.GetRed() + (aColor.GetRed() - aOldColor.GetRed()) * mnPercent;
             sal_uInt8 g = aOldColor.GetGreen() + (aColor.GetGreen() - aOldColor.GetGreen()) * mnPercent;
             sal_uInt8 b = aOldColor.GetBlue() + (aColor.GetBlue() - aOldColor.GetBlue()) * mnPercent;
-            sal_uInt8 t = aOldColor.GetTransparency() + (aColor.GetTransparency() - aOldColor.GetTransparency()) * mnPercent;
-            Color aRet(t, r, g, b);
+            sal_uInt8 a = aOldColor.GetAlpha() + (aColor.GetAlpha() - aOldColor.GetAlpha()) * mnPercent;
+            Color aRet(ColorAlpha, a, r, g, b);
             return sal_uInt32(aRet);
         }
         return fOldValue + (fValue - fOldValue) * mnPercent;
