@@ -285,7 +285,7 @@ sal_Int32 OStorageHelper::GetXStorageFormat(
     {
         // the mediatype is not known
         OUString aMsg = __func__
-                      + OUStringLiteral(u":")
+                      + OUString::Concat(u":")
                       + OUString::number(__LINE__)
                       + ": unknown media type '"
                       + aMediaType
@@ -379,11 +379,11 @@ uno::Reference< embed::XStorage > OStorageHelper::GetStorageOfFormatFromStream(
 }
 
 
-uno::Sequence< beans::NamedValue > OStorageHelper::CreatePackageEncryptionData( const OUString& aPassword )
+uno::Sequence< beans::NamedValue > OStorageHelper::CreatePackageEncryptionData( std::u16string_view aPassword )
 {
     // TODO/LATER: Should not the method be part of DocPasswordHelper?
     uno::Sequence< beans::NamedValue > aEncryptionData;
-    if ( !aPassword.isEmpty() )
+    if ( !aPassword.empty() )
     {
         sal_Int32 nSha1Ind = 0;
         // generate SHA256 start key
@@ -430,9 +430,10 @@ uno::Sequence< beans::NamedValue > OStorageHelper::CreatePackageEncryptionData(
             if ( nError != rtl_Digest_E_None )
             {
                 aEncryptionData.realloc( nSha1Ind );
-                return aEncryptionData;
+                break;
             }
 
+            // coverity[overrun-buffer-arg : FALSE] - coverity has difficulty with css::uno::Sequence
             aEncryptionData[nSha1Ind+nInd].Value <<= uno::Sequence< sal_Int8 >( reinterpret_cast<sal_Int8*>(pBuffer), RTL_DIGEST_LENGTH_SHA1 );
         }
 
