@@ -145,7 +145,7 @@ bool ReservedId::VisitNamedDecl(NamedDecl const * decl) {
     }
     auto filename = getFilenameOfLocation(spelLoc);
     if (loplugin::hasPathnamePrefix(filename, SRCDIR "/bridges/source/cpp_uno/")
-        && filename.endswith("share.hxx"))
+        && (filename.endswith("abi.hxx") || filename.endswith("share.hxx")))
     {
         return true;
     }
@@ -197,8 +197,8 @@ bool ReservedId::VisitNamedDecl(NamedDecl const * decl) {
                 // connectivity/source/inc/ado/Awrapadox.hxx, MS SDK adoctint.h
             && s != "_ADOUser"
                 // connectivity/source/inc/ado/Awrapadox.hxx, MS SDK adoctint.h
-            && s != "_DllMainCRTStartup"
-                // odk/source/unowinreg/win/unowinreg.cxx (TODO: needed?)
+            && s != "_ClipboardContent" // vcl/unx/gtk3/gtkinst.cxx
+            && s != "_ClipboardContentClass" // vcl/unx/gtk3/gtkinst.cxx
             && s != "_FcPattern" // vcl/inc/unx/fc_fontoptions.hxx
             && s != "_GdkDisplay"
                 // vcl/unx/gtk/xid_fullscreen_on_all_monitors.c
@@ -209,6 +209,8 @@ bool ReservedId::VisitNamedDecl(NamedDecl const * decl) {
             && s != "_GstVideoOverlay"
                 // avmedia/source/gstreamer/gstplayer.hxx
             && s != "_Module" // extensions/source/activex/StdAfx2.h, CComModule
+            && s != "_SurfacePaintable" // vcl/unx/gtk3/gtkinst.cxx
+            && s != "_SurfacePaintableClass" // vcl/unx/gtk3/gtkinst.cxx
             && s != "_XRegion" // vcl/unx/generic/gdi/x11cairotextrender.cxx
             && s != "_XTrap") // vcl/unx/generic/gdi/xrender_peer.hxx
         {
