@@ -872,7 +872,7 @@ Reference< XResultSetMetaData > SAL_CALL OEvoabResultSet::getMetaData(  )
 
     // the meta data should have been created at construction time
     ENSURE_OR_THROW( m_xMetaData.is(), "internal error: no meta data" );
-    return m_xMetaData.get();
+    return m_xMetaData;
 }
 // XResultSetMetaDataSupplier Interface Ends
 
@@ -1119,12 +1119,12 @@ sal_Int32 SAL_CALL OEvoabResultSet::findColumn( const OUString& columnName )
     return *getArrayHelper();
 }
 
-void SAL_CALL OEvoabResultSet::acquire() throw()
+void SAL_CALL OEvoabResultSet::acquire() noexcept
 {
     OResultSet_BASE::acquire();
 }
 
-void SAL_CALL OEvoabResultSet::release() throw()
+void SAL_CALL OEvoabResultSet::release() noexcept
 {
     OResultSet_BASE::release();
 }
