@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4; fill-column: 100 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -49,7 +49,6 @@
 #include <unotools/tempfile.hxx>
 #include <unotools/localfilehelper.hxx>
 
-#include <osl/file.hxx>
 #include <rtl/strbuf.hxx>
 #include <sal/log.hxx>
 
@@ -209,7 +208,7 @@ void Connection::construct(const OUString& url, const Sequence< PropertyValue >&
                 if (!xFileAccess->exists(m_sFirebirdURL))
                     bIsNewDatabase = true;
 
-                osl::FileBase::getSystemPathFromFileURL(m_sFirebirdURL, m_sFirebirdURL);
+                m_sFirebirdURL = m_sFirebirdURL.copy(OUString("file://").getLength());
             }
         }
 
@@ -264,19 +263,18 @@ void Connection::construct(const OUString& url, const Sequence< PropertyValue >&
 
         ISC_STATUS_ARRAY status;            /* status vector */
         ISC_STATUS aErr;
-        const OString sFirebirdURL = OUStringToOString(m_sFirebirdURL, RTL_TEXTENCODING_UTF8);
         if (bIsNewDatabase)
         {
             aErr = isc_create_database(status,
-                                       sFirebirdURL.getLength(),
-                                       sFirebirdURL.getStr(),
+                                       m_sFirebirdURL.getLength(),
+                                       OUStringToOString(m_sFirebirdURL,RTL_TEXTENCODING_UTF8).getStr(),
                                        &m_aDBHandle,
                                        dpbBuffer.size(),
                                        dpbBuffer.c_str(),
                                        0);
             if (aErr)
             {
-                evaluateStatusVector(status, "isc_create_database", *this);
+                evaluateStatusVector(status, u"isc_create_database", *this);
             }
         }
         else
@@ -287,14 +285,14 @@ void Connection::construct(const OUString& url, const Sequence< PropertyValue >&
             }
 
             aErr = isc_attach_database(status,
-                                       sFirebirdURL.getLength(),
-                                       sFirebirdURL.getStr(),
+                                       m_sFirebirdURL.getLength(),
+                                       OUStringToOString(m_sFirebirdURL, RTL_TEXTENCODING_UTF8).getStr(),
                                        &m_aDBHandle,
                                        dpbBuffer.size(),
                                        dpbBuffer.c_str());
             if (aErr)
             {
-                evaluateStatusVector(status, "isc_attach_database", *this);
+                evaluateStatusVector(status, u"isc_attach_database", *this);
             }
         }
 
@@ -492,7 +490,7 @@ void Connection::setupTransaction()
                           aTPB);
 
     evaluateStatusVector(status_vector,
-                         "isc_start_transaction",
+                         u"isc_start_transaction",
                          *this);
 }
 
@@ -518,7 +516,7 @@ void SAL_CALL Connection::commit()
         disposeStatements();
         isc_commit_transaction(status_vector, &m_aTransactionHandle);
         evaluateStatusVector(status_vector,
-                             "isc_commit_transaction",
+                             u"isc_commit_transaction",
                              *this);
     }
 }
@@ -571,7 +569,7 @@ isc_svc_handle Connection::attachServiceManager()
                             aSPBBuffer))
     {
         evaluateStatusVector(aStatusVector,
-                             "isc_service_attach",
+                             u"isc_service_attach",
                              *this);
     }
 
@@ -585,7 +583,7 @@ void Connection::detachServiceManager(isc_svc_handle aServiceHandle)
                             &aServiceHandle))
     {
         evaluateStatusVector(aStatusVector,
-                             "isc_service_detach",
+                             u"isc_service_detach",
                              *this);
     }
 }
@@ -644,7 +642,7 @@ void Connection::runBackupService(const short nAction)
                             aRequest.getLength(),
                             aRequest.getStr()))
     {
-        evaluateStatusVector(aStatusVector, "isc_service_start", *this);
+        evaluateStatusVector(aStatusVector, u"isc_service_start", *this);
     }
 
     char aInfoSPB = isc_info_svc_line;
@@ -660,7 +658,7 @@ void Connection::runBackupService(const short nAction)
                       sizeof(aResults),
                       aResults))
     {
-        evaluateStatusVector(aStatusVector, "isc_service_query", *this);
+        evaluateStatusVector(aStatusVector, u"isc_service_query", *this);
     }
 
     detachServiceManager(aServiceHandle);
@@ -913,7 +911,7 @@ void Connection::disposing()
     {
         if (isc_detach_database(status, &m_aDBHandle))
         {
-            evaluateStatusVector(status, "isc_detach_database", *this);
+            evaluateStatusVector(status, u"isc_detach_database", *this);
         }
     }
     // TODO: write to storage again?
@@ -958,4 +956,4 @@ uno::Reference< XTablesSupplier > Connection::createCatalog()
 
 }
 
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab cinoptions=b1,g0,N-s cinkeys+=0=break: */
