@@ -118,12 +118,12 @@ OPreparedStatement::~OPreparedStatement()
 {
 }
 
-void SAL_CALL OPreparedStatement::acquire() throw()
+void SAL_CALL OPreparedStatement::acquire() noexcept
 {
     OStatementCommonBase::acquire();
 }
 
-void SAL_CALL OPreparedStatement::release() throw()
+void SAL_CALL OPreparedStatement::release() noexcept
 {
     OStatementCommonBase::release();
 }
@@ -277,7 +277,7 @@ Reference< XConnection > SAL_CALL OPreparedStatement::getConnection()
     MutexGuard aGuard( m_aMutex );
     checkDisposed(OStatementCommonBase_Base::rBHelper.bDisposed);
 
-    return Reference<XConnection>(m_pConnection.get());
+    return m_pConnection;
 }
 
 sal_Bool SAL_CALL OPreparedStatement::execute()
@@ -307,7 +307,7 @@ sal_Bool SAL_CALL OPreparedStatement::execute()
             // Do not throw error. Trying to close a closed cursor is not a
             // critical mistake.
             OUString sErrMsg  = StatusVectorToString(m_statusVector,
-                    "isc_dsql_free_statement: close cursor");
+                    u"isc_dsql_free_statement: close cursor");
             SAL_WARN("connectivity.firebird", sErrMsg);
         }
     }
@@ -320,7 +320,7 @@ sal_Bool SAL_CALL OPreparedStatement::execute()
     if (aErr)
     {
         SAL_WARN("connectivity.firebird", "isc_dsql_execute failed" );
-        evaluateStatusVector(m_statusVector, "isc_dsql_execute", *this);
+        evaluateStatusVector(m_statusVector, u"isc_dsql_execute", *this);
     }
 
     m_xResultSet = new OResultSet(m_pConnection.get(),
@@ -374,9 +374,9 @@ sal_Int64 toNumericWithoutDecimalPlace(const OUString& sSource)
         OUStringBuffer sBuffer(15);
         if(nDotIndex > 0)
         {
-            sBuffer.append(std::u16string_view(sNumber).substr(0, nDotIndex));
+            sBuffer.append(sNumber.subView(0, nDotIndex));
         }
-        sBuffer.append(std::u16string_view(sNumber).substr(nDotIndex + 1));
+        sBuffer.append(sNumber.subView(nDotIndex + 1));
         return sBuffer.makeStringAndClear().toInt64();
     }
 }
@@ -565,7 +565,7 @@ void OPreparedStatement::openBlobForWriting(isc_blob_handle& rBlobHandle, ISC_QU
     if (aErr)
     {
         evaluateStatusVector(m_statusVector,
-                             "setBlob failed on " + m_sSqlStatement,
+                             OUString("setBlob failed on " + m_sSqlStatement),
                              *this);
         assert(false);
     }
@@ -580,7 +580,7 @@ void OPreparedStatement::closeBlobAfterWriting(isc_blob_handle& rBlobHandle)
     if (aErr)
     {
         evaluateStatusVector(m_statusVector,
-                "isc_close_blob failed",
+                u"isc_close_blob failed",
                 *this);
         assert(false);
     }
@@ -632,7 +632,7 @@ void SAL_CALL OPreparedStatement::setClob(sal_Int32 nParameterIndex, const Refer
     if (aErr)
     {
         evaluateStatusVector(m_statusVector,
-                "isc_put_segment failed",
+                u"isc_put_segment failed",
                 *this);
         assert(false);
     }
@@ -670,7 +670,7 @@ void OPreparedStatement::setClob( sal_Int32 nParameterIndex, const OUString& rSt
     if (aErr)
     {
         evaluateStatusVector(m_statusVector,
-                             "isc_put_segment failed",
+                             u"isc_put_segment failed",
                              *this);
         assert(false);
     }
@@ -722,7 +722,7 @@ void SAL_CALL OPreparedStatement::setBlob(sal_Int32 nParameterIndex,
     if (aErr)
     {
         evaluateStatusVector(m_statusVector,
-                             "isc_put_segment failed",
+                             u"isc_put_segment failed",
                              *this);
         assert(false);
     }
@@ -890,7 +890,7 @@ void SAL_CALL OPreparedStatement::setBytes(sal_Int32 nParameterIndex,
         if (aErr)
         {
             evaluateStatusVector(m_statusVector,
-                                 "isc_put_segment failed",
+                                 u"isc_put_segment failed",
                                  *this);
             assert(false);
         }
@@ -1015,4 +1015,4 @@ void OPreparedStatement::setParameterNull(sal_Int32 nParameterIndex,
         *pVar->sqlind = 0;
 }
 
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab cinoptions=b1,g0,N-s cinkeys+=0=break: */
