@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <string_view>
+
 #include <sal/macros.h>
 #include <java/sql/DatabaseMetaData.hxx>
 #include <java/sql/Connection.hxx>
@@ -430,14 +434,14 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTablePrivileges(
             {
                 // here we know that the count of column doesn't match
                 std::map<sal_Int32,sal_Int32> aColumnMatching;
-                static const OUStringLiteral sPrivs[] = {
-                                            "TABLE_CAT",
-                                            "TABLE_SCHEM",
-                                            "TABLE_NAME",
-                                            "GRANTOR",
-                                            "GRANTEE",
-                                            "PRIVILEGE",
-                                            "IS_GRANTABLE"
+                static const std::u16string_view sPrivs[] = {
+                                            u"TABLE_CAT",
+                                            u"TABLE_SCHEM",
+                                            u"TABLE_NAME",
+                                            u"GRANTOR",
+                                            u"GRANTEE",
+                                            u"PRIVILEGE",
+                                            u"IS_GRANTABLE"
                                         };
 
                 OUString sColumnName;
@@ -456,7 +460,7 @@ Reference< XResultSet > SAL_CALL java_sql_DatabaseMetaData::getTablePrivileges(
 
                 }
                 // fill our own resultset
-                ODatabaseMetaDataResultSet* pNewPrivRes = new ODatabaseMetaDataResultSet( ODatabaseMetaDataResultSet::eTablePrivileges );
+                rtl::Reference<ODatabaseMetaDataResultSet> pNewPrivRes = new ODatabaseMetaDataResultSet( ODatabaseMetaDataResultSet::eTablePrivileges );
                 Reference< XResultSet > xTemp = xReturn;
                 xReturn = pNewPrivRes;
                 ODatabaseMetaDataResultSet::ORows aRows;
