@@ -143,7 +143,7 @@ void SAL_CALL java_sql_PreparedStatement::setString( sal_Int32 parameterIndex, c
 
 css::uno::Reference< css::sdbc::XConnection > SAL_CALL java_sql_PreparedStatement::getConnection(  )
 {
-    return Reference< XConnection >(m_pConnection.get());
+    return m_pConnection;
 }
 
 
@@ -640,12 +640,12 @@ css::uno::Reference< css::sdbc::XResultSetMetaData > SAL_CALL java_sql_PreparedS
     return out==nullptr ? nullptr : new java_sql_ResultSetMetaData( t.pEnv, out, *m_pConnection );
 }
 
-void SAL_CALL java_sql_PreparedStatement::acquire() throw()
+void SAL_CALL java_sql_PreparedStatement::acquire() noexcept
 {
     OStatement_BASE2::acquire();
 }
 
-void SAL_CALL java_sql_PreparedStatement::release() throw()
+void SAL_CALL java_sql_PreparedStatement::release() noexcept
 {
     OStatement_BASE2::release();
 }
