@@ -37,7 +37,7 @@ void CanvasTest::testComposite()
 #ifdef LINUX
     ScopedVclPtrInstance<WorkWindow> pWin( nullptr, WB_STDWORK );
 
-    uno::Reference<rendering::XCanvas> xCanvas = pWin->GetCanvas ();
+    uno::Reference<rendering::XCanvas> xCanvas = pWin->GetOutDev()->GetCanvas ();
     if( !xCanvas.is() )
         return; // can't get a canvas working at all - truly headless ?
 
@@ -56,7 +56,7 @@ void CanvasTest::testComposite()
         xBitmapCanvas->clear();
         CPPUNIT_ASSERT( aBitmapEx.Create( xBitmapCanvas, aSize ) );
         CPPUNIT_ASSERT( aBitmapEx.IsAlpha() );
-        CPPUNIT_ASSERT( aBitmapEx.GetAlpha() );
+        CPPUNIT_ASSERT( !aBitmapEx.GetAlpha().IsEmpty() );
     }
 
     {
