@@ -73,13 +73,26 @@ void FontFeaturesDialog::initialize()
         rFilteredFontFeatures.push_back(rFontFeature);
     }
 
-    fillGrid(rFilteredFontFeatures);
+    int nRowHeight = fillGrid(rFilteredFontFeatures);
+
+    m_xContentWindow->set_size_request(
+        -1, std::min(std::max(m_xContentWindow->get_preferred_size().Height(),
+                              m_xContentGrid->get_preferred_size().Height()),
+                     static_cast<tools::Long>(300L)));
+
+    if (nRowHeight)
+    {
+        // tdf#141333 use row height + the 6 px spacing of contentGrid
+        m_xContentWindow->vadjustment_set_step_increment(nRowHeight + 6);
+    }
 
     updateFontPreview();
 }
 
-void FontFeaturesDialog::fillGrid(std::vector<vcl::font::Feature> const& rFontFeatures)
+int FontFeaturesDialog::fillGrid(std::vector<vcl::font::Feature> const& rFontFeatures)
 {
+    int nRowHeight(0);
+
     vcl::font::FeatureParser aParser(m_sFontName);
     auto aExistingFeatures = aParser.getFeaturesMap();
 
@@ -113,7 +126,7 @@ void FontFeaturesDialog::fillGrid(std::vector<vcl::font::Feature> const& rFontFe
 
         Link<weld::ComboBox&, void> aComboBoxSelectHandler
             = LINK(this, FontFeaturesDialog, ComboBoxSelectedHdl);
-        Link<weld::ToggleButton&, void> aCheckBoxToggleHandler
+        Link<weld::Toggleable&, void> aCheckBoxToggleHandler
             = LINK(this, FontFeaturesDialog, CheckBoxToggledHdl);
 
         if (aDefinition.getType() == vcl::font::FeatureParameterType::ENUM)
@@ -135,8 +148,13 @@ void FontFeaturesDialog::fillGrid(std::vector<vcl::font::Feature> const& rFontFe
             aCurrentItem.m_xCheck->show();
         }
 
+        nRowHeight
+            = std::max<int>(nRowHeight, aCurrentItem.m_xContainer->get_preferred_size().Height());
+
         i++;
     }
+
+    return nRowHeight;
 }
 
 void FontFeaturesDialog::updateFontPreview()
@@ -154,7 +172,7 @@ void FontFeaturesDialog::updateFontPreview()
     m_aPreviewWindow.SetFont(rPreviewFont, rPreviewFontCJK, rPreviewFontCTL);
 }
 
-IMPL_LINK_NOARG(FontFeaturesDialog, CheckBoxToggledHdl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(FontFeaturesDialog, CheckBoxToggledHdl, weld::Toggleable&, void)
 {
     updateFontPreview();
 }
@@ -177,7 +195,7 @@ OUString FontFeaturesDialog::createFontNameWithFeatures()
             if (sal_uInt32(rItem.m_xCheck->get_active()) != rItem.m_nDefault)
             {
                 if (!bFirst)
-                    sNameSuffix.append(OUString(vcl::font::FeatureSeparator));
+                    sNameSuffix.append(vcl::font::FeatureSeparator);
                 else
                     bFirst = false;
 
@@ -192,7 +210,7 @@ OUString FontFeaturesDialog::createFontNameWithFeatures()
             if (nSelection != int(rItem.m_nDefault))
             {
                 if (!bFirst)
-                    sNameSuffix.append(OUString(vcl::font::FeatureSeparator));
+                    sNameSuffix.append(vcl::font::FeatureSeparator);
                 else
                     bFirst = false;
 
