@@ -85,7 +85,6 @@ void SvxHlinkCtrl::StateChanged( sal_uInt16 nSID, SfxItemState eState,
 SvxHpLinkDlg::SvxHpLinkDlg(SfxBindings* pBindings, SfxChildWindow* pChild, weld::Window* pParent)
     : SfxModelessDialogController(pBindings, pChild, pParent, "cui/ui/hyperlinkdialog.ui", "HyperlinkDialog")
     , pSet            ( nullptr )
-    , pExampleSet     ( nullptr )
     , maCtrl          ( SID_HYPERLINK_GETLINK, *pBindings, this )
     , mbIsHTMLDoc     ( false )
     , m_xIconCtrl(m_xBuilder->weld_notebook("tabcontrol"))
@@ -101,7 +100,7 @@ SvxHpLinkDlg::SvxHpLinkDlg(SfxBindings* pBindings, SfxChildWindow* pChild, weld:
     // ItemSet
     if ( pSet )
     {
-        pExampleSet = new SfxItemSet( *pSet );
+        pExampleSet.reset(new SfxItemSet( *pSet ));
         pOutSet.reset(new SfxItemSet( *pSet->GetPool(), pSet->GetRanges() ));
     }
 
@@ -150,6 +149,8 @@ SvxHpLinkDlg::SvxHpLinkDlg(SfxBindings* pBindings, SfxChildWindow* pChild, weld:
 
 SvxHpLinkDlg::~SvxHpLinkDlg()
 {
+    mbGrabFocus = false; // don't do any grab if tear-down moves focus around during destruction
+
     // delete config item, so the base class (SfxModelessDialogController) can not load it on the next start
     SvtViewOptions aViewOpt( EViewType::TabDialog, OUString::number(SID_HYPERLINK_DIALOG) );
     aViewOpt.Delete();
