@@ -18,7 +18,6 @@
  */
 
 #include <config_features.h>
-#include <config_vclplug.h>
 #include <svl/zforlist.hxx>
 #include <svl/currencytable.hxx>
 #include <svtools/langhelp.hxx>
@@ -78,9 +77,6 @@
 #include <vcl/settings.hxx>
 #include <vcl/window.hxx>
 #include <vcl/IconThemeInfo.hxx>
-#if HAVE_FEATURE_OPENGL
-#include <vcl/opengl/OpenGLWrapper.hxx>
-#endif
 #include <vcl/skia/SkiaHelper.hxx>
 #include "optgdlg.hxx"
 #include <svtools/apearcfg.hxx>
@@ -89,10 +85,7 @@
 #include <svtools/imgdef.hxx>
 
 #if defined(_WIN32)
-#include <o3tl/char16_t2wchar_t.hxx>
-#include <prewin.h>
-#include <shobjidl.h>
-#include <postwin.h>
+#include <vcl/fileregistration.hxx>
 #endif
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
@@ -161,7 +154,6 @@ OfaMiscTabPage::OfaMiscTabPage(weld::Container* pPage, weld::DialogController* p
     , m_xPopUpNoHelpCB(m_xBuilder->weld_check_button("popupnohelp"))
     , m_xShowTipOfTheDay(m_xBuilder->weld_check_button("cbShowTipOfTheDay"))
     , m_xFileDlgFrame(m_xBuilder->weld_widget("filedlgframe"))
-    , m_xPrintDlgFrame(m_xBuilder->weld_widget("printdlgframe"))
     , m_xFileDlgROImage(m_xBuilder->weld_widget("lockimage"))
     , m_xFileDlgCB(m_xBuilder->weld_check_button("filedlg"))
     , m_xPrintDlgCB(m_xBuilder->weld_check_button("printdlg"))
@@ -180,6 +172,7 @@ OfaMiscTabPage::OfaMiscTabPage(weld::Container* pPage, weld::DialogController* p
 #if defined(_WIN32)
     , m_xFileAssocFrame(m_xBuilder->weld_widget("fileassoc"))
     , m_xFileAssocBtn(m_xBuilder->weld_button("assocfiles"))
+    , m_xPerformFileExtCheck(m_xBuilder->weld_check_button("cbPerformFileExtCheck"))
 #endif
 {
     if (!lcl_HasSystemFilePicker())
@@ -190,15 +183,6 @@ OfaMiscTabPage::OfaMiscTabPage(weld::Container* pPage, weld::DialogController* p
         m_xFileDlgCB->set_sensitive(false);
     }
 
-#if !ENABLE_GTK3
-    m_xPrintDlgFrame->hide();
-#else
-    if (!officecfg::Office::Common::Misc::ExperimentalMode::get())
-    {
-        m_xPrintDlgFrame->hide();
-    }
-#endif
-
     m_xQuickLaunchCB->show();
 
     //Only available in Win or if building the gtk systray
@@ -253,15 +237,6 @@ bool OfaMiscTabPage::FillItemSet( SfxItemSet* rSet )
         bModified = true;
     }
 
-    if ( m_xPrintDlgCB->get_state_changed_from_saved() )
-    {
-        std::shared_ptr< comphelper::ConfigurationChanges > xChanges(
-                comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Misc::UseSystemPrintDialog::set( !m_xPrintDlgCB->get_active(), xChanges );
-        xChanges->commit();
-        bModified = true;
-    }
-
     if (m_xDocStatusCB->get_state_changed_from_saved())
     {
         officecfg::Office::Common::Print::PrintingModifiesDocument::set(m_xDocStatusCB->get_active(), batch);
@@ -290,6 +265,15 @@ bool OfaMiscTabPage::FillItemSet( SfxItemSet* rSet )
     }
 #endif
 
+#if defined(_WIN32)
+    if (m_xPerformFileExtCheck->get_state_changed_from_saved())
+    {
+        officecfg::Office::Common::Misc::PerformFileExtCheck::set(
+            m_xPerformFileExtCheck->get_active(), batch);
+        bModified = true;
+    }
+#endif
+
     batch->commit();
 
     if( m_xQuickLaunchCB->get_state_changed_from_saved())
@@ -312,8 +296,6 @@ void OfaMiscTabPage::Reset( const SfxItemSet* rSet )
     m_xShowTipOfTheDay->save_state();
     m_xFileDlgCB->set_active( !officecfg::Office::Common::Misc::UseSystemFileDialog::get() );
     m_xFileDlgCB->save_state();
-    m_xPrintDlgCB->set_active( !officecfg::Office::Common::Misc::UseSystemPrintDialog::get() );
-    m_xPrintDlgCB->save_state();
 
     m_xDocStatusCB->set_active(officecfg::Office::Common::Print::PrintingModifiesDocument::get());
     m_xDocStatusCB->save_state();
@@ -349,6 +331,12 @@ void OfaMiscTabPage::Reset( const SfxItemSet* rSet )
     }
 
     m_xQuickLaunchCB->save_state();
+
+#if defined(_WIN32)
+    m_xPerformFileExtCheck->set_active(
+        officecfg::Office::Common::Misc::PerformFileExtCheck::get());
+    m_xPerformFileExtCheck->save_state();
+#endif
 }
 
 IMPL_LINK_NOARG( OfaMiscTabPage, TwoFigureHdl, weld::SpinButton&, void )
@@ -369,24 +357,7 @@ IMPL_LINK_NOARG( OfaMiscTabPage, TwoFigureHdl, weld::SpinButton&, void )
 #if defined(_WIN32)
 IMPL_STATIC_LINK_NOARG(OfaMiscTabPage, FileAssocClick, weld::Button&, void)
 {
-    const bool bUninit = SUCCEEDED(CoInitializeEx(nullptr, COINIT_APARTMENTTHREADED));
-    IApplicationAssociationRegistrationUI* pIf = nullptr;
-    HRESULT res = CoCreateInstance(CLSID_ApplicationAssociationRegistrationUI, nullptr,
-                                   CLSCTX_INPROC_SERVER, IID_IApplicationAssociationRegistrationUI,
-                                   reinterpret_cast<LPVOID*>(&pIf));
-
-    if (SUCCEEDED(res) && pIf)
-    {
-        // LaunchAdvancedAssociationUI only works for applications registered under
-        // Software\RegisteredApplications. See scp2/source/ooo/registryitem_ooo.scp
-        const OUString expanded = Translate::ExpandVariables("%PRODUCTNAME %PRODUCTVERSION");
-        // This will only show "To change your default apps, go to Settings > Apps > Default apps"
-        // on Win10; this is expected. At least this will self-document it to users.
-        pIf->LaunchAdvancedAssociationUI(o3tl::toW(expanded.getStr()));
-        pIf->Release();
-    }
-    if (bUninit)
-        CoUninitialize();
+    vcl::fileregistration::LaunchRegistrationUI();
 }
 #endif
 
@@ -467,13 +438,6 @@ CanvasSettings::CanvasSettings() :
 
 bool CanvasSettings::IsHardwareAccelerationAvailable() const
 {
-#if HAVE_FEATURE_OPENGL
-    if (OpenGLWrapper::isVCLOpenGLEnabled() && Application::GetToolkitName() != "gtk3")
-    {
-        mbHWAccelAvailable = false;
-        return false;
-    }
-#endif
     if( !mbHWAccelChecked )
     {
         mbHWAccelChecked = true;
@@ -593,7 +557,7 @@ OfaViewTabPage::OfaViewTabPage(weld::Container* pPage, weld::DialogController* p
     , m_xMouseMiddleLB(m_xBuilder->weld_combo_box("mousemiddle"))
     , m_xMoreIcons(m_xBuilder->weld_button("btnMoreIcons"))
 {
-    if (Application::GetToolkitName() == "gtk3")
+    if (Application::GetToolkitName().startsWith("gtk"))
         m_xMenuIconBox->hide();
 
     m_xFontAntiAliasing->connect_toggled( LINK( this, OfaViewTabPage, OnAntialiasingToggled ) );
@@ -640,7 +604,7 @@ IMPL_STATIC_LINK_NOARG(OfaViewTabPage, OnMoreIconsClick, weld::Button&, void)
     comphelper::dispatchCommand(".uno:AdditionsDialog", aArgs);
 }
 
-IMPL_LINK_NOARG( OfaViewTabPage, OnAntialiasingToggled, weld::ToggleButton&, void )
+IMPL_LINK_NOARG( OfaViewTabPage, OnAntialiasingToggled, weld::Toggleable&, void )
 {
     bool bAAEnabled = m_xFontAntiAliasing->get_active();
 
@@ -648,7 +612,7 @@ IMPL_LINK_NOARG( OfaViewTabPage, OnAntialiasingToggled, weld::ToggleButton&, voi
     m_xAAPointLimit->set_sensitive(bAAEnabled);
 }
 
-IMPL_LINK_NOARG(OfaViewTabPage, OnUseSkiaToggled, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(OfaViewTabPage, OnUseSkiaToggled, weld::Toggleable&, void)
 {
     UpdateSkiaStatus();
 }
@@ -1029,11 +993,11 @@ struct LanguageConfig_Impl
 static bool bLanguageCurrentDoc_Impl = false;
 
 // some things we'll need...
-const char sAccessSrvc[] = "com.sun.star.configuration.ConfigurationAccess";
-const char sAccessUpdSrvc[] = "com.sun.star.configuration.ConfigurationUpdateAccess";
-const char sInstalledLocalesPath[] = "org.openoffice.Setup/Office/InstalledLocales";
-const char sUserLocalePath[] = "org.openoffice.Office.Linguistic/General";
-const char sUserLocaleKey[] = "UILocale";
+constexpr OUStringLiteral sAccessSrvc = u"com.sun.star.configuration.ConfigurationAccess";
+constexpr OUStringLiteral sAccessUpdSrvc = u"com.sun.star.configuration.ConfigurationUpdateAccess";
+constexpr OUStringLiteral sInstalledLocalesPath = u"org.openoffice.Setup/Office/InstalledLocales";
+constexpr OUStringLiteral sUserLocalePath = u"org.openoffice.Office.Linguistic/General";
+constexpr OUStringLiteral sUserLocaleKey = u"UILocale";
 static Sequence< OUString > seqInstalledLanguages;
 
 static OUString lcl_getDatePatternsConfigString( const LocaleDataWrapper& rLocaleWrapper )
@@ -1215,7 +1179,7 @@ OfaLanguagesTabPage::OfaLanguagesTabPage(weld::Container* pPage, weld::DialogCon
     m_xLocaleSettingLB->connect_changed( LINK( this, OfaLanguagesTabPage, LocaleSettingHdl ) );
     m_xDatePatternsED->connect_changed( LINK( this, OfaLanguagesTabPage, DatePatternsHdl ) );
 
-    Link<weld::ToggleButton&,void> aLink( LINK( this, OfaLanguagesTabPage, SupportHdl ) );
+    Link<weld::Toggleable&,void> aLink( LINK( this, OfaLanguagesTabPage, SupportHdl ) );
     m_xAsianSupportCB->connect_toggled( aLink );
     m_xCTLSupportCB->connect_toggled( aLink );
 
@@ -1652,7 +1616,7 @@ void OfaLanguagesTabPage::Reset( const SfxItemSet* rSet )
     }
 }
 
-IMPL_LINK(OfaLanguagesTabPage, SupportHdl, weld::ToggleButton&, rBox, void)
+IMPL_LINK(OfaLanguagesTabPage, SupportHdl, weld::Toggleable&, rBox, void)
 {
     bool bCheck = rBox.get_active();
     if ( m_xAsianSupportCB.get() == &rBox )
@@ -1819,13 +1783,7 @@ IMPL_LINK( OfaLanguagesTabPage, DatePatternsHdl, weld::Entry&, rEd, void )
         }
     }
     if (bModified)
-    {
-        // gtk3 keeps the cursor position on equal length set_text() but at
-        // least the 'gen' backend does not and resets to 0.
-        const int nCursorPos = rEd.get_position();
-        rEd.set_text(aBuf.makeStringAndClear());
-        rEd.set_position(nCursorPos);
-    }
+        rEd.replace_selection(aBuf.makeStringAndClear());
     if (bValid)
         rEd.set_message_type(weld::EntryMessageType::Normal);
     else
