@@ -85,7 +85,6 @@ SvxLineTabPage::SvxLineTabPage(weld::Container* pPage, weld::DialogController* p
     , m_pSymbolList(nullptr)
     , m_bNewSize(false)
     , m_nSymbolType(SVX_SYMBOLTYPE_UNKNOWN) // unknown respectively unchanged
-    , m_pSymbolAttr(nullptr)
     , m_bLastWidthModified(false)
     , m_aSymbolLastSize(Size(0,0))
     , m_bSymbols(false)
@@ -102,7 +101,8 @@ SvxLineTabPage::SvxLineTabPage(weld::Container* pPage, weld::DialogController* p
     , m_pPosLineEndLb(nullptr)
     , m_xBoxColor(m_xBuilder->weld_widget("boxCOLOR"))
     , m_xLbLineStyle(new SvxLineLB(m_xBuilder->weld_combo_box("LB_LINE_STYLE")))
-    , m_xLbColor(new ColorListBox(m_xBuilder->weld_menu_button("LB_COLOR"), pController->getDialog()))
+    , m_xLbColor(new ColorListBox(m_xBuilder->weld_menu_button("LB_COLOR"),
+                [this]{ return GetDialogController()->getDialog(); }))
     , m_xBoxWidth(m_xBuilder->weld_widget("boxWIDTH"))
     , m_xMtrLineWidth(m_xBuilder->weld_metric_spin_button("MTR_FLD_LINE_WIDTH", FieldUnit::CM))
     , m_xBoxTransparency(m_xBuilder->weld_widget("boxTRANSPARENCY"))
@@ -173,8 +173,8 @@ SvxLineTabPage::SvxLineTabPage(weld::Container* pPage, weld::DialogController* p
     m_xLbEndStyle->connect_changed(LINK(this, SvxLineTabPage, ChangeEndListBoxHdl_Impl));
     m_xMtrStartWidth->connect_value_changed(LINK(this, SvxLineTabPage, ChangeStartModifyHdl_Impl));
     m_xMtrEndWidth->connect_value_changed(LINK( this, SvxLineTabPage, ChangeEndModifyHdl_Impl));
-    m_xTsbCenterStart->connect_clicked(LINK(this, SvxLineTabPage, ChangeStartClickHdl_Impl));
-    m_xTsbCenterEnd->connect_clicked(LINK(this, SvxLineTabPage, ChangeEndClickHdl_Impl));
+    m_xTsbCenterStart->connect_toggled(LINK(this, SvxLineTabPage, ChangeStartClickHdl_Impl));
+    m_xTsbCenterEnd->connect_toggled(LINK(this, SvxLineTabPage, ChangeEndClickHdl_Impl));
 
     Link<weld::ComboBox&,void> aEdgeStyle = LINK(this, SvxLineTabPage, ChangeEdgeStyleHdl_Impl);
     m_xLBEdgeStyle->connect_changed(aEdgeStyle);
@@ -820,13 +820,13 @@ void SvxLineTabPage::Reset( const SfxItemSet* rAttrs )
         std::unique_ptr<SdrModel> pModel(
             new SdrModel(nullptr, nullptr, true));
         pModel->GetItemPool().FreezeIdRanges();
-        SdrPage* pPage = new SdrPage( *pModel, false );
+        rtl::Reference<SdrPage> pPage = new SdrPage( *pModel, false );
         pPage->SetSize(Size(1000,1000));
-        pModel->InsertPage( pPage, 0 );
+        pModel->InsertPage( pPage.get(), 0 );
         {
-        std::unique_ptr<SdrView> pView(new SdrView( *pModel, pVDev ));
-        pView->hideMarkHandles();
-        pView->ShowSdrPage(pPage);
+        SdrView aView( *pModel, pVDev );
+        aView.hideMarkHandles();
+        aView.ShowSdrPage(pPage.get());
         size_t nSymTmp = static_cast<size_t>(nSymType);
         if(m_pSymbolList)
         {
@@ -839,9 +839,9 @@ void SvxLineTabPage::Reset( const SfxItemSet* rAttrs )
                     // directly clone to target SdrModel
                     pObj = pObj->CloneSdrObject(*pModel);
 
-                    if(m_pSymbolAttr)
+                    if(m_xSymbolAttr)
                     {
-                        pObj->SetMergedItemSet(*m_pSymbolAttr);
+                        pObj->SetMergedItemSet(*m_xSymbolAttr);
                     }
                     else
                     {
@@ -861,8 +861,8 @@ void SvxLineTabPage::Reset( const SfxItemSet* rAttrs )
                     pInvisibleSquare->SetMergedItem(XFillTransparenceItem(100));
                     pInvisibleSquare->SetMergedItem(XLineTransparenceItem(100));
 
-                    pView->MarkAll();
-                    GDIMetaFile aMeta(pView->GetMarkedObjMetaFile());
+                    aView.MarkAll();
+                    GDIMetaFile aMeta(aView.GetMarkedObjMetaFile());
 
                     m_aSymbolGraphic=Graphic(aMeta);
                     m_aSymbolSize=pObj->GetSnapRect().GetSize();
@@ -872,7 +872,7 @@ void SvxLineTabPage::Reset( const SfxItemSet* rAttrs )
                     bEnable=true;
                     bIgnoreGraphic=true;
 
-                    pView->UnmarkAll();
+                    aView.UnmarkAll();
                     pInvisibleSquare=pPage->RemoveObject(1);
                     SdrObject::Free( pInvisibleSquare);
                     pObj=pPage->RemoveObject(0);
@@ -1254,7 +1254,7 @@ void SvxLineTabPage::ChangePreviewHdl_Impl(const weld::MetricSpinButton* pCntrl)
     m_xBoxEnd->set_sensitive(bHasLineEnd && bHasLineStyle);
 }
 
-IMPL_LINK_NOARG(SvxLineTabPage, ChangeStartClickHdl_Impl, weld::Button&, void)
+IMPL_LINK_NOARG(SvxLineTabPage, ChangeStartClickHdl_Impl, weld::Toggleable&, void)
 {
     if (m_xCbxSynchronize->get_active())
         m_xTsbCenterEnd->set_state(m_xTsbCenterStart->get_state());
@@ -1311,6 +1311,18 @@ void SvxLineTabPage::ClickInvisibleHdl_Impl()
     }
     else
     {
+        // set cap style associated to the line style
+        sal_Int32 nPos = m_xLbLineStyle->get_active();
+        if( nPos > 1 && m_pDashList->Count() > static_cast<tools::Long>( nPos - 2 ) )
+        {
+            css::drawing::DashStyle eStyle =
+                m_pDashList->GetDash( nPos - 2 )->GetDash().GetDashStyle();
+            if ( eStyle == drawing::DashStyle_RECT || eStyle == drawing::DashStyle_RECTRELATIVE)
+                m_xLBCapStyle->set_active(0);
+            else
+                m_xLBCapStyle->set_active(1);
+        }
+
         m_xBoxColor->set_sensitive(true);
         m_xBoxWidth->set_sensitive(true);
 
@@ -1323,7 +1335,7 @@ void SvxLineTabPage::ClickInvisibleHdl_Impl()
     ChangePreviewHdl_Impl( nullptr );
 }
 
-IMPL_LINK_NOARG(SvxLineTabPage, ChangeEndClickHdl_Impl, weld::Button&, void)
+IMPL_LINK_NOARG(SvxLineTabPage, ChangeEndClickHdl_Impl, weld::Toggleable&, void)
 {
     if (m_xCbxSynchronize->get_active())
         m_xTsbCenterStart->set_state(m_xTsbCenterEnd->get_state());
@@ -1368,7 +1380,7 @@ void SvxLineTabPage::FillUserData()
 // #58425# Symbols on a list (e.g. StarChart)
 // Handler for the symbol selection's popup menu (NumMenueButton)
 // The following link originates from SvxNumOptionsTabPage
-IMPL_LINK_NOARG(SvxLineTabPage, MenuCreateHdl_Impl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(SvxLineTabPage, MenuCreateHdl_Impl, weld::Toggleable&, void)
 {
     ScopedVclPtrInstance< VirtualDevice > pVD;
 
@@ -1437,14 +1449,14 @@ IMPL_LINK_NOARG(SvxLineTabPage, MenuCreateHdl_Impl, weld::ToggleButton&, void)
         new SdrModel(nullptr, nullptr, true));
     pModel->GetItemPool().FreezeIdRanges();
     // Page
-    SdrPage* pPage = new SdrPage( *pModel, false );
+    rtl::Reference<SdrPage> pPage = new SdrPage( *pModel, false );
     pPage->SetSize(Size(1000,1000));
-    pModel->InsertPage( pPage, 0 );
+    pModel->InsertPage( pPage.get(), 0 );
     {
         // 3D View
-        std::unique_ptr<SdrView> pView(new SdrView( *pModel, pVDev ));
-        pView->hideMarkHandles();
-        pView->ShowSdrPage(pPage);
+        SdrView aView( *pModel, pVDev );
+        aView.hideMarkHandles();
+        aView.ShowSdrPage(pPage.get());
 
         // Generate invisible square to give all symbols a
         // bitmap size, which is independent from specific glyph
@@ -1467,18 +1479,18 @@ IMPL_LINK_NOARG(SvxLineTabPage, MenuCreateHdl_Impl, weld::ToggleButton&, void)
 
             m_aGrfNames.emplace_back("");
             pPage->NbcInsertObject(pObj);
-            if(m_pSymbolAttr)
+            if(m_xSymbolAttr)
             {
-                pObj->SetMergedItemSet(*m_pSymbolAttr);
+                pObj->SetMergedItemSet(*m_xSymbolAttr);
             }
             else
             {
                 pObj->SetMergedItemSet(m_rOutAttrs);
             }
-            pView->MarkAll();
-            BitmapEx aBitmapEx(pView->GetMarkedObjBitmapEx());
-            GDIMetaFile aMeta(pView->GetMarkedObjMetaFile());
-            pView->UnmarkAll();
+            aView.MarkAll();
+            BitmapEx aBitmapEx(aView.GetMarkedObjBitmapEx());
+            GDIMetaFile aMeta(aView.GetMarkedObjMetaFile());
+            aView.UnmarkAll();
             pObj=pPage->RemoveObject(1);
             SdrObject::Free(pObj);
 
@@ -1643,7 +1655,7 @@ IMPL_LINK( SvxLineTabPage, SizeHdl_Impl, weld::MetricSpinButton&, rField, void)
     m_aSymbolLastSize=m_aSymbolSize;
 }
 
-IMPL_LINK(SvxLineTabPage, RatioHdl_Impl, weld::ToggleButton&, rBox, void)
+IMPL_LINK(SvxLineTabPage, RatioHdl_Impl, weld::Toggleable&, rBox, void)
 {
     if (rBox.get_active())
     {
@@ -1679,7 +1691,7 @@ void SvxLineTabPage::PageCreated(const SfxAllItemSet& aSet)
         ShowSymbolControls(true);
         m_pSymbolList = static_cast<SdrObjList*>(pSdrObjListItem->GetValue());
         if (pSymbolAttrItem)
-            m_pSymbolAttr = new SfxItemSet(pSymbolAttrItem->GetItemSet());
+            m_xSymbolAttr.reset(new SfxItemSet(pSymbolAttrItem->GetItemSet()));
         if(pGraphicItem)
             m_aAutoSymbolGraphic = pGraphicItem->GetGraphic();
     }
