@@ -272,7 +272,7 @@ namespace dbaui
                     hWnd = reinterpret_cast<HWND>(tmp);
                 }
 
-                sNewDataSource = getAdoDatalink(reinterpret_cast<LONG_PTR>(hWnd),sOldDataSource);
+                sNewDataSource = getAdoDatalink(reinterpret_cast<sal_IntPtr>(hWnd),sOldDataSource);
                 if ( !sNewDataSource.isEmpty() )
                 {
                     setURLNoPrefix(sNewDataSource);
@@ -364,7 +364,7 @@ namespace dbaui
         return true;
     }
 
-    void OConnectionHelper::impl_setURL( const OUString& _rURL, bool _bPrefix )
+    void OConnectionHelper::impl_setURL( std::u16string_view _rURL, bool _bPrefix )
     {
         OUString sURL( comphelper::string::stripEnd(_rURL, '*') );
         OSL_ENSURE( m_pCollection, "OConnectionHelper::impl_setURL: have no interpreter for the URLs!" );
@@ -436,7 +436,7 @@ namespace dbaui
         return sURL;
     }
 
-    void OConnectionHelper::setURL( const OUString& _rURL )
+    void OConnectionHelper::setURL( std::u16string_view _rURL )
     {
         impl_setURL( _rURL, true );
     }
@@ -446,7 +446,7 @@ namespace dbaui
         return impl_getURL();
     }
 
-    void OConnectionHelper::setURLNoPrefix( const OUString& _rURL )
+    void OConnectionHelper::setURLNoPrefix( std::u16string_view _rURL )
     {
         impl_setURL( _rURL, false );
     }
@@ -533,7 +533,7 @@ namespace dbaui
         IS_PATH_EXIST eExists = PATH_NOT_EXIST;
         Reference< css::task::XInteractionHandler > xInteractionHandler =
             task::InteractionHandler::createWithParent(m_xORB, nullptr);
-        OFilePickerInteractionHandler* pHandler = new OFilePickerInteractionHandler(xInteractionHandler);
+        rtl::Reference<OFilePickerInteractionHandler> pHandler = new OFilePickerInteractionHandler(xInteractionHandler);
         xInteractionHandler = pHandler;
 
         Reference< XCommandEnvironment > xCmdEnv = new ::ucbhelper::CommandEnvironment( xInteractionHandler, Reference< XProgressHandler >() );
