@@ -230,7 +230,7 @@ OUString ObjectCopySource::getSelectStatement() const
                 aSQL.append( ", " );
         }
 
-        aSQL.append( "FROM " ).append( ::dbtools::composeTableNameForSelect( m_xConnection, m_xObject ) );
+        aSQL.append( "FROM " + ::dbtools::composeTableNameForSelect( m_xConnection, m_xObject ) );
 
         sSelectStatement = aSQL.makeStringAndClear();
     }
@@ -369,12 +369,8 @@ OFieldDescription* NamedTableCopySource::createFieldDescription( const OUString&
 
 OUString NamedTableCopySource::getSelectStatement() const
 {
-    OUStringBuffer aSQL;
-    aSQL.append( "SELECT * FROM " );
-
-    aSQL.append( ::dbtools::composeTableNameForSelect( m_xConnection, m_sTableCatalog, m_sTableSchema, m_sTableBareName ) );
-
-    return aSQL.makeStringAndClear();
+    return "SELECT * FROM " +
+        ::dbtools::composeTableNameForSelect( m_xConnection, m_sTableCatalog, m_sTableSchema, m_sTableBareName );
 }
 
 ::utl::SharedUNOComponent< XPreparedStatement > NamedTableCopySource::getPreparedSelectStatement() const
@@ -849,12 +845,12 @@ IMPL_LINK_NOARG(OCopyTableWizard, ImplOKHdl, weld::Button&, void)
                         aError.Message = sMsg;
                         ::rtl::Reference xRequest( new ::comphelper::OInteractionRequest( makeAny( aError ) ) );
                         ::rtl::Reference xYes = new ::comphelper::OInteractionApprove;
-                        xRequest->addContinuation( xYes.get() );
+                        xRequest->addContinuation( xYes );
                         xRequest->addContinuation( new ::comphelper::OInteractionDisapprove );
                         ::rtl::Reference< ::comphelper::OInteractionAbort > xAbort = new ::comphelper::OInteractionAbort;
-                        xRequest->addContinuation( xAbort.get() );
+                        xRequest->addContinuation( xAbort );
 
-                        m_xInteractionHandler->handle( xRequest.get() );
+                        m_xInteractionHandler->handle( xRequest );
 
                         if ( xYes->wasSelected() )
                         {
@@ -1545,7 +1541,7 @@ void OCopyTableWizard::showError(const Any& _aError)
         try
         {
             ::rtl::Reference< ::comphelper::OInteractionRequest > xRequest( new ::comphelper::OInteractionRequest( _aError ) );
-            m_xInteractionHandler->handle( xRequest.get() );
+            m_xInteractionHandler->handle( xRequest );
         }
         catch( const Exception& )
         {
