@@ -32,7 +32,7 @@ namespace dbaui
         : m_vTableRow(_rvTableRow)
     {
     }
-    bool OTableRowExchange::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId, const css::datatransfer::DataFlavor& /*rFlavor*/ )
+    bool OTableRowExchange::WriteObject( tools::SvRef<SotTempStream>& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId, const css::datatransfer::DataFlavor& /*rFlavor*/ )
     {
         if(nUserObjectId == FORMAT_OBJECT_ID_SBA_TABED)
         {
@@ -40,10 +40,8 @@ namespace dbaui
             if(pRows)
             {
                 (*rxOStm).WriteInt32( pRows->size() ); // first stream the size
-                std::vector< std::shared_ptr<OTableRow> >::const_iterator aIter = pRows->begin();
-                std::vector< std::shared_ptr<OTableRow> >::const_iterator aEnd = pRows->end();
-                for(;aIter != aEnd;++aIter)
-                    WriteOTableRow(*rxOStm, **aIter);
+                for (auto const& row : *pRows)
+                    WriteOTableRow(*rxOStm, *row);
                 return true;
             }
         }
