@@ -70,11 +70,7 @@ struct UnoRc : public rtl::StaticWithInit<
     }
 };
 
-struct OfficePipeId : public rtl::StaticWithInit<OUString, OfficePipeId> {
-    OUString operator () ();
-};
-
-OUString OfficePipeId::operator () ()
+OUString generateOfficePipeId()
 {
     OUString userPath;
     ::utl::Bootstrap::PathStatus aLocateResult =
@@ -113,7 +109,9 @@ OUString OfficePipeId::operator () ()
 
 bool existsOfficePipe()
 {
-    OUString const & pipeId = OfficePipeId::get();
+    static OUString OfficePipeId = generateOfficePipeId();
+
+    OUString const & pipeId = OfficePipeId;
     if (pipeId.isEmpty())
         return false;
     ::osl::Security sec;
@@ -195,16 +193,16 @@ bool compareExtensionFolderWithLastSynchronizedFile(
     return bNeedsSync;
 }
 
-bool needToSyncRepository(OUString const & name)
+bool needToSyncRepository(std::u16string_view name)
 {
     OUString folder;
     OUString file;
-    if ( name == "bundled" )
+    if ( name == u"bundled" )
     {
         folder = "$BUNDLED_EXTENSIONS";
         file = "$BUNDLED_EXTENSIONS_USER/lastsynchronized";
     }
-    else if ( name == "shared" )
+    else if ( name == u"shared" )
     {
         folder = "$UNO_SHARED_PACKAGES_CACHE/uno_packages";
         file = "$SHARED_EXTENSIONS_USER/lastsynchronized";
@@ -252,7 +250,7 @@ OUString makeURL( OUString const & baseURL, OUString const & relPath_ )
 {
     OUStringBuffer buf(128);
     if (baseURL.getLength() > 1 && baseURL[ baseURL.getLength() - 1 ] == '/')
-        buf.append( std::u16string_view(baseURL).substr(0, baseURL.getLength() - 1) );
+        buf.append( baseURL.subView(0, baseURL.getLength() - 1) );
     else
         buf.append( baseURL );
     OUString relPath(relPath_);
@@ -455,19 +453,19 @@ Reference<XInterface> resolveUnoURL(
     return nullptr; // warning C4715
 }
 
-static void writeConsoleWithStream(OUString const & sText, FILE * stream)
+static void writeConsoleWithStream(std::u16string_view sText, FILE * stream)
 {
     OString s = OUStringToOString(sText, osl_getThreadTextEncoding());
     fprintf(stream, "%s", s.getStr());
     fflush(stream);
 }
 
-void writeConsole(OUString const & sText)
+void writeConsole(std::u16string_view sText)
 {
     writeConsoleWithStream(sText, stdout);
 }
 
-void writeConsoleError(OUString const & sText)
+void writeConsoleError(std::u16string_view sText)
 {
     writeConsoleWithStream(sText, stderr);
 }
@@ -479,7 +477,7 @@ OUString readConsole()
     // read one char less so that the last char in buf is always zero
     if (fgets(buf, 1024, stdin) != nullptr)
     {
-        OUString value = OStringToOUString(OString(buf), osl_getThreadTextEncoding());
+        OUString value = OStringToOUString(std::string_view(buf), osl_getThreadTextEncoding());
         return value.trim();
     }
     throw css::uno::RuntimeException("reading from stdin failed");
@@ -502,7 +500,7 @@ void syncRepositories(
     //synchronize shared before bundled otherwise there are
     //more revoke and registration calls.
     bool bModified = false;
-    if (force || needToSyncRepository("shared") || needToSyncRepository("bundled"))
+    if (force || needToSyncRepository(u"shared") || needToSyncRepository(u"bundled"))
     {
         xExtensionManager =
             deployment::ExtensionManager::get(
