@@ -711,7 +711,7 @@ void VclPixelProcessor2D::processControlPrimitive2D(
             // Tiled Rendering clients usually do *not* have real VCL-Windows for the controls, but
             // exactly that would be needed on each client displaying the tiles (what would be hard
             // to do but also would have advantages - the clients would have real controls in the
-            //  shape of their traget system which could be interacted with...). It is also what the
+            //  shape of their target system which could be interacted with...). It is also what the
             // office does.
             // For now, fallback to just render these controls when Tiled Rendering is active to just
             // have them displayed on all clients.
@@ -869,7 +869,7 @@ void VclPixelProcessor2D::processBackgroundColorPrimitive2D(
     const basegfx::BColor aPolygonColor(
         maBColorModifierStack.getModifiedColor(rPrimitive.getBColor()));
     Color aFillColor(aPolygonColor);
-    aFillColor.SetTransparency(sal_uInt8((rPrimitive.getTransparency() * 255.0) + 0.5));
+    aFillColor.SetAlpha(255 - sal_uInt8((rPrimitive.getTransparency() * 255.0) + 0.5));
     mpOutputDevice->SetFillColor(aFillColor);
     mpOutputDevice->SetLineColor();
 
@@ -1034,10 +1034,10 @@ void VclPixelProcessor2D::processGlowPrimitive2D(const primitive2d::GlowPrimitiv
     // fades to both sides by the blur radius; thus blur radius is half of glow radius.
     const double fBlurRadius = aGlowRadiusVector.getLength() / 2;
     // Consider glow transparency (initial transparency near the object edge)
-    const sal_uInt8 nTransparency = rCandidate.getGlowColor().GetTransparency();
+    const sal_uInt8 nAlpha = rCandidate.getGlowColor().GetAlpha();
 
     impBufferDevice aBufferDevice(*mpOutputDevice, aRange);
-    if (aBufferDevice.isVisible() && !aRange.isEmpty())
+    if (aBufferDevice.isVisible())
     {
         // remember last OutDev and set to content
         OutputDevice* pLastOutputDevice = mpOutputDevice;
@@ -1061,8 +1061,8 @@ void VclPixelProcessor2D::processGlowPrimitive2D(const primitive2d::GlowPrimitiv
             BitmapEx bmpEx = mpOutputDevice->GetBitmapEx(aRect.TopLeft(), aRect.GetSize());
             mpOutputDevice->SetAntialiasing(aPrevAA);
 
-            AlphaMask mask = ProcessAndBlurAlphaMask(bmpEx.GetAlpha(), fBlurRadius, fBlurRadius,
-                                                     nTransparency);
+            AlphaMask mask
+                = ProcessAndBlurAlphaMask(bmpEx.GetAlpha(), fBlurRadius, fBlurRadius, 255 - nAlpha);
 
             // The end result is the bitmap filled with glow color and blurred 8-bit alpha mask
             const basegfx::BColor aGlowColor(
