@@ -12,12 +12,11 @@
 #include <rtl/string.hxx>
 #include <tools/stream.hxx>
 #include <tools/XmlWriter.hxx>
-#include <vcl/bitmapex.hxx>
-#include <toolkit/helper/vclunohelper.hxx>
 
 #include <memory>
 #include <sal/log.hxx>
 
+#include <drawinglayer/primitive2d/bitmapprimitive2d.hxx>
 #include <drawinglayer/primitive2d/pointarrayprimitive2d.hxx>
 #include <drawinglayer/primitive2d/drawinglayer_primitivetypes2d.hxx>
 #include <drawinglayer/primitive2d/Tools.hxx>
@@ -26,13 +25,14 @@
 #include <drawinglayer/primitive2d/PolyPolygonColorPrimitive2D.hxx>
 #include <drawinglayer/primitive2d/hiddengeometryprimitive2d.hxx>
 #include <drawinglayer/primitive2d/polygonprimitive2d.hxx>
+#include <drawinglayer/primitive2d/textdecoratedprimitive2d.hxx>
+#include <primitive2d/textlineprimitive2d.hxx>
 #include <drawinglayer/primitive2d/textprimitive2d.hxx>
 #include <drawinglayer/primitive2d/maskprimitive2d.hxx>
 #include <drawinglayer/primitive2d/unifiedtransparenceprimitive2d.hxx>
 #include <drawinglayer/primitive2d/objectinfoprimitive2d.hxx>
 #include <drawinglayer/primitive2d/svggradientprimitive2d.hxx>
 #include <drawinglayer/primitive2d/metafileprimitive2d.hxx>
-#include <drawinglayer/primitive2d/bitmapprimitive2d.hxx>
 #include <drawinglayer/geometry/viewinformation2d.hxx>
 #include <drawinglayer/attribute/lineattribute.hxx>
 #include <drawinglayer/attribute/fontattribute.hxx>
@@ -40,6 +40,7 @@
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <svx/sdr/primitive2d/svx_primitivetypes2d.hxx>
+#include <toolkit/helper/vclunohelper.hxx>
 
 using namespace drawinglayer::primitive2d;
 
@@ -57,6 +58,19 @@ OUString convertColorToString(const basegfx::BColor& rColor)
     return "#" + aRGBString;
 }
 
+void writeMatrix(::tools::XmlWriter& rWriter, const basegfx::B2DHomMatrix& rMatrix)
+{
+    rWriter.attribute("xy11", rMatrix.get(0,0));
+    rWriter.attribute("xy12", rMatrix.get(0,1));
+    rWriter.attribute("xy13", rMatrix.get(0,2));
+    rWriter.attribute("xy21", rMatrix.get(1,0));
+    rWriter.attribute("xy22", rMatrix.get(1,1));
+    rWriter.attribute("xy23", rMatrix.get(1,2));
+    rWriter.attribute("xy31", rMatrix.get(2,0));
+    rWriter.attribute("xy32", rMatrix.get(2,1));
+    rWriter.attribute("xy33", rMatrix.get(2,2));
+}
+
 void writePolyPolygon(::tools::XmlWriter& rWriter, const basegfx::B2DPolyPolygon& rB2DPolyPolygon)
 {
     rWriter.startElement("polypolygon");
@@ -87,6 +101,47 @@ void writePolyPolygon(::tools::XmlWriter& rWriter, const basegfx::B2DPolyPolygon
     rWriter.endElement();
 }
 
+void writeLineAttribute(::tools::XmlWriter& rWriter, const drawinglayer::attribute::LineAttribute& rLineAttribute)
+{
+    rWriter.startElement("line");
+    rWriter.attribute("color", convertColorToString(rLineAttribute.getColor()));
+    rWriter.attribute("width", rLineAttribute.getWidth());
+    switch( rLineAttribute.getLineJoin() )
+    {
+        case basegfx::B2DLineJoin::NONE:
+            rWriter.attribute("linejoin", "NONE");
+        break;
+        case basegfx::B2DLineJoin::Bevel:
+            rWriter.attribute("linejoin", "Bevel");
+        break;
+        case basegfx::B2DLineJoin::Miter:
+            rWriter.attribute("linejoin", "Miter");
+        break;
+        case basegfx::B2DLineJoin::Round:
+            rWriter.attribute("linejoin", "Round");
+        break;
+        default:
+            rWriter.attribute("linejoin", "Unknown");
+        break;
+    }
+    switch( rLineAttribute.getLineCap() )
+    {
+        case css::drawing::LineCap::LineCap_BUTT:
+            rWriter.attribute("linecap", "BUTT");
+        break;
+        case css::drawing::LineCap::LineCap_ROUND:
+            rWriter.attribute("linecap", "ROUND");
+        break;
+        case css::drawing::LineCap::LineCap_SQUARE:
+            rWriter.attribute("linecap", "SQUARE");
+        break;
+        default:
+            rWriter.attribute("linecap", "Unknown");
+        break;
+    }
+    rWriter.endElement();
+}
+
 } // end anonymous namespace
 
 Primitive2dXmlDump::Primitive2dXmlDump() :
@@ -169,24 +224,25 @@ void Primitive2dXmlDump::decomposeAndWrite(
         {
             case PRIMITIVE2D_ID_BITMAPPRIMITIVE2D:
             {
-                const BitmapPrimitive2D& rBitmapPrimitive2D
-                    = dynamic_cast<const BitmapPrimitive2D&>(*pBasePrimitive);
+                const BitmapPrimitive2D& rBitmapPrimitive2D = dynamic_cast<const BitmapPrimitive2D&>(*pBasePrimitive);
                 rWriter.startElement("bitmap");
+                writeMatrix(rWriter, rBitmapPrimitive2D.getTransform());
 
                 const BitmapEx aBitmapEx(VCLUnoHelper::GetBitmap(rBitmapPrimitive2D.getXBitmap()));
                 const Size& rSizePixel(aBitmapEx.GetSizePixel());
 
                 rWriter.attribute("height", rSizePixel.getHeight());
                 rWriter.attribute("width", rSizePixel.getWidth());
-                rWriter.attribute("checksum", OString(std::to_string(aBitmapEx.GetChecksum())));
+                rWriter.attribute("checksum", OString(std::to_string( aBitmapEx.GetChecksum() )));
 
-                for (tools::Long y = 0; y < rSizePixel.getHeight(); y++)
+                for (tools::Long y=0; y<rSizePixel.getHeight(); y++)
                 {
+
                     rWriter.startElement("data");
                     OUString aBitmapData = "";
-                    for (tools::Long x = 0; x < rSizePixel.getHeight(); x++)
+                    for (tools::Long x=0; x<rSizePixel.getHeight(); x++)
                     {
-                        if (x != 0)
+                        if (x !=0)
                             aBitmapData = aBitmapData + ",";
                         aBitmapData = aBitmapData + aBitmapEx.GetPixelColor(x, y).AsRGBHexString();
                     }
@@ -209,18 +265,7 @@ void Primitive2dXmlDump::decomposeAndWrite(
             {
                 const TransformPrimitive2D& rTransformPrimitive2D = dynamic_cast<const TransformPrimitive2D&>(*pBasePrimitive);
                 rWriter.startElement("transform");
-
-                basegfx::B2DHomMatrix const & rMatrix = rTransformPrimitive2D.getTransformation();
-                rWriter.attributeDouble("xy11", rMatrix.get(0,0));
-                rWriter.attributeDouble("xy12", rMatrix.get(0,1));
-                rWriter.attributeDouble("xy13", rMatrix.get(0,2));
-                rWriter.attributeDouble("xy21", rMatrix.get(1,0));
-                rWriter.attributeDouble("xy22", rMatrix.get(1,1));
-                rWriter.attributeDouble("xy23", rMatrix.get(1,2));
-                rWriter.attributeDouble("xy31", rMatrix.get(2,0));
-                rWriter.attributeDouble("xy32", rMatrix.get(2,1));
-                rWriter.attributeDouble("xy33", rMatrix.get(2,2));
-
+                writeMatrix(rWriter, rTransformPrimitive2D.getTransformation());
                 decomposeAndWrite(rTransformPrimitive2D.getChildren(), rWriter);
                 rWriter.endElement();
             }
@@ -267,12 +312,7 @@ void Primitive2dXmlDump::decomposeAndWrite(
                 rWriter.content(basegfx::utils::exportToSvgPoints(rPolygonStrokePrimitive2D.getB2DPolygon()));
                 rWriter.endElement();
 
-                rWriter.startElement("line");
-                const drawinglayer::attribute::LineAttribute& aLineAttribute = rPolygonStrokePrimitive2D.getLineAttribute();
-                rWriter.attribute("color", convertColorToString(aLineAttribute.getColor()));
-                rWriter.attribute("width", aLineAttribute.getWidth());
-
-                rWriter.endElement();
+                writeLineAttribute(rWriter, rPolygonStrokePrimitive2D.getLineAttribute());
 
                 rWriter.startElement("stroke");
                 const drawinglayer::attribute::StrokeAttribute& aStrokeAttribute = rPolygonStrokePrimitive2D.getStrokeAttribute();
@@ -288,13 +328,7 @@ void Primitive2dXmlDump::decomposeAndWrite(
                 const PolyPolygonStrokePrimitive2D& rPolyPolygonStrokePrimitive2D = dynamic_cast<const PolyPolygonStrokePrimitive2D&>(*pBasePrimitive);
                 rWriter.startElement("polypolygonstroke");
 
-                rWriter.startElement("line");
-                const drawinglayer::attribute::LineAttribute& aLineAttribute = rPolyPolygonStrokePrimitive2D.getLineAttribute();
-                rWriter.attribute("color", convertColorToString(aLineAttribute.getColor()));
-                rWriter.attribute("width", aLineAttribute.getWidth());
-                //rWriter.attribute("linejoin", aLineAttribute.getLineJoin());
-                //rWriter.attribute("linecap", aLineAttribute.getLineCap());
-                rWriter.endElement();
+                writeLineAttribute(rWriter, rPolyPolygonStrokePrimitive2D.getLineAttribute());
 
                 //getStrokeAttribute()
 
@@ -315,7 +349,35 @@ void Primitive2dXmlDump::decomposeAndWrite(
                 rWriter.content(basegfx::utils::exportToSvgPoints(rPolygonHairlinePrimitive2D.getB2DPolygon()));
                 rWriter.endElement();
 
+                rWriter.endElement();
+            }
+            break;
 
+            case PRIMITIVE2D_ID_TEXTDECORATEDPORTIONPRIMITIVE2D:
+            {
+                const TextDecoratedPortionPrimitive2D& rTextDecoratedPortionPrimitive2D = dynamic_cast<const TextDecoratedPortionPrimitive2D&>(*pBasePrimitive);
+                rWriter.startElement("textdecoratedportion");
+                writeMatrix(rWriter, rTextDecoratedPortionPrimitive2D.getTextTransform());
+
+                rWriter.attribute("text", rTextDecoratedPortionPrimitive2D.getText());
+                rWriter.attribute("fontcolor", convertColorToString(rTextDecoratedPortionPrimitive2D.getFontColor()));
+
+                const drawinglayer::attribute::FontAttribute& aFontAttribute = rTextDecoratedPortionPrimitive2D.getFontAttribute();
+                rWriter.attribute("familyname", aFontAttribute.getFamilyName());
+                rWriter.endElement();
+            }
+            break;
+
+            case PRIMITIVE2D_ID_TEXTLINEPRIMITIVE2D:
+            {
+                const TextLinePrimitive2D& rTextLinePrimitive2D = dynamic_cast<const TextLinePrimitive2D&>(*pBasePrimitive);
+                rWriter.startElement("textline");
+                writeMatrix(rWriter, rTextLinePrimitive2D.getObjectTransformation());
+
+                rWriter.attribute("width", rTextLinePrimitive2D.getWidth());
+                rWriter.attribute("offset", rTextLinePrimitive2D.getOffset());
+                rWriter.attribute("height", rTextLinePrimitive2D.getHeight());
+                rWriter.attribute("color", convertColorToString(rTextLinePrimitive2D.getLineColor()));
                 rWriter.endElement();
             }
             break;
@@ -334,9 +396,7 @@ void Primitive2dXmlDump::decomposeAndWrite(
                 }
                 rWriter.attribute("x", aTranslate.getX());
                 rWriter.attribute("y", aTranslate.getY());
-                OUString aText = rTextSimplePortionPrimitive2D.getText();
-                // TODO share code with sax_fastparser::FastSaxSerializer::write().
-                rWriter.attribute("text", aText.replaceAll("", "&#9;"));
+                rWriter.attribute("text", rTextSimplePortionPrimitive2D.getText());
                 rWriter.attribute("fontcolor", convertColorToString(rTextSimplePortionPrimitive2D.getFontColor()));
 
                 const drawinglayer::attribute::FontAttribute& aFontAttribute = rTextSimplePortionPrimitive2D.getFontAttribute();
@@ -368,9 +428,8 @@ void Primitive2dXmlDump::decomposeAndWrite(
             {
                 const UnifiedTransparencePrimitive2D& rUnifiedTransparencePrimitive2D = dynamic_cast<const UnifiedTransparencePrimitive2D&>(*pBasePrimitive);
                 rWriter.startElement("unifiedtransparence");
-                rWriter.attribute("transparence", OString::number(rUnifiedTransparencePrimitive2D.getTransparence()));
+                rWriter.attribute("transparence", std::lround(100 * rUnifiedTransparencePrimitive2D.getTransparence()));
                 decomposeAndWrite(rUnifiedTransparencePrimitive2D.getChildren(), rWriter);
-
                 rWriter.endElement();
             }
             break;
@@ -414,16 +473,7 @@ void Primitive2dXmlDump::decomposeAndWrite(
                 rWriter.attributeDouble("opacity", rSvgLinearGradientPrimitive2D.getGradientEntries().front().getOpacity());
 
                 rWriter.startElement("transform");
-                basegfx::B2DHomMatrix const & rMatrix = rSvgLinearGradientPrimitive2D.getGradientTransform();
-                rWriter.attributeDouble("xy11", rMatrix.get(0,0));
-                rWriter.attributeDouble("xy12", rMatrix.get(0,1));
-                rWriter.attributeDouble("xy13", rMatrix.get(0,2));
-                rWriter.attributeDouble("xy21", rMatrix.get(1,0));
-                rWriter.attributeDouble("xy22", rMatrix.get(1,1));
-                rWriter.attributeDouble("xy23", rMatrix.get(1,2));
-                rWriter.attributeDouble("xy31", rMatrix.get(2,0));
-                rWriter.attributeDouble("xy32", rMatrix.get(2,1));
-                rWriter.attributeDouble("xy33", rMatrix.get(2,2));
+                writeMatrix(rWriter, rSvgLinearGradientPrimitive2D.getGradientTransform());
                 rWriter.endElement();
 
                 writePolyPolygon(rWriter, rSvgLinearGradientPrimitive2D.getPolyPolygon());
@@ -517,42 +567,11 @@ void Primitive2dXmlDump::decomposeAndWrite(
                 break;
             }
 
-            case PRIMITIVE2D_ID_MODIFIEDCOLORPRIMITIVE2D:
-            {
-                // ModifiedColorPrimitive2D.
-                rWriter.startElement("modifiedColor");
-                drawinglayer::primitive2d::Primitive2DContainer aPrimitiveContainer;
-                pBasePrimitive->get2DDecomposition(aPrimitiveContainer,
-                                                   drawinglayer::geometry::ViewInformation2D());
-                decomposeAndWrite(aPrimitiveContainer, rWriter);
-                rWriter.endElement();
-                break;
-            }
-
             default:
             {
-                OString aName("unhandled");
-                switch (nId)
-                {
-                    case PRIMITIVE2D_ID_RANGE_SVX | 14: // PRIMITIVE2D_ID_SDRCELLPRIMITIVE2D
-                    {
-                        aName = "sdrCell";
-                        break;
-                    }
-                }
-                rWriter.startElement(aName);
+                rWriter.startElement("unhandled");
                 rWriter.attribute("id", OUStringToOString(sCurrentElementTag, RTL_TEXTENCODING_UTF8));
                 rWriter.attribute("idNumber", nId);
-
-                auto pBufferedDecomposition
-                    = dynamic_cast<const BufferedDecompositionPrimitive2D*>(pBasePrimitive);
-                if (pBufferedDecomposition)
-                {
-                    rWriter.attribute(
-                        "transparenceForShadow",
-                        OString::number(pBufferedDecomposition->getTransparenceForShadow()));
-                }
-
                 drawinglayer::primitive2d::Primitive2DContainer aPrimitiveContainer;
                 pBasePrimitive->get2DDecomposition(aPrimitiveContainer,
                                                    drawinglayer::geometry::ViewInformation2D());
