@@ -122,10 +122,10 @@ public:
     CPPUNIT_TEST_SUITE_END();
 
 private:
-    EditEngineItemPool* mpItemPool;
+    rtl::Reference<EditEngineItemPool> mpItemPool;
 };
 
-Test::Test() : mpItemPool(nullptr) {}
+Test::Test() {}
 
 void Test::setUp()
 {
@@ -138,7 +138,7 @@ void Test::setUp()
 
 void Test::tearDown()
 {
-    SfxItemPool::Free(mpItemPool);
+    mpItemPool.clear();
     test::BootstrapFixture::tearDown();
 }
 
@@ -146,7 +146,7 @@ void Test::tearDown()
 void Test::testLineSpacing()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine(mpItemPool);
+    EditEngine aEditEngine(mpItemPool.get());
 
     if(aEditEngine.GetRefDevice()->GetDPIY() != 96
         || aEditEngine.GetRefDevice()->GetDPIScaleFactor() != 1.0)
@@ -191,8 +191,8 @@ void Test::testLineSpacing()
         aEditEngine.QuickSetAttribs(*pSet, aSelection);
 
         // Assert changes
-        ParaPortion* pParaPortion = aEditEngine.GetParaPortions()[0];
-        ContentNode* const pNode = pParaPortion->GetNode();
+        ParaPortion& rParaPortion = aEditEngine.GetParaPortions()[0];
+        ContentNode* const pNode = rParaPortion.GetNode();
         const SvxLineSpacingItem& rLSItem = pNode->GetContentAttribs().GetItem(EE_PARA_SBL);
         CPPUNIT_ASSERT_EQUAL(SvxInterLineSpaceRule::Prop, rLSItem.GetInterLineSpaceRule());
         CPPUNIT_ASSERT_EQUAL(nSpace, rLSItem.GetPropLineSpace());
@@ -223,12 +223,12 @@ void Test::testLineSpacing()
 
 void Test::testConstruction()
 {
-    EditEngine aEngine(mpItemPool);
+    EditEngine aEngine(mpItemPool.get());
 
     aEngine.SetText("I am Edit Engine.");
 }
 
-bool includes(const uno::Sequence<OUString>& rSeq, const OUString& rVal)
+bool includes(const uno::Sequence<OUString>& rSeq, std::u16string_view rVal)
 {
     for (OUString const & s : rSeq)
         if (s == rVal)
@@ -243,7 +243,7 @@ void Test::testUnoTextFields()
         // DATE
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::DATE));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.DateTime");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.DateTime");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -251,7 +251,7 @@ void Test::testUnoTextFields()
         // URL
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::URL));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.URL");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.URL");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -259,7 +259,7 @@ void Test::testUnoTextFields()
         // PAGE
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::PAGE));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.PageNumber");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.PageNumber");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -267,7 +267,7 @@ void Test::testUnoTextFields()
         // PAGES
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::PAGES));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.PageCount");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.PageCount");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -275,7 +275,7 @@ void Test::testUnoTextFields()
         // TIME
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::TIME));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.DateTime");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.DateTime");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -283,7 +283,7 @@ void Test::testUnoTextFields()
         // FILE
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::DOCINFO_TITLE));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.docinfo.Title");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.docinfo.Title");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -291,7 +291,7 @@ void Test::testUnoTextFields()
         // TABLE
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::TABLE));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.SheetName");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.SheetName");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -299,7 +299,7 @@ void Test::testUnoTextFields()
         // EXTENDED TIME
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::EXTENDED_TIME));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.DateTime");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.DateTime");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -307,7 +307,7 @@ void Test::testUnoTextFields()
         // EXTENDED FILE
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::EXTENDED_FILE));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.FileName");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.FileName");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -315,7 +315,7 @@ void Test::testUnoTextFields()
         // AUTHOR
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::AUTHOR));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.Author");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.Author");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -323,7 +323,7 @@ void Test::testUnoTextFields()
         // MEASURE
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::MEASURE));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.text.textfield.Measure");
+        bool bGood = includes(aSvcs, u"com.sun.star.text.textfield.Measure");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -331,7 +331,7 @@ void Test::testUnoTextFields()
         // PRESENTATION HEADER
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::PRESENTATION_HEADER));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.presentation.textfield.Header");
+        bool bGood = includes(aSvcs, u"com.sun.star.presentation.textfield.Header");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -339,7 +339,7 @@ void Test::testUnoTextFields()
         // PRESENTATION FOOTER
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::PRESENTATION_FOOTER));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.presentation.textfield.Footer");
+        bool bGood = includes(aSvcs, u"com.sun.star.presentation.textfield.Footer");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 
@@ -347,7 +347,7 @@ void Test::testUnoTextFields()
         // PRESENTATION DATE TIME
         rtl::Reference<SvxUnoTextField> xField(new SvxUnoTextField(text::textfield::Type::PRESENTATION_DATE_TIME));
         uno::Sequence<OUString> aSvcs = xField->getSupportedServiceNames();
-        bool bGood = includes(aSvcs, "com.sun.star.presentation.textfield.DateTime");
+        bool bGood = includes(aSvcs, u"com.sun.star.presentation.textfield.DateTime");
         CPPUNIT_ASSERT_MESSAGE("expected service is not present.", bGood);
     }
 }
@@ -427,7 +427,8 @@ private:
 
         return false;
     }
-    virtual bool TransliterateRTLWord( sal_Int32& /*rSttPos*/, sal_Int32 /*nEndPos*/ ) override
+    virtual bool TransliterateRTLWord( sal_Int32& /*rSttPos*/,
+            sal_Int32 /*nEndPos*/, bool /*bApply*/ ) override
     {
         return false;
     }
@@ -501,8 +502,7 @@ void Test::testAutocorrect()
     {
         OUString sInput("T\x01");
         sal_Unicode const cNextChar('"');
-        const sal_Unicode EXPECTED[] = { 'T', 0x01, 0x0201d };
-        OUString sExpected(EXPECTED, SAL_N_ELEMENTS(EXPECTED));
+        static constexpr OUStringLiteral sExpected = u"T\x01\u201d";
         bool bNbspRunNext = false;
 
         TestAutoCorrDoc aFoo(sInput, LANGUAGE_ENGLISH_US);
@@ -510,7 +510,7 @@ void Test::testAutocorrect()
         aAutoCorrect.DoAutoCorrect(aFoo, sInput, sInput.getLength(), cNextChar, true, bNbspRunNext);
         fprintf(stderr, "text is %x\n", aFoo.getResult()[aFoo.getResult().getLength() - 1]);
 
-        CPPUNIT_ASSERT_EQUAL_MESSAGE("autocorrect", sExpected, aFoo.getResult());
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("autocorrect", OUString(sExpected), aFoo.getResult());
     }
 
 }
@@ -552,7 +552,7 @@ IMPL_STATIC_LINK( Test, CalcFieldValueHdl, EditFieldInfo*, pInfo, void )
 void Test::testHyperlinkCopyPaste()
 {
     // Create Outliner instance
-    Outliner aOutliner(mpItemPool, OutlinerMode
+    Outliner aOutliner(mpItemPool.get(), OutlinerMode
 ::TextObject);
     aOutliner.SetCalcFieldValueHdl( LINK( nullptr, Test, CalcFieldValueHdl ) );
 
@@ -676,7 +676,7 @@ void Test::testHyperlinkCopyPaste()
 void Test::testCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -708,7 +708,7 @@ void Test::testCopyPaste()
 void Test::testMultiParaSelCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -753,7 +753,7 @@ void Test::testMultiParaSelCopyPaste()
 void Test::testTabsCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -818,7 +818,7 @@ public:
 // https://bugzilla.novell.com/show_bug.cgi?id=467459
 void Test::testHyperlinkSearch()
 {
-    UrlEditEngine aEngine(mpItemPool);
+    UrlEditEngine aEngine(mpItemPool.get());
     EditDoc &rDoc = aEngine.GetEditDoc();
 
     OUString aSampleText = "Please write email to . if you find a fish(not a dog).";
@@ -903,7 +903,7 @@ bool hasItalic(const editeng::Section& rSecAttr)
 void Test::testBoldItalicCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -985,7 +985,8 @@ void Test::testBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 8, static_cast<int>(aAttrs2[2].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 14, static_cast<int>(aAttrs2[2].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs2[2].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs2[2]) && hasItalic(aAttrs2[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs2[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs2[2]) );
 
     CPPUNIT_ASSERT_EQUAL( 0, static_cast<int>(aAttrs2[3].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 14, static_cast<int>(aAttrs2[3].mnStart) );
@@ -1031,7 +1032,8 @@ void Test::testBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 8, static_cast<int>(aAttrs3[2].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 14, static_cast<int>(aAttrs3[2].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[2].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[2]) && hasItalic(aAttrs3[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs3[2]) );
 
     CPPUNIT_ASSERT_EQUAL( 0, static_cast<int>(aAttrs3[3].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 14, static_cast<int>(aAttrs3[3].mnStart) );
@@ -1054,7 +1056,8 @@ void Test::testBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 27, static_cast<int>(aAttrs3[6].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 33, static_cast<int>(aAttrs3[6].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[6].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[6]) && hasItalic(aAttrs3[6]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[6]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs3[6]) );
 
     CPPUNIT_ASSERT_EQUAL( 0, static_cast<int>(aAttrs3[7].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 33, static_cast<int>(aAttrs3[7].mnStart) );
@@ -1081,7 +1084,7 @@ bool hasUnderline(const editeng::Section& rSecAttr)
 void Test::testUnderlineCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -1174,7 +1177,7 @@ void Test::testUnderlineCopyPaste()
 void Test::testMultiParaCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -1216,7 +1219,7 @@ void Test::testMultiParaCopyPaste()
 void Test::testParaBoldItalicCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get()     );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -1332,7 +1335,8 @@ void Test::testParaBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 14, static_cast<int>(aAttrs2[2].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 18, static_cast<int>(aAttrs2[2].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs2[2].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs2[2]) && hasItalic(aAttrs2[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs2[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs2[2]) );
 
     CPPUNIT_ASSERT_EQUAL( 0, static_cast<int>(aAttrs2[3].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 18, static_cast<int>(aAttrs2[3].mnStart) );
@@ -1350,7 +1354,8 @@ void Test::testParaBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 5, static_cast<int>(aAttrs2[5].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 9, static_cast<int>(aAttrs2[5].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs2[5].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs2[5]) && hasItalic(aAttrs2[5]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs2[5]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs2[5]) );
 
     CPPUNIT_ASSERT_EQUAL( 1, static_cast<int>(aAttrs2[6].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 9, static_cast<int>(aAttrs2[6].mnStart) );
@@ -1405,7 +1410,8 @@ void Test::testParaBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 14, static_cast<int>(aAttrs3[2].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 18, static_cast<int>(aAttrs3[2].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[2].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[2]) && hasItalic(aAttrs3[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[2]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs3[2]) );
 
     CPPUNIT_ASSERT_EQUAL( 0, static_cast<int>(aAttrs3[3].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 18, static_cast<int>(aAttrs3[3].mnStart) );
@@ -1423,7 +1429,8 @@ void Test::testParaBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 5, static_cast<int>(aAttrs3[5].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 9, static_cast<int>(aAttrs3[5].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[5].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[5]) && hasItalic(aAttrs3[5]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[5]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs3[5]) );
 
     CPPUNIT_ASSERT_EQUAL( 1, static_cast<int>(aAttrs3[6].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 9, static_cast<int>(aAttrs3[6].mnStart) );
@@ -1451,7 +1458,8 @@ void Test::testParaBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 29, static_cast<int>(aAttrs3[10].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 33, static_cast<int>(aAttrs3[10].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[10].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[10]) && hasItalic(aAttrs3[10]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[10]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs3[10]) );
 
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[11].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 33, static_cast<int>(aAttrs3[11].mnStart) );
@@ -1469,7 +1477,8 @@ void Test::testParaBoldItalicCopyPaste()
     CPPUNIT_ASSERT_EQUAL( 5, static_cast<int>(aAttrs3[13].mnStart) );
     CPPUNIT_ASSERT_EQUAL( 9, static_cast<int>(aAttrs3[13].mnEnd) );
     CPPUNIT_ASSERT_EQUAL( 2, static_cast<int>(aAttrs3[13].maAttributes.size()) );
-    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[13]) && hasItalic(aAttrs3[13]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasBold(aAttrs3[13]) );
+    CPPUNIT_ASSERT_MESSAGE( "This section must be bold and italic.", hasItalic(aAttrs3[13]) );
 
     CPPUNIT_ASSERT_EQUAL( 3, static_cast<int>(aAttrs3[14].mnParagraph) );
     CPPUNIT_ASSERT_EQUAL( 9, static_cast<int>(aAttrs3[14].mnStart) );
@@ -1481,7 +1490,7 @@ void Test::testParaBoldItalicCopyPaste()
 void Test::testParaStartCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -1525,7 +1534,7 @@ void Test::testParaStartCopyPaste()
 
 void Test::testSectionAttributes()
 {
-    EditEngine aEngine(mpItemPool);
+    EditEngine aEngine(mpItemPool.get());
 
     std::unique_ptr<SfxItemSet> pSet(new SfxItemSet(aEngine.GetEmptyItemSet()));
     SvxWeightItem aBold(WEIGHT_BOLD, EE_CHAR_WEIGHT);
@@ -1561,7 +1570,8 @@ void Test::testSectionAttributes()
         CPPUNIT_ASSERT_EQUAL(3, static_cast<int>(aAttrs[1].mnStart));
         CPPUNIT_ASSERT_EQUAL(6, static_cast<int>(aAttrs[1].mnEnd));
         CPPUNIT_ASSERT_EQUAL(2, static_cast<int>(aAttrs[1].maAttributes.size()));
-        CPPUNIT_ASSERT_MESSAGE("This section must be bold and italic.", hasBold(aAttrs[1]) && hasItalic(aAttrs[1]));
+        CPPUNIT_ASSERT_MESSAGE("This section must be bold and italic.", hasBold(aAttrs[1]));
+        CPPUNIT_ASSERT_MESSAGE("This section must be bold and italic.", hasItalic(aAttrs[1]));
 
         // Third section should be 6-9, and it should be only italic.
         CPPUNIT_ASSERT_EQUAL(0, static_cast<int>(aAttrs[2].mnParagraph));
@@ -1666,7 +1676,7 @@ void Test::testSectionAttributes()
 void Test::testLargeParaCopyPaste()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     // Get EditDoc for current EditEngine's instance
     EditDoc &rDoc = aEditEngine.GetEditDoc();
@@ -1738,7 +1748,7 @@ void Test::testLargeParaCopyPaste()
 void Test::testTransliterate()
 {
     // Create EditEngine's instance
-    EditEngine aEditEngine( mpItemPool );
+    EditEngine aEditEngine( mpItemPool.get() );
 
     OUString sText("one (two) three");
     aEditEngine.SetText(sText);
