@@ -21,9 +21,11 @@
 #include <utility>
 
 #include <comphelper/lok.hxx>
+#include <comphelper/processfactory.hxx>
 #include <config_global.h>
-#include <vcl/weld.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/weld.hxx>
+#include <vcl/window.hxx>
 
 #include <tools/stream.hxx>
 
@@ -66,6 +68,7 @@
 #include <vcl/help.hxx>
 #include <vcl/transfer.hxx>
 #include <com/sun/star/datatransfer/clipboard/XClipboard.hpp>
+#include <com/sun/star/frame/Desktop.hpp>
 
 #if OSL_DEBUG_LEVEL > 1
 #include <editeng/frmdiritem.hxx>
@@ -81,7 +84,8 @@ using namespace ::com::sun::star::linguistic2;
 static bool bDebugPaint = false;
 #endif
 
-static SfxItemPool* pGlobalPool=nullptr;
+
+static rtl::Reference<SfxItemPool> pGlobalPool;
 
 EditEngine::EditEngine( SfxItemPool* pItemPool )
 {
@@ -196,35 +200,35 @@ const SfxItemSet& EditEngine::GetEmptyItemSet() const
     return pImpEditEngine->GetEmptyItemSet();
 }
 
-void EditEngine::Draw( OutputDevice* pOutDev, const tools::Rectangle& rOutRect )
+void EditEngine::Draw( OutputDevice& rOutDev, const tools::Rectangle& rOutRect )
 {
-    Draw( pOutDev, rOutRect, Point( 0, 0 ) );
+    Draw( rOutDev, rOutRect, Point( 0, 0 ) );
 }
 
-void EditEngine::Draw( OutputDevice* pOutDev, const Point& rStartPos, Degree10 nOrientation )
+void EditEngine::Draw( OutputDevice& rOutDev, const Point& rStartPos, Degree10 nOrientation )
 {
     // Create with 2 points, as with positive points it will end up with
     // LONGMAX as Size, Bottom and Right in the range > LONGMAX.
     tools::Rectangle aBigRect( -0x3FFFFFFF, -0x3FFFFFFF, 0x3FFFFFFF, 0x3FFFFFFF );
-    if( pOutDev->GetConnectMetaFile() )
-        pOutDev->Push();
+    if( rOutDev.GetConnectMetaFile() )
+        rOutDev.Push();
     Point aStartPos( rStartPos );
     if ( IsVertical() )
     {
         aStartPos.AdjustX(GetPaperSize().Width() );
         aStartPos = Rotate( aStartPos, nOrientation, rStartPos );
     }
-    pImpEditEngine->Paint( pOutDev, aBigRect, aStartPos, false, nOrientation );
-    if( pOutDev->GetConnectMetaFile() )
-        pOutDev->Pop();
+    pImpEditEngine->Paint(rOutDev, aBigRect, aStartPos, false, nOrientation);
+    if( rOutDev.GetConnectMetaFile() )
+        rOutDev.Pop();
 }
 
-void EditEngine::Draw( OutputDevice* pOutDev, const tools::Rectangle& rOutRect, const Point& rStartDocPos )
+void EditEngine::Draw( OutputDevice& rOutDev, const tools::Rectangle& rOutRect, const Point& rStartDocPos )
 {
-    Draw( pOutDev, rOutRect, rStartDocPos, true );
+    Draw( rOutDev, rOutRect, rStartDocPos, true );
 }
 
-void EditEngine::Draw( OutputDevice* pOutDev, const tools::Rectangle& rOutRect, const Point& rStartDocPos, bool bClip )
+void EditEngine::Draw( OutputDevice& rOutDev, const tools::Rectangle& rOutRect, const Point& rStartDocPos, bool bClip )
 {
 #if defined( DBG_UTIL ) || (OSL_DEBUG_LEVEL > 1)
     if ( bDebugPaint )
@@ -233,8 +237,8 @@ void EditEngine::Draw( OutputDevice* pOutDev, const tools::Rectangle& rOutRect,
 
     // Align to the pixel boundary, so that it becomes exactly the same
     // as Paint ()
-    tools::Rectangle aOutRect( pOutDev->LogicToPixel( rOutRect ) );
-    aOutRect = pOutDev->PixelToLogic( aOutRect );
+    tools::Rectangle aOutRect( rOutDev.LogicToPixel( rOutRect ) );
+    aOutRect = rOutDev.PixelToLogic( aOutRect );
 
     Point aStartPos;
     if ( !IsVertical() )
@@ -248,14 +252,14 @@ void EditEngine::Draw( OutputDevice* pOutDev, const tools::Rectangle& rOutRect,
         aStartPos.setY( aOutRect.Top() - rStartDocPos.X() );
     }
 
-    bool bClipRegion = pOutDev->IsClipRegion();
-    bool bMetafile = pOutDev->GetConnectMetaFile();
-    vcl::Region aOldRegion = pOutDev->GetClipRegion();
+    bool bClipRegion = rOutDev.IsClipRegion();
+    bool bMetafile = rOutDev.GetConnectMetaFile();
+    vcl::Region aOldRegion = rOutDev.GetClipRegion();
 
     // If one existed => intersection!
     // Use Push/pop for creating the Meta file
     if ( bMetafile )
-        pOutDev->Push();
+        rOutDev.Push();
 
     // Always use the Intersect method, it is a must for Metafile!
     if ( bClip )
@@ -268,25 +272,25 @@ void EditEngine::Draw( OutputDevice* pOutDev, const tools::Rectangle& rOutRect,
             // Some printer drivers cause problems if characters graze the
             // ClipRegion, therefore rather add a pixel more ...
             tools::Rectangle aClipRect( aOutRect );
-            if ( pOutDev->GetOutDevType() == OUTDEV_PRINTER )
+            if ( rOutDev.GetOutDevType() == OUTDEV_PRINTER )
             {
                 Size aPixSz( 1, 0 );
-                aPixSz = pOutDev->PixelToLogic( aPixSz );
+                aPixSz = rOutDev.PixelToLogic( aPixSz );
                 aClipRect.AdjustRight(aPixSz.Width() );
                 aClipRect.AdjustBottom(aPixSz.Width() );
             }
-            pOutDev->IntersectClipRegion( aClipRect );
+            rOutDev.IntersectClipRegion( aClipRect );
         }
     }
 
-    pImpEditEngine->Paint( pOutDev, aOutRect, aStartPos );
+    pImpEditEngine->Paint( rOutDev, aOutRect, aStartPos );
 
     if ( bMetafile )
-        pOutDev->Pop();
+        rOutDev.Pop();
     else if ( bClipRegion )
-        pOutDev->SetClipRegion( aOldRegion );
+        rOutDev.SetClipRegion( aOldRegion );
     else
-        pOutDev->SetClipRegion();
+        rOutDev.SetClipRegion();
 }
 
 void EditEngine::InsertView(EditView* pEditView, size_t nIndex)
@@ -448,6 +452,11 @@ bool EditEngine::GetDirectVertical() const
     return pImpEditEngine->GetDirectVertical();
 }
 
+void EditEngine::SetTextColumns(sal_Int16 nColumns, sal_Int32 nSpacing)
+{
+    pImpEditEngine->SetTextColumns(nColumns, nSpacing);
+}
+
 void EditEngine::SetFixedCellHeight( bool bUseFixedCellHeight )
 {
     pImpEditEngine->SetFixedCellHeight( bUseFixedCellHeight );
@@ -555,6 +564,11 @@ void EditEngine::SetMaxAutoPaperSize( const Size& rSz )
     pImpEditEngine->SetMaxAutoPaperSize( rSz );
 }
 
+void EditEngine::SetMinColumnWrapHeight(tools::Long nVal)
+{
+    pImpEditEngine->SetMinColumnWrapHeight(nVal);
+}
+
 OUString EditEngine::GetText( LineEnd eEnd ) const
 {
     return pImpEditEngine->GetEditDoc().GetText( eEnd );
@@ -680,12 +694,12 @@ bool EditEngine::IsIdleFormatterActive() const
 
 ParaPortion* EditEngine::FindParaPortion(ContentNode const * pNode)
 {
-    return pImpEditEngine->FindParaPortion(pNode);
+    return &pImpEditEngine->FindParaPortion(pNode);
 }
 
 const ParaPortion* EditEngine::FindParaPortion(ContentNode const * pNode) const
 {
-    return pImpEditEngine->FindParaPortion(pNode);
+    return &pImpEditEngine->FindParaPortion(pNode);
 }
 
 const ParaPortion* EditEngine::GetPrevVisPortion(const ParaPortion* pCurPortion) const
@@ -1047,9 +1061,9 @@ bool EditEngine::PostKeyEvent( const KeyEvent& rKeyEvent, EditView* pEditView, v
                         Point P2( P1 );
                         P2.AdjustX(n20 );
                         P2.AdjustY(nH );
-                        pEditView->GetWindow()->SetLineColor();
-                        pEditView->GetWindow()->SetFillColor( (n%2) ? COL_YELLOW : COL_LIGHTGREEN );
-                        pEditView->GetWindow()->DrawRect( tools::Rectangle( P1, P2 ) );
+                        pEditView->GetWindow()->GetOutDev()->SetLineColor();
+                        pEditView->GetWindow()->GetOutDev()->SetFillColor( (n%2) ? COL_YELLOW : COL_LIGHTGREEN );
+                        pEditView->GetWindow()->GetOutDev()->DrawRect( tools::Rectangle( P1, P2 ) );
                         aPos.AdjustY(nH );
                     }
                 }
@@ -1816,7 +1830,7 @@ void EditEngine::StripPortions()
             aBigRect.SetBottom( 0 );
         }
     }
-    pImpEditEngine->Paint( aTmpDev.get(), aBigRect, Point(), true );
+    pImpEditEngine->Paint(*aTmpDev, aBigRect, Point(), true);
 }
 
 void EditEngine::GetPortions( sal_Int32 nPara, std::vector<sal_Int32>& rList )
@@ -1902,7 +1916,7 @@ void EditEngine::SetControlWord( EEControlBits nWord )
         for ( sal_Int32 n = 0; n < nNodes; n++ )
         {
             ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( n );
-            const ParaPortion* pPortion = pImpEditEngine->GetParaPortions()[n];
+            const ParaPortion& rPortion = pImpEditEngine->GetParaPortions()[n];
             bool bWrongs = false;
             if (pNode->GetWrongList() != nullptr)
                 bWrongs = !pNode->GetWrongList()->empty();
@@ -1912,10 +1926,10 @@ void EditEngine::SetControlWord( EEControlBits nWord )
                 pImpEditEngine->aInvalidRect.SetLeft( 0 );
                 pImpEditEngine->aInvalidRect.SetRight( pImpEditEngine->GetPaperSize().Width() );
                 pImpEditEngine->aInvalidRect.SetTop( nY+1 );
-                pImpEditEngine->aInvalidRect.SetBottom( nY+pPortion->GetHeight()-1 );
+                pImpEditEngine->aInvalidRect.SetBottom( nY + rPortion.GetHeight()-1 );
                 pImpEditEngine->UpdateViews( pImpEditEngine->pActiveView );
             }
-            nY += pPortion->GetHeight();
+            nY += rPortion.GetHeight();
         }
     }
 }
@@ -2013,29 +2027,12 @@ bool EditEngine::IsTextPos( const Point& rPaperPos, sal_uInt16 nBorder )
     if ( !pImpEditEngine->IsFormatted() )
         pImpEditEngine->FormatDoc();
 
-    bool bTextPos = false;
     // take unrotated positions for calculation here
     Point aDocPos = GetDocPos( rPaperPos );
 
     if ( ( aDocPos.Y() > 0  ) && ( aDocPos.Y() < static_cast<tools::Long>(pImpEditEngine->GetTextHeight()) ) )
-    {
-        EditPaM aPaM = pImpEditEngine->GetPaM( aDocPos, false );
-        if ( aPaM.GetNode() )
-        {
-            const ParaPortion* pParaPortion = pImpEditEngine->FindParaPortion( aPaM.GetNode() );
-            DBG_ASSERT( pParaPortion, "ParaPortion?" );
-
-            sal_Int32 nLine = pParaPortion->GetLineNumber( aPaM.GetIndex() );
-            const EditLine& rLine = pParaPortion->GetLines()[nLine];
-            Range aLineXPosStartEnd = pImpEditEngine->GetLineXPosStartEnd( pParaPortion, &rLine );
-            if ( ( aDocPos.X() >= aLineXPosStartEnd.Min() - nBorder ) &&
-                 ( aDocPos.X() <= aLineXPosStartEnd.Max() + nBorder ) )
-            {
-                 bTextPos = true;
-            }
-        }
-    }
-    return bTextPos;
+        return pImpEditEngine->IsTextPos(aDocPos, nBorder);
+    return false;
 }
 
 void EditEngine::SetEditTextObjectPool( SfxItemPool* pPool )
@@ -2274,8 +2271,8 @@ bool EditEngine::ShouldCreateBigTextObject() const
     sal_Int32 nParas = pImpEditEngine->GetEditDoc().Count();
     for ( sal_Int32 nPara = 0; nPara < nParas; nPara++  )
     {
-        ParaPortion* pParaPortion = pImpEditEngine->GetParaPortions()[nPara];
-        nTextPortions = nTextPortions + pParaPortion->GetTextPortions().Count();
+        ParaPortion& rParaPortion = pImpEditEngine->GetParaPortions()[nPara];
+        nTextPortions = nTextPortions + rParaPortion.GetTextPortions().Count();
     }
     return nTextPortions >= pImpEditEngine->GetBigTextObjectStart();
 }
@@ -2432,11 +2429,11 @@ ParagraphInfos EditEngine::GetParagraphInfos( sal_Int32 nPara )
     aInfos.bValid = pImpEditEngine->IsFormatted();
     if ( pImpEditEngine->IsFormatted() )
     {
-        const ParaPortion* pParaPortion = pImpEditEngine->GetParaPortions()[nPara];
-        const EditLine* pLine = (pParaPortion && pParaPortion->GetLines().Count()) ?
-                &pParaPortion->GetLines()[0] : nullptr;
-        DBG_ASSERT( pParaPortion && pLine, "GetParagraphInfos - Paragraph out of range" );
-        if ( pParaPortion && pLine )
+        const ParaPortion& rParaPortion = pImpEditEngine->GetParaPortions()[nPara];
+        const EditLine* pLine = rParaPortion.GetLines().Count() ?
+                &rParaPortion.GetLines()[0] : nullptr;
+        DBG_ASSERT( pLine, "GetParagraphInfos - Paragraph out of range" );
+        if ( pLine )
         {
             aInfos.nFirstLineHeight = pLine->GetHeight();
             aInfos.nFirstLineTextHeight = pLine->GetTxtHeight();
@@ -2472,7 +2469,7 @@ void EditEngine::DrawingTab( const Point& /*rStartPos*/, tools::Long /*nWidth*/,
 {
 }
 
-void EditEngine::PaintingFirstLine( sal_Int32, const Point&, tools::Long, const Point&, Degree10, OutputDevice* )
+void EditEngine::PaintingFirstLine(sal_Int32, const Point&, const Point&, Degree10, OutputDevice&)
 {
 }
 
@@ -2588,16 +2585,37 @@ void EditEngine::FieldClicked( const SvxFieldItem& )
 
 // ======================     Static Methods     =======================
 
-SfxItemPool* EditEngine::CreatePool()
+rtl::Reference<SfxItemPool> EditEngine::CreatePool()
 {
-    SfxItemPool* pPool = new EditEngineItemPool();
-    return pPool;
+    return new EditEngineItemPool();
 }
 
+
+/** If we let the libc runtime clean us up, we trigger a crash */
+namespace
+{
+class TerminateListener : public ::cppu::WeakImplHelper< css::frame::XTerminateListener >
+{
+    void SAL_CALL queryTermination( const lang::EventObject& ) override
+    {}
+    void SAL_CALL notifyTermination( const lang::EventObject& ) override
+    {
+        pGlobalPool.clear();
+    }
+    virtual void SAL_CALL disposing( const ::css::lang::EventObject& ) override
+    {}
+};
+};
+
 SfxItemPool& EditEngine::GetGlobalItemPool()
 {
     if ( !pGlobalPool )
+    {
         pGlobalPool = CreatePool();
+        uno::Reference< frame::XDesktop2 > xDesktop = frame::Desktop::create(comphelper::getProcessComponentContext());
+        uno::Reference< frame::XTerminateListener > xListener( new TerminateListener );
+        xDesktop->addTerminateListener( xListener );
+    }
     return *pGlobalPool;
 }
 
@@ -2618,7 +2636,7 @@ void EditEngine::SetFontInfoInItemSet( SfxItemSet& rSet, const SvxFont& rFont )
     rSet.Put( SvxEscapementItem( rFont.GetEscapement(), rFont.GetPropr(), EE_CHAR_ESCAPEMENT )  );
     rSet.Put( SvxWeightItem( rFont.GetWeight(), EE_CHAR_WEIGHT )  );
     rSet.Put( SvxColorItem( rFont.GetColor(), EE_CHAR_COLOR )  );
-    rSet.Put( SvxBackgroundColorItem( rFont.GetFillColor(), EE_CHAR_BKGCOLOR )  );
+    rSet.Put( SvxColorItem( rFont.GetFillColor(), EE_CHAR_BKGCOLOR )  );
     rSet.Put( SvxUnderlineItem( rFont.GetUnderline(), EE_CHAR_UNDERLINE )  );
     rSet.Put( SvxOverlineItem( rFont.GetOverline(), EE_CHAR_OVERLINE )  );
     rSet.Put( SvxCrossedOutItem( rFont.GetStrikeout(), EE_CHAR_STRIKEOUT )  );
