@@ -155,9 +155,8 @@ void ImpEditEngine::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                 UpdateParagraphsWithStyleSheet( pStyle );
             }
         }
-        else if ( dynamic_cast< const SfxStyleSheet* >(&rBC) !=  nullptr )
+        else if ( auto pStyle = dynamic_cast< SfxStyleSheet* >(&rBC) )
         {
-            SfxStyleSheet* pStyle = static_cast<SfxStyleSheet*>(&rBC);
             SfxHintId nId = rHint.GetId();
             if ( nId == SfxHintId::Dying )
             {
@@ -403,7 +402,7 @@ SfxItemSet ImpEditEngine::GetAttribs( sal_Int32 nPara, sal_Int32 nStart, sal_Int
     DBG_ASSERT( pNode, "GetAttribs - unknown paragraph!" );
     DBG_ASSERT( nStart <= nEnd, "getAttribs: Start > End not supported!" );
 
-    SfxItemSet aAttribs( const_cast<ImpEditEngine*>(this)->GetEmptyItemSet() );
+    SfxItemSet aAttribs(GetEmptyItemSet());
 
     if ( pNode )
     {
@@ -521,7 +520,7 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, SetA
         DBG_ASSERT( GetParaPortions().SafeGetObject( nNode ), "Portion not found: SetAttribs" );
 
         ContentNode* pNode = aEditDoc.GetObject( nNode );
-        ParaPortion* pPortion = GetParaPortions()[nNode];
+        ParaPortion& rPortion = GetParaPortions()[nNode];
 
         const sal_Int32 nStartPos = nNode==nStartNode ? aSel.Min().GetIndex() : 0;
         const sal_Int32 nEndPos = nNode==nEndNode ? aSel.Max().GetIndex() : pNode->Len(); // can also be == nStart!
@@ -563,14 +562,14 @@ void ImpEditEngine::SetAttribs( EditSelection aSel, const SfxItemSet& rSet, SetA
 
         if ( bParaAttribFound )
         {
-            ParaAttribsChanged( pPortion->GetNode() );
+            ParaAttribsChanged( rPortion.GetNode() );
         }
         else if ( bCharAttribFound )
         {
             bFormatted = false;
             if ( !pNode->Len() || ( nStartPos != nEndPos  ) )
             {
-                pPortion->MarkSelectionInvalid( nStartPos );
+                rPortion.MarkSelectionInvalid( nStartPos );
                 if ( bCheckLanguage )
                     pNode->GetWrongList()->SetInvalidRange(nStartPos, nEndPos);
             }
@@ -601,7 +600,7 @@ void ImpEditEngine::RemoveCharAttribs( EditSelection aSel, EERemoveParaAttribsMo
     for ( sal_Int32 nNode = nStartNode; nNode <= nEndNode; nNode++ )
     {
         ContentNode* pNode = aEditDoc.GetObject( nNode );
-        ParaPortion* pPortion = GetParaPortions()[nNode];
+        ParaPortion& rPortion = GetParaPortions()[nNode];
 
         DBG_ASSERT( aEditDoc.GetObject( nNode ), "Node not found: SetAttribs" );
         DBG_ASSERT( GetParaPortions().SafeGetObject( nNode ), "Portion not found: SetAttribs" );
@@ -635,7 +634,7 @@ void ImpEditEngine::RemoveCharAttribs( EditSelection aSel, EERemoveParaAttribsMo
         if ( bChanged && !bRemoveParaAttribs )
         {
             bFormatted = false;
-            pPortion->MarkSelectionInvalid( nStartPos );
+            rPortion.MarkSelectionInvalid( nStartPos );
         }
     }
 }
@@ -745,10 +744,7 @@ void ImpEditEngine::GetCharAttribs( sal_Int32 nPara, std::vector<EECharAttrib>&
     for (const auto & i : rAttrs)
     {
         const EditCharAttrib& rAttr = *i;
-        EECharAttrib aEEAttr;
-        aEEAttr.pAttr = rAttr.GetItem();
-        aEEAttr.nStart = rAttr.GetStart();
-        aEEAttr.nEnd = rAttr.GetEnd();
+        EECharAttrib aEEAttr(rAttr.GetStart(), rAttr.GetEnd(), rAttr.GetItem());
         rLst.push_back(aEEAttr);
     }
 }
