@@ -43,6 +43,7 @@
 #include <editeng/editids.hrc>
 #include <editeng/numdef.hxx>
 #include <o3tl/enumarray.hxx>
+#include <o3tl/temporary.hxx>
 #include <memory>
 
 using ::com::sun::star::util::XCloneable;
@@ -95,7 +96,7 @@ SvxUnoNumberingRules::SvxUnoNumberingRules(const SvxNumRule& rRule)
 {
 }
 
-SvxUnoNumberingRules::~SvxUnoNumberingRules() throw()
+SvxUnoNumberingRules::~SvxUnoNumberingRules() noexcept
 {
 }
 
@@ -324,8 +325,7 @@ void SvxUnoNumberingRules::setNumberingRuleByIndex(const Sequence<beans::Propert
             {
                 if(!aStr.isEmpty())
                 {
-                    sal_Int32 nIndexUtf16 = 0;
-                    aFmt.SetBulletChar(aStr.iterateCodePoints(&nIndexUtf16));
+                    aFmt.SetBulletChar(aStr.iterateCodePoints(&o3tl::temporary(sal_Int32(0))));
                 }
                 else
                 {
@@ -427,10 +427,10 @@ void SvxUnoNumberingRules::setNumberingRuleByIndex(const Sequence<beans::Propert
         }
         else if ( rPropName == UNO_NAME_NRULE_BULLET_COLOR )
         {
-            sal_Int32 nColor = 0;
-            if( aVal >>= nColor )
+            Color aColor;
+            if( aVal >>= aColor )
             {
-                aFmt.SetBulletColor( static_cast<Color>(nColor) );
+                aFmt.SetBulletColor( aColor );
                 continue;
             }
         }
@@ -481,18 +481,9 @@ const SvxNumRule& SvxGetNumRule( Reference< XIndexReplace > const & xRule )
     return pRule->getNumRule();
 }
 
-css::uno::Reference< css::container::XIndexReplace > SvxCreateNumRule(const SvxNumRule* pRule)
+css::uno::Reference< css::container::XIndexReplace > SvxCreateNumRule(const SvxNumRule& rRule)
 {
-    DBG_ASSERT( pRule, "No default SvxNumRule!" );
-    if( pRule )
-    {
-        return new SvxUnoNumberingRules( *pRule );
-    }
-    else
-    {
-        SvxNumRule aDefaultRule( SvxNumRuleFlags::BULLET_REL_SIZE | SvxNumRuleFlags::BULLET_COLOR, SVX_MAX_NUM, false);
-        return new SvxUnoNumberingRules( aDefaultRule );
-    }
+    return new SvxUnoNumberingRules( rRule );
 }
 
 namespace {
@@ -546,7 +537,7 @@ sal_Int16 SvxUnoNumberingRules::Compare( const Any& Any1, const Any& Any2 )
     return -1;
 }
 
-Reference< XAnyCompare > SvxCreateNumRuleCompare() throw()
+Reference< XAnyCompare > SvxCreateNumRuleCompare() noexcept
 {
     return new SvxUnoNumberingRulesCompare;
 }
@@ -554,7 +545,7 @@ Reference< XAnyCompare > SvxCreateNumRuleCompare() throw()
 css::uno::Reference< css::container::XIndexReplace > SvxCreateNumRule()
 {
     SvxNumRule aTempRule( SvxNumRuleFlags::NONE, 10, false );
-    return SvxCreateNumRule( &aTempRule );
+    return SvxCreateNumRule( aTempRule );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
