@@ -17,13 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "modulepcr.hxx"
 #include "pcrcommon.hxx"
-#include "pcrservices.hxx"
 #include "inspectormodelbase.hxx"
 
 #include <com/sun/star/ucb/AlreadyInitializedException.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
 
 
 namespace pcr
@@ -64,14 +63,6 @@ namespace pcr
         virtual OUString SAL_CALL getImplementationName(  ) override;
         virtual Sequence< OUString > SAL_CALL getSupportedServiceNames(  ) override;
 
-        // XServiceInfo - static versions
-        /// @throws RuntimeException
-        static OUString getImplementationName_static(  );
-        /// @throws RuntimeException
-        static Sequence< OUString > getSupportedServiceNames_static(  );
-        static Reference< XInterface >
-                        Create(const Reference< XComponentContext >&);
-
     protected:
         void    createDefault();
         void    createWithHandlerFactories( const Sequence< Any >& _rFactories );
@@ -135,9 +126,9 @@ namespace pcr
             return;
         }
 
-        sal_Int32 nMinHelpTextLines( 0 ), nMaxHelpTextLines( 0 );
         if ( arguments.size() == 3 )
         {   // constructor: "createWithHandlerFactoriesAndHelpSection( any[], long, long )"
+            sal_Int32 nMinHelpTextLines( 0 ), nMaxHelpTextLines( 0 );
             impl_verifyArgument_throw( arguments[1] >>= nMinHelpTextLines, 2 );
             impl_verifyArgument_throw( arguments[2] >>= nMaxHelpTextLines, 3 );
             createWithHandlerFactoriesAndHelpSection( factories, nMinHelpTextLines, nMaxHelpTextLines );
@@ -150,34 +141,16 @@ namespace pcr
 
     OUString SAL_CALL ObjectInspectorModel::getImplementationName(  )
     {
-        return getImplementationName_static();
+        return "org.openoffice.comp.extensions.ObjectInspectorModel";
     }
 
 
     Sequence< OUString > SAL_CALL ObjectInspectorModel::getSupportedServiceNames(  )
-    {
-        return getSupportedServiceNames_static();
-    }
-
-
-    OUString ObjectInspectorModel::getImplementationName_static(  )
-    {
-        return "org.openoffice.comp.extensions.ObjectInspectorModel";
-    }
-
-
-    Sequence< OUString > ObjectInspectorModel::getSupportedServiceNames_static(  )
     {
         return { "com.sun.star.inspection.ObjectInspectorModel" };
     }
 
 
-    Reference< XInterface > ObjectInspectorModel::Create(const Reference< XComponentContext >& /* _rxContext */ )
-    {
-        return *( new ObjectInspectorModel() );
-    }
-
-
     void ObjectInspectorModel::createDefault()
     {
         m_aFactories.realloc( 1 );
@@ -213,10 +186,11 @@ namespace pcr
 
 } // namespace pcr
 
-
-extern "C" void createRegistryInfo_ObjectInspectorModel()
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface*
+extensions_propctrlr_ObjectInspectorModel_get_implementation(
+    css::uno::XComponentContext* , css::uno::Sequence<css::uno::Any> const&)
 {
-    ::pcr::OAutoRegistration< ::pcr::ObjectInspectorModel > aObjectInspectorModelRegistration;
+    return cppu::acquire(new pcr::ObjectInspectorModel());
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
