@@ -38,7 +38,7 @@
 #include <com/sun/star/util/VetoException.hpp>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
-#include <toolkit/awt/vclxwindow.hxx>
+#include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/weld.hxx>
 #include <vcl/weldutils.hxx>
@@ -344,8 +344,7 @@ namespace pcr
         }
         else
         {
-            VCLXWindow* pContainerWindow = comphelper::getUnoTunnelImplementation<VCLXWindow>(xContainerWindow);
-            VclPtr<vcl::Window> pParentWin = pContainerWindow ? pContainerWindow->GetWindow() : VclPtr<vcl::Window>();
+            VclPtr<vcl::Window> pParentWin = VCLUnoHelper::GetWindow(xContainerWindow);
             if (!pParentWin)
                 throw RuntimeException("The frame is invalid. Unable to extract the container window.",*this);
             xBuilder.reset(Application::CreateInterimBuilder(pParentWin, sUIFile, true));
@@ -693,7 +692,7 @@ namespace pcr
                 bool bMultiLineTextField = ControlType == PropertyControlType::MultiLineTextField;
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/multiline.ui", m_xContext));
                 auto pContainer = xBuilder->weld_container("multiline");
-                auto pControl = new OMultilineEditControl(std::move(pContainer), std::move(xBuilder),
+                rtl::Reference<OMultilineEditControl> pControl = new OMultilineEditControl(std::move(pContainer), std::move(xBuilder),
                                                           bMultiLineTextField ? eMultiLineText : eStringList, bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
@@ -704,7 +703,7 @@ namespace pcr
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/listbox.ui", m_xContext));
                 auto pComboBox = xBuilder->weld_combo_box("listbox");
-                auto pControl = new OListboxControl(std::move(pComboBox), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<OListboxControl> pControl = new OListboxControl(std::move(pComboBox), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -714,7 +713,7 @@ namespace pcr
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/combobox.ui", m_xContext));
                 auto pComboBox = xBuilder->weld_combo_box("combobox");
-                auto pControl = new OComboboxControl(std::move(pComboBox), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<OComboboxControl> pControl = new OComboboxControl(std::move(pComboBox), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -726,7 +725,7 @@ namespace pcr
                 bool bCharacterField = ControlType == PropertyControlType::CharacterField;
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/textfield.ui", m_xContext));
                 auto pEntry = xBuilder->weld_entry("textfield");
-                auto pControl = new OEditControl(std::move(pEntry), std::move(xBuilder), bCharacterField, bCreateReadOnly);
+                rtl::Reference<OEditControl> pControl = new OEditControl(std::move(pEntry), std::move(xBuilder), bCharacterField, bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -736,7 +735,7 @@ namespace pcr
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/numericfield.ui", m_xContext));
                 auto pSpinButton = xBuilder->weld_metric_spin_button("numericfield", FieldUnit::NONE);
-                auto pControl = new ONumericControl(std::move(pSpinButton), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<ONumericControl> pControl = new ONumericControl(std::move(pSpinButton), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -746,7 +745,7 @@ namespace pcr
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/datetimefield.ui", m_xContext));
                 auto pContainer = xBuilder->weld_container("datetimefield");
-                auto pControl = new ODateTimeControl(std::move(pContainer), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<ODateTimeControl> pControl = new ODateTimeControl(std::move(pContainer), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -755,8 +754,8 @@ namespace pcr
             case PropertyControlType::DateField:
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/datefield.ui", m_xContext));
-                auto pContainer = xBuilder->weld_container("datefield");
-                auto pControl = new ODateControl(std::move(pContainer), std::move(xBuilder), bCreateReadOnly);
+                auto pMenuButton = xBuilder->weld_menu_button("datefield");
+                rtl::Reference<ODateControl> pControl = new ODateControl(std::make_unique<SvtCalendarBox>(std::move(pMenuButton)), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -766,7 +765,7 @@ namespace pcr
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/timefield.ui", m_xContext));
                 auto pTimeSpinButton = xBuilder->weld_formatted_spin_button("timefield");
-                auto pControl = new OTimeControl(std::move(pTimeSpinButton), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<OTimeControl> pControl = new OTimeControl(std::move(pTimeSpinButton), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -774,10 +773,10 @@ namespace pcr
 
             case PropertyControlType::ColorListBox:
             {
-                weld::Window* pTopLevel = PropertyHandlerHelper::getDialogParentFrame(m_xContext);
+                auto lambda = [this]{ return PropertyHandlerHelper::getDialogParentFrame(m_xContext); };
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/colorlistbox.ui", m_xContext));
                 auto pMenuButton = xBuilder->weld_menu_button("colorlistbox");
-                auto pControl = new OColorControl(std::make_unique<ColorListBox>(std::move(pMenuButton), pTopLevel), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<OColorControl> pControl = new OColorControl(std::make_unique<ColorListBox>(std::move(pMenuButton), lambda), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -787,7 +786,7 @@ namespace pcr
             {
                 std::unique_ptr<weld::Builder> xBuilder(PropertyHandlerHelper::makeBuilder("modules/spropctrlr/ui/hyperlinkfield.ui", m_xContext));
                 auto pContainer = xBuilder->weld_container("hyperlinkfield");
-                auto pControl = new OHyperlinkControl(std::move(pContainer), std::move(xBuilder), bCreateReadOnly);
+                rtl::Reference<OHyperlinkControl> pControl = new OHyperlinkControl(std::move(pContainer), std::move(xBuilder), bCreateReadOnly);
                 pControl->SetModifyHandler();
                 xControl = pControl;
                 break;
@@ -1105,6 +1104,16 @@ namespace pcr
             }
 
             _rDescriptor.bReadOnly = impl_isReadOnlyModel_throw();
+
+            // for ui-testing try and distinguish different instances of the controls
+            auto xWindow = _rDescriptor.Control->getControlWindow();
+            if (weld::TransportAsXWindow* pTunnel = dynamic_cast<weld::TransportAsXWindow*>(xWindow.get()))
+            {
+                weld::Widget* m_pControlWindow = pTunnel->getWidget();
+                if (m_pControlWindow)
+                    m_pControlWindow->set_buildable_name(m_pControlWindow->get_buildable_name() + "-" + _rDescriptor.DisplayName.toUtf8());
+            }
+
         }
         catch( const Exception& )
         {
