@@ -11,6 +11,8 @@
 #include <algorithm>
 #include <cstring>
 #include <map>
+#include <optional>
+#include <string_view>
 #include <utility>
 #include <vector>
 #include <libxml/parser.h>
@@ -147,7 +149,7 @@ namespace XSLT
             streamName = ensureStringValue(streamName, ctxt);
 
             oh->insertByName(OStringToOUString(reinterpret_cast<char*>(streamName->stringval), RTL_TEXTENCODING_UTF8),
-                             OString(reinterpret_cast<char*>(value->stringval)));
+                             std::string_view(reinterpret_cast<char*>(value->stringval)));
             valuePush(ctxt, xmlXPathNewCString(""));
         }
 
@@ -287,7 +289,7 @@ namespace XSLT
         xsltSetGenericDebugFunc(stderr, NULL);
         xsltDebugDumpExtensions(NULL);
 #endif
-        std::unique_ptr<OleHandler> oh(new OleHandler(m_transformer->getComponentContext()));
+        std::optional<OleHandler> oh(std::in_place, m_transformer->getComponentContext());
         if (styleSheet)
         {
             xsltTransformContextPtr tcontext = xsltNewTransformContext(
