@@ -227,7 +227,7 @@ public:
     DECL_LINK(EditedEntryHdl, const IterString&, bool);
     DECL_LINK(KeyInputHdl, const KeyEvent&, bool);
 
-    void            ExecuteContextMenuAction(const OString& rSelectedPopentry);
+    void            ExecuteContextMenuAction(std::string_view rSelectedPopentry);
 };
 
 }
@@ -301,13 +301,13 @@ public:
     void                    CreateDisplayText_Impl();
     void                    SortFolderContent_Impl();
 
-    void                    EntryRemoved( const OUString& rURL );
+    void                    EntryRemoved( std::u16string_view rURL );
     void                    EntryRenamed( OUString& rURL,
                                           const OUString& rName );
     const SortingData_Impl& FolderInserted( const OUString& rURL,
                                             const OUString& rTitle );
 
-    int                     GetEntryPos( const OUString& rURL );
+    int                     GetEntryPos( std::u16string_view rURL );
 
     void                    SetViewMode( FileViewMode eMode );
 
@@ -576,7 +576,7 @@ IMPL_LINK(ViewTabListBox_Impl, CommandHdl, const CommandEvent&, rCEvt, bool)
     return true;
 }
 
-void ViewTabListBox_Impl::ExecuteContextMenuAction(const OString& rSelectedPopupEntry)
+void ViewTabListBox_Impl::ExecuteContextMenuAction(std::string_view rSelectedPopupEntry)
 {
     if (rSelectedPopupEntry == "delete")
         DeleteEntries();
@@ -1218,13 +1218,13 @@ FileViewResult SvtFileView_Impl::GetFolderContent_Impl(
     m_aCurrentAsyncActionHandler = Link<void*,void>();
 
     // minimum time to wait
-    std::unique_ptr< TimeValue > pTimeout( new TimeValue );
+    TimeValue aTimeout;
     sal_Int32 nMinTimeout = pAsyncDescriptor->nMinTimeout;
     OSL_ENSURE( nMinTimeout > 0, "SvtFileView_Impl::GetFolderContent_Impl: invalid minimum timeout!" );
     if ( nMinTimeout <= 0 )
         nMinTimeout = sal_Int32( 1000 );
-    pTimeout->Seconds = nMinTimeout / 1000;
-    pTimeout->Nanosec = ( nMinTimeout % 1000 ) * 1000000;
+    aTimeout.Seconds = nMinTimeout / 1000;
+    aTimeout.Nanosec = ( nMinTimeout % 1000 ) * 1000000;
 
     m_xContentEnumerator->enumerateFolderContent( _rFolder, this );
 
@@ -1240,7 +1240,7 @@ FileViewResult SvtFileView_Impl::GetFolderContent_Impl(
         SolarMutexReleaser aSolarRelease;
 
         // now wait. Note that if we didn't get a pAsyncDescriptor, then this is an infinite wait.
-        eResult = m_aAsyncActionFinished.wait( pTimeout.get() );
+        eResult = m_aAsyncActionFinished.wait( &aTimeout );
     }
 
     ::osl::MutexGuard aGuard2( maMutex );
@@ -1668,7 +1668,7 @@ void SvtFileView_Impl::SortFolderContent_Impl()
 }
 
 
-void SvtFileView_Impl::EntryRemoved( const OUString& rURL )
+void SvtFileView_Impl::EntryRemoved( std::u16string_view rURL )
 {
     ::osl::MutexGuard aGuard( maMutex );
 
@@ -1727,7 +1727,7 @@ const SortingData_Impl& SvtFileView_Impl::FolderInserted( const OUString& rURL,
     return *maContent.back();
 }
 
-int SvtFileView_Impl::GetEntryPos(const OUString& rURL)
+int SvtFileView_Impl::GetEntryPos(std::u16string_view rURL)
 {
     ::osl::MutexGuard aGuard( maMutex );
 
