@@ -182,7 +182,6 @@ void DispatchTest::dispatchCommand(const uno::Reference<lang::XComponent>& xComp
 CPPUNIT_TEST_FIXTURE(DispatchTest, testInterception)
 {
     mxComponent = loadFromDesktop("private:factory/swriter", "com.sun.star.text.TextDocument");
-    CPPUNIT_ASSERT(mxComponent.is());
     uno::Reference<frame::XModel> xModel(mxComponent, uno::UNO_QUERY);
     CPPUNIT_ASSERT(xModel.is());
 
@@ -191,8 +190,7 @@ CPPUNIT_TEST_FIXTURE(DispatchTest, testInterception)
     CPPUNIT_ASSERT(xRegistration.is());
 
     rtl::Reference<MyInterceptor> pInterceptor(new MyInterceptor());
-    xRegistration->registerDispatchProviderInterceptor(
-        uno::Reference<frame::XDispatchProviderInterceptor>(pInterceptor.get()));
+    xRegistration->registerDispatchProviderInterceptor(pInterceptor);
 
     dispatchCommand(mxComponent, ".uno:Bold", {});
     CPPUNIT_ASSERT_EQUAL(1, pInterceptor->getExpected());
