@@ -28,10 +28,9 @@
 
 #include <com/sun/star/document/LockedDocumentRequest.hpp>
 
+#include <vcl/errcode.hxx>
 #include <vcl/svapp.hxx>
 
-#include <vcl/errinf.hxx>
-
 namespace framework{
 
 QuietInteraction::QuietInteraction()
