@@ -201,15 +201,28 @@ Calendar_hanja::getDisplayName( sal_Int16 displayIndex, sal_Int16 idx, sal_Int16
         return Calendar_gregorian::getDisplayName( displayIndex, idx, nameType );
 }
 
-void SAL_CALL
-Calendar_hanja::loadCalendar( const OUString& /*uniqueID*/, const css::lang::Locale& rLocale )
+
+Calendar_hanja_yoil::Calendar_hanja_yoil()
 {
-    // Since this class could be called by service name 'hanja_yoil', we have to
-    // rename uniqueID to get right calendar defined in locale data.
-    Calendar_gregorian::loadCalendar("hanja", rLocale);
+    cCalendar = "com.sun.star.i18n.Calendar_Calendar_hanja_yoil";
 }
 
-static const Era gengou_eraArray[] = {
+OUString SAL_CALL
+Calendar_hanja_yoil::getDisplayName( sal_Int16 displayIndex, sal_Int16 idx, sal_Int16 nameType )
+{
+    if ( displayIndex == CalendarDisplayIndex::AM_PM ) {
+        // Am/Pm string for Korean Hanja calendar will refer to Japanese locale
+        css::lang::Locale jaLocale("ja", OUString(), OUString());
+        if (idx == 0) return LocaleDataImpl::get()->getLocaleItem(jaLocale).timeAM;
+        else if (idx == 1) return LocaleDataImpl::get()->getLocaleItem(jaLocale).timePM;
+        else throw ERROR;
+    }
+    else
+        return Calendar_gregorian::getDisplayName( displayIndex, idx, nameType );
+}
+
+
+const Era gengou_eraArray[] = {
     {1868,  1,  1, 0},  // Meiji
     {1912,  7, 30, 0},  // Taisho
     {1926, 12, 25, 0},  // Showa
@@ -222,7 +235,7 @@ Calendar_gengou::Calendar_gengou() : Calendar_gregorian(gengou_eraArray)
     cCalendar = "com.sun.star.i18n.Calendar_gengou";
 }
 
-static const Era ROC_eraArray[] = {
+const Era ROC_eraArray[] = {
     {1912, 1, 1, kDisplayEraForcedLongYear},    // #i116701#
     {0, 0, 0, 0}
 };
@@ -235,7 +248,7 @@ Calendar_ROC::Calendar_ROC() : Calendar_gregorian(ROC_eraArray)
 * The start year of the Korean traditional calendar (Dan-gi) is the inaugural
 * year of Dan-gun (BC 2333).
 */
-static const Era dangi_eraArray[] = {
+const Era dangi_eraArray[] = {
     {-2332, 1, 1, 0},
     {0, 0, 0, 0}
 };
@@ -244,7 +257,7 @@ Calendar_dangi::Calendar_dangi() : Calendar_gregorian(dangi_eraArray)
     cCalendar = "com.sun.star.i18n.Calendar_dangi";
 }
 
-static const Era buddhist_eraArray[] = {
+const Era buddhist_eraArray[] = {
     {-542, 1, 1, 0},
     {0, 0, 0, 0}
 };
@@ -347,13 +360,7 @@ Calendar_gregorian::setLocalDateTime( double fTimeInDays )
             "Calendar_gregorian::setLocalDateTime: " << std::fixed << fM << " rounded to " << fR);
     int32_t nZoneOffset, nDSTOffset;
     UErrorCode status = U_ZERO_ERROR;
-    body->getTimeZone().getOffset( fR,
-#if U_ICU_VERSION_MAJOR_NUM >= 68
-    true,
-#else
-    TRUE,
-#endif
-    nZoneOffset, nDSTOffset, status );
+    body->getTimeZone().getOffset( fR, true, nZoneOffset, nDSTOffset, status );
 
     if ( !U_SUCCESS(status) ) throw ERROR;
     status = U_ZERO_ERROR;
