@@ -18,6 +18,7 @@
  */
 
 #include <memory>
+#include <string_view>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/container/XIndexAccess.hpp>
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
@@ -80,6 +81,8 @@ const struct {
     { "en_ZM",  lcl_DATA_EN },
     { "en_LK",  lcl_DATA_EN },
     { "en_NG",  lcl_DATA_EN },
+    { "en_KE",  lcl_DATA_EN },
+    { "en_DK",  lcl_DATA_EN },
 
     { "es_ES",  lcl_DATA_ES },
     { "es_AR",  lcl_DATA_ES },
@@ -217,7 +220,7 @@ const struct {
     { "pa_IN",  lcl_DATA_OTHERS },
     { "bn_IN",  lcl_DATA_OTHERS },
     { "or_IN",  lcl_DATA_OTHERS },
-    { "en_IN",  lcl_DATA_OTHERS },
+    { "en_IN",  lcl_DATA_OTHERS },  // keep in OTHERS for IN
     { "ml_IN",  lcl_DATA_OTHERS },
     { "bn_BD",  lcl_DATA_OTHERS },
     { "th_TH",  lcl_DATA_OTHERS },
@@ -226,7 +229,7 @@ const struct {
     { "hu_HU",  lcl_DATA_OTHERS },
     { "id_ID",  lcl_DATA_OTHERS },
     { "ms_MY",  lcl_DATA_OTHERS },
-    { "en_MY",  lcl_DATA_OTHERS },
+    { "en_MY",  lcl_DATA_OTHERS },  // needs to be in OTHERS instead of EN because currency inherited from ms_MY
     { "ia",     lcl_DATA_OTHERS },
     { "mn_Cyrl_MN",  lcl_DATA_OTHERS },
     { "az_AZ",  lcl_DATA_OTHERS },
@@ -330,8 +333,7 @@ const struct {
     { "ilo_PH", lcl_DATA_OTHERS },
     { "ha_Latn_NG",  lcl_DATA_OTHERS },
     { "min_ID", lcl_DATA_OTHERS },
-    { "sun_ID", lcl_DATA_OTHERS },
-    { "en_KE",  lcl_DATA_OTHERS }
+    { "sun_ID", lcl_DATA_OTHERS }
 };
 
 #else
@@ -702,7 +704,7 @@ Sequence< CalendarItem2 > LocaleDataImpl::getCalendarItems(
         const Locale & rLocale, const Sequence< Calendar2 > & calendarsSeq )
 {
     Sequence< CalendarItem2 > aItems;
-    if ( OUString( allCalendars[rnOffset] ) == "ref" )
+    if ( allCalendars[rnOffset] == std::u16string_view(u"ref") )
     {
         aItems = getCalendarItemByName( OUString( allCalendars[rnOffset+1]), rLocale, calendarsSeq, nWhichItem);
         rnOffset += 2;
@@ -719,10 +721,9 @@ Sequence< CalendarItem2 > LocaleDataImpl::getCalendarItems(
             case REF_PMONTHS:
                 for (CalendarItem2& rItem : aItems)
                 {
-                    CalendarItem2 item{ OUString(allCalendars[rnOffset]),
+                    rItem = CalendarItem2{ OUString(allCalendars[rnOffset]),
                             OUString(allCalendars[rnOffset+1]),
                             OUString(allCalendars[rnOffset+2]), OUString(allCalendars[rnOffset+3])};
-                    rItem = item;
                     rnOffset += 4;
                 }
                 break;
@@ -730,10 +731,9 @@ Sequence< CalendarItem2 > LocaleDataImpl::getCalendarItems(
                 // Absent narrow name.
                 for (CalendarItem2& rItem : aItems)
                 {
-                    CalendarItem2 item{ OUString(allCalendars[rnOffset]),
+                    rItem = CalendarItem2{ OUString(allCalendars[rnOffset]),
                             OUString(allCalendars[rnOffset+1]),
                             OUString(allCalendars[rnOffset+2]), OUString()};
-                    rItem = item;
                     rnOffset += 3;
                 }
                 break;
@@ -784,8 +784,7 @@ LocaleDataImpl::getAllCalendars2( const Locale& rLocale )
         return calendarsSeq;
     }
     else {
-        Sequence< Calendar2 > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -828,8 +827,7 @@ LocaleDataImpl::getAllCurrencies2( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< Currency2 > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -910,8 +908,7 @@ LocaleDataImpl::getDateAcceptancePatterns( const Locale& rLocale )
     }
     else
     {
-        Sequence< OUString > seq(0);
-        return seq;
+        return {};
     }
 }
 
@@ -922,7 +919,7 @@ LocaleDataImpl::getDateAcceptancePatterns( const Locale& rLocale )
 #define COLLATOR_ELEMENTS       3
 
 OUString
-LocaleDataImpl::getCollatorRuleByAlgorithm( const Locale& rLocale, const OUString& algorithm )
+LocaleDataImpl::getCollatorRuleByAlgorithm( const Locale& rLocale, std::u16string_view algorithm )
 {
     MyFunc_Type func = reinterpret_cast<MyFunc_Type>(getFunctionSymbol( rLocale, "getCollatorImplementation" ));
     if ( func ) {
@@ -954,8 +951,7 @@ LocaleDataImpl::getCollatorImplementations( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< Implementation > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -974,8 +970,7 @@ LocaleDataImpl::getCollationOptions( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -994,8 +989,7 @@ LocaleDataImpl::getSearchOptions( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -1023,8 +1017,7 @@ LocaleDataImpl::getIndexAlgorithm( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -1059,7 +1052,7 @@ LocaleDataImpl::hasPhonetic( const Locale& rLocale )
 }
 
 sal_Unicode **
-LocaleDataImpl::getIndexArrayForAlgorithm(const Locale& rLocale, const OUString& algorithm)
+LocaleDataImpl::getIndexArrayForAlgorithm(const Locale& rLocale, std::u16string_view algorithm)
 {
     sal_Int16 indexCount = 0;
     sal_Unicode **indexArray = getIndexArray(rLocale, indexCount);
@@ -1073,21 +1066,21 @@ LocaleDataImpl::getIndexArrayForAlgorithm(const Locale& rLocale, const OUString&
 }
 
 bool
-LocaleDataImpl::isPhonetic( const Locale& rLocale, const OUString& algorithm )
+LocaleDataImpl::isPhonetic( const Locale& rLocale, std::u16string_view algorithm )
 {
     sal_Unicode **indexArray = getIndexArrayForAlgorithm(rLocale, algorithm);
     return indexArray && indexArray[4][0];
 }
 
 OUString
-LocaleDataImpl::getIndexKeysByAlgorithm( const Locale& rLocale, const OUString& algorithm )
+LocaleDataImpl::getIndexKeysByAlgorithm( const Locale& rLocale, std::u16string_view algorithm )
 {
     sal_Unicode **indexArray = getIndexArrayForAlgorithm(rLocale, algorithm);
     return indexArray ? (OUString::Concat(u"0-9") + indexArray[2]) : OUString();
 }
 
 OUString
-LocaleDataImpl::getIndexModuleByAlgorithm( const Locale& rLocale, const OUString& algorithm )
+LocaleDataImpl::getIndexModuleByAlgorithm( const Locale& rLocale, std::u16string_view algorithm )
 {
     sal_Unicode **indexArray = getIndexArrayForAlgorithm(rLocale, algorithm);
     return indexArray ? OUString(indexArray[1]) : OUString();
@@ -1108,8 +1101,7 @@ LocaleDataImpl::getUnicodeScripts( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< UnicodeScript > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -1128,8 +1120,7 @@ LocaleDataImpl::getFollowPageWords( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -1150,8 +1141,7 @@ LocaleDataImpl::getTransliterations( const Locale& rLocale )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 
 
@@ -1229,8 +1219,7 @@ LocaleDataImpl::getBreakIteratorRules( const Locale& rLocale  )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -1251,8 +1240,7 @@ LocaleDataImpl::getReservedWord( const Locale& rLocale  )
         return seq;
     }
     else {
-        Sequence< OUString > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
@@ -1427,8 +1415,7 @@ LocaleDataImpl::getOutlineNumberingLevels( const lang::Locale& rLocale )
         return aRet;
     }
     else {
-        Sequence< Reference<container::XIndexAccess> > seq1(0);
-        return seq1;
+        return {};
     }
 }
 
