@@ -94,11 +94,11 @@ namespace
     {
         //DOUBLE VERTICAL LINE instead of || because the translations make their
         //way into action_names under gtk3 where || is illegal
-        return OUStringToOString(OUString(u'\x2016'), RTL_TEXTENCODING_UTF8);
+        return OUStringToOString(u"\x2016", RTL_TEXTENCODING_UTF8);
     }
 }
 
-OString MergeEntrys::GetQTZText(const ResData& rResData, const OString& rOrigText)
+OString MergeEntrys::GetQTZText(const ResData& rResData, std::string_view rOrigText)
 {
     const OString sFilename = rResData.sFilename.copy(rResData.sFilename.lastIndexOf('/')+1);
     const OString sKey =
@@ -112,7 +112,8 @@ MergeDataFile::MergeDataFile(
     const OString &rFileName, const OString &rFile,
     bool bCaseSensitive, bool bWithQtz )
 {
-    OString sEnableReleaseBuild(getenv("ENABLE_RELEASE_BUILD"));
+    auto const env = getenv("ENABLE_RELEASE_BUILD");
+    OString sEnableReleaseBuild(env == nullptr ? "" : env);
 
     std::ifstream aInputStream( rFileName.getStr() );
     if ( !aInputStream.is_open() )
@@ -275,8 +276,8 @@ MergeEntrys *MergeDataFile::GetMergeEntrysCaseSensitive( ResData *pResData )
 }
 
 void MergeDataFile::InsertEntry(
-    const OString &rTYP, const OString &rGID,
-    const OString &rLID, const OString &nLANG,
+    std::string_view rTYP, std::string_view rGID,
+    std::string_view rLID, const OString &nLANG,
     const OString &rTEXT, const OString &rQHTEXT,
     const OString &rTITLE, const OString &rInFilename,
     bool bFirstLang, bool bCaseSensitive )
@@ -317,11 +318,11 @@ void MergeDataFile::InsertEntry(
     }
 }
 
-OString MergeDataFile::CreateKey(const OString& rTYP, const OString& rGID,
-    const OString& rLID, const OString& rFilename, bool bCaseSensitive)
+OString MergeDataFile::CreateKey(std::string_view rTYP, std::string_view rGID,
+    std::string_view rLID, const OString& rFilename, bool bCaseSensitive)
 {
     static const char sStroke[] = "-";
-    OString sKey = rTYP + sStroke + rGID + sStroke + rLID + sStroke +
+    OString sKey = OString::Concat(rTYP) + sStroke + rGID + sStroke + rLID + sStroke +
         lcl_NormalizeFilename(rFilename);
     if(bCaseSensitive)
         return sKey;         // officecfg case sensitive identifier
