@@ -19,10 +19,11 @@
 
 #include <sal/config.h>
 
+#include <string_view>
+
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/lang/Locale.hpp>
 #include <com/sun/star/lang/NoSupportException.hpp>
-#include <com/sun/star/lang/XSingleServiceFactory.hpp>
 #include <com/sun/star/linguistic2/ConversionDictionaryType.hpp>
 #include <com/sun/star/linguistic2/XConversionDictionaryList.hpp>
 #include <com/sun/star/uno/Reference.h>
@@ -43,7 +44,6 @@
 #include "convdic.hxx"
 #include "convdiclist.hxx"
 #include "hhconvdic.hxx"
-#include "lngreg.hxx"
 #include <linguistic/misc.hxx>
 
 using namespace osl;
@@ -54,13 +54,11 @@ using namespace com::sun::star::container;
 using namespace com::sun::star::linguistic2;
 using namespace linguistic;
 
-#define SN_CONV_DICTIONARY_LIST  "com.sun.star.linguistic2.ConversionDictionaryList"
-
-static OUString GetConvDicMainURL( const OUString &rDicName, const OUString &rDirectoryURL )
+static OUString GetConvDicMainURL( std::u16string_view rDicName, const OUString &rDirectoryURL )
 {
     // build URL to use for new (persistent) dictionaries
 
-    OUString aFullDicName = rDicName + CONV_DIC_DOT_EXT;
+    OUString aFullDicName = OUString::Concat(rDicName) + CONV_DIC_DOT_EXT;
 
     INetURLObject aURLObj;
     aURLObj.SetSmartProtocol( INetProtocol::File );
@@ -78,7 +76,7 @@ class ConvDicNameContainer :
 {
     std::vector< uno::Reference< XConversionDictionary > >   aConvDics;
 
-    sal_Int32 GetIndexByName_Impl( const OUString& rName );
+    sal_Int32 GetIndexByName_Impl( std::u16string_view rName );
 
 public:
     ConvDicNameContainer();
@@ -109,7 +107,7 @@ public:
     void    FlushDics() const;
 
     sal_Int32   GetCount() const    { return aConvDics.size(); }
-    uno::Reference< XConversionDictionary > GetByName( const OUString& rName );
+    uno::Reference< XConversionDictionary > GetByName( std::u16string_view rName );
 
     const uno::Reference< XConversionDictionary >&  GetByIndex( sal_Int32 nIdx )
     {
@@ -142,7 +140,7 @@ void ConvDicNameContainer::FlushDics() const
 }
 
 sal_Int32 ConvDicNameContainer::GetIndexByName_Impl(
-        const OUString& rName )
+        std::u16string_view rName )
 {
     sal_Int32 nRes = -1;
     sal_Int32 nLen = aConvDics.size();
@@ -155,7 +153,7 @@ sal_Int32 ConvDicNameContainer::GetIndexByName_Impl(
 }
 
 uno::Reference< XConversionDictionary > ConvDicNameContainer::GetByName(
-        const OUString& rName )
+        std::u16string_view rName )
 {
     uno::Reference< XConversionDictionary > xRes;
     sal_Int32 nIdx = GetIndexByName_Impl( rName );
@@ -315,9 +313,9 @@ void ConvDicNameContainer::AddConvDics(
 namespace
 {
     struct StaticConvDicList : public rtl::StaticWithInit<
-        uno::Reference<XInterface>, StaticConvDicList> {
-        uno::Reference<XInterface> operator () () {
-            return static_cast<cppu::OWeakObject *>(new ConvDicList);
+        rtl::Reference<ConvDicList>, StaticConvDicList> {
+        rtl::Reference<ConvDicList> operator () () {
+            return new ConvDicList;
         }
     };
 }
@@ -374,9 +372,9 @@ ConvDicNameContainer & ConvDicList::GetNameContainer()
         // since there is no UI to active/deactivate the dictionaries
         // for chinese text conversion they should be activated by default
         uno::Reference< XConversionDictionary > xS2TDic =
-                    mxNameContainer->GetByName( "ChineseS2T" );
+                    mxNameContainer->GetByName( u"ChineseS2T" );
         uno::Reference< XConversionDictionary > xT2SDic =
-                    mxNameContainer->GetByName( "ChineseT2S" );
+                    mxNameContainer->GetByName( u"ChineseT2S" );
         if (xS2TDic.is())
             xS2TDic->setActive( true );
         if (xT2SDic.is())
@@ -391,7 +389,7 @@ uno::Reference< container::XNameContainer > SAL_CALL ConvDicList::getDictionaryC
     MutexGuard  aGuard( GetLinguMutex() );
     GetNameContainer();
     DBG_ASSERT( mxNameContainer.is(), "missing name container" );
-    return mxNameContainer.get();
+    return mxNameContainer;
 }
 
 uno::Reference< XConversionDictionary > SAL_CALL ConvDicList::addNewDictionary(
@@ -454,7 +452,7 @@ uno::Sequence< OUString > SAL_CALL ConvDicList::queryConversions(
             const Sequence< OUString > aNewConv( xDic->getConversions(
                                 rText, nStartPos, nLength,
                                 eDirection, nTextConversionOptions ) );
-            std::copy(aNewConv.begin(), aNewConv.end(), std::back_inserter(aRes));
+            aRes.insert( aRes.end(), aNewConv.begin(), aNewConv.end() );
         }
     }
 
@@ -520,7 +518,7 @@ void SAL_CALL ConvDicList::removeEventListener(
 
 OUString SAL_CALL ConvDicList::getImplementationName()
 {
-    return getImplementationName_Static();
+    return "com.sun.star.lingu2.ConvDicList";
 }
 
 sal_Bool SAL_CALL ConvDicList::supportsService( const OUString& rServiceName )
@@ -530,41 +528,15 @@ sal_Bool SAL_CALL ConvDicList::supportsService( const OUString& rServiceName )
 
 uno::Sequence< OUString > SAL_CALL ConvDicList::getSupportedServiceNames()
 {
-    return getSupportedServiceNames_Static();
+    return { "com.sun.star.linguistic2.ConversionDictionaryList" };
 }
 
-uno::Sequence< OUString > ConvDicList::getSupportedServiceNames_Static()
-    throw()
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface*
+linguistic_ConvDicList_get_implementation(
+    css::uno::XComponentContext* , css::uno::Sequence<css::uno::Any> const&)
 {
-    uno::Sequence<OUString> aSNS { SN_CONV_DICTIONARY_LIST };
-    return aSNS;
+    return cppu::acquire(StaticConvDicList::get().get());
 }
 
-/// @throws css::uno::Exception
-static uno::Reference< uno::XInterface > ConvDicList_CreateInstance(
-        const uno::Reference< XMultiServiceFactory > & /*rSMgr*/ )
-{
-    return StaticConvDicList::get();
-}
-
-void * ConvDicList_getFactory(
-        const char * pImplName,
-        XMultiServiceFactory * pServiceManager  )
-{
-    void * pRet = nullptr;
-    if ( ConvDicList::getImplementationName_Static().equalsAscii( pImplName ) )
-    {
-        uno::Reference< XSingleServiceFactory > xFactory =
-            cppu::createOneInstanceFactory(
-                pServiceManager,
-                ConvDicList::getImplementationName_Static(),
-                ConvDicList_CreateInstance,
-                ConvDicList::getSupportedServiceNames_Static());
-        // acquire, because we return an interface pointer instead of a reference
-        xFactory->acquire();
-        pRet = xFactory.get();
-    }
-    return pRet;
-}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
