@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  *  The Contents of this file are made available subject to the terms of
@@ -39,8 +40,6 @@
 
 
 
-import java.lang.Math;
-
 import com.sun.star.uno.UnoRuntime;
 
 public class SDraw  {
@@ -124,7 +123,6 @@ public class SDraw  {
         com.sun.star.uno.XComponentContext xContext)
     {
         com.sun.star.frame.XComponentLoader xCLoader;
-        com.sun.star.text.XTextDocument xDoc = null;
         com.sun.star.lang.XComponent xComp = null;
 
         try {
@@ -185,7 +183,7 @@ public class SDraw  {
             com.sun.star.beans.XPropertySet.class, xShape);
 
         try {
-            xSPS.setPropertyValue("FillColor", new Integer(col));
+            xSPS.setPropertyValue("FillColor", Integer.valueOf(col));
         } catch (Exception e) {
             System.err.println("Can't change colors " + e);
             e.printStackTrace(System.err);
@@ -240,8 +238,8 @@ public class SDraw  {
                                       xShape);
 
             try {
-                xSPS.setPropertyValue("FillColor", new Integer(getCol(r,g,b)));
-                xSPS.setPropertyValue("Shadow", new Boolean(true));
+                xSPS.setPropertyValue("FillColor", Integer.valueOf(getCol(r,g,b)));
+                xSPS.setPropertyValue("Shadow", Boolean.TRUE);
             } catch (Exception e) {
                 System.err.println("Can't change colors " + e);
                 e.printStackTrace(System.err);
@@ -265,3 +263,4 @@ public class SDraw  {
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
