@@ -35,6 +35,7 @@
 #include <drawingml/chart/chartspacefragment.hxx>
 #include <drawingml/chart/chartspacemodel.hxx>
 #include <o3tl/safeint.hxx>
+#include <o3tl/unit_conversion.hxx>
 #include <oox/ppt/pptimport.hxx>
 #include <oox/vml/vmldrawing.hxx>
 #include <oox/vml/vmlshape.hxx>
@@ -295,12 +296,7 @@ void Shape::addShape(
             if( meFrameType == FRAMETYPE_DIAGRAM )
             {
                 keepDiagramCompatibilityInfo();
-
-                // Check if this is the PPTX import, so far converting SmartArt to a non-editable
-                // metafile is only imlemented for DOCX.
-                bool bPowerPoint = dynamic_cast<oox::ppt::PowerPointImport*>(&rFilterBase) != nullptr;
-
-                if (!SvtFilterOptions::Get().IsSmartArt2Shape() && !bPowerPoint)
+                if( !SvtFilterOptions::Get().IsSmartArt2Shape() )
                     convertSmartArtToMetafile( rFilterBase );
             }
 
@@ -555,21 +551,21 @@ static void lcl_createPresetShape(const uno::Reference<drawing::XShape>& xShape,
             if (pParagraph->getProperties().getParaAdjust())
                 eAdjust = *pParagraph->getProperties().getParaAdjust();
             xSet->setPropertyValue( "ParaAdjust", uno::makeAny( eAdjust ) );
-            SvxShape* pShape = comphelper::getUnoTunnelImplementation<SvxShape>( xShape );
+            SdrObject* pShape = SdrObject::getSdrObjectFromXShape( xShape );
             assert(pShape);
             SdrTextHorzAdjust eHorzAdjust = lcl_convertAdjust( eAdjust );
-            pShape->GetSdrObject()->SetMergedItem( SdrTextHorzAdjustItem( eHorzAdjust ) );
+            pShape->SetMergedItem( SdrTextHorzAdjustItem( eHorzAdjust ) );
         }
     }
 
     // Apply vertical adjustment for text on arc
     // ToDo: The property is currently not evaluated.
-    SvxShape* pShape = comphelper::getUnoTunnelImplementation<SvxShape>(xShape);
+    SdrObject* pShape = SdrObject::getSdrObjectFromXShape(xShape);
     assert(pShape);
     if (rClass == "fontwork-arch-up-curve")
-        pShape->GetSdrObject()->SetMergedItem( SdrTextVertAdjustItem( SdrTextVertAdjust::SDRTEXTVERTADJUST_BOTTOM ) );
+        pShape->SetMergedItem( SdrTextVertAdjustItem( SdrTextVertAdjust::SDRTEXTVERTADJUST_BOTTOM ) );
     else if (rClass == "fontwork-arch-down-curve")
-        pShape->GetSdrObject()->SetMergedItem( SdrTextVertAdjustItem( SdrTextVertAdjust::SDRTEXTVERTADJUST_TOP ) );
+        pShape->SetMergedItem( SdrTextVertAdjustItem( SdrTextVertAdjust::SDRTEXTVERTADJUST_TOP ) );
 
     // Apply preset shape
     xDefaulter->createCustomShapeDefaults( rClass );
@@ -581,9 +577,9 @@ static void lcl_createPresetShape(const uno::Reference<drawing::XShape>& xShape,
             aGeomPropSeq );
 
     // Reset old properties
-    const OUString sTextPath( "TextPath" );
-    const OUString sAdjustmentValues( "AdjustmentValues" );
-    const OUString sPresetTextWarp( "PresetTextWarp" );
+    static const OUStringLiteral sTextPath( u"TextPath" );
+    static const OUStringLiteral sAdjustmentValues( u"AdjustmentValues" );
+    static const OUStringLiteral sPresetTextWarp( u"PresetTextWarp" );
 
     lcl_resetPropertyValue( aGeomPropVec, "CoordinateSize" );
     lcl_resetPropertyValue( aGeomPropVec, "Equations" );
@@ -721,7 +717,11 @@ Reference< XShape > const & Shape::createAndInsert(
         }
     }
 
-    awt::Rectangle aShapeRectHmm( maPosition.X / EMU_PER_HMM, maPosition.Y / EMU_PER_HMM, maSize.Width / EMU_PER_HMM, maSize.Height / EMU_PER_HMM );
+    awt::Rectangle aShapeRectHmm(
+        o3tl::convert(maPosition.X, o3tl::Length::emu, o3tl::Length::mm100),
+        o3tl::convert(maPosition.Y, o3tl::Length::emu, o3tl::Length::mm100),
+        o3tl::convert(maSize.Width, o3tl::Length::emu, o3tl::Length::mm100),
+        o3tl::convert(maSize.Height, o3tl::Length::emu, o3tl::Length::mm100));
 
     OUString aServiceName;
     if (pMathXml)
@@ -812,7 +812,9 @@ Reference< XShape > const & Shape::createAndInsert(
     {
         // if global position is used, add it to transformation
         if (mbWps && pParentGroupShape == nullptr)
-            aTransformation.translate( maPosition.X * EMU_PER_HMM, maPosition.Y * EMU_PER_HMM);
+            aTransformation.translate(
+                o3tl::convert(maPosition.X, o3tl::Length::mm100, o3tl::Length::emu),
+                o3tl::convert(maPosition.Y, o3tl::Length::mm100, o3tl::Length::emu));
         else
             aTransformation.translate(maPosition.X, maPosition.Y);
     }
@@ -879,7 +881,9 @@ Reference< XShape > const & Shape::createAndInsert(
         aTransformation.translate(aParentTranslate);
 
     aParentTransformation = aTransformation;
-    aTransformation.scale(1/double(EMU_PER_HMM), 1/double(EMU_PER_HMM));
+
+    constexpr double fEmuToMm100 = o3tl::convert(1.0, o3tl::Length::emu, o3tl::Length::mm100);
+    aTransformation.scale(fEmuToMm100, fEmuToMm100);
 
     // OOXML flips shapes before rotating them, so the rotation needs to be inverted
     if( bIsCustomShape && mbFlipH != mbFlipV )
@@ -969,17 +973,7 @@ Reference< XShape > const & Shape::createAndInsert(
 
     Reference< lang::XMultiServiceFactory > xServiceFact( rFilterBase.getModel(), UNO_QUERY_THROW );
     if ( !mxShape.is() )
-    {
         mxShape.set( xServiceFact->createInstance( aServiceName ), UNO_QUERY_THROW );
-        if (aServiceName == "com.sun.star.drawing.GroupShape")
-        {
-            // TODO why is this necessary? A newly created group shape should have an empty
-            // grab-bag.
-            uno::Reference<beans::XPropertySet> xPropertySet(mxShape, uno::UNO_QUERY);
-            beans::PropertyValues aVals;
-            xPropertySet->setPropertyValue("InteropGrabBag", uno::makeAny(aVals));
-        }
-    }
 
     Reference< XPropertySet > xSet( mxShape, UNO_QUERY );
     if (xSet.is())
@@ -1044,8 +1038,8 @@ Reference< XShape > const & Shape::createAndInsert(
 
         const GraphicHelper& rGraphicHelper = rFilterBase.getGraphicHelper();
 
-        ::Color nLinePhClr(0xffffffff);
-        ::Color nFillPhClr(0xffffffff);
+        ::Color nLinePhClr(ColorTransparency, 0xffffffff);
+        ::Color nFillPhClr(ColorTransparency, 0xffffffff);
         // TODO: use ph color when applying effect properties
         //sal_Int32 nEffectPhClr = -1;
 
@@ -1121,15 +1115,15 @@ Reference< XShape > const & Shape::createAndInsert(
             mpTextBody->getTextProperties().pushRotationAdjustments();
             aShapeProps.assignUsed( mpTextBody->getTextProperties().maPropertyMap );
             // Push char properties as well - specifically useful when this is a placeholder
-            if( mpMasterTextListStyle &&  mpMasterTextListStyle->getListStyle()[0]->getTextCharacterProperties().moHeight.has() )
-                aShapeProps.setProperty(PROP_CharHeight, GetFontHeight( mpMasterTextListStyle->getListStyle()[0]->getTextCharacterProperties().moHeight.get() ));
+            if( mpMasterTextListStyle &&  mpMasterTextListStyle->getListStyle()[0].getTextCharacterProperties().moHeight.has() )
+                aShapeProps.setProperty(PROP_CharHeight, GetFontHeight( mpMasterTextListStyle->getListStyle()[0].getTextCharacterProperties().moHeight.get() ));
         }
 
         // applying properties
         aShapeProps.assignUsed( getShapeProperties() );
         aShapeProps.assignUsed( maDefaultShapeProperties );
         if(mnRotation != 0 && bIsCustomShape)
-            aShapeProps.setProperty( PROP_RotateAngle, sal_Int32( NormAngle36000( mnRotation / -600 ) ));
+            aShapeProps.setProperty( PROP_RotateAngle, sal_Int32( NormAngle36000( Degree100(mnRotation / -600) ) ));
         if( bIsEmbMedia ||
             bIsCustomShape ||
             aServiceName == "com.sun.star.drawing.GraphicObjectShape" ||
@@ -1247,7 +1241,7 @@ Reference< XShape > const & Shape::createAndInsert(
                 if(mnRotation)
                 {
                     uno::Reference<beans::XPropertySet> xPropertySet(mxShape, uno::UNO_QUERY);
-                    const OUString aGrabBagPropName = "FrameInteropGrabBag";
+                    static const OUStringLiteral aGrabBagPropName = u"FrameInteropGrabBag";
                     uno::Sequence<beans::PropertyValue> aGrabBag;
                     xPropertySet->getPropertyValue(aGrabBagPropName) >>= aGrabBag;
                     beans::PropertyValue aPair;
@@ -1513,6 +1507,9 @@ Reference< XShape > const & Shape::createAndInsert(
                 sal_Int32 nTextRotateAngle = static_cast< sal_Int32 >( getTextBody()->getTextProperties().moRotation.get( 0 ) );
 
                 nTextRotateAngle -= mnDiagramRotation;
+                /* OOX measures text rotation clockwise in 1/60000th degrees,
+                   relative to the containing shape. setTextRotateAngle wants degrees anticlockwise. */
+                nTextRotateAngle = -1 * nTextRotateAngle / 60000;
 
                 if (getTextBody()->getTextProperties().moUpright)
                 {
@@ -1521,18 +1518,15 @@ Reference< XShape > const & Shape::createAndInsert(
                     // shape containing it is rotated.
                     // Hence, we rotate the text into the opposite direction of
                     // the rotation of the shape, by as much as the shape was rotated.
-                    mpCustomShapePropertiesPtr->setTextRotateAngle(mnRotation / 60000);
+                    mpCustomShapePropertiesPtr->setTextRotateAngle((mnRotation / 60000) + nTextRotateAngle);
                     // Also put the initial angles away in a GrabBag.
                     putPropertyToGrabBag("Upright", Any(true));
                     putPropertyToGrabBag("nShapeRotationAtImport", Any(mnRotation / 60000));
-                    putPropertyToGrabBag("nTextRotationAtImport", Any(mnRotation / 60000));
+                    putPropertyToGrabBag("nTextRotationAtImport", Any(nTextRotateAngle));
                 }
                 else
                 {
-                    /* OOX measures text rotation clockwise in 1/60000th degrees,
-                       relative to the containing shape. setTextRotateAngle wants
-                       degrees anticlockwise. */
-                    mpCustomShapePropertiesPtr->setTextRotateAngle(-1 * nTextRotateAngle / 60000);
+                    mpCustomShapePropertiesPtr->setTextRotateAngle(nTextRotateAngle);
                 }
 
                 auto sHorzOverflow = getTextBody()->getTextProperties().msHorzOverflow;
@@ -1572,7 +1566,8 @@ Reference< XShape > const & Shape::createAndInsert(
         if ( !bUseRotationTransform && (mnRotation != 0 || nCameraRotation != 0) )
         {
             // use the same logic for rotation from VML exporter (SimpleShape::implConvertAndInsert at vmlshape.cxx)
-            aPropertySet.setAnyProperty( PROP_RotateAngle, makeAny( sal_Int32( NormAngle36000( (mnRotation - nCameraRotation) / -600 ) ) ) );
+            Degree100 nAngle = NormAngle36000( Degree100((mnRotation - nCameraRotation) / -600) );
+            aPropertySet.setAnyProperty( PROP_RotateAngle, makeAny( sal_Int32( nAngle.get() ) ) );
             aPropertySet.setAnyProperty( PROP_HoriOrientPosition, makeAny( maPosition.X ) );
             aPropertySet.setAnyProperty( PROP_VertOrientPosition, makeAny( maPosition.Y ) );
         }
@@ -1664,7 +1659,7 @@ void Shape::keepDiagramDrawing(XmlFilterBase& rFilterBase, const OUString& rFrag
     maDiagramDoms.realloc(length + 1);
 
     diagramDrawing[0] <<= rFilterBase.importFragment(rFragmentPath);
-    diagramDrawing[1] <<= resolveRelationshipsOfTypeFromOfficeDoc(rFilterBase, rFragmentPath, "image");
+    diagramDrawing[1] <<= resolveRelationshipsOfTypeFromOfficeDoc(rFilterBase, rFragmentPath, u"image");
 
     beans::PropertyValue* pValue = maDiagramDoms.getArray();
     pValue[length].Name = "OOXDrawing";
@@ -1912,10 +1907,10 @@ void Shape::finalizeXShape( XmlFilterBase& rFilter, const Reference< XShapes >&
                 // load the chart data from the XML fragment
                 bool bMSO2007Doc = rFilter.isMSO2007Document();
                 chart::ChartSpaceModel aModel(bMSO2007Doc);
-                chart::ChartSpaceFragment *pChartSpaceFragment = new chart::ChartSpaceFragment(
+                rtl::Reference<chart::ChartSpaceFragment> pChartSpaceFragment = new chart::ChartSpaceFragment(
                         rFilter, mxChartShapeInfo->maFragmentPath, aModel );
                 const OUString aThemeOverrideFragmentPath( pChartSpaceFragment->
-                        getFragmentPathFromFirstTypeFromOfficeDoc("themeOverride") );
+                        getFragmentPathFromFirstTypeFromOfficeDoc(u"themeOverride") );
                 rFilter.importFragment( pChartSpaceFragment );
                 ::oox::ppt::PowerPointImport *pPowerPointImport =
                     dynamic_cast< ::oox::ppt::PowerPointImport* >(&rFilter);
@@ -2091,7 +2086,7 @@ EffectProperties Shape::getActualEffectProperties(const Theme* pTheme) const
     return aEffectProperties;
 }
 
-uno::Sequence< uno::Sequence< uno::Any > >  Shape::resolveRelationshipsOfTypeFromOfficeDoc(core::XmlFilterBase& rFilter, const OUString& sFragment, const OUString& sType )
+uno::Sequence< uno::Sequence< uno::Any > >  Shape::resolveRelationshipsOfTypeFromOfficeDoc(core::XmlFilterBase& rFilter, const OUString& sFragment, std::u16string_view sType )
 {
     uno::Sequence< uno::Sequence< uno::Any > > xRelListTemp;
     sal_Int32 counter = 0;
