@@ -89,7 +89,7 @@ void SaveInteropProperties(uno::Reference<frame::XModel> const& xModel,
        OUString const& rObjectName, OUString const*const pOldObjectName,
        OUString const& rProgId)
 {
-    static const char sEmbeddingsPropName[] = "EmbeddedObjects";
+    static constexpr OUStringLiteral sEmbeddingsPropName = u"EmbeddedObjects";
 
     // get interop grab bag from document
     uno::Reference<beans::XPropertySet> const xDocProps(xModel, uno::UNO_QUERY);
