@@ -26,6 +26,8 @@
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/drawing/XDrawPage.hpp>
+#include <com/sun/star/drawing/XDrawPages.hpp>
+#include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
 #include <com/sun/star/drawing/XShapes.hpp>
 #include <com/sun/star/text/XText.hpp>
 #include <basegfx/matrix/b2dhommatrix.hxx>
@@ -114,8 +116,7 @@ void PPTShape::addShape(
         const oox::drawingml::Theme* pTheme,
         const Reference< XShapes >& rxShapes,
         basegfx::B2DHomMatrix& aTransformation,
-        ::oox::drawingml::ShapeIdMap* pShapeMap,
-        bool bhasSameSubTypeIndex )
+        ::oox::drawingml::ShapeIdMap* pShapeMap )
 {
     SAL_INFO("oox.ppt","add shape id: " << msId << " location: " << ((meShapeLocation == Master) ? "master" : ((meShapeLocation == Slide) ? "slide" : ((meShapeLocation == Layout) ? "layout" : "other"))) << " subtype: " << mnSubType << " service: " << msServiceName);
     // only placeholder from layout are being inserted
@@ -134,7 +135,7 @@ void PPTShape::addShape(
         if (sServiceName != "com.sun.star.drawing.GraphicObjectShape" &&
             sServiceName != "com.sun.star.drawing.OLE2Shape")
         {
-            const OUString sOutlinerShapeService("com.sun.star.presentation.OutlinerShape");
+            static const OUStringLiteral sOutlinerShapeService(u"com.sun.star.presentation.OutlinerShape");
             SAL_INFO("oox.ppt","has master: " << std::hex << rSlidePersist.getMasterPersist().get());
             switch (mnSubType)
             {
@@ -225,36 +226,6 @@ void PPTShape::addShape(
             }
         }
 
-        if (sServiceName != "com.sun.star.drawing.TableShape")
-        {
-            if (TextBodyPtr pTextBody = getTextBody())
-            {
-                // If slide shape has not numCol but placeholder has we should inherit from placeholder.
-                if (pTextBody->getTextProperties().mnNumCol == 1 &&
-                    mnSubType &&
-                    getSubTypeIndex().has() &&
-                    rSlidePersist.getMasterPersist())
-                {
-                    oox::drawingml::ShapePtr pPlaceholder = PPTShape::findPlaceholderByIndex(
-                                                                            getSubTypeIndex().get(),
-                                                                            rSlidePersist.getMasterPersist()->getShapes()->getChildren());
-                    if (pPlaceholder && pPlaceholder->getTableProperties())
-                        pTextBody->getTextProperties().mnNumCol = pPlaceholder->getTableProperties()->getTableGrid().size();
-                }
-
-                sal_Int32 nNumCol = pTextBody->getTextProperties().mnNumCol;
-                if (nNumCol > 1)
-                {
-                    // This shape is not a table, but has multiple columns,
-                    // represent that as a table.
-                    sServiceName = "com.sun.star.drawing.TableShape";
-                    oox::drawingml::table::TablePropertiesPtr pTableProperties = getTableProperties();
-                    pTableProperties->pullFromTextBody(pTextBody, maSize.Width, bhasSameSubTypeIndex, meShapeLocation == Layout);
-                    setTextBody(nullptr);
-                }
-            }
-        }
-
         SAL_INFO("oox.ppt","shape service: " << sServiceName);
 
         if (mnSubType && getSubTypeIndex().has() && meShapeLocation == Layout)
@@ -363,17 +334,39 @@ void PPTShape::addShape(
                 setMasterTextListStyle( aMasterTextListStyle );
 
             Reference< XShape > xShape( createAndInsert( rFilterBase, sServiceName, pTheme, rxShapes, bClearText, bool(mpPlaceholder), aTransformation, getFillProperties() ) );
+            // if exists and not duplicated, try to use the title text as slide name to help its re-use on UI
             if (!rSlidePersist.isMasterPage() && rSlidePersist.getPage().is() && mnSubType == XML_title)
-             {
+            {
                 try
                 {
+                    sal_Int32 nCount = 1;
                     OUString aTitleText;
                     Reference<XTextRange> xText(xShape, UNO_QUERY_THROW);
                     aTitleText = xText->getString();
-                    if (!aTitleText.isEmpty() && (aTitleText.getLength() < 64))    // just a magic value, but we don't want to set slide names which are too long
+                    Reference<drawing::XDrawPagesSupplier> xDPS(rFilterBase.getModel(), uno::UNO_QUERY_THROW);
+                    Reference<drawing::XDrawPages> xDrawPages(xDPS->getDrawPages(), uno::UNO_SET_THROW);
+                    sal_uInt32 nMaxPages = xDrawPages->getCount();
+                    bool bUseTitleAsSlideName = !aTitleText.isEmpty() &&
+                          // just a magic value, but we don't want to set slide names which are too long
+                          aTitleText.getLength() < 64;
+                    // check duplicated title name
+                    if (bUseTitleAsSlideName)
                     {
+                        for (sal_uInt32 nPage = 0; nPage < nMaxPages; ++nPage)
+                        {
+                            Reference<XDrawPage> xDrawPage(xDrawPages->getByIndex(nPage), uno::UNO_QUERY);
+                            Reference<container::XNamed> xNamed(xDrawPage, UNO_QUERY_THROW);
+                            OUString sRest;
+                            if (xNamed->getName().startsWith(aTitleText, &sRest)
+                                && (sRest.isEmpty()
+                                    || (sRest.startsWith(" (") && sRest.endsWith(")")
+                                        && sRest.copy(2, sRest.getLength() - 3).toInt32() > 0)))
+                                nCount++;
+                        }
                         Reference<container::XNamed> xName(rSlidePersist.getPage(), UNO_QUERY_THROW);
-                        xName->setName(aTitleText);
+                        xName->setName(
+                            aTitleText
+                            + (nCount == 1 ? OUString("") : " (" + OUString::number(nCount) + ")"));
                     }
                 }
                 catch (uno::Exception&)
