@@ -20,7 +20,6 @@ package mod._xmloff.Chart;
 
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -67,19 +66,13 @@ public class XMLExporter extends TestCase {
      * New text document created.
      */
     @Override
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
 
         // get a soffice factory object
         SOfficeFactory SOF = SOfficeFactory.getFactory( tParam.getMSF());
 
-        try {
-            log.println( "creating a chartdocument" );
-            xChartDoc = SOF.createChartDoc();
-        } catch ( Exception e ) {
-            // Some exception occurs.FAILED
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
+        log.println( "creating a chartdocument" );
+        xChartDoc = SOF.createChartDoc();
     }
 
     /**
@@ -95,7 +88,7 @@ public class XMLExporter extends TestCase {
     }
 
     /**
-    * Creating a Testenvironment for the interfaces to be tested.
+    * Creating a TestEnvironment for the interfaces to be tested.
     * Creates an instance of the service
     * <code>com.sun.star.comp.Chart.XMLExporter</code> with
     * argument which is an implementation of <code>XDocumentHandler</code>
@@ -116,8 +109,8 @@ public class XMLExporter extends TestCase {
     * </ul>
     */
     @Override
-    public synchronized TestEnvironment createTestEnvironment
-            (TestParameters tParam, PrintWriter log ) {
+    public TestEnvironment createTestEnvironment
+            (TestParameters tParam, PrintWriter log ) throws Exception {
 
         XMultiServiceFactory xMSF = tParam.getMSF() ;
         XInterface oObj = null;
@@ -126,20 +119,15 @@ public class XMLExporter extends TestCase {
         FilterChecker filter = new FilterChecker(log);
         Any arg = new Any(new Type(XDocumentHandler.class),filter);
 
-        try {
-            oObj = (XInterface) xMSF.createInstanceWithArguments(
-                "com.sun.star.comp.Chart.XMLExporter", new Object[] {arg});
-            XExporter xEx = UnoRuntime.queryInterface(XExporter.class,oObj);
-            xEx.setSourceDocument(xChartDoc);
+        oObj = (XInterface) xMSF.createInstanceWithArguments(
+            "com.sun.star.comp.Chart.XMLExporter", new Object[] {arg});
+        XExporter xEx = UnoRuntime.queryInterface(XExporter.class,oObj);
+        xEx.setSourceDocument(xChartDoc);
 
-            Object oTitle = xChartDoc.getTitle() ;
-            XPropertySet xTitleProp = UnoRuntime.queryInterface
-                (XPropertySet.class, oTitle) ;
-            xTitleProp.setPropertyValue("String", exportStr) ;
-        } catch (com.sun.star.uno.Exception e) {
-            e.printStackTrace(log) ;
-            throw new StatusException("Can't create component.", e) ;
-        }
+        Object oTitle = xChartDoc.getTitle() ;
+        XPropertySet xTitleProp = UnoRuntime.queryInterface
+            (XPropertySet.class, oTitle) ;
+        xTitleProp.setPropertyValue("String", exportStr) ;
 
         filter.addTag(new XMLTools.Tag("office:document")) ;
         filter.addTagEnclosed(new XMLTools.Tag("office:meta"),
