@@ -22,6 +22,7 @@
 #include <xmloff/xmlnamespace.hxx>
 #include <osl/diagnose.h>
 #include <sal/log.hxx>
+#include <tools/diagnose_ex.h>
 
 
 namespace rptxml
@@ -34,7 +35,7 @@ OXMLFormattedField::OXMLFormattedField( ORptFilter& rImport
                 ,const uno::Reference< XFormattedField > & _xComponent
                 ,OXMLTable* _pContainer
                 ,bool _bPageCount) :
-    OXMLReportElementBase( rImport,_xComponent.get(),_pContainer)
+    OXMLReportElementBase( rImport,_xComponent,_pContainer)
 {
     OSL_ENSURE(m_xReportComponent.is(),"Component is NULL!");
 
@@ -42,12 +43,10 @@ OXMLFormattedField::OXMLFormattedField( ORptFilter& rImport
     {
         for (auto &aIter : sax_fastparser::castToFastAttributeList( _xAttrList ))
         {
-            OUString sValue = aIter.toString();
-
             switch( aIter.getToken() )
             {
                 case XML_ELEMENT(REPORT, XML_FORMULA):
-                    _xComponent->setDataField(ORptFilter::convertFormula(sValue));
+                    _xComponent->setDataField(ORptFilter::convertFormula(aIter.toString()));
                     break;
                 case XML_ELEMENT(REPORT, XML_SELECT_PAGE):
                     _xComponent->setDataField("rpt:PageNumber()");
@@ -64,7 +63,7 @@ OXMLFormattedField::OXMLFormattedField( ORptFilter& rImport
     }
     catch(Exception&)
     {
-        OSL_FAIL("Exception caught while filling the report definition props");
+        TOOLS_WARN_EXCEPTION( "reportdesign", "Exception caught while filling the report definition props");
     }
 }
 
