@@ -39,10 +39,11 @@
 #include <svx/dbaexchange.hxx>
 #include <svx/sdtagitm.hxx>
 
+#include <com/sun/star/awt/PopupMenuDirection.hpp>
 #include <com/sun/star/frame/XPopupMenuController.hpp>
 #include <comphelper/propertyvalue.hxx>
-#include <toolkit/awt/vclxmenu.hxx>
 #include <toolkit/helper/convert.hxx>
+#include <tools/diagnose_ex.h>
 #include <RptDef.hxx>
 #include <SectionWindow.hxx>
 #include <helpids.h>
@@ -50,6 +51,7 @@
 #include <rptui_slotid.hrc>
 
 #include <vcl/commandevent.hxx>
+#include <o3tl/safeint.hxx>
 
 #include <svl/itempool.hxx>
 #include <svtools/extcolorcfg.hxx>
@@ -91,7 +93,7 @@ OReportSection::OReportSection(OSectionWindow* _pParent,const uno::Reference< re
     }
     catch(uno::Exception&)
     {
-        OSL_FAIL("Exception caught!");
+        TOOLS_WARN_EXCEPTION( "reportdesign", "");
     }
 
     m_pFunc.reset(new DlgEdFuncSelect( this ));
@@ -143,7 +145,7 @@ void OReportSection::Paint( vcl::RenderContext& rRenderContext, const tools::Rec
     // mark repaint start
     if (pPgView)
     {
-        pTargetPaintWindow = pPgView->GetView().BeginDrawLayers(this, aPaintRectRegion);
+        pTargetPaintWindow = pPgView->GetView().BeginDrawLayers(GetOutDev(), aPaintRectRegion);
         OSL_ENSURE(pTargetPaintWindow, "BeginDrawLayers: Got no SdrPaintWindow (!)");
         // draw background self using wallpaper
         OutputDevice& rTargetOutDev = pTargetPaintWindow->GetTargetOutputDevice();
@@ -163,7 +165,7 @@ void OReportSection::fill()
     if ( !m_xSection.is() )
         return;
 
-    m_pMulti = new comphelper::OPropertyChangeMultiplexer(this,m_xSection.get());
+    m_pMulti = new comphelper::OPropertyChangeMultiplexer(this,m_xSection);
     m_pMulti->addProperty(PROPERTY_BACKCOLOR);
 
     m_pReportListener = addStyleListener(m_xSection->getReportDefinition(),this);
@@ -205,7 +207,7 @@ void OReportSection::fill()
     sal_Int32 nColor = m_xSection->getBackColor();
     if ( nColor == static_cast<sal_Int32>(COL_TRANSPARENT) )
         nColor = getStyleProperty<sal_Int32>(m_xSection->getReportDefinition(),PROPERTY_BACKCOLOR);
-    m_pView->SetApplicationDocumentColor(Color(nColor));
+    m_pView->SetApplicationDocumentColor(Color(ColorTransparency, nColor));
 
     uno::Reference<report::XReportDefinition> xReportDefinition = m_xSection->getReportDefinition();
     const sal_Int32 nLeftMargin = getStyleProperty<sal_Int32>(xReportDefinition,PROPERTY_LEFTMARGIN);
@@ -245,8 +247,7 @@ void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyC
                 rObject.Value >>= aCopies;
                 for (const uno::Reference<report::XReportComponent>& rCopy : std::as_const(aCopies))
                 {
-                    SvxShape* pShape = comphelper::getUnoTunnelImplementation<SvxShape>( rCopy );
-                    SdrObject* pObject = pShape ? pShape->GetSdrObject() : nullptr;
+                    SdrObject* pObject = SdrObject::getSdrObjectFromXShape( rCopy );
                     if ( pObject )
                     {
                         // Clone to target SdrModel
@@ -274,7 +275,7 @@ void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyC
             }
             catch(uno::Exception&)
             {
-                OSL_FAIL("Exception caught while pasting a new object!");
+                TOOLS_WARN_EXCEPTION( "reportdesign", "Exception caught while pasting a new object!");
             }
             if ( !_bForce )
                 break;
@@ -432,12 +433,21 @@ void OReportSection::Command( const CommandEvent& _rCEvt )
     if (!xMenuController.is())
         return;
 
-    rtl::Reference<VCLXPopupMenu> xPopupMenu(new VCLXPopupMenu);
-    xMenuController->setPopupMenu(xPopupMenu.get());
+    css::uno::Reference<css::awt::XPopupMenu> xPopupMenu(
+        xContext->getServiceManager()->createInstanceWithContext(
+        "com.sun.star.awt.PopupMenu", xContext), css::uno::UNO_QUERY);
+
+    if (!xPopupMenu.is())
+        return;
+
+    xMenuController->setPopupMenu(xPopupMenu);
 
     Point aPos = _rCEvt.GetMousePosPixel();
     m_pView->EndAction();
-    static_cast<PopupMenu*>(xPopupMenu->GetMenu())->Execute(this, aPos);
+
+    xPopupMenu->execute(GetComponentInterface(),
+                        css::awt::Rectangle(aPos.X(), aPos.Y(), 1, 1),
+                        css::awt::PopupMenuDirection::EXECUTE_DOWN);
 
     css::uno::Reference<css::lang::XComponent> xComponent(xMenuController, css::uno::UNO_QUERY);
     xComponent->dispose();
@@ -453,7 +463,7 @@ void OReportSection::_propertyChanged(const beans::PropertyChangeEvent& _rEvent)
         sal_Int32 nColor = m_xSection->getBackColor();
         if ( nColor == static_cast<sal_Int32>(COL_TRANSPARENT) )
             nColor = getStyleProperty<sal_Int32>(m_xSection->getReportDefinition(),PROPERTY_BACKCOLOR);
-        m_pView->SetApplicationDocumentColor(Color(nColor));
+        m_pView->SetApplicationDocumentColor(Color(ColorTransparency, nColor));
         Invalidate(InvalidateFlags::NoChildren|InvalidateFlags::NoErase);
     }
     else
@@ -494,8 +504,7 @@ void OReportSection::impl_adjustObjectSizePosition(sal_Int32 i_nPaperWidth,sal_I
             uno::Reference< report::XReportComponent> xReportComponent(m_xSection->getByIndex(i),uno::UNO_QUERY_THROW);
             awt::Point aPos = xReportComponent->getPosition();
             awt::Size aSize = xReportComponent->getSize();
-            SvxShape* pShape = comphelper::getUnoTunnelImplementation<SvxShape>( xReportComponent );
-            SdrObject* pObject = pShape ? pShape->GetSdrObject() : nullptr;
+            SdrObject* pObject = SdrObject::getSdrObjectFromXShape( xReportComponent );
             if ( pObject )
             {
                 bool bChanged = false;
@@ -541,7 +550,7 @@ void OReportSection::impl_adjustObjectSizePosition(sal_Int32 i_nPaperWidth,sal_I
     }
     catch(const uno::Exception &)
     {
-        OSL_FAIL("Exception caught: OReportSection::impl_adjustObjectSizePosition()");
+        TOOLS_WARN_EXCEPTION( "reportdesign", "OReportSection::impl_adjustObjectSizePosition()");
     }
 }
 
@@ -603,12 +612,9 @@ void OReportSection::createDefault(const OUString& _sType,SdrObject* _pObj)
                                 EE_ITEMS_START, EE_ITEMS_END>{});
                         aDest.Set( rSource );
                         _pObj->SetMergedItemSet( aDest );
-                        sal_Int32 nAngle = pSourceObj->GetRotateAngle();
+                        Degree100 nAngle = pSourceObj->GetRotateAngle();
                         if ( nAngle )
-                        {
-                            double a = nAngle * F_PI18000;
-                            _pObj->NbcRotate( _pObj->GetSnapRect().Center(), nAngle, sin( a ), cos( a ) );
-                        }
+                            _pObj->NbcRotate( _pObj->GetSnapRect().Center(), nAngle );
                         bAttributesAppliedFromGallery = true;
                     }
                 }
