@@ -32,6 +32,7 @@
 
 #include "system.hxx"
 
+#include <o3tl/safeint.hxx>
 #include <osl/security.h>
 #include <rtl/bootstrap.hxx>
 #include <sal/log.hxx>
@@ -68,7 +69,7 @@ static bool sysconf_SC_GETPW_R_SIZE_MAX(std::size_t * value) {
            way and always set EINVAL, so be resilient here: */
         return false;
     }
-    SAL_WARN_IF( m < 0 || static_cast<unsigned long>(m) >= std::numeric_limits<std::size_t>::max(), "sal.osl",
+    SAL_WARN_IF( m < 0 || o3tl::make_unsigned(m) >= std::numeric_limits<std::size_t>::max(), "sal.osl",
                 "m < 0 || (unsigned long) m >= std::numeric_limits<std::size_t>::max()");
     *value = static_cast<std::size_t>(m);
     return true;
@@ -193,7 +194,7 @@ oslSecurityError SAL_CALL osl_loginUserOnFileServer(
 sal_Bool SAL_CALL osl_getUserIdent(oslSecurity Security, rtl_uString **ustrIdent)
 {
     bool     bRet = false;
-    sal_Char pszIdent[1024];
+    char pszIdent[1024];
 
     pszIdent[0] = '\0';
 
@@ -205,9 +206,9 @@ sal_Bool SAL_CALL osl_getUserIdent(oslSecurity Security, rtl_uString **ustrIdent
     return bRet;
 }
 
-bool osl_psz_getUserIdent(oslSecurity Security, sal_Char *pszIdent, sal_uInt32 nMax)
+bool osl_psz_getUserIdent(oslSecurity Security, char *pszIdent, sal_uInt32 nMax)
 {
-    sal_Char  buffer[32];
+    char  buffer[32];
     sal_Int32 nChr;
 
     oslSecurityImpl *pSecImpl = static_cast<oslSecurityImpl *>(Security);
@@ -227,7 +228,7 @@ bool osl_psz_getUserIdent(oslSecurity Security, sal_Char *pszIdent, sal_uInt32 n
 sal_Bool SAL_CALL osl_getUserName(oslSecurity Security, rtl_uString **ustrName)
 {
     bool     bRet = false;
-    sal_Char * pszName;
+    char * pszName;
     sal_Int32 len;
 
     oslSecurityImpl *pSecImpl = static_cast<oslSecurityImpl *>(Security);
@@ -235,7 +236,7 @@ sal_Bool SAL_CALL osl_getUserName(oslSecurity Security, rtl_uString **ustrName)
     if (pSecImpl != nullptr && pSecImpl->m_pPasswd.pw_name != nullptr) {
         pszName = pSecImpl->m_pPasswd.pw_name;
         auto const n = std::strlen(pszName);
-        if (n <= sal_uInt32(std::numeric_limits<sal_Int32>::max())) {
+        if (n <= o3tl::make_unsigned(std::numeric_limits<sal_Int32>::max())) {
             len = n;
             bRet = true;
         }
@@ -285,7 +286,7 @@ static bool osl_psz_getHomeDir(oslSecurity Security, OString* pszDirectory)
 
 #ifdef HAIKU
     dev_t volume = dev_for_path("/boot");
-    sal_Char homeDir[B_PATH_NAME_LENGTH + B_FILE_NAME_LENGTH];
+    char homeDir[B_PATH_NAME_LENGTH + B_FILE_NAME_LENGTH];
     status_t result = find_directory(B_USER_DIRECTORY, volume, false, homeDir,
                                      sizeof(homeDir));
     if (result == B_OK) {
@@ -330,7 +331,7 @@ static bool osl_psz_getHomeDir(oslSecurity Security, OString* pszDirectory)
     /* if current user, check also environment for HOME */
     if (getuid() == pSecImpl->m_pPasswd.pw_uid)
     {
-        sal_Char *pStr = nullptr;
+        char *pStr = nullptr;
 #ifdef __sun
         char    buffer[8192];
 
@@ -353,7 +354,7 @@ static bool osl_psz_getHomeDir(oslSecurity Security, OString* pszDirectory)
         if (pStr != nullptr && pStr[0] != '\0' && access(pStr, 0) == 0)
         {
             auto const len = std::strlen(pStr);
-            if (len > sal_uInt32(std::numeric_limits<sal_Int32>::max())) {
+            if (len > o3tl::make_unsigned(std::numeric_limits<sal_Int32>::max())) {
                 return false;
             }
             *pszDirectory = OString(pStr, len);
@@ -363,7 +364,7 @@ static bool osl_psz_getHomeDir(oslSecurity Security, OString* pszDirectory)
     if (pSecImpl->m_pPasswd.pw_dir != nullptr)
     {
         auto const len = std::strlen(pSecImpl->m_pPasswd.pw_dir);
-        if (len > sal_uInt32(std::numeric_limits<sal_Int32>::max())) {
+        if (len > o3tl::make_unsigned(std::numeric_limits<sal_Int32>::max())) {
             return false;
         }
         *pszDirectory = OString(pSecImpl->m_pPasswd.pw_dir, len);
@@ -398,7 +399,7 @@ static bool osl_psz_getConfigDir(oslSecurity Security, OString* pszDirectory)
     assert(pszDirectory != nullptr);
     (void) Security;
     dev_t volume = dev_for_path("/boot");
-    sal_Char configDir[B_PATH_NAME_LENGTH + B_FILE_NAME_LENGTH];
+    char configDir[B_PATH_NAME_LENGTH + B_FILE_NAME_LENGTH];
     status_t result = find_directory(B_USER_SETTINGS_DIRECTORY, volume, false,
                                      configDir, sizeof(configDir));
     if (result == B_OK) {
@@ -417,7 +418,7 @@ static bool osl_psz_getConfigDir(oslSecurity Security, OString* pszDirectory)
 {
     assert(pszDirectory != nullptr);
 
-    sal_Char *pStr = getenv("XDG_CONFIG_HOME");
+    char *pStr = getenv("XDG_CONFIG_HOME");
 
     if (pStr == nullptr || pStr[0] == '\0' || access(pStr, 0) != 0)
     {
@@ -472,7 +473,7 @@ static bool osl_psz_getConfigDir(oslSecurity Security, OString* pszDirectory)
     else
     {
         auto const len = std::strlen(pStr);
-        if (len > sal_uInt32(std::numeric_limits<sal_Int32>::max())) {
+        if (len > o3tl::make_unsigned(std::numeric_limits<sal_Int32>::max())) {
             return false;
         }
         *pszDirectory = OString(pStr, len);
