@@ -50,10 +50,14 @@ public:
     void testTdf107902();
     void testTdf131296_legacy();
     void testTdf131296_new();
+    void testTdf46119();
     void testTdf128218();
     void testTdf71271();
     void testTdf43003();
+    void testTdf133887();
+    void testTdf133889();
     void testTdf138646();
+    void testTdf105558();
     void testTdf90278();
 
     CPPUNIT_TEST_SUITE(ScMacrosTest);
@@ -70,10 +74,15 @@ public:
     CPPUNIT_TEST(testTdf107902);
     CPPUNIT_TEST(testTdf131296_legacy);
     CPPUNIT_TEST(testTdf131296_new);
+    CPPUNIT_TEST(testTdf46119);
+    CPPUNIT_TEST(testTdf128218);
     CPPUNIT_TEST(testTdf128218);
     CPPUNIT_TEST(testTdf71271);
     CPPUNIT_TEST(testTdf43003);
+    CPPUNIT_TEST(testTdf133887);
+    CPPUNIT_TEST(testTdf133889);
     CPPUNIT_TEST(testTdf138646);
+    CPPUNIT_TEST(testTdf105558);
     CPPUNIT_TEST(testTdf90278);
 
     CPPUNIT_TEST_SUITE_END();
@@ -104,10 +113,9 @@ void ScMacrosTest::saveAndReload(css::uno::Reference<css::lang::XComponent>& xCo
 void ScMacrosTest::testMSP()
 {
     OUString aFileName;
-    createFileURL("MasterScriptProviderProblem.ods", aFileName);
+    createFileURL(u"MasterScriptProviderProblem.ods", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load MasterScriptProviderProblem.ods", xComponent.is());
 
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
@@ -135,11 +143,9 @@ void ScMacrosTest::testMSP()
 void ScMacrosTest::testPasswordProtectedStarBasic()
 {
     OUString aFileName;
-    createFileURL("testTypePassword.ods", aFileName);
+    createFileURL(u"testTypePassword.ods", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load testTypePassword.ods", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -189,11 +195,9 @@ void ScMacrosTest::testPasswordProtectedStarBasic()
 void ScMacrosTest::testStarBasic()
 {
     OUString aFileName;
-    createFileURL("StarBasic.ods", aFileName);
+    createFileURL(u"StarBasic.ods", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load StarBasic.ods", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -337,10 +341,8 @@ void ScMacrosTest::testVba()
     for (const auto& rTestInfo : testInfo)
     {
         OUString aFileName;
-        createFileURL(rTestInfo.sFileBaseName + "xls", aFileName);
+        createFileURL(OUString(rTestInfo.sFileBaseName + "xls"), aFileName);
         uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-        OUString sMsg( "Failed to load " + aFileName );
-        CPPUNIT_ASSERT_MESSAGE( OUStringToOString( sMsg, RTL_TEXTENCODING_UTF8 ).getStr(), xComponent.is() );
 
         // process all events such as OnLoad events etc.
         // otherwise the tend to arrive later at a random
@@ -389,11 +391,9 @@ void ScMacrosTest::testVba()
 void ScMacrosTest::testTdf107885()
 {
     OUString aFileName;
-    createFileURL("tdf107885.xlsm", aFileName);
+    createFileURL(u"tdf107885.xlsm", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load the doc", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -439,11 +439,9 @@ void ScMacrosTest::testTdf107885()
 void ScMacrosTest::testRowColumn()
 {
     OUString aFileName;
-    createFileURL("StarBasic.ods", aFileName);
+    createFileURL(u"StarBasic.ods", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load StarBasic.ods", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -476,11 +474,9 @@ void ScMacrosTest::testRowColumn()
 void ScMacrosTest::testTdf131562()
 {
     OUString aFileName;
-    createFileURL("tdf131562.xlsm", aFileName);
+    createFileURL(u"tdf131562.xlsm", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load the doc", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -510,14 +506,13 @@ void ScMacrosTest::testTdf131562()
 void ScMacrosTest::testPasswordProtectedUnicodeString()
 {
     const OUString sCorrectString(u"English Русский 中文");
-    const OUString sMacroURL(
-        "vnd.sun.Star.script:Protected.Module1.TestUnicodeString?language=Basic&location=document");
-    const OUString sLibName("Protected");
+    static const OUStringLiteral sMacroURL(
+        u"vnd.sun.Star.script:Protected.Module1.TestUnicodeString?language=Basic&location=document");
+    static const OUStringLiteral sLibName(u"Protected");
 
     OUString aFileName;
-    createFileURL("tdf57113.ods", aFileName);
+    createFileURL(u"tdf57113.ods", aFileName);
     auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-    CPPUNIT_ASSERT(xComponent);
 
     // Check that loading password-protected macro image correctly loads Unicode strings
     {
@@ -569,14 +564,13 @@ void ScMacrosTest::testPasswordProtectedUnicodeString()
 
 void ScMacrosTest::testPasswordProtectedArrayInUserType()
 {
-    const OUString sMacroURL(
-        "vnd.sun.Star.script:Protected.Module1.TestMyType?language=Basic&location=document");
-    const OUString sLibName("Protected");
+    static const OUStringLiteral sMacroURL(
+        u"vnd.sun.Star.script:Protected.Module1.TestMyType?language=Basic&location=document");
+    static const OUStringLiteral sLibName(u"Protected");
 
     OUString aFileName;
-    createFileURL("ProtectedArrayInCustomType.ods", aFileName);
+    createFileURL(u"ProtectedArrayInCustomType.ods", aFileName);
     auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-    CPPUNIT_ASSERT(xComponent);
 
     // Check that loading password-protected macro image correctly loads array bounds
     {
@@ -629,11 +623,9 @@ void ScMacrosTest::testPasswordProtectedArrayInUserType()
 void ScMacrosTest::testTdf114427()
 {
     OUString aFileName;
-    createFileURL("tdf114427.ods", aFileName);
+    createFileURL(u"tdf114427.ods", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load the doc", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -665,11 +657,9 @@ void ScMacrosTest::testTdf114427()
 void ScMacrosTest::testTdf107902()
 {
     OUString aFileName;
-    createFileURL("tdf107902.xlsm", aFileName);
+    createFileURL(u"tdf107902.xlsm", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load the doc", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -716,10 +706,8 @@ void ScMacrosTest::testTdf131296_legacy()
     });
 
     OUString aFileName;
-    createFileURL("tdf131296_legacy.ods", aFileName);
+    createFileURL(u"tdf131296_legacy.ods", aFileName);
     auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-    CPPUNIT_ASSERT(xComponent);
-
     {
         Any aRet;
         Sequence<sal_Int16> aOutParamIndex;
@@ -756,10 +744,8 @@ void ScMacrosTest::testTdf131296_new()
     });
 
     OUString aFileName;
-    createFileURL("tdf131296_new.ods", aFileName);
+    createFileURL(u"tdf131296_new.ods", aFileName);
     auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-    CPPUNIT_ASSERT(xComponent);
-
     {
         Any aRet;
         Sequence<sal_Int16> aOutParamIndex;
@@ -783,14 +769,53 @@ void ScMacrosTest::testTdf131296_new()
     xCloseable->close(true);
 }
 
+void ScMacrosTest::testTdf46119()
+{
+    OUString aFileName;
+    createFileURL(u"tdf46119.ods", aFileName);
+    uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
+
+    Any aRet;
+    Sequence< sal_Int16 > aOutParamIndex;
+    Sequence< Any > aOutParam;
+    Sequence< uno::Any > aParams;
+
+    SfxObjectShell* pFoundShell = SfxObjectShell::GetShellFromComponent(xComponent);
+
+    CPPUNIT_ASSERT_MESSAGE("Failed to access document shell", pFoundShell);
+    ScDocShell* pDocSh = static_cast<ScDocShell*>(pFoundShell);
+    ScDocument& rDoc = pDocSh->GetDocument();
+
+    SfxObjectShell::CallXScript(
+        xComponent,
+        "vnd.sun.Star.script:Standard.Module1.Main?language=Basic&location=document",
+        aParams, aRet, aOutParamIndex, aOutParam);
+
+    CPPUNIT_ASSERT_EQUAL(OUString("0.074"), rDoc.GetString(ScAddress(2, 24, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.067"), rDoc.GetString(ScAddress(2, 25, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.273"), rDoc.GetString(ScAddress(2, 26, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.259"), rDoc.GetString(ScAddress(2, 27, 0)));
+
+    CPPUNIT_ASSERT_EQUAL(OUString("0.097"), rDoc.GetString(ScAddress(3, 24, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.087"), rDoc.GetString(ScAddress(3, 25, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.311"), rDoc.GetString(ScAddress(3, 26, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.296"), rDoc.GetString(ScAddress(3, 27, 0)));
+
+    CPPUNIT_ASSERT_EQUAL(OUString("0.149"), rDoc.GetString(ScAddress(4, 24, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.134"), rDoc.GetString(ScAddress(4, 25, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.386"), rDoc.GetString(ScAddress(4, 26, 0)));
+    CPPUNIT_ASSERT_EQUAL(OUString("0.366"), rDoc.GetString(ScAddress(4, 27, 0)));
+
+    css::uno::Reference<css::util::XCloseable> xCloseable(xComponent, css::uno::UNO_QUERY_THROW);
+    xCloseable->close(true);
+}
+
 void ScMacrosTest::testTdf128218()
 {
     OUString aFileName;
-    createFileURL("tdf128218.ods", aFileName);
+    createFileURL(u"tdf128218.ods", aFileName);
     uno::Reference< css::lang::XComponent > xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
 
-    CPPUNIT_ASSERT_MESSAGE("Failed to load the doc", xComponent.is());
-
     Any aRet;
     Sequence< sal_Int16 > aOutParamIndex;
     Sequence< Any > aOutParam;
@@ -817,7 +842,6 @@ void ScMacrosTest::testTdf128218()
 void ScMacrosTest::testTdf71271()
 {
     uno::Reference<lang::XComponent> xComponent = loadFromDesktop("private:factory/scalc");
-    CPPUNIT_ASSERT(xComponent);
 
     {
         uno::Reference<sheet::XSpreadsheetDocument> xDoc(xComponent, uno::UNO_QUERY_THROW);
@@ -848,9 +872,8 @@ void ScMacrosTest::testTdf71271()
 void ScMacrosTest::testTdf43003()
 {
     OUString aFileName;
-    createFileURL("tdf43003.ods", aFileName);
+    createFileURL(u"tdf43003.ods", aFileName);
     auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-    CPPUNIT_ASSERT(xComponent);
 
     SfxObjectShell* pFoundShell = SfxObjectShell::GetShellFromComponent(xComponent);
     CPPUNIT_ASSERT(pFoundShell);
@@ -869,12 +892,69 @@ void ScMacrosTest::testTdf43003()
     xCloseable->close(true);
 }
 
+void ScMacrosTest::testTdf133887()
+{
+    OUString aFileName;
+    createFileURL(u"tdf133887.ods", aFileName);
+    auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
+
+    css::uno::Any aRet;
+    css::uno::Sequence<sal_Int16> aOutParamIndex;
+    css::uno::Sequence<css::uno::Any> aOutParam;
+    css::uno::Sequence<css::uno::Any> aParams{ css::uno::Any(sal_Int16(0)) };
+
+    SfxObjectShell::CallXScript(
+        xComponent,
+        "vnd.sun.Star.script:Standard.Module1.TestInvoke?language=Basic&location=document", aParams,
+        aRet, aOutParamIndex, aOutParam);
+
+    double aReturnValue;
+    aOutParam[0] >>= aReturnValue;
+
+    // Without the fix in place, this test would have failed with
+    // - Expected: 6.75
+    // - Actual  : 7
+
+    CPPUNIT_ASSERT_EQUAL(6.75, aReturnValue);
+
+    css::uno::Reference<css::util::XCloseable> xCloseable(xComponent, css::uno::UNO_QUERY_THROW);
+    xCloseable->close(true);
+}
+
+void ScMacrosTest::testTdf133889()
+{
+    OUString aFileName;
+    createFileURL(u"tdf133889.ods", aFileName);
+    auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
+
+    css::uno::Any aRet;
+    css::uno::Sequence<sal_Int16> aOutParamIndex;
+    css::uno::Sequence<css::uno::Any> aOutParam;
+    css::uno::Sequence<css::uno::Any> aParams{ css::uno::Any(sal_Int32(0)) };
+
+    SfxObjectShell::CallXScript(
+        xComponent,
+        "vnd.sun.Star.script:Standard.Module1.TestInvoke?language=Basic&location=document", aParams,
+        aRet, aOutParamIndex, aOutParam);
+
+    sal_Int32 aReturnValue;
+    aOutParam[0] >>= aReturnValue;
+
+    // Without the fix in place, this test would have failed with
+    // - Expected: 100000
+    // - Actual  : 0
+
+    CPPUNIT_ASSERT_EQUAL(sal_Int32(100000), aReturnValue);
+
+    css::uno::Reference<css::util::XCloseable> xCloseable(xComponent, css::uno::UNO_QUERY_THROW);
+    xCloseable->close(true);
+}
+
 void ScMacrosTest::testTdf138646()
 {
     OUString aFileName;
     createFileURL(u"tdf138646.ods", aFileName);
     auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
-    CPPUNIT_ASSERT_MESSAGE("Failed to load the doc", xComponent.is());
 
     SfxObjectShell* pFoundShell = SfxObjectShell::GetShellFromComponent(xComponent);
     CPPUNIT_ASSERT_MESSAGE("Failed to access document shell", pFoundShell);
@@ -915,6 +995,28 @@ void ScMacrosTest::testTdf138646()
     pDocSh->DoClose();
 }
 
+void ScMacrosTest::testTdf105558()
+{
+    OUString aFileName;
+    createFileURL(u"tdf105558.ods", aFileName);
+    auto xComponent = loadFromDesktop(aFileName, "com.sun.star.sheet.SpreadsheetDocument");
+
+    SfxObjectShell* pFoundShell = SfxObjectShell::GetShellFromComponent(xComponent);
+    CPPUNIT_ASSERT(pFoundShell);
+
+    ScDocShellRef xDocSh = dynamic_cast<ScDocShell*>(pFoundShell);
+    CPPUNIT_ASSERT(xDocSh);
+    ScDocument& rDoc = xDocSh->GetDocument();
+
+    // Without the fix in place, this test would have failed with
+    // - Expected: 5.5
+    // - Actual  : 0
+    CPPUNIT_ASSERT_EQUAL(5.5, rDoc.GetValue(ScAddress(0, 0, 0)));
+
+    css::uno::Reference<css::util::XCloseable> xCloseable(xComponent, css::uno::UNO_QUERY_THROW);
+    xCloseable->close(true);
+}
+
 void ScMacrosTest::testTdf90278()
 {
     OUString aFileName;
