@@ -6,17 +6,8 @@
 #
 from uitest.framework import UITestCase
 from libreoffice.uno.propertyvalue import mkPropertyValues
-from libreoffice.calc.document import get_row
-import org.libreoffice.unotest
-import pathlib
-
-def get_url_for_data_file(file_name):
-    return pathlib.Path(org.libreoffice.unotest.makeCopyFromTDOC(file_name)).as_uri()
-
-def is_row_hidden(doc, index):
-    row = get_row(doc, index)
-    val = row.getPropertyValue("IsVisible")
-    return not val
+from libreoffice.calc.document import is_row_hidden
+from uitest.uihelper.common import get_url_for_data_file
 
 #Bug 122260 - EDITING Autofilters not properly cleared
 class tdf122260(UITestCase):
