@@ -5,12 +5,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 from uitest.framework import UITestCase
-from uitest.uihelper.common import get_state_as_dict
-from uitest.uihelper.common import select_pos
-from uitest.uihelper.calc import enter_text_to_cell
-from libreoffice.calc.document import get_sheet_from_doc
-from libreoffice.calc.conditional_format import get_conditional_format_from_sheet
-from uitest.debug import sleep
+from uitest.uihelper.common import select_by_text
 from libreoffice.calc.document import get_cell_by_position
 from libreoffice.uno.propertyvalue import mkPropertyValues
 
@@ -34,9 +29,7 @@ class fillRandomNumber(UITestCase):
         xdecimalplacesspin = xDialog.getChild("decimal-places-spin")
 
         xcellrangeedit.executeAction("TYPE", mkPropertyValues({"TEXT":"$Sheet1.$A$1:$A$2"}))
-        props = {"TEXT": "Uniform Integer"}
-        actionProps = mkPropertyValues(props)
-        xdistributioncombo.executeAction("SELECT", actionProps)
+        select_by_text(xdistributioncombo, "Uniform Integer")
 
         xparameter1spin.executeAction("UP", tuple())
         xparameter2spin.executeAction("UP", tuple())
