@@ -7,12 +7,8 @@
 from uitest.framework import UITestCase
 from uitest.uihelper.common import get_state_as_dict
 from uitest.uihelper.common import select_pos
+from uitest.uihelper.common import select_by_text
 from uitest.uihelper.common import change_measurement_unit
-from uitest.uihelper.calc import enter_text_to_cell
-from libreoffice.calc.document import get_sheet_from_doc
-from libreoffice.calc.conditional_format import get_conditional_format_from_sheet
-from uitest.debug import sleep
-from libreoffice.calc.document import get_cell_by_position
 from libreoffice.uno.propertyvalue import mkPropertyValues
 
 class formatCell(UITestCase):
@@ -38,17 +34,7 @@ class formatCell(UITestCase):
         xlanguagelb = xDialog.getChild("languagelb")
         xformatted = xDialog.getChild("formatted")
         #language
-        props3 = {"TEXT": "English (USA)"}
-        actionProps3 = mkPropertyValues(props3)
-        xlanguagelb.executeAction("SELECT", actionProps3)
-        #set Number
-        props = {"TEXT": "Number"}
-        actionProps = mkPropertyValues(props)
-        xliststore1.executeAction("SELECT", actionProps)
-        #set Standard
-        props2 = {"TEXT": "Standard"}
-        actionProps2 = mkPropertyValues(props2)
-        xliststore2.executeAction("SELECT", actionProps2)
+        select_by_text(xlanguagelb, "English (USA)")
         #other properties
         xdecimalsed.executeAction("UP", tuple())
         xleadzerosed.executeAction("UP", tuple())
@@ -221,20 +207,14 @@ class formatCell(UITestCase):
         xcheckHyphActive = xDialog.getChild("checkHyphActive")
         xcomboTextDirBox = xDialog.getChild("comboTextDirBox")
 
-        props = {"TEXT": "Left"}
-        actionProps = mkPropertyValues(props)
-        comboboxHorzAlign.executeAction("SELECT", actionProps)
+        select_by_text(comboboxHorzAlign, "Left")
         xspinIndentFrom.executeAction("UP", tuple())
         indentVal = get_state_as_dict(xspinIndentFrom)["Text"]
-        props2 = {"TEXT": "Top"}
-        actionProps2 = mkPropertyValues(props2)
-        xcomboboxVertAlign.executeAction("SELECT", actionProps2)
+        select_by_text(xcomboboxVertAlign, "Top")
         xcheckVertStack.executeAction("CLICK", tuple())
         xcheckWrapTextAuto.executeAction("CLICK", tuple())
         xcheckHyphActive.executeAction("CLICK", tuple())
-        props3 = {"TEXT": "Left-to-right (LTR)"}
-        actionProps3 = mkPropertyValues(props3)
-        xcomboTextDirBox.executeAction("SELECT", actionProps3)
+        select_by_text(xcomboTextDirBox, "Left-to-right (LTR)")
         xOK = xDialog.getChild("ok")
         xOK.executeAction("CLICK", tuple())
         #Verify- select cell A1
