@@ -9,26 +9,31 @@
 
 #include <sal/config.h>
 
-#include <cstdlib>
+#include <string_view>
 
 #include <test/calc_unoapi_test.hxx>
 
-#include <comphelper/dispatchcommand.hxx>
 #include <comphelper/propertyvalue.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/request.hxx>
+#include <svl/intitem.hxx>
 #include <svx/svdoashp.hxx>
 #include <svx/svdomeas.hxx>
-#include <svx/svdpage.hxx>
 #include <svx/svdorect.hxx>
+#include <svx/svdouno.hxx>
+#include <svx/svdpage.hxx>
 #include <unotools/tempfile.hxx>
 #include <vcl/keycodes.hxx>
 
 #include <docsh.hxx>
 #include <drwlayer.hxx>
+#include <fuconcustomshape.hxx>
+#include <fuconuno.hxx>
 #include <tabvwsh.hxx>
 #include <userdat.hxx>
 
+#include <com/sun/star/beans/XPropertySet.hpp>
+
 #include <sc.hrc> // defines of slot-IDs
 
 using namespace css;
@@ -41,7 +46,9 @@ public:
     ScShapeTest();
     void saveAndReload(css::uno::Reference<css::lang::XComponent>& xComponent,
                        const OUString& rFilter);
-    void testTdf143619_validation_circle_pos();
+    void testTdf140252_DragCreateFormControl();
+    void testTdf134355_DragCreateCustomShape();
+    void testTdf140252_LayerOfControl();
     void testTdf137082_LTR_to_RTL();
     void testTdf137082_RTL_cell_anchored();
     void testTdf137081_RTL_page_anchored();
@@ -65,7 +72,9 @@ public:
     void testCustomShapeCellAnchoredRotatedShape();
 
     CPPUNIT_TEST_SUITE(ScShapeTest);
-    CPPUNIT_TEST(testTdf143619_validation_circle_pos);
+    CPPUNIT_TEST(testTdf140252_DragCreateFormControl);
+    CPPUNIT_TEST(testTdf134355_DragCreateCustomShape);
+    CPPUNIT_TEST(testTdf140252_LayerOfControl);
     CPPUNIT_TEST(testTdf137082_LTR_to_RTL);
     CPPUNIT_TEST(testTdf137082_RTL_cell_anchored);
     CPPUNIT_TEST(testTdf137081_RTL_page_anchored);
@@ -111,44 +120,48 @@ void ScShapeTest::saveAndReload(css::uno::Reference<css::lang::XComponent>& xCom
     xComponent = loadFromDesktop(aTempFile.GetURL(), "com.sun.star.sheet.SpreadsheetDocument");
 }
 
-static void lcl_AssertRectEqualWithTolerance(const OString& sInfo,
+static void lcl_AssertRectEqualWithTolerance(std::string_view sInfo,
                                              const tools::Rectangle& rExpected,
                                              const tools::Rectangle& rActual,
                                              const sal_Int32 nTolerance)
 {
     // Left
-    OString sMsg = sInfo + " Left expected " + OString::number(rExpected.Left()) + " actual "
-                   + OString::number(rActual.Left()) + " Tolerance " + OString::number(nTolerance);
+    OString sMsg = OString::Concat(sInfo) + " Left expected " + OString::number(rExpected.Left())
+                   + " actual " + OString::number(rActual.Left()) + " Tolerance "
+                   + OString::number(nTolerance);
     CPPUNIT_ASSERT_MESSAGE(sMsg.getStr(),
                            std::abs(rExpected.Left() - rActual.Left()) <= nTolerance);
 
     // Top
-    sMsg = sInfo + " Top expected " + OString::number(rExpected.Top()) + " actual "
+    sMsg = OString::Concat(sInfo) + " Top expected " + OString::number(rExpected.Top()) + " actual "
            + OString::number(rActual.Top()) + " Tolerance " + OString::number(nTolerance);
     CPPUNIT_ASSERT_MESSAGE(sMsg.getStr(), std::abs(rExpected.Top() - rActual.Top()) <= nTolerance);
 
     // Width
-    sMsg = sInfo + " Width expected " + OString::number(rExpected.GetWidth()) + " actual "
-           + OString::number(rActual.GetWidth()) + " Tolerance " + OString::number(nTolerance);
+    sMsg = OString::Concat(sInfo) + " Width expected " + OString::number(rExpected.GetWidth())
+           + " actual " + OString::number(rActual.GetWidth()) + " Tolerance "
+           + OString::number(nTolerance);
     CPPUNIT_ASSERT_MESSAGE(sMsg.getStr(),
                            std::abs(rExpected.GetWidth() - rActual.GetWidth()) <= nTolerance);
 
     // Height
-    sMsg = sInfo + " Height expected " + OString::number(rExpected.GetHeight()) + " actual "
-           + OString::number(rActual.GetHeight()) + " Tolerance " + OString::number(nTolerance);
+    sMsg = OString::Concat(sInfo) + " Height expected " + OString::number(rExpected.GetHeight())
+           + " actual " + OString::number(rActual.GetHeight()) + " Tolerance "
+           + OString::number(nTolerance);
     CPPUNIT_ASSERT_MESSAGE(sMsg.getStr(),
                            std::abs(rExpected.GetHeight() - rActual.GetHeight()) <= nTolerance);
 }
 
-static void lcl_AssertPointEqualWithTolerance(const OString& sInfo, const Point rExpected,
+static void lcl_AssertPointEqualWithTolerance(std::string_view sInfo, const Point rExpected,
                                               const Point rActual, const sal_Int32 nTolerance)
 {
     // X
-    OString sMsg = sInfo + " X expected " + OString::number(rExpected.X()) + " actual "
-                   + OString::number(rActual.X()) + " Tolerance " + OString::number(nTolerance);
+    OString sMsg = OString::Concat(sInfo) + " X expected " + OString::number(rExpected.X())
+                   + " actual " + OString::number(rActual.X()) + " Tolerance "
+                   + OString::number(nTolerance);
     CPPUNIT_ASSERT_MESSAGE(sMsg.getStr(), std::abs(rExpected.X() - rActual.X()) <= nTolerance);
     // Y
-    sMsg = sInfo + " Y expected " + OString::number(rExpected.Y()) + " actual "
+    sMsg = OString::Concat(sInfo) + " Y expected " + OString::number(rExpected.Y()) + " actual "
            + OString::number(rActual.Y()) + " Tolerance " + OString::number(nTolerance);
     CPPUNIT_ASSERT_MESSAGE(sMsg.getStr(), std::abs(rExpected.Y() - rActual.Y()) <= nTolerance);
 }
@@ -191,34 +204,131 @@ static SdrObject* lcl_getSdrObjectWithAssert(ScDocument& rDoc, sal_uInt16 nObjNu
     return pObj;
 }
 
-void ScShapeTest::testTdf143619_validation_circle_pos()
+void ScShapeTest::testTdf140252_DragCreateFormControl()
 {
-    // Load a document, which has validation circle around cell E6.
-
+    // Error was, that drag-created form controls were initially not on layer 'controls' and thus
+    // other shapes could be placed in front of form controls.
+    // Load an empty document.
     OUString aFileURL;
-    createFileURL(u"tdf143619_validationCirclePos.ods", aFileURL);
+    createFileURL(u"ManualColWidthRowHeight.ods", aFileURL);
+    uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
+    CPPUNIT_ASSERT(xComponent.is());
+
+    // Get ScTabViewShell
+    ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
+    ScTabViewShell* pTabViewShell = lcl_getScTabViewShellWithAssert(pDocSh);
+
+    // drag-create a push button as example of form control
+    SfxUInt16Item aIdentifierItem(SID_FM_CONTROL_IDENTIFIER, OBJ_FM_BUTTON);
+    SfxUInt32Item aInventorItem(SID_FM_CONTROL_INVENTOR, sal_uInt32(SdrInventor::FmForm));
+    const SfxPoolItem* pArgs[] = { &aIdentifierItem, &aInventorItem, nullptr };
+    pTabViewShell->GetViewData().GetDispatcher().Execute(SID_FM_CREATE_CONTROL,
+                                                         SfxCallMode::SYNCHRON, pArgs);
+    // above includes creation of FuConstUnoControl and call of its Activate() method
+
+    // get FuConstUnoControl
+    ScTabView* pTabView = pTabViewShell->GetViewData().GetView();
+    CPPUNIT_ASSERT(pTabView);
+    FuConstUnoControl* pFuConstUC = static_cast<FuConstUnoControl*>(pTabView->GetDrawFuncPtr());
+    CPPUNIT_ASSERT(pFuConstUC);
+
+    // drag-create shape, points are in pixel
+    MouseEvent aMouseEvent(Point(50, 100), 1, MouseEventModifiers::NONE, MOUSE_LEFT, 0);
+    pFuConstUC->MouseButtonDown(aMouseEvent);
+    aMouseEvent = MouseEvent(Point(200, 250), 1, MouseEventModifiers::DRAGMOVE, MOUSE_LEFT, 0);
+    pFuConstUC->MouseMove(aMouseEvent);
+    aMouseEvent = MouseEvent(Point(200, 250), 1, MouseEventModifiers::NONE, MOUSE_LEFT, 0);
+    pFuConstUC->MouseButtonUp(aMouseEvent);
+    pFuConstUC->Deactivate();
+    pTabViewShell->SetDrawShell(false);
+
+    // Get document and newly created push button.
+    ScDocument& rDoc = pDocSh->GetDocument();
+    SdrUnoObj* pObj = static_cast<SdrUnoObj*>(lcl_getSdrObjectWithAssert(rDoc, 0));
+
+    // Without the fix in place, the shape would be on layer SC_LAYER_FRONT (0)
+    sal_uInt8 nExpectedID = sal_uInt8(SC_LAYER_CONTROLS);
+    sal_uInt8 nActualID = pObj->GetLayer().get();
+    CPPUNIT_ASSERT_EQUAL(nExpectedID, nActualID);
+
+    pDocSh->DoClose();
+}
+
+void ScShapeTest::testTdf134355_DragCreateCustomShape()
+{
+    // Error was, that drag-created custom shapes were initially on layer "controls", although that
+    // layer is exclusively for form controls. Effect was, that other shapes could not be brought in
+    // front of custom shapes.
+    // Load an empty document.
+    OUString aFileURL;
+    createFileURL(u"ManualColWidthRowHeight.ods", aFileURL);
+    uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
+    CPPUNIT_ASSERT(xComponent.is());
+
+    // Get ScTabView
+    ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
+    ScTabViewShell* pTabViewShell = lcl_getScTabViewShellWithAssert(pDocSh);
+    ScTabView* pTabView = pTabViewShell->GetViewData().GetView();
+
+    // drag-create custom shape
+    uno::Sequence<beans::PropertyValue> aPropertyValues = {
+        comphelper::makePropertyValue("SymbolShapes", OUString("smiley")),
+    };
+    dispatchCommand(xComponent, ".uno:SymbolShapes", aPropertyValues);
+    // above includes creation of FuConstCustomShape and call of its Activate() method
+    FuConstCustomShape* pFuConstCS = static_cast<FuConstCustomShape*>(pTabView->GetDrawFuncPtr());
+    CPPUNIT_ASSERT(pFuConstCS);
+    // points are in pixel
+    MouseEvent aMouseEvent(Point(50, 100), 1, MouseEventModifiers::NONE, MOUSE_LEFT, 0);
+    pFuConstCS->MouseButtonDown(aMouseEvent);
+    aMouseEvent = MouseEvent(Point(200, 250), 1, MouseEventModifiers::DRAGMOVE, MOUSE_LEFT, 0);
+    pFuConstCS->MouseMove(aMouseEvent);
+    aMouseEvent = MouseEvent(Point(200, 250), 1, MouseEventModifiers::NONE, MOUSE_LEFT, 0);
+    pFuConstCS->MouseButtonUp(aMouseEvent);
+    pFuConstCS->Deactivate();
+    pTabViewShell->SetDrawShell(false);
+
+    // Get document and newly created custom shape.
+    ScDocument& rDoc = pDocSh->GetDocument();
+    SdrObjCustomShape* pObj = static_cast<SdrObjCustomShape*>(lcl_getSdrObjectWithAssert(rDoc, 0));
+
+    // Without the fix in place, the shape would be on layer SC_LAYER_CONTROLS (3)
+    sal_uInt8 nExpectedID = sal_uInt8(SC_LAYER_FRONT);
+    sal_uInt8 nActualID = pObj->GetLayer().get();
+    CPPUNIT_ASSERT_EQUAL(nExpectedID, nActualID);
+
+    pDocSh->DoClose();
+}
+
+void ScShapeTest::testTdf140252_LayerOfControl()
+{
+    // Error was, that a newly inserted control shape was put on layer
+    // "vorne" instead of layer "control".
+    // Load an empty document.
+    OUString aFileURL;
+    createFileURL(u"ManualColWidthRowHeight.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
 
-    // Get document
+    // Get ScDocShell
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
-    ScDocument& rDoc = pDocSh->GetDocument();
 
-    // Get shape. That is the validation circle.
+    // Create default push button
+    SfxUInt16Item aIdentifierItem(SID_FM_CONTROL_IDENTIFIER, OBJ_FM_BUTTON);
+    SfxUInt32Item aInventorItem(SID_FM_CONTROL_INVENTOR, sal_uInt32(SdrInventor::FmForm));
+    const SfxPoolItem* pArgs[] = { &aIdentifierItem, &aInventorItem, nullptr };
+    const SfxPoolItem* pInternalArgs[] = { nullptr };
+    ScTabViewShell* pTabViewShell = lcl_getScTabViewShellWithAssert(pDocSh);
+    pTabViewShell->GetViewData().GetDispatcher().Execute(
+        SID_FM_CREATE_CONTROL, SfxCallMode::SYNCHRON, pArgs, KEY_MOD1, pInternalArgs);
+
+    // Get document and newly created push button.
+    ScDocument& rDoc = pDocSh->GetDocument();
     SdrObject* pObj = lcl_getSdrObjectWithAssert(rDoc, 0);
 
-    // Error was, that deleting row and col before E6 does not move circle to D5, but to B3.
-    // Delete first row and first column.
-    uno::Sequence<beans::PropertyValue> aPropertyValues = {
-        comphelper::makePropertyValue("ToPoint", OUString("$A$1")),
-    };
-    dispatchCommand(xComponent, ".uno:GoToCell", aPropertyValues);
-    dispatchCommand(xComponent, ".uno:DeleteRows", {});
-    dispatchCommand(xComponent, ".uno:GoToCell", aPropertyValues);
-    dispatchCommand(xComponent, ".uno:DeleteColumns", {});
-
-    // Without fix in place the position was (2007, 833)
-    Point aPos = pObj->GetSnapRect().TopLeft();
-    lcl_AssertPointEqualWithTolerance("after row and col delete", Point(6523, 1736), aPos, 1);
+    // Check LayerID of object. Without the fix in place it was 0.
+    sal_uInt8 nExpectedID = sal_uInt8(SC_LAYER_CONTROLS);
+    sal_uInt8 nActualID = pObj->GetLayer().get();
+    CPPUNIT_ASSERT_EQUAL(nExpectedID, nActualID);
 
     pDocSh->DoClose();
 }
@@ -233,7 +343,6 @@ void ScShapeTest::testTdf137082_LTR_to_RTL()
     OUString aFileURL;
     createFileURL(u"tdf137082_LTR_arrow_image.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -241,21 +350,22 @@ void ScShapeTest::testTdf137082_LTR_to_RTL()
 
     // Get objects and their transformation angles
     SdrObject* pObjCS = lcl_getSdrObjectWithAssert(rDoc, 0);
-    const tools::Long nRotateLTR = pObjCS->GetRotateAngle();
+    const Degree100 nRotateLTR = pObjCS->GetRotateAngle();
     SdrObject* pObjImage = lcl_getSdrObjectWithAssert(rDoc, 1);
-    const tools::Long nShearLTR = pObjImage->GetShearAngle();
+    const Degree100 nShearLTR = pObjImage->GetShearAngle();
 
     // Switch to RTL
     ScTabViewShell* pViewShell = lcl_getScTabViewShellWithAssert(pDocSh);
     pViewShell->GetViewData().GetDispatcher().Execute(FID_TAB_RTL);
 
     // Check custom shape is mirrored, image not.
-    const tools::Long nShearRTLActual = pObjImage->GetShearAngle();
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("image should not be mirrored", nShearLTR, nShearRTLActual);
-    const tools::Long nRotateRTLExpected = 36000.00 - nRotateLTR;
-    const tools::Long nRotateRTLActual = pObjCS->GetRotateAngle();
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("custom shape should be mirrored", nRotateRTLExpected,
-                                 nRotateRTLActual);
+    const Degree100 nShearRTLActual = pObjImage->GetShearAngle();
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("image should not be mirrored", nShearLTR.get(),
+                                 nShearRTLActual.get());
+    const Degree100 nRotateRTLExpected = 36000_deg100 - nRotateLTR;
+    const Degree100 nRotateRTLActual = pObjCS->GetRotateAngle();
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("custom shape should be mirrored", nRotateRTLExpected.get(),
+                                 nRotateRTLActual.get());
 
     pDocSh->DoClose();
 }
@@ -263,11 +373,10 @@ void ScShapeTest::testTdf137082_LTR_to_RTL()
 void ScShapeTest::testTdf137082_RTL_cell_anchored()
 {
     // Error was, that cell anchored custom shapes wrote wrong offsets to file and thus were wrong on
-    // reloading. The file contains one custome shape with "resize" and another one without.
+    // reloading. The file contains one custom shape with "resize" and another one without.
     OUString aFileURL;
     createFileURL(u"tdf137082_RTL_cell_anchored.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -310,7 +419,6 @@ void ScShapeTest::testTdf137081_RTL_page_anchored()
     OUString aFileURL;
     createFileURL(u"tdf137081_RTL_page_anchored.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -377,7 +485,6 @@ void ScShapeTest::testTdf139583_Rotate180deg()
     OUString aFileURL;
     createFileURL(u"ManualColWidthRowHeight.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and draw page
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -395,7 +502,7 @@ void ScShapeTest::testTdf139583_Rotate180deg()
     // Anchor "to cell (resize with cell)" and then rotate it by 180deg around center
     // The order is important here.
     ScDrawLayer::SetCellAnchoredFromPosition(*pObj, rDoc, 0 /*SCTAB*/, true /*bResizeWithCell*/);
-    pObj->Rotate(aRect.Center(), 18000.0, 0.0, -1.0);
+    pObj->Rotate(aRect.Center(), Degree100(18000), 0.0, -1.0);
 
     // Save and reload.
     saveAndReload(xComponent, "calc8");
@@ -414,11 +521,10 @@ void ScShapeTest::testTdf139583_Rotate180deg()
 void ScShapeTest::testTdf137033_FlipHori_Resize()
 {
     // Load a document, which has a rotated custom shape, which is horizontal flipped. Error was, that
-    // if such shape was anchored "resize with cell", then after save and reload it was destorted.
+    // if such shape was anchored "resize with cell", then after save and reload it was distorted.
     OUString aFileURL;
-    createFileURL("tdf137033_FlipHoriRotCustomShape.ods", aFileURL);
+    createFileURL(u"tdf137033_FlipHoriRotCustomShape.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -455,9 +561,8 @@ void ScShapeTest::testTdf137033_RotShear_ResizeHide()
 
     // Load a document, which has a rotated and sheared shape, anchored to cell with resize.
     OUString aFileURL;
-    createFileURL("tdf137033_RotShearResizeAnchor.ods", aFileURL);
+    createFileURL(u"tdf137033_RotShearResizeAnchor.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -472,16 +577,17 @@ void ScShapeTest::testTdf137033_RotShear_ResizeHide()
 
     // Verify hiding has changed shape geometry as expected
     tools::Rectangle aSnapRect(pObj->GetSnapRect());
-    tools::Long aRotateAngle(pObj->GetRotateAngle());
-    tools::Long aShearAngle(pObj->GetShearAngle());
+    Degree100 aRotateAngle(pObj->GetRotateAngle());
+    Degree100 aShearAngle(pObj->GetShearAngle());
     // mathematical exact would be Point(3868, 4795), Size(9763, 1909)
     // current values as of LO 7.2
     const tools::Rectangle aExpectRect(Point(3871, 4796), Size(9764, 1910));
-    const tools::Long aExpectRotateAngle(20923);
-    const tools::Long aExpectShearAngle(-6572);
-    CPPUNIT_ASSERT_MESSAGE("Hide rows, shear angle: ", abs(aShearAngle - aExpectShearAngle) <= 1);
+    const Degree100 aExpectRotateAngle(20923_deg100);
+    const Degree100 aExpectShearAngle(-6572_deg100);
+    CPPUNIT_ASSERT_MESSAGE("Hide rows, shear angle: ",
+                           abs(aShearAngle - aExpectShearAngle) <= 1_deg100);
     CPPUNIT_ASSERT_MESSAGE("Hide rows, rotate angle: ",
-                           abs(aRotateAngle - aExpectRotateAngle) <= 1);
+                           abs(aRotateAngle - aExpectRotateAngle) <= 1_deg100);
     lcl_AssertRectEqualWithTolerance("Reload: wrong pos or size", aExpectRect, aSnapRect, 1);
 
     // Save and reload.
@@ -497,8 +603,10 @@ void ScShapeTest::testTdf137033_RotShear_ResizeHide()
     aSnapRect = pObj->GetSnapRect();
     aRotateAngle = pObj->GetRotateAngle();
     aShearAngle = pObj->GetShearAngle();
-    CPPUNIT_ASSERT_MESSAGE("Reload, shear angle: ", abs(aShearAngle - aExpectShearAngle) <= 3);
-    CPPUNIT_ASSERT_MESSAGE("Reload, rotate angle: ", abs(aRotateAngle - aExpectRotateAngle) <= 3);
+    CPPUNIT_ASSERT_MESSAGE("Reload, shear angle: ",
+                           abs(aShearAngle - aExpectShearAngle) <= 3_deg100);
+    CPPUNIT_ASSERT_MESSAGE("Reload, rotate angle: ",
+                           abs(aRotateAngle - aExpectRotateAngle) <= 3_deg100);
     lcl_AssertRectEqualWithTolerance("Reload: wrong pos or size", aExpectRect, aSnapRect, 4);
 
     pDocSh->DoClose();
@@ -512,9 +620,8 @@ void ScShapeTest::testTdf137033_RotShear_Hide()
 
     // Load a document, which has a rotated and sheared shape, anchored to cell, without resize.
     OUString aFileURL;
-    createFileURL("tdf137033_RotShearCellAnchor.ods", aFileURL);
+    createFileURL(u"tdf137033_RotShearCellAnchor.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -549,14 +656,16 @@ void ScShapeTest::testTdf137033_RotShear_Hide()
 #if !defined MACOSX
 void ScShapeTest::testTdf137576_LogicRectInDefaultMeasureline()
 {
+    if (!IsDefaultDPI())
+        return;
+
     // Error was, that the empty logical rectangle of a default measure line (Ctrl+Click)
     // resulted in zeros in NonRotatedAnchor and a wrong position when reloading.
 
     // Load an empty document.
     OUString aFileURL;
-    createFileURL("ManualColWidthRowHeight.ods", aFileURL);
+    createFileURL(u"ManualColWidthRowHeight.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get ScDocShell
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -611,9 +720,8 @@ void ScShapeTest::testTdf137576_LogicRectInNewMeasureline()
 
     // Load an empty document
     OUString aFileURL;
-    createFileURL("ManualColWidthRowHeight.ods", aFileURL);
+    createFileURL(u"ManualColWidthRowHeight.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and draw page
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -634,21 +742,22 @@ void ScShapeTest::testTdf137576_LogicRectInNewMeasureline()
     ScDrawObjData* pNData = ScDrawLayer::GetNonRotatedObjData(pObj);
     CPPUNIT_ASSERT_MESSAGE("Failed to get NonRotatedAnchor", pNData);
     // Without the fix all four values would be zero.
-    CPPUNIT_ASSERT(pNData->maStart.Col() == 1 && pNData->maStart.Row() == 2);
-    CPPUNIT_ASSERT(pNData->maEnd.Col() == 7 && pNData->maEnd.Row() == 2);
+    CPPUNIT_ASSERT_EQUAL(SCCOL(1), pNData->maStart.Col());
+    CPPUNIT_ASSERT_EQUAL(SCROW(2), pNData->maStart.Row());
+    CPPUNIT_ASSERT_EQUAL(SCCOL(7), pNData->maEnd.Col());
+    CPPUNIT_ASSERT_EQUAL(SCROW(2), pNData->maEnd.Row());
 
     pDocSh->DoClose();
 }
 
 void ScShapeTest::testMeasurelineHideColSave()
 {
-    // The document contains a SdrMeasureObj anchored "To Cell (resive with cell)" with start in cell
+    // The document contains a SdrMeasureObj anchored "To Cell (resize with cell)" with start in cell
     // D11 and end in cell I5. Error was, that after hiding col A and saving, start and end point
     // position were lost.
     OUString aFileURL;
-    createFileURL("measurelineHideColSave.ods", aFileURL);
+    createFileURL(u"measurelineHideColSave.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -693,9 +802,8 @@ void ScShapeTest::testHideColsShow()
     // to column E
 
     OUString aFileURL;
-    createFileURL("hideColsShow.ods", aFileURL);
+    createFileURL(u"hideColsShow.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -738,9 +846,8 @@ void ScShapeTest::testTdf138138_MoveCellWithRotatedShape()
     // The document contains a 90deg rotated, cell-anchored rectangle in column D. Insert 2 columns
     // after column B, save and reload. The shape was not correctly moved to column F.
     OUString aFileURL;
-    createFileURL("tdf138138_MoveCellWithRotatedShape.ods", aFileURL);
+    createFileURL(u"tdf138138_MoveCellWithRotatedShape.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -787,9 +894,8 @@ void ScShapeTest::testLoadVerticalFlip()
     // The document has a cell anchored custom shape with vertical flip. Error was, that the
     // flip was lost on loading.
     OUString aFileURL;
-    createFileURL("loadVerticalFlip.ods", aFileURL);
+    createFileURL(u"loadVerticalFlip.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -808,9 +914,8 @@ void ScShapeTest::testTdf117948_CollapseBeforeShape()
     // group, save and reload. The original error was, that the line was on wrong position after reload.
     // After the fix for 'resize with cell', the custom shape had wrong position and size too.
     OUString aFileURL;
-    createFileURL("tdf117948_CollapseBeforeShape.ods", aFileURL);
+    createFileURL(u"tdf117948_CollapseBeforeShape.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and objects
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -862,9 +967,8 @@ void ScShapeTest::testTdf137355_UndoHideRows()
     // Error was, that hiding rows 3 to 6 and undo that action "lost" the shape.
     // Actually it was not lost but hidden.
     OUString aFileURL;
-    createFileURL("tdf137355_UndoHideRows.ods", aFileURL);
+    createFileURL(u"tdf137355_UndoHideRows.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -906,9 +1010,8 @@ void ScShapeTest::testTdf115655_HideDetail()
     // Error was, that after collapsing the group, save and reload, and expanding the group, the image
     // was "lost". Actually is was resized to zero height.
     OUString aFileURL;
-    createFileURL("tdf115655_HideDetail.ods", aFileURL);
+    createFileURL(u"tdf115655_HideDetail.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and image
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -956,9 +1059,8 @@ void ScShapeTest::testFitToCellSize()
     // FitToCellSize should resize and position the shape so,
     // that it fits into its anchor cell. That did not happened.
     OUString aFileURL;
-    createFileURL("tdf119191_FitToCellSize.ods", aFileURL);
+    createFileURL(u"tdf119191_FitToCellSize.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
@@ -990,9 +1092,8 @@ void ScShapeTest::testCustomShapeCellAnchoredRotatedShape()
     // and sheared. Error was, that the shape lost position and size on
     // loading.
     OUString aFileURL;
-    createFileURL("tdf119191_transformedShape.ods", aFileURL);
+    createFileURL(u"tdf119191_transformedShape.ods", aFileURL);
     uno::Reference<css::lang::XComponent> xComponent = loadFromDesktop(aFileURL);
-    CPPUNIT_ASSERT(xComponent.is());
 
     // Get document and shape
     ScDocShell* pDocSh = lcl_getScDocShellWithAssert(xComponent);
