@@ -375,7 +375,7 @@ void ScAttrArray::RemoveCondFormat( SCROW nStartRow, SCROW nEndRow, sal_uInt32 n
                     if(itr != rCondFormatData.end())
                     {
                         ScCondFormatIndexes aNewCondFormatData(rCondFormatData);
-                        aNewCondFormatData.erase(nIndex);
+                        aNewCondFormatData.erase_at(std::distance(rCondFormatData.begin(), itr));
                         ScCondFormatItem aItem( std::move(aNewCondFormatData) );
                         pPatternAttr->GetItemSet().Put( aItem );
                         SetPatternArea( nTempStartRow, nTempEndRow, std::move(pPatternAttr), true );
@@ -1355,8 +1355,8 @@ bool ScAttrArray::HasAttrib_Impl(const ScPatternAttr* pPattern, HasAttrFlags nMa
         const ScRotateValueItem* pRotate = &pPattern->GetItem( ATTR_ROTATE_VALUE );
         // 90 or 270 degrees is former SvxOrientationItem - only look for other values
         // (see ScPatternAttr::GetCellOrientation)
-        sal_Int32 nAngle = pRotate->GetValue();
-        if ( nAngle != 0 && nAngle != 9000 && nAngle != 27000 )
+        Degree100 nAngle = pRotate->GetValue();
+        if ( nAngle && nAngle != 9000_deg100 && nAngle != 27000_deg100 )
             bFound = true;
     }
     if ( nMask & HasAttrFlags::NeedHeight )
@@ -1529,12 +1529,11 @@ void ScAttrArray::RemoveAreaMerge(SCROW nStartRow, SCROW nEndRow)
             for (SCROW nThisRow = nThisStart; nThisRow <= nThisEnd; nThisRow++)
                 rDocument.ApplyAttr( nThisCol, nThisRow, nTab, *pAttr );
 
-            std::unique_ptr<ScPatternAttr> pNewPattern(new ScPatternAttr( rDocument.GetPool() ));
-            SfxItemSet*     pSet = &pNewPattern->GetItemSet();
+            ScPatternAttr aNewPattern( rDocument.GetPool() );
+            SfxItemSet*     pSet = &aNewPattern.GetItemSet();
             pSet->Put( *pFlagAttr );
             rDocument.ApplyPatternAreaTab( nThisCol, nThisStart, nMergeEndCol, nMergeEndRow,
-                                                nTab, *pNewPattern );
-            pNewPattern.reset();
+                                                nTab, aNewPattern );
 
             Search( nThisEnd, nIndex );    // data changed
         }
@@ -1819,15 +1818,14 @@ void ScAttrArray::FindStyleSheet( const SfxStyleSheetBase* pStyleSheet, ScFlatBo
 
             if (bReset)
             {
-                std::unique_ptr<ScPatternAttr> pNewPattern(new ScPatternAttr(*mvData[nPos].pPattern));
+                ScPatternAttr aNewPattern(*mvData[nPos].pPattern);
                 rDocument.GetPool()->Remove(*mvData[nPos].pPattern);
-                pNewPattern->SetStyleSheet( static_cast<ScStyleSheet*>(
+                aNewPattern.SetStyleSheet( static_cast<ScStyleSheet*>(
                     rDocument.GetStyleSheetPool()->
                         Find( ScResId(STR_STYLENAME_STANDARD),
                               SfxStyleFamily::Para,
                               SfxStyleSearchBits::Auto | SfxStyleSearchBits::ScStandard ) ) );
-                mvData[nPos].pPattern = &rDocument.GetPool()->Put(*pNewPattern);
-                pNewPattern.reset();
+                mvData[nPos].pPattern = &rDocument.GetPool()->Put(aNewPattern);
 
                 if (Concat(nPos))
                 {
@@ -1959,17 +1957,21 @@ bool ScAttrArray::GetLastVisibleAttr( SCROW& rLastRow, SCROW nLastData ) const
     Search( nLastData, nPos );
     while ( nPos < mvData.size() )
     {
+        SCROW nAttrStartRow = ( nPos > 0 ) ? ( mvData[nPos-1].nEndRow + 1 ) : 0;
+        if ( nAttrStartRow <= nLastData )
+            nAttrStartRow = nLastData + 1;
         // find range of visually equal formats
         SCSIZE nEndPos = nPos;
         while ( nEndPos < mvData.size()-1 &&
                 mvData[nEndPos].pPattern->IsVisibleEqual( *mvData[nEndPos+1].pPattern))
+        {
+            if ( (mvData[nEndPos].nEndRow + 1 - nAttrStartRow) >= SC_VISATTR_STOP )
+                return false; // ignore this range and below
             ++nEndPos;
-        SCROW nAttrStartRow = ( nPos > 0 ) ? ( mvData[nPos-1].nEndRow + 1 ) : 0;
-        if ( nAttrStartRow <= nLastData )
-            nAttrStartRow = nLastData + 1;
+        }
         SCROW nAttrSize = mvData[nEndPos].nEndRow + 1 - nAttrStartRow;
         if ( nAttrSize >= SC_VISATTR_STOP )
-            break;  // while, ignore this range and below
+            return false; // ignore this range and below
         else if ( mvData[nEndPos].pPattern->IsVisible() )
         {
             rLastRow = mvData[nEndPos].nEndRow;
@@ -2423,20 +2425,20 @@ void ScAttrArray::CopyArea(
             }
             else if ( nStripFlags != ScMF::NONE )
             {
-                std::unique_ptr<ScPatternAttr> pTmpPattern(new ScPatternAttr( *pOldPattern ));
+                ScPatternAttr aTmpPattern( *pOldPattern );
                 ScMF nNewFlags = ScMF::NONE;
                 if ( nStripFlags != ScMF::All )
-                    nNewFlags = pTmpPattern->GetItem(ATTR_MERGE_FLAG).GetValue() & ~nStripFlags;
+                    nNewFlags = aTmpPattern.GetItem(ATTR_MERGE_FLAG).GetValue() & ~nStripFlags;
 
                 if ( nNewFlags != ScMF::NONE )
-                    pTmpPattern->GetItemSet().Put( ScMergeFlagAttr( nNewFlags ) );
+                    aTmpPattern.GetItemSet().Put( ScMergeFlagAttr( nNewFlags ) );
                 else
-                    pTmpPattern->GetItemSet().ClearItem( ATTR_MERGE_FLAG );
+                    aTmpPattern.GetItemSet().ClearItem( ATTR_MERGE_FLAG );
 
                 if (bSamePool)
-                    pNewPattern = &pDestDocPool->Put(*pTmpPattern);
+                    pNewPattern = &pDestDocPool->Put(aTmpPattern);
                 else
-                    pNewPattern = pTmpPattern->PutInPool( &rAttrArray.rDocument, &rDocument );
+                    pNewPattern = aTmpPattern.PutInPool( &rAttrArray.rDocument, &rDocument );
             }
             else
             {
