@@ -152,9 +152,9 @@ void CopyFromClipContext::setSingleCell( const ScAddress& rSrcPos, const ScColum
         aRef.InitAddress(rSrcPos);
         aRef.SetFlag3D(true);
 
-        ScTokenArray aArr(mpClipDoc);
+        ScTokenArray aArr(*mpClipDoc);
         aArr.AddSingleReference(aRef);
-        rSrcCell.set(new ScFormulaCell(mpClipDoc, rSrcPos, aArr));
+        rSrcCell.set(new ScFormulaCell(*mpClipDoc, rSrcPos, aArr));
         return;
     }
 
@@ -216,7 +216,7 @@ void CopyFromClipContext::setSingleCell( const ScAddress& rSrcPos, const ScColum
                 else
                 {
                     // Turn this into a formula cell with just the error code.
-                    ScFormulaCell* pErrCell = new ScFormulaCell(mpClipDoc, rSrcPos);
+                    ScFormulaCell* pErrCell = new ScFormulaCell(*mpClipDoc, rSrcPos);
                     pErrCell->SetErrCode(nErr);
                     rSrcCell.set(pErrCell);
                 }
