@@ -35,6 +35,8 @@
 #include <basic/basmgr.hxx>
 #include <comphelper/threadpool.hxx>
 #include <sal/log.hxx>
+#include <osl/diagnose.h>
+#include <unotools/configmgr.hxx>
 
 #include <scmod.hxx>
 #include <document.hxx>
@@ -53,7 +55,6 @@
 #include <validat.hxx>
 #include <detdata.hxx>
 #include <defaultsoptions.hxx>
-#include <sc.hrc>
 #include <ddelink.hxx>
 #include <chgtrack.hxx>
 #include <chgviset.hxx>
@@ -91,6 +92,15 @@ using namespace com::sun::star;
 
 const sal_uInt16 ScDocument::nSrcVer = SC_CURRENT_VERSION;
 
+static ScSheetLimits* CreateSheetLimits()
+{
+    const ScDefaultsOptions& rOpt = SC_MOD()->GetDefaultsOptions();
+    if (rOpt.GetInitJumboSheets())
+        return new ScSheetLimits(MAXCOL_JUMBO, MAXROW_JUMBO);
+    else
+        return new ScSheetLimits(MAXCOL, MAXROW);
+}
+
 ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
         mpCellStringPool(std::make_shared<svl::SharedStringPool>(*ScGlobal::getCharClassPtr())),
         mpDocLinkMgr(new sc::DocumentLinkManager(pDocShell)),
@@ -101,16 +111,17 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
         mpPrinter( nullptr ),
         mpVirtualDevice_100th_mm( nullptr ),
         pFormatExchangeList( nullptr ),
-        mxSheetLimits(new ScSheetLimits(MAXCOL, MAXROW)),
+        mxSheetLimits(CreateSheetLimits()),
         pFormulaTree( nullptr ),
         pEOFormulaTree( nullptr ),
         pFormulaTrack( nullptr ),
         pEOFormulaTrack( nullptr ),
         pPreviewCellStyle( nullptr ),
-        maPreviewSelection(MAXROW, MAXCOL),
+        maPreviewSelection(*mxSheetLimits),
         nUnoObjectId( 0 ),
         nRangeOverflowType( 0 ),
         aCurTextWidthCalcPos(MaxCol(),0,0),
+        aTrackIdle("sc ScDocument Track Idle"),
         nFormulaCodeInTree(0),
         nXMLImportedFormulaCount( 0 ),
         nInterpretLevel(0),
@@ -170,12 +181,7 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
         mbDocShellRecalc(false),
         mnMutationGuardFlags(0)
 {
-    const ScDefaultsOptions& rOpt = SC_MOD()->GetDefaultsOptions();
-    if (rOpt.GetInitJumboSheets())
-    {
-        mxSheetLimits = new ScSheetLimits(MAXCOL_JUMBO, MAXROW_JUMBO);
-    }
-    maPreviewSelection = { MaxRow(), MaxCol() };
+    maPreviewSelection = { *mxSheetLimits };
     aCurTextWidthCalcPos = { MaxCol(), 0, 0 };
 
     SetStorageGrammar( formula::FormulaGrammar::GRAM_STORAGE_DEFAULT);
@@ -186,17 +192,17 @@ ScDocument::ScDocument( ScDocumentMode eMode, SfxObjectShell* pDocShell ) :
      * have all of these available. */
     if ( eMode == SCDOCMODE_DOCUMENT || eMode == SCDOCMODE_FUNCTIONACCESS )
     {
-        mxPoolHelper = new ScPoolHelper( this );
-
-        pBASM.reset( new ScBroadcastAreaSlotMachine( this ) );
-        pChartListenerCollection.reset( new ScChartListenerCollection( this ) );
+        mxPoolHelper = new ScPoolHelper( *this );
+        if (!utl::ConfigManager::IsFuzzing()) //just too slow
+            pBASM.reset( new ScBroadcastAreaSlotMachine( this ) );
+        pChartListenerCollection.reset( new ScChartListenerCollection( *this ) );
         pRefreshTimerControl.reset( new ScRefreshTimerControl );
     }
     else
     {
         pChartListenerCollection = nullptr;
     }
-    pDBCollection.reset( new ScDBCollection(this) );
+    pDBCollection.reset( new ScDBCollection(*this) );
     pSelectionAttr = nullptr;
     apTemporaryChartLock.reset( new ScTemporaryChartLock(this) );
     xColNameRanges = new ScRangePairList;
@@ -257,7 +263,7 @@ sal_uInt32 ScDocument::GetDocumentID() const
 void ScDocument::StartChangeTracking()
 {
     if (!pChangeTrack)
-        pChangeTrack.reset( new ScChangeTrack( this ) );
+        pChangeTrack.reset( new ScChangeTrack( *this ) );
 }
 
 void ScDocument::EndChangeTracking()
@@ -267,8 +273,8 @@ void ScDocument::EndChangeTracking()
 
 void ScDocument::SetChangeTrack( std::unique_ptr<ScChangeTrack> pTrack )
 {
-    OSL_ENSURE( pTrack->GetDocument() == this, "SetChangeTrack: different documents" );
-    if ( !pTrack || pTrack == pChangeTrack || pTrack->GetDocument() != this )
+    OSL_ENSURE( &pTrack->GetDocument() == this, "SetChangeTrack: different documents" );
+    if ( !pTrack || pTrack == pChangeTrack || &pTrack->GetDocument() != this )
         return ;
     EndChangeTracking();
     pChangeTrack = std::move(pTrack);
@@ -322,7 +328,7 @@ ScDocument::~ScDocument()
     OSL_PRECOND( !bInLinkUpdate, "bInLinkUpdate in dtor" );
 
     // Join any pending(recalc) threads in global threadpool
-    comphelper::ThreadPool::getSharedOptimalPool().joinAll();
+    comphelper::ThreadPool::getSharedOptimalPool().joinThreadsIfIdle();
 
     bInDtorClear = true;
 
@@ -383,8 +389,8 @@ ScDocument::~ScDocument()
     mxPoolHelper.clear();
 
     pScriptTypeData.reset();
-    delete maNonThreaded.pRecursionHelper;
-    delete maThreadSpecific.pRecursionHelper;
+    maNonThreaded.xRecursionHelper.reset();
+    assert(!maThreadSpecific.xRecursionHelper);
 
     pPreviewFont.reset();
     SAL_WARN_IF( pAutoNameCache, "sc.core", "AutoNameCache still set in dtor" );
@@ -403,7 +409,7 @@ void ScDocument::InitClipPtrs( ScDocument* pSourceDoc )
 {
     OSL_ENSURE(bIsClip, "InitClipPtrs and not bIsClip");
 
-    ScMutationGuard aGuard(this, ScMutationGuardFlags::CORE);
+    ScMutationGuard aGuard(*this, ScMutationGuardFlags::CORE);
 
     pValidationList.reset();
 
@@ -415,7 +421,7 @@ void ScDocument::InitClipPtrs( ScDocument* pSourceDoc )
     // TODO: Copy Templates?
     const ScValidationDataList* pSourceValid = pSourceDoc->pValidationList.get();
     if ( pSourceValid )
-        pValidationList.reset(new ScValidationDataList(this, *pSourceValid));
+        pValidationList.reset(new ScValidationDataList(*this, *pSourceValid));
 
     // store Links in Stream
     pClipData.reset();
@@ -464,7 +470,7 @@ ScNoteEditEngine& ScDocument::GetNoteEngine()
 {
     if ( !mpNoteEngine )
     {
-        ScMutationGuard aGuard(this, ScMutationGuardFlags::CORE);
+        ScMutationGuard aGuard(*this, ScMutationGuardFlags::CORE);
         mpNoteEngine.reset( new ScNoteEditEngine( GetEnginePool(), GetEditPool() ) );
         mpNoteEngine->SetUpdateMode( false );
         mpNoteEngine->EnableUndo( false );
@@ -491,7 +497,7 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, const ScMarkData* pMarks )
                     OUString aString = pSourceDoc->maTabs[i]->GetName();
                     if ( i < static_cast<SCTAB>(maTabs.size()) )
                     {
-                        maTabs[i].reset( new ScTable(this, i, aString) );
+                        maTabs[i].reset( new ScTable(*this, i, aString) );
 
                     }
                     else
@@ -500,7 +506,7 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, const ScMarkData* pMarks )
                         {
                             maTabs.resize(i);
                         }
-                        maTabs.emplace_back(new ScTable(this, i, aString));
+                        maTabs.emplace_back(new ScTable(*this, i, aString));
                     }
                     maTabs[i]->SetLayoutRTL( pSourceDoc->maTabs[i]->IsLayoutRTL() );
                 }
@@ -520,7 +526,7 @@ void ScDocument::ResetClip( ScDocument* pSourceDoc, SCTAB nTab )
         {
             maTabs.resize(nTab+1);
         }
-        maTabs[nTab].reset( new ScTable(this, nTab, "baeh") );
+        maTabs[nTab].reset( new ScTable(*this, nTab, "baeh") );
         if (nTab < static_cast<SCTAB>(pSourceDoc->maTabs.size()) && pSourceDoc->maTabs[nTab])
             maTabs[nTab]->SetLayoutRTL( pSourceDoc->maTabs[nTab]->IsLayoutRTL() );
     }
@@ -537,7 +543,7 @@ void ScDocument::EnsureTable( SCTAB nTab )
         maTabs.resize(nTab+1);
 
     if (!maTabs[nTab])
-        maTabs[nTab].reset( new ScTable(this, nTab, "temp", bExtras, bExtras) );
+        maTabs[nTab].reset( new ScTable(*this, nTab, "temp", bExtras, bExtras) );
 }
 
 ScRefCellValue ScDocument::GetRefCellValue( const ScAddress& rPos )
@@ -567,11 +573,11 @@ const svl::SharedStringPool& ScDocument::GetSharedStringPool() const
 }
 
 bool ScDocument::GetPrintArea( SCTAB nTab, SCCOL& rEndCol, SCROW& rEndRow,
-                                bool bNotes ) const
+                                bool bNotes) const
 {
     if (ValidTab(nTab) && nTab < static_cast<SCTAB>(maTabs.size()) && maTabs[nTab])
     {
-        bool bAny = maTabs[nTab]->GetPrintArea( rEndCol, rEndRow, bNotes );
+        bool bAny = maTabs[nTab]->GetPrintArea( rEndCol, rEndRow, bNotes, /*bCalcHiddens*/false);
         if (mpDrawLayer)
         {
             ScRange aDrawRange(0,0,nTab, MaxCol(),MaxRow(),nTab);
@@ -786,7 +792,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
         if (nNewPos >= static_cast<SCTAB>(maTabs.size()))
         {
             nNewPos = static_cast<SCTAB>(maTabs.size());
-            maTabs.emplace_back(new ScTable(this, nNewPos, aName));
+            maTabs.emplace_back(new ScTable(*this, nNewPos, aName));
         }
         else
         {
@@ -816,7 +822,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
                         (*it)->UpdateInsertTab(aCxt);
                 if (nNewPos <= nOldPos)
                     nOldPos++;
-                maTabs.emplace(maTabs.begin() + nNewPos, new ScTable(this, nNewPos, aName));
+                maTabs.emplace(maTabs.begin() + nNewPos, new ScTable(*this, nNewPos, aName));
                 bValid = true;
                 for (TableContainer::iterator it = maTabs.begin(); it != maTabs.end(); ++it)
                     if (*it && it != maTabs.begin()+nOldPos && it != maTabs.begin() + nNewPos)
@@ -899,7 +905,7 @@ bool ScDocument::CopyTab( SCTAB nOldPos, SCTAB nNewPos, const ScMarkData* pOnlyM
     return bValid;
 }
 
-sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
+sal_uLong ScDocument::TransferTab( ScDocument& rSrcDoc, SCTAB nSrcPos,
                                 SCTAB nDestPos, bool bInsertNew,
                                 bool bResultsOnly )
 {
@@ -907,29 +913,29 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                                             // 3 => NameBox
                                             // 4 => both
 
-    if (pSrcDoc->mpShell->GetMedium())
+    if (rSrcDoc.mpShell->GetMedium())
     {
-        pSrcDoc->maFileURL = pSrcDoc->mpShell->GetMedium()->GetURLObject().GetMainURL(INetURLObject::DecodeMechanism::ToIUri);
+        rSrcDoc.maFileURL = rSrcDoc.mpShell->GetMedium()->GetURLObject().GetMainURL(INetURLObject::DecodeMechanism::ToIUri);
         // for unsaved files use the title name and adjust during save of file
-        if (pSrcDoc->maFileURL.isEmpty())
-            pSrcDoc->maFileURL = pSrcDoc->mpShell->GetName();
+        if (rSrcDoc.maFileURL.isEmpty())
+            rSrcDoc.maFileURL = rSrcDoc.mpShell->GetName();
     }
     else
     {
-        pSrcDoc->maFileURL = pSrcDoc->mpShell->GetName();
+        rSrcDoc.maFileURL = rSrcDoc.mpShell->GetName();
     }
 
     bool bValid = true;
     if (bInsertNew)             // re-insert
     {
         OUString aName;
-        pSrcDoc->GetName(nSrcPos, aName);
+        rSrcDoc.GetName(nSrcPos, aName);
         CreateValidTabName(aName);
         bValid = InsertTab(nDestPos, aName);
 
         // Copy the RTL settings
-        maTabs[nDestPos]->SetLayoutRTL(pSrcDoc->maTabs[nSrcPos]->IsLayoutRTL());
-        maTabs[nDestPos]->SetLoadingRTL(pSrcDoc->maTabs[nSrcPos]->IsLoadingRTL());
+        maTabs[nDestPos]->SetLayoutRTL(rSrcDoc.maTabs[nSrcPos]->IsLayoutRTL());
+        maTabs[nDestPos]->SetLoadingRTL(rSrcDoc.maTabs[nSrcPos]->IsLoadingRTL());
     }
     else                        // replace existing tables
     {
@@ -949,12 +955,12 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
         SetNoListening( true );
         if ( bResultsOnly )
         {
-            bOldAutoCalcSrc = pSrcDoc->GetAutoCalc();
-            pSrcDoc->SetAutoCalc( true );   // in case something needs calculation
+            bOldAutoCalcSrc = rSrcDoc.GetAutoCalc();
+            rSrcDoc.SetAutoCalc( true );   // in case something needs calculation
         }
 
         {
-            NumFmtMergeHandler aNumFmtMergeHdl(this, pSrcDoc);
+            NumFmtMergeHandler aNumFmtMergeHdl(*this, rSrcDoc);
 
             sc::CopyToDocContext aCxt(*this);
             nDestPos = std::min(nDestPos, static_cast<SCTAB>(GetTableCount() - 1));
@@ -963,19 +969,19 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
                 if (!bResultsOnly)
                 {
                     const bool bGlobalNamesToLocal = false;
-                    const ScRangeName* pNames = pSrcDoc->GetRangeName( nSrcPos);
+                    const ScRangeName* pNames = rSrcDoc.GetRangeName( nSrcPos);
                     if (pNames)
-                        pNames->CopyUsedNames( nSrcPos, nSrcPos, nDestPos, *pSrcDoc, *this, bGlobalNamesToLocal);
-                    pSrcDoc->GetRangeName()->CopyUsedNames( -1, nSrcPos, nDestPos, *pSrcDoc, *this, bGlobalNamesToLocal);
+                        pNames->CopyUsedNames( nSrcPos, nSrcPos, nDestPos, rSrcDoc, *this, bGlobalNamesToLocal);
+                    rSrcDoc.GetRangeName()->CopyUsedNames( -1, nSrcPos, nDestPos, rSrcDoc, *this, bGlobalNamesToLocal);
                 }
-                pSrcDoc->maTabs[nSrcPos]->CopyToTable(aCxt, 0, 0, MaxCol(), MaxRow(),
+                rSrcDoc.maTabs[nSrcPos]->CopyToTable(aCxt, 0, 0, MaxCol(), MaxRow(),
                         ( bResultsOnly ? InsertDeleteFlags::ALL & ~InsertDeleteFlags::FORMULA : InsertDeleteFlags::ALL),
                         false, maTabs[nDestPos].get(), /*pMarkData*/nullptr, /*bAsLink*/false, /*bColRowFlags*/true,
                         /*bGlobalNamesToLocal*/false, /*bCopyCaptions*/true );
             }
         }
         maTabs[nDestPos]->SetTabNo(nDestPos);
-        maTabs[nDestPos]->SetTabBgColor(pSrcDoc->maTabs[nSrcPos]->GetTabBgColor());
+        maTabs[nDestPos]->SetTabBgColor(rSrcDoc.maTabs[nSrcPos]->GetTabBgColor());
 
         if ( !bResultsOnly )
         {
@@ -987,7 +993,7 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
 
             // Readjust self-contained absolute references to this sheet
             maTabs[nDestPos]->TestTabRefAbs(nSrcPos);
-            sc::CompileFormulaContext aFormulaCxt(this);
+            sc::CompileFormulaContext aFormulaCxt(*this);
             maTabs[nDestPos]->CompileAll(aFormulaCxt);
         }
 
@@ -1000,15 +1006,15 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
         SetDirty( ScRange( 0, 0, nDestPos, MaxCol(), MaxRow(), nDestPos), false);
 
         if ( bResultsOnly )
-            pSrcDoc->SetAutoCalc( bOldAutoCalcSrc );
+            rSrcDoc.SetAutoCalc( bOldAutoCalcSrc );
         SetAutoCalc( bOldAutoCalc );
 
         //  copy Drawing
 
         if (bInsertNew)
-            TransferDrawPage( pSrcDoc, nSrcPos, nDestPos );
+            TransferDrawPage( rSrcDoc, nSrcPos, nDestPos );
 
-        maTabs[nDestPos]->SetPendingRowHeights( pSrcDoc->maTabs[nSrcPos]->IsPendingRowHeights() );
+        maTabs[nDestPos]->SetPendingRowHeights( rSrcDoc.maTabs[nSrcPos]->IsPendingRowHeights() );
     }
     if (!bValid)
         nRetVal = 0;
@@ -1016,7 +1022,7 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
 
     if ( bVbaEnabled  )
     {
-        SfxObjectShell* pSrcShell = pSrcDoc->GetDocumentShell();
+        SfxObjectShell* pSrcShell = rSrcDoc.GetDocumentShell();
         if ( pSrcShell )
         {
             OUString aLibName("Standard");
@@ -1037,7 +1043,7 @@ sal_uLong ScDocument::TransferTab( ScDocument* pSrcDoc, SCTAB nSrcPos,
             if( xLib.is() )
             {
                 OUString sSrcCodeName;
-                pSrcDoc->GetCodeName( nSrcPos, sSrcCodeName );
+                rSrcDoc.GetCodeName( nSrcPos, sSrcCodeName );
                 OUString sRTLSource;
                 xLib->getByName( sSrcCodeName ) >>= sRTLSource;
                 sSource = sRTLSource;
@@ -1144,22 +1150,17 @@ void ScDocument::DisposeFieldEditEngine(std::unique_ptr<ScFieldEditEngine>& rpEd
         rpEditEngine.reset();
 }
 
-ScRecursionHelper* ScDocument::CreateRecursionHelperInstance()
-{
-    return new ScRecursionHelper;
-}
-
 ScLookupCache & ScDocument::GetLookupCache( const ScRange & rRange, ScInterpreterContext* pContext )
 {
     ScLookupCache* pCache = nullptr;
-    ScLookupCacheMap*& rpCacheMap = pContext->mScLookupCache;
-    if (!rpCacheMap)
-        rpCacheMap = new ScLookupCacheMap;
+    if (!pContext->mxScLookupCache)
+        pContext->mxScLookupCache.reset(new ScLookupCacheMap);
+    ScLookupCacheMap* pCacheMap = pContext->mxScLookupCache.get();
     // insert with temporary value to avoid doing two lookups
-    auto [findIt, bInserted] = rpCacheMap->aCacheMap.emplace(rRange, nullptr);
+    auto [findIt, bInserted] = pCacheMap->aCacheMap.emplace(rRange, nullptr);
     if (bInserted)
     {
-        findIt->second = std::make_unique<ScLookupCache>(this, rRange, *rpCacheMap);
+        findIt->second = std::make_unique<ScLookupCache>(this, rRange, *pCacheMap);
         pCache = findIt->second.get();
         // The StartListeningArea() call is not thread-safe, as all threads
         // would access the same SvtBroadcaster.
@@ -1194,7 +1195,7 @@ void ScDocument::RemoveLookupCache( ScLookupCache & rCache )
 void ScDocument::ClearLookupCaches()
 {
     assert(!IsThreadedGroupCalcInProgress());
-    DELETEZ(GetNonThreadedContext().mScLookupCache);
+    GetNonThreadedContext().mxScLookupCache.reset();
     // Clear lookup cache in all interpreter-contexts in the (threaded/non-threaded) pools.
     ScInterpreterContextPool::ClearLookupCaches();
 }
@@ -1211,10 +1212,9 @@ bool ScDocument::IsCellInChangeTrack(const ScAddress &cell,Color *pColCellBorder
     const ScChangeAction* pAction = pTrack->GetFirst();
     while (pAction)
     {
-        ScChangeActionType eType;
         if ( pAction->IsVisible() )
         {
-            eType = pAction->GetType();
+            ScChangeActionType eType = pAction->GetType();
             const ScBigRange& rBig = pAction->GetBigRange();
             if ( rBig.aStart.Tab() == cell.Tab())
             {
@@ -1269,85 +1269,85 @@ void ScDocument::GetCellChangeTrackNote( const ScAddress &aCellPos, OUString &aT
     //  Change-Tracking
     ScChangeTrack* pTrack = GetChangeTrack();
     ScChangeViewSettings* pSettings = GetChangeViewSettings();
-    if ( pTrack && pTrack->GetFirst() && pSettings && pSettings->ShowChanges())
+    if ( !(pTrack && pTrack->GetFirst() && pSettings && pSettings->ShowChanges()))
+        return;
+
+    const ScChangeAction* pFound = nullptr;
+    const ScChangeAction* pFoundContent = nullptr;
+    const ScChangeAction* pFoundMove = nullptr;
+    const ScChangeAction* pAction = pTrack->GetFirst();
+    while (pAction)
     {
-        const ScChangeAction* pFound = nullptr;
-        const ScChangeAction* pFoundContent = nullptr;
-        const ScChangeAction* pFoundMove = nullptr;
-        const ScChangeAction* pAction = pTrack->GetFirst();
-        while (pAction)
+        if ( pAction->IsVisible() &&
+             ScViewUtil::IsActionShown( *pAction, *pSettings, *this ) )
         {
-            if ( pAction->IsVisible() &&
-                 ScViewUtil::IsActionShown( *pAction, *pSettings, *this ) )
+            ScChangeActionType eType = pAction->GetType();
+            const ScBigRange& rBig = pAction->GetBigRange();
+            if ( rBig.aStart.Tab() == aCellPos.Tab())
             {
-                ScChangeActionType eType = pAction->GetType();
-                const ScBigRange& rBig = pAction->GetBigRange();
-                if ( rBig.aStart.Tab() == aCellPos.Tab())
+                ScRange aRange = rBig.MakeRange();
+                if ( eType == SC_CAT_DELETE_ROWS )
+                    aRange.aEnd.SetRow( aRange.aStart.Row() );
+                else if ( eType == SC_CAT_DELETE_COLS )
+                    aRange.aEnd.SetCol( aRange.aStart.Col() );
+                if ( aRange.In( aCellPos ) )
                 {
-                    ScRange aRange = rBig.MakeRange();
-                    if ( eType == SC_CAT_DELETE_ROWS )
-                        aRange.aEnd.SetRow( aRange.aStart.Row() );
-                    else if ( eType == SC_CAT_DELETE_COLS )
-                        aRange.aEnd.SetCol( aRange.aStart.Col() );
-                    if ( aRange.In( aCellPos ) )
+                    pFound = pAction;       // the last wins
+                    switch ( eType )
                     {
-                        pFound = pAction;       // the last wins
-                        switch ( eType )
-                        {
-                            case SC_CAT_CONTENT :
-                                pFoundContent = pAction;
+                        case SC_CAT_CONTENT :
+                            pFoundContent = pAction;
+                        break;
+                        case SC_CAT_MOVE :
+                            pFoundMove = pAction;
+                        break;
+                        default:
                             break;
-                            case SC_CAT_MOVE :
-                                pFoundMove = pAction;
-                            break;
-                            default:
-                                break;
-                        }
-                    }
-                }
-                if ( eType == SC_CAT_MOVE )
-                {
-                    ScRange aRange =
-                        static_cast<const ScChangeActionMove*>(pAction)->
-                        GetFromRange().MakeRange();
-                    if ( aRange.In( aCellPos ) )
-                    {
-                        pFound = pAction;
                     }
                 }
             }
-            pAction = pAction->GetNext();
-        }
-        if ( pFound )
-        {
-            if ( pFoundContent && pFound->GetType() != SC_CAT_CONTENT )
-                pFound = pFoundContent;     // Content wins
-            if ( pFoundMove && pFound->GetType() != SC_CAT_MOVE &&
-                    pFoundMove->GetActionNumber() >
-                    pFound->GetActionNumber() )
-                pFound = pFoundMove;        // Move wins
-            //  for deleted columns: arrow on left side of row
-            if ( pFound->GetType() == SC_CAT_DELETE_COLS )
-                bLeftEdge = true;
-            DateTime aDT = pFound->GetDateTime();
-            aTrackText  = pFound->GetUser();
-            aTrackText += ", ";
-            aTrackText += ScGlobal::getLocaleDataPtr()->getDate(aDT);
-            aTrackText += " ";
-            aTrackText += ScGlobal::getLocaleDataPtr()->getTime(aDT);
-            aTrackText += ":\n";
-            OUString aComStr = pFound->GetComment();
-            if(!aComStr.isEmpty())
+            if ( eType == SC_CAT_MOVE )
             {
-                aTrackText += aComStr;
-                aTrackText += "\n( ";
-            }
-            pFound->GetDescription( aTrackText, this );
-            if (!aComStr.isEmpty())
-            {
-                aTrackText += ")";
+                ScRange aRange =
+                    static_cast<const ScChangeActionMove*>(pAction)->
+                    GetFromRange().MakeRange();
+                if ( aRange.In( aCellPos ) )
+                {
+                    pFound = pAction;
+                }
             }
         }
+        pAction = pAction->GetNext();
+    }
+    if ( !pFound )
+        return;
+
+    if ( pFoundContent && pFound->GetType() != SC_CAT_CONTENT )
+        pFound = pFoundContent;     // Content wins
+    if ( pFoundMove && pFound->GetType() != SC_CAT_MOVE &&
+            pFoundMove->GetActionNumber() >
+            pFound->GetActionNumber() )
+        pFound = pFoundMove;        // Move wins
+    //  for deleted columns: arrow on left side of row
+    if ( pFound->GetType() == SC_CAT_DELETE_COLS )
+        bLeftEdge = true;
+    DateTime aDT = pFound->GetDateTime();
+    aTrackText  = pFound->GetUser();
+    aTrackText += ", ";
+    aTrackText += ScGlobal::getLocaleDataPtr()->getDate(aDT);
+    aTrackText += " ";
+    aTrackText += ScGlobal::getLocaleDataPtr()->getTime(aDT);
+    aTrackText += ":\n";
+    OUString aComStr = pFound->GetComment();
+    if(!aComStr.isEmpty())
+    {
+        aTrackText += aComStr;
+        aTrackText += "\n( ";
+    }
+    pFound->GetDescription( aTrackText, *this );
+    if (!aComStr.isEmpty())
+    {
+        aTrackText += ")";
     }
 }
 
