@@ -28,6 +28,7 @@
 #include <sfx2/viewsh.hxx>
 #include <vcl/svapp.hxx>
 #include <osl/thread.hxx>
+#include <osl/diagnose.h>
 #include <document.hxx>
 #include <attrib.hxx>
 #include <table.hxx>
@@ -66,7 +67,6 @@
 #include <refupdatecontext.hxx>
 #include <scopetools.hxx>
 #include <filterentries.hxx>
-#include <docsh.hxx>
 #include <queryparam.hxx>
 
 #include <globalnames.hxx>
@@ -235,7 +235,7 @@ bool ScDocument::InsertNewRangeName( SCTAB nTab, const OUString& rName, const Sc
     return pLocalNames->insert(pName);
 }
 
-const ScRangeData* ScDocument::GetRangeAtBlock( const ScRange& rBlock, OUString* pName ) const
+const ScRangeData* ScDocument::GetRangeAtBlock( const ScRange& rBlock, OUString& rName, bool* pSheetLocal ) const
 {
     const ScRangeData* pData = nullptr;
     if (rBlock.aStart.Tab() == rBlock.aEnd.Tab())
@@ -246,8 +246,9 @@ const ScRangeData* ScDocument::GetRangeAtBlock( const ScRange& rBlock, OUString*
             pData = pLocalNames->findByRange( rBlock );
             if (pData)
             {
-                if (pName)
-                    *pName = pData->GetName();
+                rName = pData->GetName();
+                if (pSheetLocal)
+                    *pSheetLocal = true;
                 return pData;
             }
         }
@@ -255,8 +256,12 @@ const ScRangeData* ScDocument::GetRangeAtBlock( const ScRange& rBlock, OUString*
     if ( pRangeName )
     {
         pData = pRangeName->findByRange( rBlock );
-        if (pData && pName)
-            *pName = pData->GetName();
+        if (pData)
+        {
+            rName = pData->GetName();
+            if (pSheetLocal)
+                *pSheetLocal = false;
+        }
     }
     return pData;
 }
@@ -546,8 +551,8 @@ void ScDocument::SetLink( SCTAB nTab, ScLinkMode nMode, const OUString& rDoc,
         maTabs[nTab]->SetLink( nMode, rDoc, rFilter, rOptions, rTabName, nRefreshDelay );
 }
 
-bool ScDocument::HasLink( const OUString& rDoc,
-                            const OUString& rFilter, const OUString& rOptions ) const
+bool ScDocument::HasLink( std::u16string_view rDoc,
+                            std::u16string_view rFilter, std::u16string_view rOptions ) const
 {
     SCTAB nCount = static_cast<SCTAB>(maTabs.size());
     for (SCTAB i=0; i<nCount; i++)
@@ -1107,7 +1112,7 @@ void ScDocument::UpdateTranspose( const ScAddress& rDestPos, ScDocument* pClipDo
     OSL_ENSURE(pClipDoc->bIsClip, "UpdateTranspose: No Clip");
 
     ScRange aSource;
-    ScClipParam& rClipParam = GetClipParam();
+    ScClipParam& rClipParam = pClipDoc->GetClipParam();
     if (!rClipParam.maRanges.empty())
         aSource = rClipParam.maRanges.front();
     ScAddress aDest = rDestPos;
@@ -1443,6 +1448,17 @@ void ScDocument::Reorder( const sc::ReorderParam& rParam )
     EnableIdle(bOldEnableIdle);
 }
 
+void ScDocument::PrepareQuery( SCTAB nTab, ScQueryParam& rQueryParam )
+{
+    if( ValidTab(nTab) && nTab < static_cast<SCTAB>(maTabs.size()) && maTabs[nTab] )
+        maTabs[nTab]->PrepareQuery(rQueryParam);
+    else
+    {
+        OSL_FAIL("missing tab");
+        return;
+    }
+}
+
 SCSIZE ScDocument::Query(SCTAB nTab, const ScQueryParam& rQueryParam, bool bKeepSub)
 {
     if ( ValidTab(nTab) && nTab < static_cast<SCTAB>(maTabs.size()) && maTabs[nTab] )
@@ -1571,7 +1587,7 @@ void ScDocument::GetFilterEntries(
 
     if ( bFilter )
     {
-        maTabs[nTab]->GetFilteredFilterEntries( nCol, nStartRow, nEndRow, aParam, rFilterEntries );
+        maTabs[nTab]->GetFilteredFilterEntries( nCol, nStartRow, nEndRow, aParam, rFilterEntries, bFilter );
     }
     else
     {
@@ -1590,7 +1606,7 @@ void ScDocument::GetFilterEntriesArea(
 {
     if ( ValidTab(nTab) && nTab < static_cast<SCTAB>(maTabs.size()) && maTabs[nTab] )
     {
-        maTabs[nTab]->GetFilterEntries( nCol, nStartRow, nEndRow, rFilterEntries );
+        maTabs[nTab]->GetFilterEntries( nCol, nStartRow, nEndRow, rFilterEntries, true );
         sortAndRemoveDuplicates( rFilterEntries.maStrData, bCaseSens);
     }
 }
@@ -1600,12 +1616,12 @@ void ScDocument::GetFilterEntriesArea(
  */
 void ScDocument::GetDataEntries(
     SCCOL nCol, SCROW nRow, SCTAB nTab,
-    std::vector<ScTypedStrData>& rStrings, bool bLimit )
+    std::vector<ScTypedStrData>& rStrings, bool bValidation )
 {
-    if( !bLimit )
+    if( bValidation )
     {
         /*  Try to generate the list from list validation. This part is skipped,
-            if bLimit==true, because in that case this function is called to get
+            if bValidation==false, because in that case this function is called to get
             cell values for auto completion on input. */
         sal_uInt32 nValidation = GetAttr( nCol, nRow, nTab, ATTR_VALIDDATA )->GetValue();
         if( nValidation )
@@ -1628,7 +1644,7 @@ void ScDocument::GetDataEntries(
         return;
 
     std::set<ScTypedStrData> aStrings;
-    if (maTabs[nTab]->GetDataEntries(nCol, nRow, aStrings, bLimit))
+    if (maTabs[nTab]->GetDataEntries(nCol, nRow, aStrings))
     {
         rStrings.insert(rStrings.end(), aStrings.begin(), aStrings.end());
         sortAndRemoveDuplicates(rStrings, true/*bCaseSens*/);
@@ -1896,7 +1912,7 @@ bool ScDocument::IsTabProtected( SCTAB nTab ) const
     return false;
 }
 
-ScTableProtection* ScDocument::GetTabProtection( SCTAB nTab ) const
+const ScTableProtection* ScDocument::GetTabProtection(SCTAB nTab) const
 {
     if (ValidTab(nTab) && nTab < static_cast<SCTAB>(maTabs.size()) && maTabs[nTab])
         return maTabs[nTab]->GetProtection();
