@@ -1081,14 +1081,10 @@ bool ScTable::SearchRangeForAllEmptyCells(
         if (aCol[nCol].IsEmptyData())
         {
             // The entire column is empty.
-            const SCROW nEndRow = rRange.aEnd.Row();
-            for (SCROW nRow = rRange.aStart.Row(); nRow <= nEndRow; ++nRow)
+            for (SCROW nRow = rRange.aStart.Row(); nRow <= rRange.aEnd.Row(); ++nRow)
             {
                 SCROW nLastRow;
-                const bool bFiltered = RowFiltered(nRow, nullptr, &nLastRow);
-                if (nLastRow > nEndRow)
-                    nLastRow = nEndRow;
-                if (!bFiltered)
+                if (!RowFiltered(nRow, nullptr, &nLastRow))
                 {
                     rMatchedRanges.Join(ScRange(nCol, nRow, nTab, nCol, nLastRow, nTab));
                     if (bReplace)
