@@ -19,7 +19,6 @@
 
 #include <cellform.hxx>
 
-#include <sfx2/objsh.hxx>
 #include <svl/zforlist.hxx>
 #include <svl/sharedstring.hxx>
 
@@ -27,7 +26,6 @@
 #include <document.hxx>
 #include <cellvalue.hxx>
 #include <formula/errorcodes.hxx>
-#include <sc.hrc>
 #include <editutil.hxx>
 
 void ScCellFormat::GetString( const ScRefCellValue& rCell, sal_uInt32 nFormat, OUString& rString,
@@ -118,7 +116,7 @@ OUString ScCellFormat::GetString(
 }
 
 void ScCellFormat::GetInputString(
-    const ScRefCellValue& rCell, sal_uInt32 nFormat, OUString& rString, SvNumberFormatter& rFormatter, const ScDocument& rDoc )
+    const ScRefCellValue& rCell, sal_uInt32 nFormat, OUString& rString, SvNumberFormatter& rFormatter, const ScDocument& rDoc, bool bFiltering )
 {
     switch (rCell.meType)
     {
@@ -127,7 +125,7 @@ void ScCellFormat::GetInputString(
             rString = rCell.getString(&rDoc);
         break;
         case CELLTYPE_VALUE:
-            rFormatter.GetInputLineString(rCell.mfValue, nFormat, rString );
+            rFormatter.GetInputLineString(rCell.mfValue, nFormat, rString, bFiltering);
         break;
         case CELLTYPE_FORMULA:
         {
