@@ -38,6 +38,7 @@
 
 #include <vector>
 #include <memory>
+#include <string_view>
 
 using ::std::unique_ptr;
 using ::std::vector;
@@ -137,7 +138,7 @@ public:
     sal_uInt16          InsertEuroTool( const OUString& rName );
     /** Inserts a DDE link.
         @return  The 1-based (Excel-like) list index of the DDE link. */
-    sal_uInt16          InsertDde( const OUString& rApplic, const OUString& rTopic, const OUString& rItem );
+    sal_uInt16          InsertDde( std::u16string_view rApplic, std::u16string_view rTopic, const OUString& rItem );
 
     sal_uInt16          InsertExtName( const XclExpSupbook& rSupbook, const OUString& rName, const ScExternalRefCache::TokenArrayRef& rArray );
 
@@ -148,7 +149,7 @@ public:
 
 private:
     /** Returns the 1-based (Excel-like) list index of the external name or 0, if not found. */
-    sal_uInt16          GetIndex( const OUString& rName ) const;
+    sal_uInt16          GetIndex( std::u16string_view rName ) const;
     /** Appends the passed newly crested external name.
         @return  The 1-based (Excel-like) list index of the appended name. */
     sal_uInt16          AppendNew( XclExpExtNameBase* pExtName );
@@ -263,7 +264,7 @@ public:
     /** Creates an EXTERNSHEET record containing a special code (i.e. own document or sheet). */
     explicit            XclExpExternSheet( const XclExpRoot& rRoot, sal_Unicode cCode );
     /** Creates an EXTERNSHEET record referring to an internal sheet. */
-    explicit            XclExpExternSheet( const XclExpRoot& rRoot, const OUString& rTabName );
+    explicit            XclExpExternSheet( const XclExpRoot& rRoot, std::u16string_view rTabName );
 
     /** Finds or inserts an EXTERNNAME record for add-ins.
         @return  The 1-based EXTERNNAME record index; or 0, if the record list is full. */
@@ -274,7 +275,7 @@ public:
 
 private:
     /** Initializes the record data with the passed encoded URL. */
-    void                Init( const OUString& rEncUrl );
+    void                Init( std::u16string_view rEncUrl );
     /** Writes the contents of the EXTERNSHEET  record. */
     virtual void        WriteBody( XclExpStream& rStrm ) override;
 
@@ -300,9 +301,9 @@ public:
     explicit            XclExpSupbook( const XclExpRoot& rRoot, const OUString& rApplic, const OUString& rTopic );
 
     /** Returns true, if this SUPBOOK contains the passed URL of an external document. */
-    bool                IsUrlLink( const OUString& rUrl ) const;
+    bool                IsUrlLink( std::u16string_view rUrl ) const;
     /** Returns true, if this SUPBOOK contains the passed DDE link. */
-    bool                IsDdeLink( const OUString& rApplic, const OUString& rTopic ) const;
+    bool                IsDdeLink( std::u16string_view rApplic, std::u16string_view rTopic ) const;
     /** Fills the passed reference log entry with the URL and sheet names. */
     void                FillRefLogEntry( XclExpRefLogEntry& rRefLogEntry,
                             sal_uInt16 nFirstSBTab, sal_uInt16 nLastSBTab ) const;
@@ -460,13 +461,13 @@ private:
         @param rnIndex  (out-param) Returns the list index, if the SUPBOOK exists.
         @return  True, if the SUPBOOK record exists (out-parameters are valid). */
     bool                GetSupbookUrl( XclExpSupbookRef& rxSupbook, sal_uInt16& rnIndex,
-                            const OUString& rUrl ) const;
+                            std::u16string_view rUrl ) const;
     /** Searches for the SUPBOOK record containing the passed DDE link.
         @param rxSupbook  (out-param) Returns a reference to the SUPBOOK record, or 0.
         @param rnIndex  (out-param) Returns the list index, if the SUPBOOK exists.
         @return  True, if the SUPBOOK record exists (out-parameters are valid). */
     bool                GetSupbookDde( XclExpSupbookRef& rxSupbook, sal_uInt16& rnIndex,
-                            const OUString& rApplic, const OUString& rTopic ) const;
+                            std::u16string_view rApplic, std::u16string_view rTopic ) const;
 
     /** Appends a new SUPBOOK to the list.
         @return  The list index of the SUPBOOK record. */
@@ -1090,7 +1091,7 @@ sal_uInt16 XclExpExtNameBuffer::InsertEuroTool( const OUString& rName )
 }
 
 sal_uInt16 XclExpExtNameBuffer::InsertDde(
-        const OUString& rApplic, const OUString& rTopic, const OUString& rItem )
+        std::u16string_view rApplic, std::u16string_view rTopic, const OUString& rItem )
 {
     sal_uInt16 nIndex = GetIndex( rItem );
     if( nIndex == 0 )
@@ -1128,7 +1129,7 @@ void XclExpExtNameBuffer::SaveXml(XclExpXmlStream& rStrm)
     maNameList.SaveXml(rStrm);
 }
 
-sal_uInt16 XclExpExtNameBuffer::GetIndex( const OUString& rName ) const
+sal_uInt16 XclExpExtNameBuffer::GetIndex( std::u16string_view rName ) const
 {
     for( size_t nPos = 0, nSize = maNameList.GetSize(); nPos < nSize; ++nPos )
         if( maNameList.GetRecord( nPos )->GetName() == rName )
@@ -1457,14 +1458,14 @@ void XclExpExternSheetBase::WriteExtNameBufferXml( XclExpXmlStream& rStrm )
 XclExpExternSheet::XclExpExternSheet( const XclExpRoot& rRoot, sal_Unicode cCode ) :
     XclExpExternSheetBase( rRoot, EXC_ID_EXTERNSHEET )
 {
-    Init( OUString(cCode) );
+    Init( OUStringChar(cCode) );
 }
 
-XclExpExternSheet::XclExpExternSheet( const XclExpRoot& rRoot, const OUString& rTabName ) :
+XclExpExternSheet::XclExpExternSheet( const XclExpRoot& rRoot, std::u16string_view rTabName ) :
     XclExpExternSheetBase( rRoot, EXC_ID_EXTERNSHEET )
 {
     // reference to own sheet: \03<sheetname>
-    Init(OUStringChar(EXC_EXTSH_TABNAME) + rTabName);
+    Init(OUString(OUStringChar(EXC_EXTSH_TABNAME) + rTabName));
 }
 
 void XclExpExternSheet::Save( XclExpStream& rStrm )
@@ -1475,7 +1476,7 @@ void XclExpExternSheet::Save( XclExpStream& rStrm )
     WriteExtNameBuffer( rStrm );
 }
 
-void XclExpExternSheet::Init( const OUString& rEncUrl )
+void XclExpExternSheet::Init( std::u16string_view rEncUrl )
 {
     OSL_ENSURE_BIFF( GetBiff() <= EXC_BIFF5 );
     maTabName.AssignByte( rEncUrl, GetTextEncoding(), XclStrFlags::EightBitLength );
@@ -1562,12 +1563,12 @@ XclExpSupbook::XclExpSupbook( const XclExpRoot& rRoot, const OUString& rApplic,
     SetRecSize( 2 + maUrlEncoded.GetSize() );
 }
 
-bool XclExpSupbook::IsUrlLink( const OUString& rUrl ) const
+bool XclExpSupbook::IsUrlLink( std::u16string_view rUrl ) const
 {
     return (meType == XclSupbookType::Extern || meType == XclSupbookType::Eurotool) && (maUrl == rUrl);
 }
 
-bool XclExpSupbook::IsDdeLink( const OUString& rApplic, const OUString& rTopic ) const
+bool XclExpSupbook::IsDdeLink( std::u16string_view rApplic, std::u16string_view rTopic ) const
 {
     return (meType == XclSupbookType::Special) && (maUrl == rApplic) && (maDdeTopic == rTopic);
 }
@@ -2082,8 +2083,8 @@ void XclExpSupbookBuffer::Save( XclExpStream& rStrm )
 
 void XclExpSupbookBuffer::SaveXml( XclExpXmlStream& rStrm )
 {
-    // Unused external references are not saved, only kept in memory
-    // saveds must be indexed from 1, so indexes must be reordered
+    // Unused external references are not saved, only kept in memory.
+    // Those that are saved must be indexed from 1, so indexes must be reordered
     ScExternalRefManager* pRefMgr = GetDoc().GetExternalRefManager();
     vector<sal_uInt16> aExternFileIds;
     for (size_t nPos = 0, nSize = maSupbookList.GetSize(); nPos < nSize; ++nPos)
@@ -2147,7 +2148,7 @@ bool XclExpSupbookBuffer::HasExternalReferences() const
 }
 
 bool XclExpSupbookBuffer::GetSupbookUrl(
-        XclExpSupbookRef& rxSupbook, sal_uInt16& rnIndex, const OUString& rUrl ) const
+        XclExpSupbookRef& rxSupbook, sal_uInt16& rnIndex, std::u16string_view rUrl ) const
 {
     for( size_t nPos = 0, nSize = maSupbookList.GetSize(); nPos < nSize; ++nPos )
     {
@@ -2162,7 +2163,7 @@ bool XclExpSupbookBuffer::GetSupbookUrl(
 }
 
 bool XclExpSupbookBuffer::GetSupbookDde( XclExpSupbookRef& rxSupbook,
-        sal_uInt16& rnIndex, const OUString& rApplic, const OUString& rTopic ) const
+        sal_uInt16& rnIndex, std::u16string_view rApplic, std::u16string_view rTopic ) const
 {
     for( size_t nPos = 0, nSize = maSupbookList.GetSize(); nPos < nSize; ++nPos )
     {
