@@ -19,6 +19,7 @@
 
 #include <comphelper/docpasswordhelper.hxx>
 #include <comphelper/sequenceashashmap.hxx>
+#include <o3tl/safeint.hxx>
 #include <osl/thread.h>
 #include <osl/diagnose.h>
 #include <sal/log.hxx>
@@ -745,19 +746,21 @@ std::size_t XclImpStream::Read( void* pData, std::size_t nBytes )
 std::size_t XclImpStream::CopyToStream( SvStream& rOutStrm, std::size_t nBytes )
 {
     std::size_t nRet = 0;
-    if( mbValid && (nBytes > 0) )
+    if (mbValid && nBytes)
     {
         const std::size_t nMaxBuffer = 4096;
-        std::unique_ptr<sal_uInt8[]> pnBuffer(new sal_uInt8[ ::std::min( nBytes, nMaxBuffer ) ]);
+        std::vector<sal_uInt8> aBuffer(o3tl::sanitizing_min(nBytes, nMaxBuffer));
         std::size_t nBytesLeft = nBytes;
 
-        while( mbValid && (nBytesLeft > 0) )
+        while (mbValid)
         {
-            std::size_t nReadSize = ::std::min( nBytesLeft, nMaxBuffer );
-            nRet += Read( pnBuffer.get(), nReadSize );
+            if (!nBytesLeft)
+                break;
+            std::size_t nReadSize = o3tl::sanitizing_min(nBytesLeft, nMaxBuffer);
+            nRet += Read(aBuffer.data(), nReadSize);
             // writing more bytes than read results in invalid memory access
             SAL_WARN_IF(nRet != nReadSize, "sc", "read less bytes than requested");
-            rOutStrm.WriteBytes(pnBuffer.get(), nReadSize);
+            rOutStrm.WriteBytes(aBuffer.data(), nReadSize);
             nBytesLeft -= nReadSize;
         }
     }
@@ -796,8 +799,10 @@ void XclImpStream::Ignore( std::size_t nBytes )
 {
     // implementation similar to Read(), but without really reading anything
     std::size_t nBytesLeft = nBytes;
-    while( mbValid && (nBytesLeft > 0) )
+    while (mbValid)
     {
+        if (!nBytesLeft)
+            break;
         sal_uInt16 nReadSize = GetMaxRawReadSize( nBytesLeft );
         mbValid = checkSeek(mrStrm, mrStrm.Tell() + nReadSize);
         mnRawRecLeft = mnRawRecLeft - nReadSize;
@@ -831,15 +836,15 @@ std::size_t XclImpStream::ReadUniStringExtHeader( bool& rb16Bit, sal_uInt8 nFlag
 
 OUString XclImpStream::ReadRawUniString( sal_uInt16 nChars, bool b16Bit )
 {
-    OUStringBuffer aRet(std::min<sal_uInt16>(nChars, mnRawRecLeft / (b16Bit ? 2 : 1)));
+    OUStringBuffer aRet(o3tl::sanitizing_min<sal_uInt16>(nChars, mnRawRecLeft / (b16Bit ? 2 : 1)));
     sal_uInt16 nCharsLeft = nChars;
     sal_uInt16 nReadSize;
 
-    while( IsValid() && (nCharsLeft > 0) )
+    while (IsValid() && nCharsLeft)
     {
         if( b16Bit )
         {
-            nReadSize = std::min<sal_uInt16>(nCharsLeft, mnRawRecLeft / 2);
+            nReadSize = o3tl::sanitizing_min<sal_uInt16>(nCharsLeft, mnRawRecLeft / 2);
             OSL_ENSURE( (nReadSize <= nCharsLeft) || !(mnRawRecLeft & 0x1),
                 "XclImpStream::ReadRawUniString - missing a byte" );
         }
@@ -911,7 +916,7 @@ void XclImpStream::IgnoreRawUniString( sal_uInt16 nChars, bool b16Bit )
     {
         if( b16Bit )
         {
-            nReadSize = ::std::min< sal_uInt16 >( nCharsLeft, mnRawRecLeft / 2 );
+            nReadSize = o3tl::sanitizing_min<sal_uInt16>(nCharsLeft, mnRawRecLeft / 2);
             OSL_ENSURE( (nReadSize <= nCharsLeft) || !(mnRawRecLeft & 0x1),
                 "XclImpStream::IgnoreRawUniString - missing a byte" );
             Ignore( nReadSize * 2 );
@@ -1061,7 +1066,7 @@ bool XclImpStream::EnsureRawReadSize( sal_uInt16 nBytes )
 
 sal_uInt16 XclImpStream::GetMaxRawReadSize( std::size_t nBytes ) const
 {
-    return static_cast< sal_uInt16 >( ::std::min< std::size_t >( nBytes, mnRawRecLeft ) );
+    return static_cast<sal_uInt16>(o3tl::sanitizing_min<std::size_t>(nBytes, mnRawRecLeft));
 }
 
 sal_uInt16 XclImpStream::ReadRawData( void* pData, sal_uInt16 nBytes )
