@@ -46,6 +46,7 @@
 #include <editeng/editids.hrc>
 #include <sal/macros.h>
 #include <sal/log.hxx>
+#include <tools/UnitConversion.hxx>
 #include <vcl/fontcharmap.hxx>
 #include <vcl/outdev.hxx>
 #include <document.hxx>
@@ -355,7 +356,7 @@ void XclImpFont::FillToItemSet( SfxItemSet& rItemSet, XclFontItemType eType, boo
     {
         sal_Int32 nHeight = maData.mnHeight;
         if( bEE && (eType != XclFontItemType::HeaderFooter) )     // do not convert header/footer height
-            nHeight = (nHeight * 127 + 36) / EXC_POINTS_PER_INCH;   // 1 in == 72 pt
+            nHeight = convertTwipToMm100(nHeight);
 
         SvxFontHeightItem aHeightItem( nHeight, 100, ATTR_FONT_HEIGHT );
         PUTITEM( aHeightItem,   ATTR_FONT_HEIGHT,       EE_CHAR_FONTHEIGHT );
@@ -834,7 +835,7 @@ void XclImpCellAlign::FillToItemSet( SfxItemSet& rItemSet, const XclImpFont* pFo
     bool bStacked = (nXclRot == EXC_ROT_STACKED);
     ScfTools::PutItem( rItemSet, ScVerticalStackCell( bStacked ), bSkipPoolDefs );
     // set an angle in the range from -90 to 90 degrees
-    sal_Int32 nAngle = XclTools::GetScRotation( nXclRot, 0 );
+    Degree100 nAngle = XclTools::GetScRotation( nXclRot, 0_deg100 );
     ScfTools::PutItem( rItemSet, ScRotateValueItem( nAngle ), bSkipPoolDefs );
     // set "Use asian vertical layout", if cell is stacked and font contains CKJ characters
     bool bAsianVert = bStacked && pFont && pFont->HasAsianChars();
@@ -1569,16 +1570,18 @@ void XclImpXFBuffer::Initialize()
 
 void XclImpXFBuffer::ReadXF( XclImpStream& rStrm )
 {
-    XclImpXF* pXF = new XclImpXF( GetRoot() );
-    pXF->ReadXF( rStrm );
-    maXFList.push_back( std::unique_ptr<XclImpXF>(pXF) );
+    std::unique_ptr<XclImpXF> xXF = std::make_unique<XclImpXF>(GetRoot());
+    xXF->ReadXF(rStrm);
+    maXFList.emplace_back(std::move(xXF));
 }
 
 void XclImpXFBuffer::ReadStyle( XclImpStream& rStrm )
 {
-    XclImpStyle* pStyle = new XclImpStyle( GetRoot() );
-    pStyle->ReadStyle( rStrm );
-    (pStyle->IsBuiltin() ? maBuiltinStyles : maUserStyles).push_back( std::unique_ptr<XclImpStyle>(pStyle) );
+    std::unique_ptr<XclImpStyle> xStyle(std::make_unique<XclImpStyle>(GetRoot()));
+    xStyle->ReadStyle(rStrm);
+    XclImpStyleList& rStyleList = (xStyle->IsBuiltin() ? maBuiltinStyles : maUserStyles);
+    rStyleList.emplace_back(std::move(xStyle));
+    XclImpStyle* pStyle = rStyleList.back().get();
     OSL_ENSURE( maStylesByXf.count( pStyle->GetXfId() ) == 0, "XclImpXFBuffer::ReadStyle - multiple styles with equal XF identifier" );
     maStylesByXf[ pStyle->GetXfId() ] = pStyle;
 }
