@@ -26,7 +26,6 @@
 #include <formulacell.hxx>
 #include <global.hxx>
 
-#include <root.hxx>
 #include <lotfntbf.hxx>
 #include <lotform.hxx>
 #include <tool.h>
@@ -35,8 +34,6 @@
 #include <stringutil.hxx>
 #include <config_fuzzers.h>
 
-#include <unotools/configmgr.hxx>
-
 
 static osl::Mutex aLotImpSemaphore;
 
@@ -72,9 +69,6 @@ void ImportLotus::Bof()
     Skip( 1 );
     Read( nFlags );
 
-    if (!pIn->good())
-        return;
-
     if( nFileSub == 0x0004 )
     {
         if( nFileCode == 0x1000 )
@@ -90,7 +84,7 @@ void ImportLotus::Bof()
 
 bool ImportLotus::BofFm3()
 {
-    sal_uInt16 nFileCode(0), nFileSub(0);
+    sal_uInt16  nFileCode, nFileSub;
 
     Read( nFileCode );
     Read( nFileSub );
@@ -179,9 +173,16 @@ void ImportLotus::Errcell()
 
     Read( aA );
 
+    if (!rD.ValidAddress(aA))
+    {
+        SAL_WARN("sc.filter", "invalid address");
+        return;
+    }
+
     ScSetStringParam aParam;
     aParam.setTextInput();
     rD.EnsureTable(aA.Tab());
+    // coverity[tainted_data : FALSE] - ValidAddress has sanitized aA
     rD.SetString(aA, "#ERR!", &aParam);
 }
 
@@ -191,9 +192,16 @@ void ImportLotus::Nacell()
 
     Read( aA );
 
+    if (!rD.ValidAddress(aA))
+    {
+        SAL_WARN("sc.filter", "invalid address");
+        return;
+    }
+
     ScSetStringParam aParam;
     aParam.setTextInput();
     rD.EnsureTable(aA.Tab());
+    // coverity[tainted_data : FALSE] - ValidAddress has sanitized aA
     rD.SetString(aA, "#NA!", &aParam);
 }
 
@@ -207,9 +215,16 @@ void ImportLotus::Labelcell()
     Read( cAlign );
     Read( aLabel );
 
+    if (!rD.ValidAddress(aA))
+    {
+        SAL_WARN("sc.filter", "invalid address");
+        return;
+    }
+
     ScSetStringParam aParam;
     aParam.setTextInput();
     rD.EnsureTable(aA.Tab());
+    // coverity[tainted_data : FALSE] - ValidAddress has sanitized aA
     rD.SetString(aA, aLabel, &aParam);
 }
 
@@ -221,7 +236,14 @@ void ImportLotus::Numbercell()
     Read( aAddr );
     Read( fVal );
 
+    if (!rD.ValidAddress(aAddr))
+    {
+        SAL_WARN("sc.filter", "invalid address");
+        return;
+    }
+
     rD.EnsureTable(aAddr.Tab());
+    // coverity[tainted_data : FALSE] - ValidAddress has sanitized aAddr
     rD.SetValue(aAddr, fVal);
 }
 
@@ -233,7 +255,14 @@ void ImportLotus::Smallnumcell()
     Read( aAddr );
     Read( nVal );
 
+    if (!rD.ValidAddress(aAddr))
+    {
+        SAL_WARN("sc.filter", "invalid address");
+        return;
+    }
+
     rD.EnsureTable(aAddr.Tab());
+    // coverity[tainted_data : FALSE] - ValidAddress has sanitized aAddr
     rD.SetValue(aAddr, SnumToDouble(nVal));
 }
 
@@ -257,9 +286,16 @@ void ImportLotus::Formulacell( sal_uInt16 n )
     if (!aConv.good())
         return;
 
+    if (!rD.ValidAddress(aAddr))
+    {
+        SAL_WARN("sc.filter", "invalid address");
+        return;
+    }
+
     ScFormulaCell* pCell = pErg ? new ScFormulaCell(rD, aAddr, std::move(pErg)) : new ScFormulaCell(rD, aAddr);
     pCell->AddRecalcMode( ScRecalcMode::ONLOAD_ONCE );
     rD.EnsureTable(aAddr.Tab());
+    // coverity[tainted_data : FALSE] - ValidAddress has sanitized aAddr
     rD.SetFormulaCell(aAddr, pCell);
 }
 
