@@ -25,6 +25,8 @@
 #include <com/sun/star/sheet/XDDELinks.hpp>
 #include <com/sun/star/sheet/XDDELinkResults.hpp>
 #include <com/sun/star/sheet/XExternalDocLinks.hpp>
+#include <com/sun/star/sheet/XSpreadsheetDocument.hpp>
+#include <o3tl/safeint.hxx>
 #include <osl/diagnose.h>
 #include <sal/log.hxx>
 #include <oox/core/filterbase.hxx>
@@ -37,8 +39,7 @@
 #include <addressconverter.hxx>
 #include <biffhelper.hxx>
 
-namespace oox {
-namespace xls {
+namespace oox::xls {
 
 using namespace ::com::sun::star::sheet;
 using namespace ::com::sun::star::uno;
@@ -538,7 +539,7 @@ void ExternalLink::insertExternalSheet( const OUString& rSheetName )
 
 ExternalNameRef ExternalLink::createExternalName()
 {
-    ExternalNameRef xExtName( new ExternalName( *this ) );
+    ExternalNameRef xExtName = std::make_shared<ExternalName>( *this );
     maExtNames.push_back( xExtName );
     return xExtName;
 }
@@ -559,7 +560,7 @@ void RefSheetsModel::readBiff12Data( SequenceInputStream& rStrm )
 
 ExternalLinkBuffer::ExternalLinkBuffer( const WorkbookHelper& rHelper ) :
     WorkbookHelper( rHelper ),
-    mxSelfRef( new ExternalLink( rHelper ) ),
+    mxSelfRef( std::make_shared<ExternalLink>( rHelper ) ),
     mbUseRefSheets( false )
 {
     mxSelfRef->setSelfLinkType();
@@ -654,18 +655,17 @@ LinkSheetRange ExternalLinkBuffer::getSheetRange( sal_Int32 nRefId ) const
 
 ExternalLinkRef ExternalLinkBuffer::createExternalLink()
 {
-    ExternalLinkRef xExtLink( new ExternalLink( *this ) );
+    ExternalLinkRef xExtLink = std::make_shared<ExternalLink>( *this );
     maLinks.push_back( xExtLink );
     return xExtLink;
 }
 
 const RefSheetsModel* ExternalLinkBuffer::getRefSheets( sal_Int32 nRefId ) const
 {
-    return ((0 <= nRefId) && (static_cast< size_t >( nRefId ) < maRefSheets.size())) ?
+    return ((0 <= nRefId) && (o3tl::make_unsigned( nRefId ) < maRefSheets.size())) ?
         &maRefSheets[ static_cast< size_t >( nRefId ) ] : nullptr;
 }
 
-} // namespace xls
 } // namespace oox
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
