@@ -46,6 +46,7 @@
 #include <sal/log.hxx>
 
 #include <stylesbuffer.hxx>
+#include <orcus/exception.hpp>
 
 using namespace com::sun::star;
 
@@ -158,51 +159,54 @@ orcus::spreadsheet::formula_grammar_t ScOrcusGlobalSettings::get_default_formula
 ScOrcusRefResolver::ScOrcusRefResolver( const ScOrcusGlobalSettings& rGS ) :
     mrGlobalSettings(rGS) {}
 
-os::address_t ScOrcusRefResolver::resolve_address(const char* p, size_t n)
+os::src_address_t ScOrcusRefResolver::resolve_address(const char* p, size_t n)
 {
     OUString aStr(p, n, mrGlobalSettings.getTextEncoding());
 
     ScAddress aAddr;
-    aAddr.Parse(aStr, nullptr,
+    aAddr.Parse(aStr, mrGlobalSettings.getDoc().getDoc(),
         formula::FormulaGrammar::extractRefConvention(
             mrGlobalSettings.getCalcGrammar()));
 
-    os::address_t ret;
-    ret.column = 0;
-    ret.row = 0;
-
-    if (aAddr.IsValid())
+    if (!aAddr.IsValid())
     {
-        ret.column = aAddr.Col();
-        ret.row = aAddr.Row();
+        std::ostringstream os;
+        os << "'" << std::string(p, n) << "' is not a valid address expression.";
+        throw orcus::invalid_arg_error(os.str());
     }
 
+    os::src_address_t ret;
+    ret.sheet = aAddr.Tab();
+    ret.column = aAddr.Col();
+    ret.row = aAddr.Row();
+
     return ret;
 }
 
-os::range_t ScOrcusRefResolver::resolve_range(const char* p, size_t n)
+os::src_range_t ScOrcusRefResolver::resolve_range(const char* p, size_t n)
 {
     OUString aStr(p, n, mrGlobalSettings.getTextEncoding());
 
     ScRange aRange;
-    aRange.Parse(aStr, nullptr,
+    aRange.Parse(aStr, mrGlobalSettings.getDoc().getDoc(),
         formula::FormulaGrammar::extractRefConvention(
             mrGlobalSettings.getCalcGrammar()));
 
-    os::range_t ret;
-    ret.first.column = 0;
-    ret.first.row = 0;
-    ret.last.column = 0;
-    ret.last.row = 0;
-
-    if (aRange.IsValid())
+    if (!aRange.IsValid())
     {
-        ret.first.column = aRange.aStart.Col();
-        ret.first.row    = aRange.aStart.Row();
-        ret.last.column  = aRange.aEnd.Col();
-        ret.last.row     = aRange.aEnd.Row();
+        std::ostringstream os;
+        os << "'" << std::string(p, n) << "' is not a valid range expression.";
+        throw orcus::invalid_arg_error(os.str());
     }
 
+    os::src_range_t ret;
+    ret.first.sheet  = aRange.aStart.Tab();
+    ret.first.column = aRange.aStart.Col();
+    ret.first.row    = aRange.aStart.Row();
+    ret.last.sheet   = aRange.aEnd.Tab();
+    ret.last.column  = aRange.aEnd.Col();
+    ret.last.row     = aRange.aEnd.Row();
+
     return ret;
 }
 
@@ -210,20 +214,46 @@ ScOrcusNamedExpression::ScOrcusNamedExpression(
     ScDocumentImport& rDoc, const ScOrcusGlobalSettings& rGS, SCTAB nTab ) :
     mrDoc(rDoc), mrGlobalSettings(rGS), mnTab(nTab) {}
 
-void ScOrcusNamedExpression::define_name(const char* p_name, size_t n_name, const char* p_exp, size_t n_exp)
+void ScOrcusNamedExpression::reset()
 {
-    OUString aName(p_name, n_name, mrGlobalSettings.getTextEncoding());
-    OUString aExpr(p_exp, n_exp, mrGlobalSettings.getTextEncoding());
+    maBasePos.SetTab(0);
+    maBasePos.SetCol(0);
+    maBasePos.SetRow(0);
+    maName.clear();
+    maExpr.clear();
+}
 
+void ScOrcusNamedExpression::set_base_position(const orcus::spreadsheet::src_address_t& pos)
+{
+    maBasePos.SetTab(pos.sheet);
+    maBasePos.SetCol(pos.column);
+    maBasePos.SetRow(pos.row);
+}
+
+void ScOrcusNamedExpression::set_named_expression(const char* p_name, size_t n_name, const char* p_exp, size_t n_exp)
+{
+    maName = OUString(p_name, n_name, mrGlobalSettings.getTextEncoding());
+    maExpr = OUString(p_exp, n_exp, mrGlobalSettings.getTextEncoding());
+}
+
+void ScOrcusNamedExpression::set_named_range(const char* /*p_name*/, size_t /*n_name*/, const char* /*p_range*/, size_t /*n_range*/)
+{
+    throw std::runtime_error("ScOrcusNamedExpression::set_named_range not implemented yet.");
+}
+
+void ScOrcusNamedExpression::commit()
+{
     ScRangeName* pNames = mnTab >= 0 ? mrDoc.getDoc().GetRangeName(mnTab) : mrDoc.getDoc().GetRangeName();
     if (!pNames)
         return;
 
     ScRangeData* pRange = new ScRangeData(
-        &mrDoc.getDoc(), aName, aExpr, ScAddress(), ScRangeData::Type::Name,
+        mrDoc.getDoc(), maName, maExpr, maBasePos, ScRangeData::Type::Name,
         mrGlobalSettings.getCalcGrammar());
 
     pNames->insert(pRange, false);
+
+    reset(); // make sure to reset the state for the next run.
 }
 
 ScOrcusFactory::CellStoreToken::CellStoreToken(const ScAddress& rPos, Type eType)
@@ -380,7 +410,7 @@ void ScOrcusFactory::finalize()
         if (!pArray)
             return std::unique_ptr<ScFormulaCell>();
 
-        return std::make_unique<ScFormulaCell>(&maDoc.getDoc(), rToken.maPos, *pArray);
+        return std::make_unique<ScFormulaCell>(maDoc.getDoc(), rToken.maPos, *pArray);
     };
 
     int nCellCount = 0;
@@ -466,7 +496,7 @@ void ScOrcusFactory::finalize()
                 aRange.aEnd.IncCol(rToken.mnIndex1-1);
                 aRange.aEnd.IncRow(rToken.mnIndex2-1);
 
-                ScCompiler aComp(&maDoc.getDoc(), aRange.aStart, rToken.meGrammar);
+                ScCompiler aComp(maDoc.getDoc(), aRange.aStart, rToken.meGrammar);
                 std::unique_ptr<ScTokenArray> pArray(aComp.CompileString(rToken.maStr1));
                 if (!pArray)
                     break;
@@ -673,16 +703,12 @@ double translateToInternal(double nVal, orcus::length_unit_t unit)
     {
         case orcus::length_unit_t::inch:
             return nVal * 72.0 * 20.0;
-            break;
         case orcus::length_unit_t::twip:
             return nVal;
-            break;
         case orcus::length_unit_t::point:
             return nVal * 20.0;
-            break;
         case orcus::length_unit_t::centimeter:
             return nVal * 20.0 * 72.0 / 2.54;
-            break;
         case orcus::length_unit_t::unknown:
             if (nVal != 0)
                 SAL_WARN("sc.orcus", "unknown unit");
@@ -980,7 +1006,7 @@ void ScOrcusFormula::commit()
             // topmost shared formula with new formula token.
 
             // Compile the formula expression into tokens.
-            ScCompiler aComp(&mrSheet.getDoc().getDoc(), aPos, meGrammar);
+            ScCompiler aComp(mrSheet.getDoc().getDoc(), aPos, meGrammar);
             std::unique_ptr<ScTokenArray> pArray = aComp.CompileString(maFormula);
             if (!pArray)
                 // Tokenization failed.
@@ -1164,7 +1190,7 @@ void ScOrcusSheet::set_date_time(
     sal_uInt32 nSec = floor(second);
     sal_uInt32 nNanoSec = (second - nSec) * ::tools::Time::nanoSecPerSec;
     tools::Time aTime(hour, minute, nSec, nNanoSec);
-    long nDateDiff = aDate - pFormatter->GetNullDate();
+    tools::Long nDateDiff = aDate - pFormatter->GetNullDate();
 
     double fTime =
         static_cast<double>(aTime.GetNanoSec()) / ::tools::Time::nanoSecPerSec +
@@ -1404,16 +1430,12 @@ SvxBoxItemLine getDirection(os::border_direction_t dir)
     {
         case os::border_direction_t::right:
             return SvxBoxItemLine::RIGHT;
-        break;
         case os::border_direction_t::left:
             return SvxBoxItemLine::LEFT;
-        break;
         case os::border_direction_t::top:
             return SvxBoxItemLine::TOP;
-        break;
         case os::border_direction_t::bottom:
             return SvxBoxItemLine::BOTTOM;
-        break;
         default:
         break;
     }
@@ -1697,7 +1719,7 @@ void ScOrcusStyles::set_font_underline_color(orcus::spreadsheet::color_elem_t al
             orcus::spreadsheet::color_elem_t green,
             orcus::spreadsheet::color_elem_t blue)
 {
-    maCurrentFont.maUnderlineColor = Color(alpha, red, green, blue);
+    maCurrentFont.maUnderlineColor = Color(ColorTransparency, alpha, red, green, blue);
 }
 
 void ScOrcusStyles::set_font_color(orcus::spreadsheet::color_elem_t /*alpha*/,
