@@ -81,9 +81,6 @@ using ::oox::drawingml::ShapeExport;
 using ::oox::vml::VMLExport;
 using namespace oox;
 
-sal_Int32 XclExpObjList::mnDrawingMLCount;
-sal_Int32 XclExpObjList::mnVmlCount;
-
 XclExpObjList::XclExpObjList( const XclExpRoot& rRoot, XclEscherEx& rEscherEx ) :
     XclExpRoot( rRoot ),
     mnScTab( rRoot.GetCurrScTab() ),
@@ -237,7 +234,7 @@ void SaveDrawingMLObjects( XclExpObjList& rList, XclExpXmlStream& rStrm )
     if (aList.empty())
         return;
 
-    sal_Int32 nDrawing = XclExpObjList::getNewDrawingUniqueId();
+    sal_Int32 nDrawing = drawingml::DrawingML::getNewDrawingUniqueId();
     OUString sId;
     sax_fastparser::FSHelperPtr pDrawing = rStrm.CreateOutputStream(
             XclXmlUtils::GetStreamName( "xl/", "drawings/drawing", nDrawing ),
@@ -318,12 +315,12 @@ void SaveFormControlObjects(XclExpObjList& rList, XclExpXmlStream& rStrm)
     rWorksheet->endElement(FSNS(XML_mc, XML_AlternateContent));
 }
 
-void SaveVmlObjects( XclExpObjList& rList, XclExpXmlStream& rStrm, sal_Int32& nVmlCount )
+void SaveVmlObjects( XclExpObjList& rList, XclExpXmlStream& rStrm )
 {
     if( GetVmlObjectCount( rList ) == 0 )
         return;
 
-    sal_Int32 nDrawing = ++nVmlCount;
+    sal_Int32 nDrawing = drawingml::DrawingML::getNewVMLUniqueId();
     OUString sId;
     sax_fastparser::FSHelperPtr pVmlDrawing = rStrm.CreateOutputStream(
             XclXmlUtils::GetStreamName( "xl/", "drawings/vmlDrawing", nDrawing ),
@@ -365,16 +362,10 @@ void XclExpObjList::SaveXml( XclExpXmlStream& rStrm )
         return;
 
     SaveDrawingMLObjects( *this, rStrm );
-    SaveVmlObjects( *this, rStrm, mnVmlCount );
+    SaveVmlObjects( *this, rStrm );
     SaveFormControlObjects( *this, rStrm );
 }
 
-void XclExpObjList::ResetCounters()
-{
-    mnDrawingMLCount    = 0;
-    mnVmlCount          = 0;
-}
-
 // --- class XclObj --------------------------------------------------
 
 XclObj::XclObj( XclExpObjectManager& rObjMgr, sal_uInt16 nObjType, bool bOwnEscher ) :
@@ -463,7 +454,7 @@ void XclObj::WriteBody( XclExpStream& rStrm )
 
     // create a substream to be able to create subrecords
     SvMemoryStream aMemStrm;
-    std::unique_ptr< XclExpStream > pXclStrm( new XclExpStream( aMemStrm, rStrm.GetRoot() ) );
+    std::optional< XclExpStream > pXclStrm( std::in_place, aMemStrm, rStrm.GetRoot() );
 
     // write the ftCmo subrecord
     pXclStrm->StartRecord( EXC_ID_OBJCMO, 18 );
@@ -875,10 +866,10 @@ XclTxo::XclTxo( const XclExpRoot& rRoot, const SdrTextObj& rTextObj ) :
     SetVerAlign( lcl_GetVerAlignFromItemSet( rItemSet ) );
 
     // rotation
-    tools::Long nAngle = rTextObj.GetRotateAngle();
-    if( (4500 < nAngle) && (nAngle < 13500) )
+    Degree100 nAngle = rTextObj.GetRotateAngle();
+    if( (4500_deg100 < nAngle) && (nAngle < 13500_deg100) )
         mnRotation = EXC_OBJ_ORIENT_90CCW;
-    else if( (22500 < nAngle) && (nAngle < 31500) )
+    else if( (22500_deg100 < nAngle) && (nAngle < 31500_deg100) )
         mnRotation = EXC_OBJ_ORIENT_90CW;
     else
         mnRotation = EXC_OBJ_ORIENT_NONE;
@@ -1101,11 +1092,11 @@ void XclObjAny::WriteFromTo( XclExpXmlStream& rStrm, const Reference< XShape >&
     awt::Size   aSize       = rShape->getSize();
 
     // There are a few cases where we must adjust these values
-    SdrObject* pObj = SdrObject::getSdrObjectFromXShape(rShape.get());
+    SdrObject* pObj = SdrObject::getSdrObjectFromXShape(rShape);
     if (pObj)
     {
-        sal_Int32 nRotation = pObj->GetRotateAngle();
-        if (nRotation != 0)
+        Degree100 nRotation = pObj->GetRotateAngle();
+        if (nRotation)
         {
             sal_Int16 nHalfWidth = aSize.Width / 2;
             sal_Int16 nHalfHeight = aSize.Height / 2;
@@ -1117,7 +1108,7 @@ void XclObjAny::WriteFromTo( XclExpXmlStream& rStrm, const Reference< XShape >&
             // MSO changes the anchor positions at these angles and that does an extra 90 degrees
             // rotation on our shapes, so we output it in such position that MSO
             // can draw this shape correctly.
-            if ((nRotation >= 45 * 100 && nRotation < 135 * 100) || (nRotation >= 225 * 100 && nRotation < 315 * 100))
+            if ((nRotation >= 4500_deg100 && nRotation < 13500_deg100) || (nRotation >= 22500_deg100 && nRotation < 31500_deg100))
             {
                 aTopLeft.X = aTopLeft.X - nHalfHeight + nHalfWidth;
                 aTopLeft.Y = aTopLeft.Y - nHalfWidth + nHalfHeight;
@@ -1393,7 +1384,7 @@ void ExcBundlesheet8::SaveXml( XclExpXmlStream& rStrm )
 
     rStrm.GetCurrentStream()->singleElement( XML_sheet,
             XML_name,               sUnicodeName.toUtf8(),
-            XML_sheetId,            OString::number( ( nTab+1 ) ),
+            XML_sheetId,            OString::number( nTab+1 ),
             XML_state,              nGrbit == 0x0000 ? "visible" : "hidden",
             FSNS( XML_r, XML_id ),  sId.toUtf8() );
 }
@@ -1686,7 +1677,7 @@ XclExpSheetProtectOptions::XclExpSheetProtectOptions( const XclExpRoot& rRoot, S
     };
 
     mnOptions = 0x0000;
-    ScTableProtection* pProtect = rRoot.GetDoc().GetTabProtection(nTab);
+    const ScTableProtection* pProtect = rRoot.GetDoc().GetTabProtection(nTab);
     if (!pProtect)
         return;
 
