@@ -20,7 +20,6 @@
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/text/XText.hpp>
 #include <com/sun/star/sheet/XHeaderFooterContent.hpp>
-#include <xmloff/namespacemap.hxx>
 #include <xmloff/xmlnamespace.hxx>
 #include <xmloff/xmlimp.hxx>
 #include "XMLTableHeaderFooterContext.hxx"
@@ -42,7 +41,7 @@ XMLTableHeaderFooterContext::XMLTableHeaderFooterContext( SvXMLImport& rImport,
                        const uno::Reference<
                             xml::sax::XFastAttributeList > & xAttrList,
                        const Reference < XPropertySet > & rPageStylePropSet,
-                       bool bFooter, bool bLeft ) :
+                       bool bFooter, bool bLeft, bool bFirst ) :
     SvXMLImportContext( rImport ),
     xPropSet( rPageStylePropSet ),
     bContainsLeft(false),
@@ -52,19 +51,20 @@ XMLTableHeaderFooterContext::XMLTableHeaderFooterContext( SvXMLImport& rImport,
     OUString sOn( bFooter ? OUString(SC_UNO_PAGE_FTRON) : OUString(SC_UNO_PAGE_HDRON) );
     OUString sContent( bFooter ? OUString(SC_UNO_PAGE_RIGHTFTRCON) : OUString(SC_UNO_PAGE_RIGHTHDRCON) );
     OUString sContentLeft( bFooter ? OUString(SC_UNO_PAGE_LEFTFTRCONT) : OUString(SC_UNO_PAGE_LEFTHDRCONT) );
+    OUString sContentFirst( bFooter ? OUString(SC_UNO_PAGE_FIRSTFTRCONT) : OUString(SC_UNO_PAGE_FIRSTHDRCONT) );
     OUString sShareContent( bFooter ? OUString(SC_UNO_PAGE_FTRSHARED) : OUString(SC_UNO_PAGE_HDRSHARED) );
+    OUString sShareFirstContent( bFooter ? OUString(SC_UNO_PAGE_FIRSTFTRSHARED) : OUString(SC_UNO_PAGE_FIRSTHDRSHARED) );
     bool bDisplay( true );
     for( auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ) )
     {
         if( aIter.getToken() == XML_ELEMENT(STYLE, XML_DISPLAY) )
-            bDisplay = IsXMLToken(aIter.toString(), XML_TRUE);
+            bDisplay = IsXMLToken(aIter, XML_TRUE);
         else
             XMLOFF_WARN_UNKNOWN("sc", aIter);
     }
+    bool bOn(::cppu::any2bool(xPropSet->getPropertyValue( sOn )));
     if( bLeft )
     {
-        bool bOn(::cppu::any2bool(xPropSet->getPropertyValue( sOn )));
-
         if( bOn && bDisplay )
         {
             if( ::cppu::any2bool(xPropSet->getPropertyValue( sShareContent )) )
@@ -80,14 +80,22 @@ XMLTableHeaderFooterContext::XMLTableHeaderFooterContext( SvXMLImport& rImport,
     }
     else
     {
-        bool bOn(::cppu::any2bool(xPropSet->getPropertyValue( sOn )));
         if ( bOn != bDisplay )
             xPropSet->setPropertyValue( sOn, uno::makeAny(bDisplay) );
     }
     if (bLeft)
+    {
         sCont = sContentLeft;
+    }
+    else if (bFirst)
+    {
+        sCont = sContentFirst;
+        xPropSet->setPropertyValue( sShareFirstContent, uno::makeAny(!bDisplay) );
+    }
     else
+    {
         sCont = sContent;
+    }
     xPropSet->getPropertyValue( sCont ) >>= xHeaderFooterContent;
 }
 
@@ -97,7 +105,7 @@ XMLTableHeaderFooterContext::~XMLTableHeaderFooterContext()
 
 css::uno::Reference< css::xml::sax::XFastContextHandler > XMLTableHeaderFooterContext::createFastChildContext(
     sal_Int32 nElement,
-    const css::uno::Reference< css::xml::sax::XFastAttributeList >& /*xAttrList*/ )
+    const css::uno::Reference< css::xml::sax::XFastAttributeList >& xAttrList )
 {
     if (xHeaderFooterContent.is())
     {
@@ -125,18 +133,8 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > XMLTableHeaderFooterCo
             return new XMLHeaderFooterRegionContext( GetImport(), xTempTextCursor);
         }
     }
-    return nullptr;
-}
 
-SvXMLImportContextRef XMLTableHeaderFooterContext::CreateChildContext(
-    sal_uInt16 nPrefix,
-    const OUString& rLocalName,
-    const uno::Reference< xml::sax::XAttributeList > & xAttrList )
-{
-    SvXMLImportContext *pContext(nullptr);
-
-    if ((nPrefix == XML_NAMESPACE_TEXT) &&
-        IsXMLToken(rLocalName, XML_P))
+    if ( nElement == XML_ELEMENT(TEXT, XML_P) )
     {
         if (!xTextCursor.is())
         {
@@ -150,14 +148,14 @@ SvXMLImportContextRef XMLTableHeaderFooterContext::CreateChildContext(
                 bContainsCenter = true;
             }
         }
-        pContext =
+        return
             GetImport().GetTextImport()->CreateTextChildContext(GetImport(),
-                                                                    nPrefix,
-                                                                    rLocalName,
+                                                                    nElement,
                                                                     xAttrList);
     }
 
-    return pContext;
+    XMLOFF_WARN_UNKNOWN_ELEMENT("sc", nElement);
+    return nullptr;
 }
 
 void XMLTableHeaderFooterContext::endFastElement(sal_Int32 )
@@ -202,23 +200,19 @@ XMLHeaderFooterRegionContext::~XMLHeaderFooterRegionContext()
 {
 }
 
-SvXMLImportContextRef XMLHeaderFooterRegionContext::CreateChildContext(
-    sal_uInt16 nPrefix,
-    const OUString& rLocalName,
-    const uno::Reference< xml::sax::XAttributeList > & xAttrList )
+css::uno::Reference< css::xml::sax::XFastContextHandler > XMLHeaderFooterRegionContext::createFastChildContext(
+    sal_Int32 nElement,
+    const css::uno::Reference< css::xml::sax::XFastAttributeList >& xAttrList )
 {
     SvXMLImportContext *pContext(nullptr);
 
-    if ((nPrefix == XML_NAMESPACE_TEXT) &&
-        IsXMLToken(rLocalName, XML_P))
+    if (nElement == XML_ELEMENT(TEXT, XML_P))
     {
-        pContext =
-            GetImport().GetTextImport()->CreateTextChildContext(GetImport(),
-                                                                    nPrefix,
-                                                                    rLocalName,
+        return GetImport().GetTextImport()->CreateTextChildContext(GetImport(),
+                                                                    nElement,
                                                                     xAttrList);
     }
-
+    XMLOFF_WARN_UNKNOWN_ELEMENT("sc", nElement);
     return pContext;
 }
 
