@@ -142,24 +142,21 @@ class ScXMLChangeCellContext;
 
 class ScXMLChangeTextPContext : public ScXMLImportContext
 {
-    css::uno::Reference< css::xml::sax::XAttributeList> xAttrList;
-    OUString                    sLName;
+    css::uno::Reference< css::xml::sax::XFastAttributeList> mxAttrList;
+    sal_Int32                   mnElement;
     OUStringBuffer              sText;
     ScXMLChangeCellContext*     pChangeCellContext;
     rtl::Reference<SvXMLImportContext>
                                 pTextPContext;
-    sal_uInt16                  nPrefix;
 
 public:
 
-    ScXMLChangeTextPContext( ScXMLImport& rImport, sal_uInt16 nPrfx,
-                       const OUString& rLName,
-                       const css::uno::Reference<css::xml::sax::XAttributeList>& xAttrList,
+    ScXMLChangeTextPContext( ScXMLImport& rImport, sal_Int32 nElement,
+                       const css::uno::Reference<css::xml::sax::XFastAttributeList>& xAttrList,
                         ScXMLChangeCellContext* pChangeCellContext);
 
-    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
-                                     const OUString& rLocalName,
-                                     const css::uno::Reference<css::xml::sax::XAttributeList>& xAttrList ) override;
+    virtual css::uno::Reference< css::xml::sax::XFastContextHandler > SAL_CALL createFastChildContext(
+        sal_Int32 nElement, const css::uno::Reference< css::xml::sax::XFastAttributeList >& xAttrList ) override;
 
     virtual void SAL_CALL characters( const OUString& rChars ) override;
 
@@ -189,12 +186,8 @@ public:
                                       OUString& rInputString, double& fValue, sal_uInt16& nType,
                                       ScMatrixMode& nMatrixFlag, sal_Int32& nMatrixCols, sal_Int32& nMatrixRows);
 
-    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
-                                                    const OUString& rLocalName,
-                                                    const css::uno::Reference<css::xml::sax::XAttributeList>& xAttrList ) override;
     virtual css::uno::Reference< css::xml::sax::XFastContextHandler > SAL_CALL createFastChildContext(
-        sal_Int32 /*nElement*/, const css::uno::Reference< css::xml::sax::XFastAttributeList >& /*xAttrList*/ ) override
-    { return nullptr; }
+        sal_Int32 nElement, const css::uno::Reference< css::xml::sax::XFastAttributeList >& xAttrList ) override;
 
     void CreateTextPContext(bool bIsNewParagraph);
     bool IsEditCell() const { return mpEditTextObj.is(); }
@@ -529,7 +522,7 @@ ScXMLCellContentDeletionContext::ScXMLCellContentDeletionContext(  ScXMLImport&
     {
         auto aIter( rAttrList->find( XML_ELEMENT( TABLE, XML_ID ) ) );
         if (aIter != rAttrList->end())
-            nID = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+            nID = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
     }
 }
 
@@ -575,7 +568,7 @@ ScXMLDependenceContext::ScXMLDependenceContext(  ScXMLImport& rImport,
     {
         auto aIter( rAttrList->find( XML_ELEMENT( TABLE, XML_ID ) ) );
         if (aIter != rAttrList->end())
-            nID = ScXMLChangeTrackingImportHelper::GetIDFromString(aIter.toString());
+            nID = ScXMLChangeTrackingImportHelper::GetIDFromString(aIter.toView());
     }
     pChangeTrackingImportHelper->AddDependence(nID);
 }
@@ -615,7 +608,7 @@ ScXMLChangeDeletionContext::ScXMLChangeDeletionContext(  ScXMLImport& rImport,
     {
         auto aIter( rAttrList->find( XML_ELEMENT( TABLE, XML_ID ) ) );
         if (aIter != rAttrList->end())
-            nID = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+            nID = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
     }
     pChangeTrackingImportHelper->AddDeleted(nID);
 }
@@ -649,39 +642,34 @@ uno::Reference< xml::sax::XFastContextHandler > SAL_CALL ScXMLDeletionsContext::
 }
 
 ScXMLChangeTextPContext::ScXMLChangeTextPContext( ScXMLImport& rImport,
-                                      sal_uInt16 nPrfx,
-                                      const OUString& rLName,
-                                      const css::uno::Reference<css::xml::sax::XAttributeList>& xTempAttrList,
+                                      sal_Int32 nElement,
+                                      const css::uno::Reference<css::xml::sax::XFastAttributeList>& xAttrList,
                                       ScXMLChangeCellContext* pTempChangeCellContext) :
-    ScXMLImportContext( rImport, nPrfx, rLName ),
-    xAttrList(xTempAttrList),
-    sLName(rLName),
+    ScXMLImportContext( rImport ),
+    mxAttrList(xAttrList),
+    mnElement(nElement),
     sText(),
-    pChangeCellContext(pTempChangeCellContext),
-    nPrefix(nPrfx)
+    pChangeCellContext(pTempChangeCellContext)
 {
     // here are no attributes
 }
 
-SvXMLImportContextRef ScXMLChangeTextPContext::CreateChildContext( sal_uInt16 nTempPrefix,
-                                            const OUString& rLName,
-                                            const css::uno::Reference<css::xml::sax::XAttributeList>& xTempAttrList )
+uno::Reference< xml::sax::XFastContextHandler > SAL_CALL ScXMLChangeTextPContext::createFastChildContext(
+    sal_Int32 nElement,
+    const uno::Reference< xml::sax::XFastAttributeList >& xAttrList )
 {
-    SvXMLImportContextRef xContext;
-
-    if ((nPrefix == XML_NAMESPACE_TEXT) && (IsXMLToken(rLName, XML_S)) && !pTextPContext)
+    uno::Reference< xml::sax::XFastContextHandler > xContext;
+    if (IsTokenInNamespace(mnElement, XML_NAMESPACE_TEXT)
+        && (nElement & TOKEN_MASK) == XML_S
+        && !pTextPContext)
     {
         sal_Int32 nRepeat(0);
-        sal_Int16 nAttrCount(xAttrList.is() ? xAttrList->getLength() : 0);
-        for( sal_Int16 i=0; i < nAttrCount; ++i )
+        for( auto& aIter : sax_fastparser::castToFastAttributeList(mxAttrList) )
         {
-            const OUString& sAttrName(xAttrList->getNameByIndex( i ));
-            const OUString& sValue(xAttrList->getValueByIndex( i ));
-            OUString aLocalName;
-            sal_uInt16 nPrfx(GetScImport().GetNamespaceMap().GetKeyByAttrName(
-                                                sAttrName, &aLocalName ));
-            if ((nPrfx == XML_NAMESPACE_TEXT) && (IsXMLToken(aLocalName, XML_C)))
-                nRepeat = sValue.toInt32();
+            if (aIter.getToken() == XML_ELEMENT(TEXT, XML_C))
+                nRepeat = aIter.toInt32();
+            else
+                XMLOFF_WARN_UNKNOWN("sc", aIter);
         }
         if (nRepeat)
             for (sal_Int32 j = 0; j < nRepeat; ++j)
@@ -697,14 +685,14 @@ SvXMLImportContextRef ScXMLChangeTextPContext::CreateChildContext( sal_uInt16 nT
         if (!pTextPContext)
         {
             bWasContext = false;
-            pTextPContext= GetScImport().GetTextImport()->CreateTextChildContext(
-                                    GetScImport(), nPrefix, sLName, xAttrList);
+            pTextPContext = GetScImport().GetTextImport()->CreateTextChildContext(
+                                    GetScImport(), mnElement, mxAttrList);
         }
         if (pTextPContext)
         {
             if (!bWasContext)
                 pTextPContext->characters(sText.makeStringAndClear());
-            xContext = pTextPContext->CreateChildContext(nTempPrefix, rLName, xTempAttrList);
+            xContext = pTextPContext->createFastChildContext(nElement, xAttrList);
         }
     }
 
@@ -719,7 +707,7 @@ void ScXMLChangeTextPContext::characters( const OUString& rChars )
         pTextPContext->characters(rChars);
 }
 
-void ScXMLChangeTextPContext::endFastElement(sal_Int32 )
+void ScXMLChangeTextPContext::endFastElement(sal_Int32 /*nElement*/)
 {
     if (!pTextPContext)
         pChangeCellContext->SetText(sText.makeStringAndClear());
@@ -807,18 +795,17 @@ ScXMLChangeCellContext::ScXMLChangeCellContext( ScXMLImport& rImport,
         nMatrixFlag = ScMatrixMode::Formula;
 }
 
-SvXMLImportContextRef ScXMLChangeCellContext::CreateChildContext( sal_uInt16 nPrefix,
-                                     const OUString& rLocalName,
-                                     const css::uno::Reference<css::xml::sax::XAttributeList>& xAttrList )
+uno::Reference< xml::sax::XFastContextHandler > ScXMLChangeCellContext::createFastChildContext(
+    sal_Int32 nElement, const uno::Reference< xml::sax::XFastAttributeList >& xAttrList )
 {
     SvXMLImportContext *pContext(nullptr);
 
-    if ((nPrefix == XML_NAMESPACE_TEXT) && (IsXMLToken(rLocalName, XML_P)))
+    if (nElement == XML_ELEMENT(TEXT, XML_P))
     {
         bEmpty = false;
         if (bFirstParagraph)
         {
-            pContext = new ScXMLChangeTextPContext(GetScImport(), nPrefix, rLocalName, xAttrList, this);
+            pContext = new ScXMLChangeTextPContext(GetScImport(), nElement, xAttrList, this);
             bFirstParagraph = false;
         }
         else
@@ -826,9 +813,11 @@ SvXMLImportContextRef ScXMLChangeCellContext::CreateChildContext( sal_uInt16 nPr
             if (!mpEditTextObj.is())
                 CreateTextPContext(true);
             pContext = GetScImport().GetTextImport()->CreateTextChildContext(
-                GetScImport(), nPrefix, rLocalName, xAttrList);
+                GetScImport(), nElement, xAttrList);
         }
     }
+    else
+        XMLOFF_WARN_UNKNOWN_ELEMENT("sc", nElement);
 
     return pContext;
 }
@@ -840,7 +829,7 @@ void ScXMLChangeCellContext::CreateTextPContext(bool bIsNewParagraph)
 
     mpEditTextObj = new ScEditEngineTextObj();
     mpEditTextObj->GetEditEngine()->SetEditTextObjectPool(GetScImport().GetDocument()->GetEditPool());
-    uno::Reference <text::XText> xText(mpEditTextObj.get());
+    uno::Reference <text::XText> xText(mpEditTextObj);
     if (xText.is())
     {
         uno::Reference<text::XTextCursor> xTextCursor(xText->createTextCursor());
@@ -918,7 +907,7 @@ ScXMLPreviousContext::ScXMLPreviousContext(  ScXMLImport& rImport,
     {
         auto aIter( rAttrList->find( XML_ELEMENT( TABLE, XML_ID ) ) );
         if (aIter != rAttrList->end())
-            nID = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+            nID = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
     }
 }
 
@@ -959,7 +948,7 @@ ScXMLContentChangeContext::ScXMLContentChangeContext(  ScXMLImport& rImport,
             switch (aIter.getToken())
             {
             case XML_ELEMENT( TABLE, XML_ID ):
-                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_ACCEPTANCE_STATE ):
                 if (IsXMLToken( aIter, XML_ACCEPTED ))
@@ -968,7 +957,7 @@ ScXMLContentChangeContext::ScXMLContentChangeContext(  ScXMLImport& rImport,
                     nActionState = SC_CAS_REJECTED;
                 break;
             case XML_ELEMENT( TABLE, XML_REJECTING_CHANGE_ID ):
-                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
             }
         }
     }
@@ -1035,7 +1024,7 @@ ScXMLInsertionContext::ScXMLInsertionContext( ScXMLImport& rImport,
             switch (aIter.getToken())
             {
             case XML_ELEMENT( TABLE, XML_ID ):
-                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_ACCEPTANCE_STATE ):
                 if (IsXMLToken( aIter, XML_ACCEPTED ))
@@ -1044,7 +1033,7 @@ ScXMLInsertionContext::ScXMLInsertionContext( ScXMLImport& rImport,
                     nActionState = SC_CAS_REJECTED;
                 break;
             case XML_ELEMENT( TABLE, XML_REJECTING_CHANGE_ID ):
-                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_TYPE ):
                 if (IsXMLToken( aIter, XML_ROW ))
@@ -1109,15 +1098,13 @@ ScXMLInsertionCutOffContext::ScXMLInsertionCutOffContext( ScXMLImport& rImport,
     sal_Int32 nPosition(0);
     for (auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ))
     {
-        const OUString sValue = aIter.toString();
-
         switch (aIter.getToken())
         {
             case XML_ELEMENT(TABLE, XML_ID):
-                nID = ScXMLChangeTrackingImportHelper::GetIDFromString(sValue);
+                nID = ScXMLChangeTrackingImportHelper::GetIDFromString(aIter.toView());
                 break;
             case XML_ELEMENT(TABLE, XML_POSITION):
-                ::sax::Converter::convertNumber(nPosition, sValue);
+                ::sax::Converter::convertNumber(nPosition, aIter.toView());
                 break;
         }
     }
@@ -1137,22 +1124,20 @@ ScXMLMovementCutOffContext::ScXMLMovementCutOffContext( ScXMLImport& rImport,
     bool bPosition(false);
     for (auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ))
     {
-        const OUString sValue = aIter.toString();
-
         switch (aIter.getToken())
         {
             case XML_ELEMENT(TABLE, XML_ID):
-                nID = ScXMLChangeTrackingImportHelper::GetIDFromString(sValue);
+                nID = ScXMLChangeTrackingImportHelper::GetIDFromString(aIter.toView());
                 break;
             case XML_ELEMENT(TABLE, XML_POSITION):
                 bPosition = true;
-                ::sax::Converter::convertNumber(nPosition, sValue);
+                ::sax::Converter::convertNumber(nPosition, aIter.toView());
                 break;
             case XML_ELEMENT(TABLE, XML_START_POSITION):
-                ::sax::Converter::convertNumber(nStartPosition, sValue);
+                ::sax::Converter::convertNumber(nStartPosition, aIter.toView());
                 break;
             case XML_ELEMENT(TABLE, XML_END_POSITION):
-                ::sax::Converter::convertNumber(nEndPosition, sValue);
+                ::sax::Converter::convertNumber(nEndPosition, aIter.toView());
                 break;
         }
     }
@@ -1204,7 +1189,7 @@ ScXMLDeletionContext::ScXMLDeletionContext( ScXMLImport& rImport,
             switch (nToken)
             {
             case XML_ELEMENT( TABLE, XML_ID ):
-                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_ACCEPTANCE_STATE ):
                 if (IsXMLToken( aIter, XML_ACCEPTED ))
@@ -1213,7 +1198,7 @@ ScXMLDeletionContext::ScXMLDeletionContext( ScXMLImport& rImport,
                     nActionState = SC_CAS_REJECTED;
                 break;
             case XML_ELEMENT( TABLE, XML_REJECTING_CHANGE_ID ):
-                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_TYPE ):
                 if (IsXMLToken( aIter, XML_ROW ))
@@ -1290,7 +1275,7 @@ ScXMLMovementContext::ScXMLMovementContext( ScXMLImport& rImport,
             switch (aIter.getToken())
             {
             case XML_ELEMENT( TABLE, XML_ID ):
-                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_ACCEPTANCE_STATE ):
                 if (IsXMLToken( aIter, XML_ACCEPTED ))
@@ -1299,7 +1284,7 @@ ScXMLMovementContext::ScXMLMovementContext( ScXMLImport& rImport,
                     nActionState = SC_CAS_REJECTED;
                 break;
             case XML_ELEMENT( TABLE, XML_REJECTING_CHANGE_ID ):
-                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             }
         }
@@ -1363,7 +1348,7 @@ ScXMLRejectionContext::ScXMLRejectionContext( ScXMLImport& rImport,
             switch (aIter.getToken())
             {
             case XML_ELEMENT( TABLE, XML_ID ):
-                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nActionNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             case XML_ELEMENT( TABLE, XML_ACCEPTANCE_STATE ):
                 if (IsXMLToken( aIter, XML_ACCEPTED ))
@@ -1372,7 +1357,7 @@ ScXMLRejectionContext::ScXMLRejectionContext( ScXMLImport& rImport,
                     nActionState = SC_CAS_REJECTED;
                 break;
             case XML_ELEMENT( TABLE, XML_REJECTING_CHANGE_ID ):
-                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toString() );
+                nRejectingNumber = ScXMLChangeTrackingImportHelper::GetIDFromString( aIter.toView() );
                 break;
             }
         }
