@@ -18,9 +18,9 @@
 
 ScFTestDialog::ScFTestDialog(
                     SfxBindings* pSfxBindings, SfxChildWindow* pChildWindow,
-                    weld::Window* pParent, ScViewData* pViewData ) :
+                    weld::Window* pParent, ScViewData& rViewData ) :
     ScStatisticsTwoVariableDialog(
-            pSfxBindings, pChildWindow, pParent, pViewData,
+            pSfxBindings, pChildWindow, pParent, rViewData,
             "modules/scalc/ui/ttestdialog.ui", "TTestDialog" )
 {
     m_xDialog->set_title(ScResId(STR_FTEST));
@@ -41,7 +41,7 @@ const char* ScFTestDialog::GetUndoNameId()
 
 ScRange ScFTestDialog::ApplyOutput(ScDocShell* pDocShell)
 {
-    AddressWalkerWriter aOutput(mOutputAddress, pDocShell, &mDocument,
+    AddressWalkerWriter aOutput(mOutputAddress, pDocShell, mDocument,
             formula::FormulaGrammar::mergeToGrammar(formula::FormulaGrammar::GRAM_ENGLISH, mAddressDetails.eConv));
     FormulaTemplate aTemplate(&mDocument);
 
