@@ -23,6 +23,7 @@
 #include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/embed/XTransactedObject.hpp>
 
+#include <o3tl/unit_conversion.hxx>
 #include <osl/diagnose.h>
 #include <unotools/tempfile.hxx>
 #include <unotools/ucbstreamhelper.hxx>
@@ -208,6 +209,7 @@ ScTransferObj* ScTransferObj::GetOwnClipboard(const uno::Reference<datatransfer:
 
 void ScTransferObj::AddSupportedFormats()
 {
+    //  same formats as in ScSelectionTransferObj::AddSupportedFormats
     AddFormat( SotClipboardFormatId::EMBED_SOURCE );
     AddFormat( SotClipboardFormatId::OBJECTDESCRIPTOR );
     AddFormat( SotClipboardFormatId::GDIMETAFILE );
@@ -441,7 +443,7 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
     return bOK;
 }
 
-bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId,
+bool ScTransferObj::WriteObject( tools::SvRef<SotTempStream>& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId,
                                         const datatransfer::DataFlavor& rFlavor )
 {
     // called from SetObject, put data into stream
@@ -529,7 +531,6 @@ bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* p
 
                 xWorkStore->dispose();
                 xWorkStore.clear();
-                rxOStm->Commit();
             }
             break;
 
@@ -769,8 +770,8 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
     for (nCol=0; nCol<nStartX; nCol++)
         nPosX += rDestDoc.GetColWidth( nCol, 0 );
     nPosY += rDestDoc.GetRowHeight( 0, nStartY-1, 0 );
-    nPosX = static_cast<tools::Long>( nPosX * HMM_PER_TWIPS );
-    nPosY = static_cast<tools::Long>( nPosY * HMM_PER_TWIPS );
+    nPosX = o3tl::convert(nPosX, o3tl::Length::twip, o3tl::Length::mm100);
+    nPosY = o3tl::convert(nPosY, o3tl::Length::twip, o3tl::Length::mm100);
 
     aPaperSize.setWidth( aPaperSize.Width() * 2 );       // limit OLE object to double of page size
     aPaperSize.setHeight( aPaperSize.Height() * 2 );
@@ -791,8 +792,8 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
             break;
         nSizeY += nAdd;
     }
-    nSizeX = static_cast<tools::Long>( nSizeX * HMM_PER_TWIPS );
-    nSizeY = static_cast<tools::Long>( nSizeY * HMM_PER_TWIPS );
+    nSizeX = o3tl::convert(nSizeX, o3tl::Length::twip, o3tl::Length::mm100);
+    nSizeY = o3tl::convert(nSizeY, o3tl::Length::twip, o3tl::Length::mm100);
 
 //      pDocSh->SetVisAreaSize( Size(nSizeX,nSizeY) );
 
@@ -905,14 +906,10 @@ void ScTransferObj::StripRefs( ScDocument& rDoc,
     }
 }
 
-namespace
-{
-    class theScTransferUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theScTransferUnoTunnelId> {};
-}
-
 const css::uno::Sequence< sal_Int8 >& ScTransferObj::getUnoTunnelId()
 {
-    return theScTransferUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theScTransferUnoTunnelId;
+    return theScTransferUnoTunnelId.getSeq();
 }
 
 sal_Int64 SAL_CALL ScTransferObj::getSomething( const css::uno::Sequence< sal_Int8 >& rId )
