@@ -38,6 +38,7 @@
 #include <vcl/settings.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/virdev.hxx>
+#include <vcl/weldutils.hxx>
 
 #include <editeng/colritem.hxx>
 #include <editeng/fhgtitem.hxx>
@@ -76,7 +77,7 @@ ScCsvGrid::ScCsvGrid(const ScCsvLayoutData& rData, std::unique_ptr<weld::Menu> x
     , mpGridDev( VclPtr<VirtualDevice>::Create() )
     , mxPopup(std::move(xPopup))
     , mpColorConfig( nullptr )
-    , mpEditEngine( new ScEditEngineDefaulter( EditEngine::CreatePool(), true ) )
+    , mpEditEngine( new ScEditEngineDefaulter( EditEngine::CreatePool().get(), true ) )
     , maColStates( 1 )
     , maTypeNames( 1 )
     , mnFirstImpLine( 0 )
@@ -96,11 +97,8 @@ void ScCsvGrid::SetDrawingArea(weld::DrawingArea* pDrawingArea)
     maHeaderFont = Application::GetSettings().GetStyleSettings().GetAppFont();
 
     // expand the point size of the desired font to the equivalent pixel size
-    if (vcl::Window* pDefaultDevice = dynamic_cast<vcl::Window*>(Application::GetDefaultDevice()))
-    {
-        pDefaultDevice->SetPointFont(rRefDevice, maHeaderFont);
-        maHeaderFont = rRefDevice.GetFont();
-    }
+    weld::SetPointFont(rRefDevice, maHeaderFont);
+    maHeaderFont = rRefDevice.GetFont();
 
     // Because this is an always LeftToRight layout widget the initial size of
     // this widget needs to be smaller than the size of the parent scrolling
@@ -349,29 +347,29 @@ void ScCsvGrid::RemoveSplit( sal_Int32 nPos )
 void ScCsvGrid::MoveSplit( sal_Int32 nPos, sal_Int32 nNewPos )
 {
     sal_uInt32 nColIx = GetColumnFromPos( nPos );
-    if( nColIx != CSV_COLUMN_INVALID )
+    if( nColIx == CSV_COLUMN_INVALID )
+        return;
+
+    DisableRepaint();
+    if( (GetColumnPos( nColIx - 1 ) < nNewPos) && (nNewPos < GetColumnPos( nColIx + 1 )) )
     {
-        DisableRepaint();
-        if( (GetColumnPos( nColIx - 1 ) < nNewPos) && (nNewPos < GetColumnPos( nColIx + 1 )) )
-        {
-            // move a split in the range between 2 others -> keep selection state of both columns
-            maSplits.Remove( nPos );
-            maSplits.Insert( nNewPos );
-            Execute( CSVCMD_UPDATECELLTEXTS );
-            ImplDrawColumn( nColIx - 1 );
-            ImplDrawColumn( nColIx );
-            ValidateGfx();  // performance: do not redraw all columns
-            AccSendTableUpdateEvent( nColIx - 1, nColIx );
-        }
-        else
-        {
-            ImplRemoveSplit( nPos );
-            ImplInsertSplit( nNewPos );
-            Execute( CSVCMD_EXPORTCOLUMNTYPE );
-            Execute( CSVCMD_UPDATECELLTEXTS );
-        }
-        EnableRepaint();
+        // move a split in the range between 2 others -> keep selection state of both columns
+        maSplits.Remove( nPos );
+        maSplits.Insert( nNewPos );
+        Execute( CSVCMD_UPDATECELLTEXTS );
+        ImplDrawColumn( nColIx - 1 );
+        ImplDrawColumn( nColIx );
+        ValidateGfx();  // performance: do not redraw all columns
+        AccSendTableUpdateEvent( nColIx - 1, nColIx );
     }
+    else
+    {
+        ImplRemoveSplit( nPos );
+        ImplInsertSplit( nNewPos );
+        Execute( CSVCMD_EXPORTCOLUMNTYPE );
+        Execute( CSVCMD_UPDATECELLTEXTS );
+    }
+    EnableRepaint();
 }
 
 void ScCsvGrid::RemoveAllSplits()
@@ -712,28 +710,28 @@ void ScCsvGrid::MoveCursor( sal_uInt32 nColIndex )
 
 void ScCsvGrid::MoveCursorRel( ScMoveMode eDir )
 {
-    if( GetFocusColumn() != CSV_COLUMN_INVALID )
+    if( GetFocusColumn() == CSV_COLUMN_INVALID )
+        return;
+
+    switch( eDir )
     {
-        switch( eDir )
+        case MOVE_FIRST:
+            MoveCursor( 0 );
+        break;
+        case MOVE_LAST:
+            MoveCursor( GetColumnCount() - 1 );
+        break;
+        case MOVE_PREV:
+            if( GetFocusColumn() > 0 )
+                MoveCursor( GetFocusColumn() - 1 );
+        break;
+        case MOVE_NEXT:
+            if( GetFocusColumn() < GetColumnCount() - 1 )
+                MoveCursor( GetFocusColumn() + 1 );
+        break;
+        default:
         {
-            case MOVE_FIRST:
-                MoveCursor( 0 );
-            break;
-            case MOVE_LAST:
-                MoveCursor( GetColumnCount() - 1 );
-            break;
-            case MOVE_PREV:
-                if( GetFocusColumn() > 0 )
-                    MoveCursor( GetFocusColumn() - 1 );
-            break;
-            case MOVE_NEXT:
-                if( GetFocusColumn() < GetColumnCount() - 1 )
-                    MoveCursor( GetFocusColumn() + 1 );
-            break;
-            default:
-            {
-                // added to avoid warnings
-            }
+            // added to avoid warnings
         }
     }
 }
@@ -789,7 +787,7 @@ void ScCsvGrid::ImplSetTextLineSep(
         /* TODO: signal overflow somewhere in UI */
 
         // update column width
-        sal_Int32 nWidth = std::max( CSV_MINCOLWIDTH, aCellText.getLength() + 1 );
+        sal_Int32 nWidth = std::max( CSV_MINCOLWIDTH, ScImportExport::CountVisualWidth( aCellText ) + 1 );
         if( IsValidColumn( nColIx ) )
         {
             // expand existing column
@@ -826,9 +824,9 @@ void ScCsvGrid::ImplSetTextLineFix( sal_Int32 nLine, const OUString& rTextLine )
 {
     if( nLine < GetFirstVisLine() ) return;
 
-    sal_Int32 nChars = rTextLine.getLength();
-    if( nChars > GetPosCount() )
-        Execute( CSVCMD_SETPOSCOUNT, nChars );
+    sal_Int32 nWidth = ScImportExport::CountVisualWidth( rTextLine );
+    if( nWidth > GetPosCount() )
+        Execute( CSVCMD_SETPOSCOUNT, nWidth );
 
     sal_uInt32 nLineIx = nLine - GetFirstVisLine();
     while( maTexts.size() <= nLineIx )
@@ -842,9 +840,11 @@ void ScCsvGrid::ImplSetTextLineFix( sal_Int32 nLine, const OUString& rTextLine )
     for( sal_uInt32 nColIx = 0; (nColIx < nColCount) && (nStrIx < nStrLen); ++nColIx )
     {
         sal_Int32 nColWidth = GetColumnWidth( nColIx );
-        sal_Int32 nLen = std::min( std::min( nColWidth, CSV_MAXSTRLEN ), nStrLen - nStrIx);
+        sal_Int32 nLastIx = nStrIx;
+        ScImportExport::CountVisualWidth( rTextLine, nLastIx, nColWidth );
+        sal_Int32 nLen = std::min( CSV_MAXSTRLEN, nLastIx - nStrIx );
         rStrVec.push_back( rTextLine.copy( nStrIx, nLen ) );
-        nStrIx = nStrIx + nColWidth;
+        nStrIx = nStrIx + nLen;
     }
     InvalidateGfx();
 }
@@ -929,7 +929,7 @@ bool ScCsvGrid::MouseMove( const MouseEvent& rMEvt )
 
     sal_Int32 nPos = (rMEvt.GetPosPixel().X() - GetFirstX()) / GetCharWidth() + GetFirstVisPos();
     // on mouse tracking: keep position valid
-    nPos = std::max( std::min( nPos, GetPosCount() - sal_Int32( 1 ) ), sal_Int32( 0 ) );
+    nPos = std::clamp( nPos, sal_Int32(0), GetPosCount() - 1 );
     Execute( CSVCMD_MAKEPOSVISIBLE, nPos );
 
     sal_uInt32 nColIx = GetColumnFromPos( nPos );
@@ -1130,7 +1130,7 @@ void ScCsvGrid::ImplDrawCellText( const Point& rPos, const OUString& rText )
         {
             sal_Int32 nX = rPos.X() + GetCharWidth() * nBeginIx;
             mpEditEngine->SetTextCurrentDefaults( aToken );
-            mpEditEngine->Draw( mpBackgrDev.get(), Point( nX, rPos.Y() ) );
+            mpEditEngine->Draw(*mpBackgrDev, Point(nX, rPos.Y()));
         }
     }
 
@@ -1410,8 +1410,8 @@ tools::Rectangle ScCsvGrid::GetFocusRect()
 css::uno::Reference<css::accessibility::XAccessible> ScCsvGrid::CreateAccessible()
 {
     rtl::Reference<ScAccessibleCsvGrid> xRef(new ScAccessibleCsvGrid(*this));
-    mxAccessible.set(xRef.get());
-    return css::uno::Reference<css::accessibility::XAccessible>(xRef.get());
+    mxAccessible = xRef;
+    return xRef;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
