@@ -36,8 +36,9 @@
 #include <com/sun/star/uno/Sequence.hxx>
 #include <miscuno.hxx>
 #include <osl/diagnose.h>
+#include <vcl/svapp.hxx>
+#include <comphelper/lok.hxx>
 
-#include <unicode/uclean.h>
 #include <unicode/ucsdet.h>
 
 //! TODO make dynamic
@@ -326,8 +327,11 @@ ScImportAsciiDlg::ScImportAsciiDlg(weld::Window* pParent, const OUString& aDatNa
             m_xDialog->set_title(mxAltTitle->get_label());
             break;
         case SC_IMPORTFILE:
-            aName += " - [" + aDatName + "]";
-            m_xDialog->set_title(aName);
+            if (!comphelper::LibreOfficeKit::isActive())
+            {
+                aName += " - [" + aDatName + "]";
+                m_xDialog->set_title(aName);
+            }
             break;
         default:
             break;
@@ -431,19 +435,21 @@ ScImportAsciiDlg::ScImportAsciiDlg(weld::Window* pParent, const OUString& aDatNa
     // *** Separator characters ***
     lcl_FillCombo( *mxCbTextSep, gaTextSepList, mcTextSep );
     mxCbTextSep->set_entry_text(sTextSeparators);
+    // tdf#69207 - use selected text delimiter to parse the provided data
+    mcTextSep = lcl_CharFromCombo(*mxCbTextSep, gaTextSepList);
 
-    Link<weld::Button&,void> aSeparatorClickHdl =LINK( this, ScImportAsciiDlg, SeparatorClickHdl );
+    Link<weld::Toggleable&,void> aSeparatorClickHdl =LINK( this, ScImportAsciiDlg, SeparatorClickHdl );
     mxCbTextSep->connect_changed( LINK( this, ScImportAsciiDlg, SeparatorComboBoxHdl ) );
-    mxCkbTab->connect_clicked( aSeparatorClickHdl );
-    mxCkbSemicolon->connect_clicked( aSeparatorClickHdl );
-    mxCkbComma->connect_clicked( aSeparatorClickHdl );
-    mxCkbAsOnce->connect_clicked( aSeparatorClickHdl );
-    mxCkbQuotedAsText->connect_clicked( aSeparatorClickHdl );
-    mxCkbDetectNumber->connect_clicked( aSeparatorClickHdl );
-    mxCkbSkipEmptyCells->connect_clicked( aSeparatorClickHdl );
-    mxCkbSpace->connect_clicked( aSeparatorClickHdl );
-    mxCkbRemoveSpace->connect_clicked( aSeparatorClickHdl );
-    mxCkbOther->connect_clicked( aSeparatorClickHdl );
+    mxCkbTab->connect_toggled( aSeparatorClickHdl );
+    mxCkbSemicolon->connect_toggled( aSeparatorClickHdl );
+    mxCkbComma->connect_toggled( aSeparatorClickHdl );
+    mxCkbAsOnce->connect_toggled( aSeparatorClickHdl );
+    mxCkbQuotedAsText->connect_toggled( aSeparatorClickHdl );
+    mxCkbDetectNumber->connect_toggled( aSeparatorClickHdl );
+    mxCkbSkipEmptyCells->connect_toggled( aSeparatorClickHdl );
+    mxCkbSpace->connect_toggled( aSeparatorClickHdl );
+    mxCkbRemoveSpace->connect_toggled( aSeparatorClickHdl );
+    mxCkbOther->connect_toggled( aSeparatorClickHdl );
     mxEdOther->connect_changed(LINK(this, ScImportAsciiDlg, SeparatorEditHdl));
 
     // *** text encoding ListBox ***
@@ -494,11 +500,11 @@ ScImportAsciiDlg::ScImportAsciiDlg(weld::Window* pParent, const OUString& aDatNa
     mxTableBox->InitTypes( *mxLbType );
     mxTableBox->SetColTypeHdl( LINK( this, ScImportAsciiDlg, ColTypeHdl ) );
 
-    mxRbSeparated->connect_clicked( LINK( this, ScImportAsciiDlg, RbSepFixHdl ) );
-    mxRbFixed->connect_clicked( LINK( this, ScImportAsciiDlg, RbSepFixHdl ) );
+    mxRbSeparated->connect_toggled( LINK( this, ScImportAsciiDlg, RbSepFixHdl ) );
+    mxRbFixed->connect_toggled( LINK( this, ScImportAsciiDlg, RbSepFixHdl ) );
 
     SetupSeparatorCtrls();
-    RbSepFixHdl(*mxRbFixed);
+    RbSepFix();
 
     UpdateVertical();
 
@@ -528,6 +534,12 @@ ScImportAsciiDlg::ScImportAsciiDlg(weld::Window* pParent, const OUString& aDatNa
         mxCkbSkipEmptyCells->set_active(false);
         mxCkbSkipEmptyCells->hide();
     }
+    m_xDialog->SetInstallLOKNotifierHdl(LINK(this, ScImportAsciiDlg, InstallLOKNotifierHdl));
+}
+
+IMPL_STATIC_LINK_NOARG(ScImportAsciiDlg, InstallLOKNotifierHdl, void*, vcl::ILibreOfficeKitNotifier*)
+{
+    return GetpApp();
 }
 
 ScImportAsciiDlg::~ScImportAsciiDlg()
@@ -632,13 +644,9 @@ void ScImportAsciiDlg::SaveParameters()
 
 void ScImportAsciiDlg::SetSeparators()
 {
-    OString sString(OUStringToOString(maFieldSeparators,
-        RTL_TEXTENCODING_MS_1252));
-    const char *aSep = sString.getStr();
-    sal_Int32 len = maFieldSeparators.getLength();
-    for (int i = 0; i < len; ++i)
+    for (sal_Int32 i = 0; i < maFieldSeparators.getLength(); ++i)
     {
-        switch( aSep[i] )
+        switch (maFieldSeparators[i])
         {
             case '\t':  mxCkbTab->set_active(true);        break;
             case ';':   mxCkbSemicolon->set_active(true);  break;
@@ -646,7 +654,7 @@ void ScImportAsciiDlg::SetSeparators()
             case ' ':   mxCkbSpace->set_active(true);      break;
             default:
                 mxCkbOther->set_active(true);
-                mxEdOther->set_text(mxEdOther->get_text() + OUStringChar(aSep[i]));
+                mxEdOther->set_text(mxEdOther->get_text() + OUStringChar(maFieldSeparators[i]));
         }
     }
 }
@@ -697,20 +705,24 @@ void ScImportAsciiDlg::UpdateVertical()
         mpDatStream->SetStreamCharSet(meCharSet);
 }
 
-IMPL_LINK(ScImportAsciiDlg, RbSepFixHdl, weld::Button&, rButton, void)
+void ScImportAsciiDlg::RbSepFix()
 {
-    if (&rButton == mxRbFixed.get() || &rButton == mxRbSeparated.get())
-    {
-        weld::WaitObject aWaitObj(m_xDialog.get());
-        if( mxRbFixed->get_active() )
-            mxTableBox->SetFixedWidthMode();
-        else
-            mxTableBox->SetSeparatorsMode();
-        SetupSeparatorCtrls();
-    }
+    weld::WaitObject aWaitObj(m_xDialog.get());
+    if( mxRbFixed->get_active() )
+        mxTableBox->SetFixedWidthMode();
+    else
+        mxTableBox->SetSeparatorsMode();
+    SetupSeparatorCtrls();
 }
 
-IMPL_LINK(ScImportAsciiDlg, SeparatorClickHdl, weld::Button&, rCtrl, void)
+IMPL_LINK(ScImportAsciiDlg, RbSepFixHdl, weld::Toggleable&, rButton, void)
+{
+    if (!rButton.get_active())
+        return;
+    RbSepFix();
+}
+
+IMPL_LINK(ScImportAsciiDlg, SeparatorClickHdl, weld::Toggleable&, rCtrl, void)
 {
     SeparatorHdl(&rCtrl);
 }
