@@ -25,6 +25,7 @@
 #include <editeng/flstitem.hxx>
 #include <editeng/paperinf.hxx>
 #include <editeng/sizeitem.hxx>
+#include <o3tl/unit_conversion.hxx>
 #include <officecfg/Office/Common.hxx>
 #include <sal/log.hxx>
 #include <sfx2/viewfrm.hxx>
@@ -38,6 +39,7 @@
 #include <vcl/svapp.hxx>
 #include <vcl/virdev.hxx>
 #include <vcl/weld.hxx>
+#include <osl/diagnose.h>
 
 #include <docsh.hxx>
 #include "docshimp.hxx"
@@ -69,7 +71,6 @@
 #include <formulaopt.hxx>
 
 #include <comphelper/lok.hxx>
-#include <LibreOfficeKit/LibreOfficeKitEnums.h>
 #include <sfx2/lokhelper.hxx>
 
 //          Redraw - Notifications
@@ -368,7 +369,6 @@ void ScDocShell::CalcOutputFactor()
     OUString aTestString(
             "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz01234567890123456789");
     tools::Long nPrinterWidth = 0;
-    tools::Long nWindowWidth = 0;
     const ScPatternAttr* pPattern = &m_aDocument.GetPool()->GetDefaultItem(ATTR_PATTERN);
 
     vcl::Font aDefFont;
@@ -387,11 +387,11 @@ void ScDocShell::CalcOutputFactor()
     pVirtWindow->SetMapMode(MapMode(MapUnit::MapPixel));
     pPattern->GetFont(aDefFont, SC_AUTOCOL_BLACK, pVirtWindow);    // font color doesn't matter here
     pVirtWindow->SetFont(aDefFont);
-    nWindowWidth = pVirtWindow->GetTextWidth(aTestString);
-    nWindowWidth = static_cast<tools::Long>( nWindowWidth / ScGlobal::nScreenPPTX * HMM_PER_TWIPS );
+    double nWindowWidth = pVirtWindow->GetTextWidth(aTestString) / ScGlobal::nScreenPPTX;
+    nWindowWidth = o3tl::convert(nWindowWidth, o3tl::Length::twip, o3tl::Length::mm100);
 
     if (nPrinterWidth && nWindowWidth)
-        m_nPrtToScreenFactor = nPrinterWidth / static_cast<double>(nWindowWidth);
+        m_nPrtToScreenFactor = nPrinterWidth / nWindowWidth;
     else
     {
         OSL_FAIL("GetTextSize returns 0 ??");
@@ -1124,7 +1124,7 @@ void ScDocShell::MergeDocument( ScDocument& rOtherDoc, bool bShared, bool bCheck
         pSourceAction = pSourceAction->GetNext();
     }
 
-    rMarkData = aOldMarkData;
+    rMarkData = std::move(aOldMarkData);
     pThisTrack->SetUser(aOldUser);
     pThisTrack->SetUseFixDateTime( false );
 
@@ -1178,14 +1178,14 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             // merge own changes into shared document
             sal_uLong nActStartShared = pSharedAction->GetActionNumber();
             sal_uLong nActEndShared = pSharedTrack->GetActionMax();
-            std::unique_ptr<ScDocument> pTmpDoc(new ScDocument);
+            std::optional<ScDocument> pTmpDoc(std::in_place);
             for ( sal_Int32 nIndex = 0; nIndex < m_aDocument.GetTableCount(); ++nIndex )
             {
                 OUString sTabName;
                 pTmpDoc->CreateValidTabName( sTabName );
                 pTmpDoc->InsertTab( SC_TAB_APPEND, sTabName );
             }
-            m_aDocument.GetChangeTrack()->Clone( pTmpDoc.get() );
+            m_aDocument.GetChangeTrack()->Clone( &*pTmpDoc );
             ScChangeActionMergeMap aOwnInverseMergeMap;
             pSharedDocShell->MergeDocument( *pTmpDoc, true, true, 0, &aOwnInverseMergeMap, true );
             pTmpDoc.reset();
@@ -1226,14 +1226,14 @@ bool ScDocShell::MergeSharedDocument( ScDocShell* pSharedDocShell )
             pSharedTrack->Undo( nActStartOwn, nActEndOwn );
 
             // clone change track for merging into own document
-            pTmpDoc.reset(new ScDocument);
+            pTmpDoc.emplace();
             for ( sal_Int32 nIndex = 0; nIndex < m_aDocument.GetTableCount(); ++nIndex )
             {
                 OUString sTabName;
                 pTmpDoc->CreateValidTabName( sTabName );
                 pTmpDoc->InsertTab( SC_TAB_APPEND, sTabName );
             }
-            pThisTrack->Clone( pTmpDoc.get() );
+            pThisTrack->Clone( &*pTmpDoc );
 
             // undo own changes since last save in own document
             sal_uLong nStartShared = pThisAction->GetActionNumber();
