@@ -19,6 +19,7 @@
 
 #include <comphelper/processfactory.hxx>
 #include <i18nlangtag/languagetag.hxx>
+#include <i18nutil/unicode.hxx>
 #include <sot/formats.hxx>
 #include <sfx2/mieclip.hxx>
 #include <com/sun/star/i18n/CalendarFieldIndex.hpp>
@@ -62,6 +63,8 @@
 #include <editeng/editobj.hxx>
 
 #include <memory>
+#include <string_view>
+
 #include <osl/endian.h>
 
 // We don't want to end up with 2GB read in one line just because of malformed
@@ -235,8 +238,7 @@ bool ScImportExport::StartPaste()
         ScEditableTester aTester( rDoc, aRange );
         if ( !aTester.IsEditable() )
         {
-            vcl::Window* pWin = Application::GetDefDialogParent();
-            std::unique_ptr<weld::MessageDialog> xInfoBox(Application::CreateMessageDialog(pWin ? pWin->GetFrameWeld() : nullptr,
+            std::unique_ptr<weld::MessageDialog> xInfoBox(Application::CreateMessageDialog(ScDocShell::GetActiveDialogParent(),
                                                           VclMessageType::Info, VclButtonsType::Ok,
                                                           ScResId(aTester.GetMessageId())));
             xInfoBox->run();
@@ -539,6 +541,36 @@ void ScImportExport::WriteUnicodeOrByteEndl( SvStream& rStrm )
         endl( rStrm );
 }
 
+sal_Int32 ScImportExport::CountVisualWidth(const OUString& rStr, sal_Int32& nIdx, sal_Int32 nMaxWidth)
+{
+    sal_Int32 nWidth = 0;
+    while(nIdx < rStr.getLength() && nWidth < nMaxWidth)
+    {
+        sal_uInt32 nCode = rStr.iterateCodePoints(&nIdx);
+
+        if (unicode::isCJKIVSCharacter(nCode) || (nCode >= 0x3000 && nCode <= 0x303F))
+            nWidth += 2;
+        else if (!unicode::isIVSSelector(nCode))
+            nWidth += 1;
+    }
+
+    if (nIdx < rStr.getLength())
+    {
+        sal_Int32 nTmpIdx = nIdx;
+        sal_uInt32 nCode = rStr.iterateCodePoints(&nTmpIdx);
+
+        if (unicode::isIVSSelector(nCode))
+            nIdx = nTmpIdx;
+    }
+    return nWidth;
+}
+
+sal_Int32 ScImportExport::CountVisualWidth(const OUString& rStr)
+{
+    sal_Int32 nIdx = 0;
+    return CountVisualWidth(rStr, nIdx, SAL_MAX_INT32);
+}
+
 void ScImportExport::SetNoEndianSwap( SvStream& rStrm )
 {
 #ifdef OSL_BIGENDIAN
@@ -635,13 +667,13 @@ static bool lcl_appendLineData( OUString& rField, const sal_Unicode* p1, const s
 {
     if (rField.getLength() + (p2 - p1) <= nArbitraryCellLengthLimit)
     {
-        rField += OUString( p1, sal::static_int_cast<sal_Int32>( p2 - p1 ) );
+        rField += std::u16string_view( p1, sal::static_int_cast<sal_Int32>( p2 - p1 ) );
         return true;
     }
     else
     {
         SAL_WARN( "sc", "lcl_appendLineData: data overflow");
-        rField += OUString( p1, nArbitraryCellLengthLimit - rField.getLength() );
+        rField += std::u16string_view( p1, nArbitraryCellLengthLimit - rField.getLength() );
         return false;
     }
 }
@@ -762,7 +794,7 @@ static const sal_Unicode* lcl_ScanSylkString( const sal_Unicode* p,
     }
     if (!pEndQuote)
         pEndQuote = p;  // Take all data as string.
-    rString += OUString(pStartQuote + 1, sal::static_int_cast<sal_Int32>( pEndQuote - pStartQuote - 1 ) );
+    rString += std::u16string_view(pStartQuote + 1, sal::static_int_cast<sal_Int32>( pEndQuote - pStartQuote - 1 ) );
     lcl_UnescapeSylk( rString, eVersion);
     return p;
 }
@@ -784,7 +816,7 @@ static const sal_Unicode* lcl_ScanSylkFormula( const sal_Unicode* p,
             }
             ++p;
         }
-        rString += OUString( pStart, sal::static_int_cast<sal_Int32>( p - pStart));
+        rString += std::u16string_view( pStart, sal::static_int_cast<sal_Int32>( p - pStart));
         lcl_UnescapeSylk( rString, eVersion);
     }
     else
@@ -825,7 +857,7 @@ static const sal_Unicode* lcl_ScanSylkFormula( const sal_Unicode* p,
         {
             while (*p && *p != ';')
                 ++p;
-            rString += OUString( pStart, sal::static_int_cast<sal_Int32>( p - pStart));
+            rString += std::u16string_view( pStart, sal::static_int_cast<sal_Int32>( p - pStart));
         }
     }
     return p;
@@ -1117,7 +1149,7 @@ static bool lcl_PutString(
             sal_Int16 nMonth = static_cast<sal_Int16>(aMStr.toInt32());
             if (!nMonth)
             {
-                static const char aSepShortened[] = "SEP";
+                static constexpr OUStringLiteral aSepShortened = u"SEP";
                 uno::Sequence< i18n::CalendarItem2 > xMonths;
                 sal_Int32 i, nMonthCount;
                 //  first test all month names from local international
@@ -1428,6 +1460,7 @@ bool ScImportExport::ExtText2Doc( SvStream& rStrm )
             bool bMultiLine = false;
             if ( bFixed ) //  Fixed line length
             {
+                sal_Int32 nStartIdx = 0;
                 // Yes, the check is nCol<=rDoc.MaxCol()+1, +1 because it is only an
                 // overflow if there is really data following to be put behind
                 // the last column, which doesn't happen if info is
@@ -1441,10 +1474,14 @@ bool ScImportExport::ExtText2Doc( SvStream& rStrm )
                             bOverflowCol = true;    // display warning on import
                         else if (!bDetermineRange)
                         {
-                            sal_Int32 nStart = pColStart[i];
-                            sal_Int32 nNext = ( i+1 < nInfoCount ) ? pColStart[i+1] : nLineLen;
+                            sal_Int32 nNextIdx = nStartIdx;
+                            if ( i + 1 < nInfoCount )
+                                CountVisualWidth( aLine, nNextIdx, pColStart[i+1] - pColStart[i] );
+                            else
+                                nNextIdx = nLineLen;
+
                             bool bIsQuoted = false;
-                            aCell = lcl_GetFixed( aLine, nStart, nNext, bIsQuoted, bOverflowCell );
+                            aCell = lcl_GetFixed( aLine, nStartIdx, nNextIdx, bIsQuoted, bOverflowCell );
                             if (bIsQuoted && bQuotedAsText)
                                 nFmt = SC_COL_TEXT;
 
@@ -1452,6 +1489,8 @@ bool ScImportExport::ExtText2Doc( SvStream& rStrm )
                                 aDocImport, !mbOverwriting, nCol, nRow, nTab, aCell, nFmt,
                                 &aNumFormatter, bDetectNumFormat, bSkipEmptyCells, aTransliteration, aCalendar,
                                 pEnglishTransliteration.get(), pEnglishCalendar.get());
+
+                            nStartIdx = nNextIdx;
                         }
                         ++nCol;
                     }
@@ -1572,7 +1611,7 @@ void ScImportExport::EmbeddedNullTreatment( OUString & rStr )
     sal_Unicode cNull = 0;
     if (rStr.indexOf( cNull) >= 0)
     {
-        rStr = rStr.replaceAll( OUString( &cNull, 1), "");
+        rStr = rStr.replaceAll( std::u16string_view( &cNull, 1), "");
     }
 }
 
@@ -2476,17 +2515,8 @@ Label_RetryWithNewSep:
         while (!rStream.eof() && aStr.getLength() < nArbitraryLineLengthLimit)
         {
             const sal_Unicode * p = aStr.getStr() + nLastOffset;
-            const sal_Unicode * const pStop = aStr.getStr() + aStr.getLength();
-            while (p < pStop)
+            while (*p)
             {
-                if (!*p)
-                {
-                    // Skip embedded null-characters. They don't change
-                    // anything and are handled at a higher level.
-                    ++p;
-                    continue;
-                }
-
                 if (nQuotes)
                 {
                     if (*p == cFieldQuote)
@@ -2507,7 +2537,7 @@ Label_RetryWithNewSep:
                             if (eRetryState == RetryState::ALLOW && rcDetectSep == ' ')
                             {
                                 eRetryState = RetryState::RETRY;
-                                rFieldSeparators += OUString(' ');
+                                rFieldSeparators += " ";
                                 goto Label_RetryWithNewSep;
                             }
 
