@@ -46,13 +46,11 @@
 #include <comphelper/lok.hxx>
 #include <comphelper/storagehelper.hxx>
 #include <comphelper/propertysequence.hxx>
-#include <sfx2/lokhelper.hxx>
 #include <com/sun/star/embed/EmbedVerbs.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/chart2/data/XDataReceiver.hpp>
 #include <com/sun/star/chart2/XChartDocument.hpp>
-#include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
-#include <com/sun/star/ui/dialogs/ExecutableDialogResults.hpp>
+#include <com/sun/star/ui/dialogs/XAsynchronousExecutableDialog.hpp>
 #include <com/sun/star/ui/dialogs/XDialogClosedListener.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
 #include <com/sun/star/frame/XModel.hpp>
@@ -131,9 +129,9 @@ void lcl_ChartInit(const uno::Reference <embed::XEmbeddedObject>& xObj, ScViewDa
     uno::Reference<chart2::data::XDataProvider> xDataProvider;
     if (bRangeIsPivotTable)
     {
-        std::unique_ptr<sc::PivotTableDataProvider> pPivotTableDataProvider(new sc::PivotTableDataProvider(rScDoc));
+        rtl::Reference<sc::PivotTableDataProvider> pPivotTableDataProvider(new sc::PivotTableDataProvider(rScDoc));
         pPivotTableDataProvider->setPivotTableName(aRangeString);
-        xDataProvider.set(pPivotTableDataProvider.release());
+        xDataProvider = pPivotTableDataProvider;
     }
     else
     {
@@ -326,11 +324,11 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawView*
                     xObj->setVisualAreaSize( nAspect, aSz );
 
                     //  re-convert aSize to 1/100th mm to avoid rounding errors in comparison below
-                    aSize = vcl::Window::LogicToLogic( aTmp,
+                    aSize = OutputDevice::LogicToLogic( aTmp,
                                     MapMode( aMapUnit ), aMap100 );
                 }
                 else
-                    aSize = vcl::Window::LogicToLogic( aSize,
+                    aSize = OutputDevice::LogicToLogic( aSize,
                                     MapMode( aMapUnit ), aMap100 );
             }
 
@@ -508,7 +506,7 @@ FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawV
     }
     if (bSizeCh)
     {
-        aSize = vcl::Window::LogicToLogic( aSize, MapMode( MapUnit::Map100thMM ), MapMode( aMapUnit ) );
+        aSize = OutputDevice::LogicToLogic( aSize, MapMode( MapUnit::Map100thMM ), MapMode( aMapUnit ) );
         aSz.Width = aSize.Width();
         aSz.Height = aSize.Height();
         xObj->setVisualAreaSize( nAspect, aSz );
@@ -672,11 +670,10 @@ FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawV
                     }
 
                     pView->AddUndo(std::make_unique<SdrUndoNewObj>(*pObj));
-                    ::svt::DialogClosedListener* pListener = new ::svt::DialogClosedListener();
+                    rtl::Reference<::svt::DialogClosedListener> pListener = new ::svt::DialogClosedListener();
                     pListener->SetDialogClosedLink( rLink );
-                    css::uno::Reference<css::ui::dialogs::XDialogClosedListener> xListener( pListener );
 
-                    xDialog->startExecuteModal( xListener );
+                    xDialog->startExecuteModal( pListener );
                 }
                 else
                 {
