@@ -297,8 +297,8 @@ void ScFormulaDlg::Close()
 
 bool ScFormulaDlg::calculateValue( const OUString& rStrExp, OUString& rStrResult, bool bMatrixFormula )
 {
-    std::unique_ptr<ScSimpleFormulaCalculator> pFCell( new ScSimpleFormulaCalculator(
-                *m_pDoc, m_CursorPos, rStrExp, bMatrixFormula));
+    std::optional<ScSimpleFormulaCalculator> pFCell(std::in_place,
+                *m_pDoc, m_CursorPos, rStrExp, bMatrixFormula);
     pFCell->SetLimitString(true);
 
     // HACK! to avoid neither #REF! from ColRowNames
@@ -312,8 +312,7 @@ bool ScFormulaDlg::calculateValue( const OUString& rStrExp, OUString& rStrResult
         {   // ==1: area
             // ==0: would be an area if...
             OUString aBraced = "(" + rStrExp + ")";
-            pFCell.reset( new ScSimpleFormulaCalculator(
-                        *m_pDoc, m_CursorPos, aBraced, bMatrixFormula));
+            pFCell.emplace(*m_pDoc, m_CursorPos, aBraced, bMatrixFormula);
             pFCell->SetLimitString(true);
         }
         else
