@@ -278,6 +278,13 @@ void ScAcceptChgDlg::ClearView()
     nAcceptCount=0;
     nRejectCount=0;
     weld::TreeView& rTreeView = pTheView->GetWidget();
+    rTreeView.all_foreach(
+        [&rTreeView](weld::TreeIter& rEntry)
+        {
+            ScRedlinData *pEntryData = reinterpret_cast<ScRedlinData*>(rTreeView.get_id(rEntry).toInt64());
+            delete pEntryData;
+            return false;
+        });
     rTreeView.freeze();
     rTreeView.clear();
     rTreeView.thaw();
@@ -1427,7 +1434,10 @@ void ScAcceptChgDlg::RemoveEntries(sal_uLong nStartAction,sal_uLong nEndAction)
         {
             nAction = pEntryData->nActionNo;
             if (nStartAction <= nAction && nAction <= nEndAction)
+            {
                 aIdsToRemove.push_back(sId);
+                delete pEntryData;
+            }
         }
     }
     while (rTreeView.iter_next(*xEntry));
@@ -1471,6 +1481,7 @@ void ScAcceptChgDlg::UpdateEntries(const ScChangeTrack* pChgTrack, sal_uLong nSt
         if (bRemove)
         {
             rTreeView.remove(*xEntry);
+            delete pEntryData;
 
             if (!bLastEntry)
                 bLastEntry = rTreeView.get_iter_first(*xLastEntry);
