@@ -78,7 +78,7 @@ ScSolverNoSolutionDialog::~ScSolverNoSolutionDialog()
 {
 }
 
-ScSolverSuccessDialog::ScSolverSuccessDialog(weld::Window* pParent, const OUString& rSolution)
+ScSolverSuccessDialog::ScSolverSuccessDialog(weld::Window* pParent, std::u16string_view rSolution)
     : GenericDialogController(pParent, "modules/scalc/ui/solversuccessdialog.ui", "SolverSuccessDialog")
     , m_xFtResult(m_xBuilder->weld_label("result"))
     , m_xBtnOk(m_xBuilder->weld_button("ok"))
@@ -200,7 +200,7 @@ ScOptSolverDlg::ScOptSolverDlg(SfxBindings* pB, SfxChildWindow* pCW, weld::Windo
     , m_xBtnDel4(m_xBuilder->weld_button("del4"))
     , m_xScrollBar(m_xBuilder->weld_scrolled_window("scrollbar", true))
     , m_xBtnOpt(m_xBuilder->weld_button("options"))
-    , m_xBtnCancel(m_xBuilder->weld_button("close"))
+    , m_xBtnClose(m_xBuilder->weld_button("close"))
     , m_xBtnSolve(m_xBuilder->weld_button("ok"))
     , m_xBtnResetAll(m_xBuilder->weld_button("resetall"))
     , m_xResultFT(m_xBuilder->weld_label("result"))
@@ -272,7 +272,7 @@ void ScOptSolverDlg::Init(const ScAddress& rCursorPos)
         pButton->set_image(xDelNm);
 
     m_xBtnOpt->connect_clicked( LINK( this, ScOptSolverDlg, BtnHdl ) );
-    m_xBtnCancel->connect_clicked( LINK( this, ScOptSolverDlg, BtnHdl ) );
+    m_xBtnClose->connect_clicked( LINK( this, ScOptSolverDlg, BtnHdl ) );
     m_xBtnSolve->connect_clicked( LINK( this, ScOptSolverDlg, BtnHdl ) );
     m_xBtnResetAll->connect_clicked( LINK( this, ScOptSolverDlg, BtnHdl ) );
 
@@ -355,7 +355,7 @@ void ScOptSolverDlg::Init(const ScAddress& rCursorPos)
     {
         m_xRbMax->set_active(true);
         OUString aCursorStr;
-        if ( !mrDoc.GetRangeAtBlock( ScRange(rCursorPos), &aCursorStr ) )
+        if ( !mrDoc.GetRangeAtBlock( ScRange(rCursorPos), aCursorStr ) )
             aCursorStr = rCursorPos.Format(ScRefFlags::ADDR_ABS, nullptr, mrDoc.GetAddressConvention());
         m_xEdObjectiveCell->SetRefString( aCursorStr );
         if ( bImplHasElements )
@@ -465,7 +465,7 @@ void ScOptSolverDlg::SetReference( const ScRange& rRef, ScDocument& rDocP )
         aNewRef.aEnd = aAdr;
 
     OUString aName;
-    if ( rDocP.GetRangeAtBlock( aNewRef, &aName ) )            // named range: show name
+    if ( rDocP.GetRangeAtBlock( aNewRef, aName ) )            // named range: show name
         aStr = aName;
     else                                                        // format cell/range reference
     {
@@ -507,7 +507,7 @@ bool ScOptSolverDlg::IsRefInputMode() const
 
 IMPL_LINK(ScOptSolverDlg, BtnHdl, weld::Button&, rBtn, void)
 {
-    if (&rBtn == m_xBtnSolve.get() || &rBtn == m_xBtnCancel.get())
+    if (&rBtn == m_xBtnSolve.get() || &rBtn == m_xBtnClose.get())
     {
         bool bSolve = ( &rBtn == m_xBtnSolve.get() );
 
