@@ -34,6 +34,7 @@
 #include <com/sun/star/table/TableOrientation.hpp>
 #include <com/sun/star/table/CellRangeAddress.hpp>
 #include <com/sun/star/sheet/DataImportMode.hpp>
+#include <com/sun/star/sheet/FilterFieldType.hpp>
 #include <com/sun/star/sheet/FilterOperator2.hpp>
 #include <com/sun/star/sheet/TableFilterField2.hpp>
 
@@ -55,6 +56,7 @@
 #include <dputil.hxx>
 #include <sortparam.hxx>
 #include <dpobject.hxx>
+#include <filterentries.hxx>
 
 #include <comphelper/extract.hxx>
 #include <cppuhelper/supportsservice.hxx>
@@ -63,6 +65,7 @@
 #include <memory>
 
 using namespace com::sun::star;
+using namespace css::sheet;
 
 //  everything without Which-ID, map only for PropertySetInfo
 
@@ -504,8 +507,8 @@ void SAL_CALL ScSubTotalFieldObj::setSubTotalColumns(
         aParam.nSubTotals[nPos] = nCount;
         if (nCount != 0)
         {
-            aParam.pSubTotals[nPos] = new SCCOL[nCount];
-            aParam.pFunctions[nPos] = new ScSubTotalFunc[nCount];
+            aParam.pSubTotals[nPos].reset(new SCCOL[nCount]);
+            aParam.pFunctions[nPos].reset(new ScSubTotalFunc[nCount]);
 
             const sheet::SubTotalColumn* pAry = aSubTotalColumns.getConstArray();
             for (SCCOL i=0; i<nCount; i++)
@@ -516,8 +519,8 @@ void SAL_CALL ScSubTotalFieldObj::setSubTotalColumns(
         }
         else
         {
-            aParam.pSubTotals[nPos] = nullptr;
-            aParam.pFunctions[nPos] = nullptr;
+            aParam.pSubTotals[nPos].reset();
+            aParam.pFunctions[nPos].reset();
         }
     }
     //! otherwise exception or so? (too many columns)
@@ -536,7 +539,7 @@ ScSubTotalDescriptorBase::~ScSubTotalDescriptorBase()
 
 // XSubTotalDescriptor
 
-ScSubTotalFieldObj* ScSubTotalDescriptorBase::GetObjectByIndex_Impl(sal_uInt16 nIndex)
+rtl::Reference<ScSubTotalFieldObj> ScSubTotalDescriptorBase::GetObjectByIndex_Impl(sal_uInt16 nIndex)
 {
     if ( nIndex < getCount() )
         return new ScSubTotalFieldObj( this, nIndex );
@@ -578,15 +581,15 @@ void SAL_CALL ScSubTotalDescriptorBase::addNew(
     aParam.bGroupActive[nPos] = true;
     aParam.nField[nPos] = static_cast<SCCOL>(nGroupColumn);
 
-    delete aParam.pSubTotals[nPos];
-    delete aParam.pFunctions[nPos];
+    aParam.pSubTotals[nPos].reset();
+    aParam.pFunctions[nPos].reset();
 
     SCCOL nCount = static_cast<SCCOL>(nColCount);
     aParam.nSubTotals[nPos] = nCount;
     if (nCount != 0)
     {
-        aParam.pSubTotals[nPos] = new SCCOL[nCount];
-        aParam.pFunctions[nPos] = new ScSubTotalFunc[nCount];
+        aParam.pSubTotals[nPos].reset(new SCCOL[nCount]);
+        aParam.pFunctions[nPos].reset(new ScSubTotalFunc[nCount]);
 
         const sheet::SubTotalColumn* pAry = aSubTotalColumns.getConstArray();
         for (SCCOL i=0; i<nCount; i++)
@@ -597,8 +600,8 @@ void SAL_CALL ScSubTotalDescriptorBase::addNew(
     }
     else
     {
-        aParam.pSubTotals[nPos] = nullptr;
-        aParam.pFunctions[nPos] = nullptr;
+        aParam.pSubTotals[nPos].reset();
+        aParam.pFunctions[nPos].reset();
     }
 
     PutData(aParam);
@@ -1123,7 +1126,24 @@ void fillQueryParam(
             for (const auto& rVal : rVals)
             {
                 ScQueryEntry::Item aItem;
-                aItem.meType   = rVal.IsNumeric ? ScQueryEntry::ByValue : ScQueryEntry::ByString;
+                switch (rVal.FilterType)
+                {
+                    case FilterFieldType::NUMERIC:
+                        aItem.meType = ScQueryEntry::ByValue;
+                        break;
+                    case FilterFieldType::STRING:
+                        aItem.meType = ScQueryEntry::ByString;
+                        break;
+                    case FilterFieldType::DATE:
+                        aItem.meType = ScQueryEntry::ByDate;
+                        break;
+                    case FilterFieldType::TEXT_COLOR:
+                        aItem.meType = ScQueryEntry::ByTextColor;
+                        break;
+                    case FilterFieldType::BACKGROUND_COLOR:
+                        aItem.meType = ScQueryEntry::ByBackgroundColor;
+                        break;
+                }
                 aItem.mfVal    = rVal.NumericValue;
                 aItem.maString = rPool.intern(rVal.StringValue);
 
@@ -1133,8 +1153,31 @@ void fillQueryParam(
                     pDoc->GetFormatTable()->GetInputLineString(aItem.mfVal, 0, aStr);
                     aItem.maString = rPool.intern(aStr);
                 }
+                else if (aItem.meType == ScQueryEntry::ByTextColor
+                         || aItem.meType == ScQueryEntry::ByBackgroundColor)
+                {
+                    aItem.maColor = Color(ColorTransparency, rVal.ColorValue);
+                }
 
-                rItems.push_back(aItem);
+                // filter all dates starting with the given date filter YYYY or YYYY-MM and filter all datetimes
+                // starting with the given datetime filter YYYY-MM-DD, YYYY-MM-DD HH, or YYYY-MM-DD HH:MM
+                if( aItem.meType == ScQueryEntry::ByDate && aItem.maString.getLength() < 19 )
+                {
+                    ScFilterEntries aFilterEntries;
+                    pDoc->GetFilterEntries(rEntry.nField, rParam.nRow1, rParam.nTab, aFilterEntries);
+                    for( const auto& rFilter : aFilterEntries )
+                    {
+                        if( rFilter.GetString().startsWith(rVal.StringValue) )
+                        {
+                            aItem.maString = rPool.intern(rFilter.GetString());
+                            rItems.push_back(aItem);
+                        }
+                    }
+                }
+                else
+                {
+                    rItems.push_back(aItem);
+                }
             }
         }
     }
@@ -2109,7 +2152,7 @@ void ScDatabaseRangesObj::Notify( SfxBroadcaster&, const SfxHint& rHint )
 
 // XDatabaseRanges
 
-ScDatabaseRangeObj* ScDatabaseRangesObj::GetObjectByIndex_Impl(size_t nIndex)
+rtl::Reference<ScDatabaseRangeObj> ScDatabaseRangesObj::GetObjectByIndex_Impl(size_t nIndex)
 {
     if (!pDocShell)
         return nullptr;
@@ -2127,7 +2170,7 @@ ScDatabaseRangeObj* ScDatabaseRangesObj::GetObjectByIndex_Impl(size_t nIndex)
     return new ScDatabaseRangeObj(pDocShell, (*itr)->GetName());
 }
 
-ScDatabaseRangeObj* ScDatabaseRangesObj::GetObjectByName_Impl(const OUString& aName)
+rtl::Reference<ScDatabaseRangeObj> ScDatabaseRangesObj::GetObjectByName_Impl(const OUString& aName)
 {
     if ( pDocShell && hasByName(aName) )
     {
@@ -2251,7 +2294,7 @@ uno::Sequence<OUString> SAL_CALL ScDatabaseRangesObj::getElementNames()
             return aSeq;
         }
     }
-    return uno::Sequence<OUString>(0);
+    return {};
 }
 
 sal_Bool SAL_CALL ScDatabaseRangesObj::hasByName( const OUString& aName )
