@@ -26,6 +26,7 @@
 #include <sfx2/dispatch.hxx>
 #include <sfx2/request.hxx>
 #include <svl/stritem.hxx>
+#include <tools/UnitConversion.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/weld.hxx>
 #include <globstr.hrc>
@@ -47,13 +48,11 @@
 #include <columnspanset.hxx>
 #include <comphelper/lok.hxx>
 #include <LibreOfficeKit/LibreOfficeKitEnums.h>
-#include <sfx2/lokhelper.hxx>
 
 #include <memory>
 
-#define IS_EDITMODE() GetViewData()->HasEditView( GetViewData()->GetActivePart() )
+#define IS_EDITMODE() GetViewData().HasEditView( GetViewData().GetActivePart() )
 
-using sc::HMMToTwips;
 using sc::TwipsToEvenHMM;
 
 namespace
@@ -126,10 +125,10 @@ void lcl_lokGetWholeFunctionList()
                 {
                     aPayload.append("{");
                     aPayload.append("\"index\": ");
-                    aPayload.append(OString::number(nCurIndex));
+                    aPayload.append(static_cast<sal_Int64>(nCurIndex));
                     aPayload.append(", ");
                     aPayload.append("\"category\": ");
-                    aPayload.append(OString::number(ppFDesc->getCategory()->getNumber()));
+                    aPayload.append(static_cast<sal_Int64>(ppFDesc->getCategory()->getNumber()));
                     aPayload.append(", ");
                     aPayload.append("\"signature\": \"");
                     aPayload.append(escapeJSON(ppFDesc->getSignature()));
@@ -155,7 +154,7 @@ void lcl_lokGetWholeFunctionList()
 
 void ScCellShell::Execute( SfxRequest& rReq )
 {
-    ScTabViewShell* pTabViewShell   = GetViewData()->GetViewShell();
+    ScTabViewShell* pTabViewShell   = GetViewData().GetViewShell();
     SfxBindings&        rBindings   = pTabViewShell->GetViewFrame()->GetBindings();
     ScModule*           pScMod      = SC_MOD();
     const SfxItemSet*   pReqArgs    = rReq.GetArgs();
@@ -272,9 +271,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     // Enter
                     // NOTE: This also means we want to set the modified state
                     // regardless of the DontCommit parameter's value.
-                    if (comphelper::LibreOfficeKit::isActive() && !GetViewData()->GetDocShell()->IsModified())
+                    if (comphelper::LibreOfficeKit::isActive() && !GetViewData().GetDocShell()->IsModified())
                     {
-                        GetViewData()->GetDocShell()->SetModified();
+                        GetViewData().GetDocShell()->SetModified();
                         rBindings.Invalidate(SID_SAVEDOC);
                         rBindings.Invalidate(SID_DOC_MODIFIED);
                     }
@@ -289,9 +288,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     ScInputHandler* pHdl = SC_MOD()->GetInputHdl( pTabViewShell );
                     if (bCommit)
                     {
-                        pTabViewShell->EnterData( GetViewData()->GetCurX(),
-                                                  GetViewData()->GetCurY(),
-                                                  GetViewData()->GetTabNo(),
+                        pTabViewShell->EnterData( GetViewData().GetCurX(),
+                                                  GetViewData().GetCurY(),
+                                                  GetViewData().GetTabNo(),
                                                   aStr );
                     }
                     else if (pHdl)
@@ -330,7 +329,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 {
                     OUString aStr = static_cast<const SfxStringItem&>(pReqArgs->
                                     Get( SID_INSERT_MATRIX )).GetValue();
-                    ScDocument& rDoc = GetViewData()->GetDocument();
+                    ScDocument& rDoc = GetViewData().GetDocument();
                     pTabViewShell->EnterMatrix( aStr, rDoc.GetGrammar() );
                     rReq.Done();
                 }
@@ -372,9 +371,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     if (nSlot == FID_INPUTLINE_ENTER)
                     {
                         if (
-                            aCursorPos.Col() == GetViewData()->GetCurX() &&
-                            aCursorPos.Row() == GetViewData()->GetCurY() &&
-                            aCursorPos.Tab() == GetViewData()->GetTabNo()
+                            aCursorPos.Col() == GetViewData().GetCurX() &&
+                            aCursorPos.Row() == GetViewData().GetCurY() &&
+                            aCursorPos.Tab() == GetViewData().GetTabNo()
                             )
                         {
                             SfxStringItem   aItem( SID_ENTER_STRING, aString );
@@ -400,7 +399,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     }
                     else
                     {
-                        ScDocument& rDoc = GetViewData()->GetDocument();
+                        ScDocument& rDoc = GetViewData().GetDocument();
                         pTabViewShell->EnterMatrix( aString, rDoc.GetGrammar() );
                         rReq.Done();
                     }
@@ -534,9 +533,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_SCENARIOS:
             {
-                ScDocument& rDoc = GetViewData()->GetDocument();
-                ScMarkData& rMark = GetViewData()->GetMarkData();
-                SCTAB nTab = GetViewData()->GetTabNo();
+                ScDocument& rDoc = GetViewData().GetDocument();
+                ScMarkData& rMark = GetViewData().GetMarkData();
+                SCTAB nTab = GetViewData().GetTabNo();
 
                 if ( rDoc.IsScenario(nTab) )
                 {
@@ -666,7 +665,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     std::vector<sc::ColRowSpan> aRanges;
                     SCCOLROW nRow = static_cast<const SfxInt32Item*>(pRow)->GetValue() - 1;
                     nHeight = static_cast<const SfxUInt16Item*>(pHeight)->GetValue();
-                    ScMarkData& rMark = GetViewData()->GetMarkData();
+                    ScMarkData& rMark = GetViewData().GetMarkData();
 
                     if ( rMark.IsRowMarked( static_cast<SCROW>(nRow) ) )
                     {
@@ -677,30 +676,30 @@ void ScCellShell::Execute( SfxRequest& rReq )
                         aRanges.emplace_back(nRow, nRow);
                     }
 
-                    pTabViewShell->SetWidthOrHeight(false, aRanges, SC_SIZE_DIRECT, HMMToTwips(nHeight));
+                    pTabViewShell->SetWidthOrHeight(false, aRanges, SC_SIZE_DIRECT, convertMm100ToTwip(nHeight));
                 }
                 else if ( pReqArgs && pReqArgs->HasItem( FID_ROW_HEIGHT, &pHeight ) )
                 {
                     nHeight = static_cast<const SfxUInt16Item*>(pHeight)->GetValue();
 
-                    // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
+                    // #101390#; the value of the macro is in HMM so use convertMm100ToTwip to convert
                     pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_DIRECT,
-                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(nHeight) ) );
+                        sal::static_int_cast<sal_uInt16>(convertMm100ToTwip(nHeight)));
                     if( ! rReq.IsAPI() )
                         rReq.Done();
                 }
                 else
                 {
-                    ScViewData* pData      = GetViewData();
+                    ScViewData& rData      = GetViewData();
                     FieldUnit   eMetric    = SC_MOD()->GetAppOptions().GetAppMetric();
-                    sal_uInt16      nCurHeight = pData->GetDocument().
-                                                GetRowHeight( pData->GetCurY(),
-                                                              pData->GetTabNo() );
+                    sal_uInt16      nCurHeight = rData.GetDocument().
+                                                GetRowHeight( rData.GetCurY(),
+                                                              rData.GetTabNo() );
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     ScopedVclPtr<AbstractScMetricInputDlg> pDlg(pFact->CreateScMetricInputDlg(
                         pTabViewShell->GetFrameWeld(), "RowHeightDialog",
                         nCurHeight, ScGlobal::nStdRowHeight,
-                        eMetric, 2, MAX_ROW_HEIGHT));
+                        eMetric, 4, MAX_ROW_HEIGHT));
 
                     if ( pDlg->Execute() == RET_OK )
                     {
@@ -722,9 +721,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 {
                     const SfxUInt16Item&  rUInt16Item = static_cast<const SfxUInt16Item&>(pReqArgs->Get( FID_ROW_OPT_HEIGHT ));
 
-                    // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
+                    // #101390#; the value of the macro is in HMM so use convertMm100ToTwip to convert
                     pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_OPTIMAL,
-                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(rUInt16Item.GetValue()) ) );
+                                    sal::static_int_cast<sal_uInt16>( convertMm100ToTwip(rUInt16Item.GetValue()) ) );
                     ScGlobal::nLastRowHeightExtra = rUInt16Item.GetValue();
 
                     if( ! rReq.IsAPI() )
@@ -737,7 +736,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     ScopedVclPtr<AbstractScMetricInputDlg> pDlg(pFact->CreateScMetricInputDlg(
                         pTabViewShell->GetFrameWeld(), "OptimalRowHeightDialog",
-                        ScGlobal::nLastRowHeightExtra, 0, eMetric, 1, MAX_EXTRA_HEIGHT));
+                        ScGlobal::nLastRowHeightExtra, 0, eMetric, 4, MAX_EXTRA_HEIGHT));
                     if ( pDlg->Execute() == RET_OK )
                     {
                         tools::Long nVal = pDlg->GetInputValue();
@@ -765,7 +764,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     std::vector<sc::ColRowSpan> aRanges;
                     SCCOLROW nColumn = static_cast<const SfxUInt16Item*>(pColumn)->GetValue() - 1;
                     nWidth = static_cast<const SfxUInt16Item*>(pWidth)->GetValue();
-                    ScMarkData& rMark = GetViewData()->GetMarkData();
+                    ScMarkData& rMark = GetViewData().GetMarkData();
 
                     if ( rMark.IsColumnMarked( static_cast<SCCOL>(nColumn) ) )
                     {
@@ -776,29 +775,29 @@ void ScCellShell::Execute( SfxRequest& rReq )
                         aRanges.emplace_back(nColumn, nColumn);
                     }
 
-                    pTabViewShell->SetWidthOrHeight(true, aRanges, SC_SIZE_DIRECT, HMMToTwips(nWidth));
+                    pTabViewShell->SetWidthOrHeight(true, aRanges, SC_SIZE_DIRECT, convertMm100ToTwip(nWidth));
                 }
                 else if ( pReqArgs && pReqArgs->HasItem( FID_COL_WIDTH, &pWidth ) )
                 {
                     nWidth = static_cast<const SfxUInt16Item*>(pWidth)->GetValue();
 
-                    // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
+                    // #101390#; the value of the macro is in HMM so use convertMm100ToTwip to convert
                     pTabViewShell->SetMarkedWidthOrHeight( true, SC_SIZE_DIRECT,
-                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(nWidth) ) );
+                        sal::static_int_cast<sal_uInt16>(convertMm100ToTwip(nWidth)));
                     if( ! rReq.IsAPI() )
                         rReq.Done();
                 }
                 else
                 {
                     FieldUnit   eMetric    = SC_MOD()->GetAppOptions().GetAppMetric();
-                    ScViewData* pData      = GetViewData();
-                    sal_uInt16      nCurHeight = pData->GetDocument().
-                                                GetColWidth( pData->GetCurX(),
-                                                             pData->GetTabNo() );
+                    ScViewData& rData      = GetViewData();
+                    sal_uInt16      nCurHeight = rData.GetDocument().
+                                                GetColWidth( rData.GetCurX(),
+                                                             rData.GetTabNo() );
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     ScopedVclPtr<AbstractScMetricInputDlg> pDlg(pFact->CreateScMetricInputDlg(
                         pTabViewShell->GetFrameWeld(), "ColWidthDialog", nCurHeight,
-                        STD_COL_WIDTH, eMetric, 2, MAX_COL_WIDTH));
+                        STD_COL_WIDTH, eMetric, 4, MAX_COL_WIDTH));
                     if ( pDlg->Execute() == RET_OK )
                     {
                         tools::Long nVal = pDlg->GetInputValue();
@@ -819,9 +818,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 {
                     const SfxUInt16Item&  rUInt16Item = static_cast<const SfxUInt16Item&>(pReqArgs->Get( FID_COL_OPT_WIDTH ));
 
-                    // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
+                    // #101390#; the value of the macro is in HMM so use convertMm100ToTwip to convert
                     pTabViewShell->SetMarkedWidthOrHeight( true, SC_SIZE_OPTIMAL,
-                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(rUInt16Item.GetValue()) ) );
+                                    sal::static_int_cast<sal_uInt16>( convertMm100ToTwip(rUInt16Item.GetValue()) ) );
                     ScGlobal::nLastColWidthExtra = rUInt16Item.GetValue();
 
                     if( ! rReq.IsAPI() )
@@ -834,7 +833,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     ScopedVclPtr<AbstractScMetricInputDlg> pDlg(pFact->CreateScMetricInputDlg(
                         pTabViewShell->GetFrameWeld(), "OptimalColWidthDialog",
-                        ScGlobal::nLastColWidthExtra, STD_EXTRA_WIDTH, eMetric, 1, MAX_EXTRA_WIDTH));
+                        ScGlobal::nLastColWidthExtra, STD_EXTRA_WIDTH, eMetric, 4, MAX_EXTRA_WIDTH));
                     if ( pDlg->Execute() == RET_OK )
                     {
                         tools::Long nVal = pDlg->GetInputValue();
@@ -882,7 +881,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
         case FID_MERGE_OFF:
         case FID_MERGE_TOGGLE:
         {
-            if ( !GetViewData()->GetDocument().GetChangeTrack() )
+            if ( !GetViewData().GetDocument().GetChangeTrack() )
             {
                 // test whether to merge or to split
                 bool bMerge = false;
@@ -950,11 +949,11 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 SCROW nEndRow;
                 SCTAB nEndTab;
 
-                const ScMarkData& rMark = GetViewData()->GetMarkData();
+                const ScMarkData& rMark = GetViewData().GetMarkData();
                 if ( !rMark.IsMarked() && !rMark.IsMultiMarked() )
                     pTabViewShell->MarkDataArea();
 
-                GetViewData()->GetSimpleArea( nStartCol,nStartRow,nStartTab,
+                GetViewData().GetSimpleArea( nStartCol,nStartRow,nStartTab,
                                               nEndCol,nEndRow,nEndTab );
 
                 if (   ( std::abs(nEndCol-nStartCol) > 1 )
@@ -1010,7 +1009,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_CANCEL:
             {
-                if (GetViewData()->HasEditView(GetViewData()->GetActivePart()))
+                if (GetViewData().HasEditView(GetViewData().GetActivePart()))
                     pScMod->InputCancelHandler();
                 else if (pTabViewShell->HasPaintBrush())
                     pTabViewShell->ResetBrushDocument();            // abort format paint brush
@@ -1044,7 +1043,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_STATUS_DOCPOS:
             // Launch navigator.
-            GetViewData()->GetDispatcher().Execute(
+            GetViewData().GetDispatcher().Execute(
                 SID_NAVIGATOR, SfxCallMode::SYNCHRON|SfxCallMode::RECORD );
             break;
 
