@@ -246,12 +246,9 @@ void ScEditShell::Execute( SfxRequest& rReq )
             {
                 SotClipboardFormatId nFormat = SotClipboardFormatId::NONE;
                 const SfxPoolItem* pItem;
-                if ( pReqArgs &&
-                     pReqArgs->GetItemState(nSlot, true, &pItem) == SfxItemState::SET &&
-                     dynamic_cast<const SfxUInt32Item*>( pItem) !=  nullptr )
-                {
-                    nFormat = static_cast<SotClipboardFormatId>(static_cast<const SfxUInt32Item*>(pItem)->GetValue());
-                }
+                if ( pReqArgs && pReqArgs->GetItemState(nSlot, true, &pItem) == SfxItemState::SET )
+                    if (auto pIntItem = dynamic_cast<const SfxUInt32Item*>( pItem))
+                        nFormat = static_cast<SotClipboardFormatId>(pIntItem->GetValue());
 
                 if ( nFormat != SotClipboardFormatId::NONE )
                 {
@@ -423,7 +420,7 @@ void ScEditShell::Execute( SfxRequest& rReq )
                 }
                 else
                 {
-                    ScViewUtil::ExecuteCharMap( rItem, *rViewData.GetViewShell()->GetViewFrame() );
+                    ScViewUtil::ExecuteCharMap(rItem, *rViewData.GetViewShell());
 
                     // while the dialog was open, edit mode may have been stopped
                     if (!SC_MOD()->IsInputMode())
@@ -640,15 +637,9 @@ void ScEditShell::Execute( SfxRequest& rReq )
                 const SvxFieldData* pField = pEditView->GetFieldAtCursor();
                 if (const SvxURLField* pURLField = dynamic_cast<const SvxURLField*>(pField))
                 {
-                    uno::Reference<datatransfer::clipboard::XClipboard> xClipboard = GetSystemClipboard();
-
-                    if (comphelper::LibreOfficeKit::isActive())
-                    {
-                        std::function<void (int, const char*)> callback = [&] (int callbackType, const char* text) { rViewData.GetViewShell()->libreOfficeKitViewCallback(callbackType, text); } ;
-                        vcl::unohelper::TextDataObject::CopyStringTo(pURLField->GetURL(), xClipboard, &callback);
-                    }
-                    else
-                        vcl::unohelper::TextDataObject::CopyStringTo(pURLField->GetURL(), xClipboard, nullptr);
+                    uno::Reference<datatransfer::clipboard::XClipboard> xClipboard
+                        = pEditView->GetClipboard();
+                    vcl::unohelper::TextDataObject::CopyStringTo(pURLField->GetURL(), xClipboard, SfxViewShell::Current());
                 }
             }
         break;
@@ -679,8 +670,8 @@ void ScEditShell::Execute( SfxRequest& rReq )
         case SID_INSERT_ZWSP:
             lclInsertCharacter( pTableView, pTopView, CHAR_ZWSP );
         break;
-        case SID_INSERT_ZWNBSP:
-            lclInsertCharacter( pTableView, pTopView, CHAR_ZWNBSP );
+        case SID_INSERT_WJ:
+            lclInsertCharacter( pTableView, pTopView, CHAR_WJ );
         break;
         case SID_INSERT_FIELD_SHEET:
         {
@@ -721,6 +712,16 @@ static void lcl_DisableAll( SfxItemSet& rSet )    // disable all slots
     }
 }
 
+bool ScEditShell::ShouldDisableEditHyperlink() const
+{
+    return !rViewData.HasEditView(rViewData.GetActivePart()) || !URLFieldHelper::IsCursorAtURLField(*pEditView);
+}
+
+void ScEditShell::EnableEditHyperlink()
+{
+    moAtContextMenu_DisableEditHyperlink = false;
+}
+
 void ScEditShell::GetState( SfxItemSet& rSet )
 {
     // When deactivating the view, edit mode is stopped, but the EditShell is left active
@@ -786,7 +787,18 @@ void ScEditShell::GetState( SfxItemSet& rSet )
             case SID_COPY_HYPERLINK_LOCATION:
             case SID_REMOVE_HYPERLINK:
                 {
-                    if (!URLFieldHelper::IsCursorAtURLField(*pEditView))
+                    bool bDisableEditHyperlink;
+                    if (!moAtContextMenu_DisableEditHyperlink)
+                        bDisableEditHyperlink = ShouldDisableEditHyperlink();
+                    else
+                    {
+                        // tdf#140361 if a popup menu was active, use the state as of when the popup was launched and then drop
+                        // moAtContextMenu_DisableEditHyperlink
+                        bDisableEditHyperlink = *moAtContextMenu_DisableEditHyperlink;
+                        moAtContextMenu_DisableEditHyperlink.reset();
+                    }
+
+                    if (bDisableEditHyperlink)
                         rSet.DisableItem (nWhich);
                 }
                 break;
@@ -965,7 +977,7 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
                         if ( sColor == "transparent" )
                             aColor = COL_TRANSPARENT;
                         else
-                            aColor = Color( sColor.toInt32( 16 ) );
+                            aColor = Color( ColorTransparency, sColor.toInt32( 16 ) );
 
                         aSet.Put( SvxColorItem( aColor, EE_CHAR_COLOR ) );
                     }
