@@ -26,6 +26,7 @@
 #include <sfx2/lokhelper.hxx>
 #include <sfx2/objsh.hxx>
 #include <sfx2/viewfrm.hxx>
+#include <osl/diagnose.h>
 
 #include <tabview.hxx>
 #include <tabvwsh.hxx>
@@ -147,7 +148,7 @@ ScTabView::~ScTabView()
     {
         pOld->ForgetView();
         pScMod->SetSelectionTransfer( nullptr );
-        TransferableHelper::ClearSelection( GetActiveWin() );       // may delete pOld
+        TransferableHelper::ClearPrimarySelection();       // may delete pOld
     }
 
     pBrushDocument.reset();
@@ -185,7 +186,7 @@ ScTabView::~ScTabView()
         for (i=0; i<4; i++)
             if (pGridWin[i])
             {
-                pDrawView->DeleteWindowFromPaintView(pGridWin[i]);
+                pDrawView->DeleteWindowFromPaintView(pGridWin[i]->GetOutDev());
             }
 
         pDrawView->HideSdrPage();
@@ -234,12 +235,12 @@ void ScTabView::MakeDrawView( TriState nForceDesignMode )
     OSL_ENSURE(pLayer, "Where is the Draw Layer ??");
 
     sal_uInt16 i;
-    pDrawView.reset( new ScDrawView( pGridWin[SC_SPLIT_BOTTOMLEFT], &aViewData ) );
+    pDrawView.reset( new ScDrawView( pGridWin[SC_SPLIT_BOTTOMLEFT]->GetOutDev(), &aViewData ) );
     for (i=0; i<4; i++)
         if (pGridWin[i])
         {
             if ( SC_SPLIT_BOTTOMLEFT != static_cast<ScSplitPos>(i) )
-                pDrawView->AddWindowToPaintView(pGridWin[i], nullptr);
+                pDrawView->AddWindowToPaintView(pGridWin[i]->GetOutDev(), nullptr);
         }
     pDrawView->RecalcScale();
     for (i=0; i<4; i++)
@@ -272,7 +273,7 @@ void ScTabView::DoAddWin( ScGridWindow* pWin )
 {
     if (pDrawView)
     {
-        pDrawView->AddWindowToPaintView(pWin, nullptr);
+        pDrawView->AddWindowToPaintView(pWin->GetOutDev(), nullptr);
         pWin->DrawLayerCreated();
     }
     pWin->SetAutoSpellContext(mpSpellCheckCxt);
@@ -319,6 +320,13 @@ void ScTabView::TabChanged( bool bSameTabButMoved )
         }
     }
 
+    for (int i = 0; i < 4; i++)
+        if (pGridWin[i])
+        {
+            pGridWin[i]->initiatePageBreaks();
+        }
+
+
     if (!comphelper::LibreOfficeKit::isActive())
         return;
 
@@ -534,7 +542,7 @@ void ScTabView::DigitLanguageChanged()
     LanguageType eNewLang = SC_MOD()->GetOptDigitLanguage();
     for (VclPtr<ScGridWindow> & pWin : pGridWin)
         if ( pWin )
-            pWin->SetDigitLanguage( eNewLang );
+            pWin->GetOutDev()->SetDigitLanguage( eNewLang );
 }
 
 void ScTabView::ScrollToObject( const SdrObject* pDrawObj )
@@ -647,7 +655,7 @@ void ScTabView::ResetBrushDocument()
     if ( HasPaintBrush() )
     {
         SetBrushDocument( nullptr, false );
-        SetActivePointer( PointerStyle::Arrow );   // switch pointers also when ended with escape key
+        SetActivePointer( aViewData.IsThemedCursor() ? PointerStyle::FatCross : PointerStyle::Arrow ); // switch pointers also when ended with escape key
     }
 }
 
