@@ -203,12 +203,34 @@ namespace basprov
                 {
                     SbxVariableRef xSbxVar = new SbxVariable( SbxVARIANT );
                     unoToSbxValue( xSbxVar.get(), pParams[i] );
-                    xSbxParams->Put32( xSbxVar.get(), static_cast< sal_uInt32 >( i ) + 1 );
+                    xSbxParams->Put(xSbxVar.get(), static_cast<sal_uInt32>(i) + 1);
 
-                    // Enable passing by ref
-                    if ( xSbxVar->GetType() != SbxVARIANT )
-                        xSbxVar->SetFlag( SbxFlagBits::Fixed );
-                 }
+                    if (pInfo)
+                    {
+                        if (auto* p = pInfo->GetParam(static_cast<sal_uInt16>(i) + 1))
+                        {
+                            SbxDataType t = static_cast<SbxDataType>(p->eType & 0x0FFF);
+                            // tdf#133889 Revert the downcasting performed in sbxToUnoValueImpl
+                            // to allow passing by reference.
+                            SbxDataType a = xSbxVar->GetType();
+                            if (t == SbxSINGLE && (a == SbxINTEGER || a == SbxLONG))
+                            {
+                                sal_Int32 val = xSbxVar->GetLong();
+                                if (val >= -16777216 && val <= 16777215)
+                                    xSbxVar->SetType(t);
+                            }
+                            else if (t == SbxDOUBLE && (a == SbxINTEGER || a == SbxLONG))
+                                xSbxVar->SetType(t);
+                            else if (t == SbxLONG && a == SbxINTEGER)
+                                xSbxVar->SetType(t);
+                            else if (t == SbxULONG && a == SbxUSHORT)
+                                xSbxVar->SetType(t);
+                            // Enable passing by ref
+                            if (t != SbxVARIANT)
+                                xSbxVar->SetFlag(SbxFlagBits::Fixed);
+                        }
+                    }
+                }
             }
             if ( xSbxParams.is() )
                 m_xMethod->SetParameters( xSbxParams.get() );
@@ -222,8 +244,6 @@ namespace basprov
             if ( m_documentBasicManager && m_xDocumentScriptContext.is() )
                 aOldThisComponent = m_documentBasicManager->SetGlobalUNOConstant( "ThisComponent", makeAny( m_xDocumentScriptContext ) );
 
-            // tdf#143582 - clear return value of the method before calling it
-            m_xMethod->Clear();
             if ( m_caller.hasElements() && m_caller[ 0 ].hasValue()  )
             {
                 SbxVariableRef xCallerVar = new SbxVariable( SbxVARIANT );
@@ -248,13 +268,13 @@ namespace basprov
                 if ( pInfo_ )
                 {
                     OutParamMap aOutParamMap;
-                    for ( sal_uInt32 n = 1, nCount = xSbxParams->Count32(); n < nCount; ++n )
+                    for (sal_uInt32 n = 1, nCount = xSbxParams->Count(); n < nCount; ++n)
                     {
                         assert(nCount <= std::numeric_limits<sal_uInt16>::max());
                         const SbxParamInfo* pParamInfo = pInfo_->GetParam( sal::static_int_cast<sal_uInt16>(n) );
                         if ( pParamInfo && ( pParamInfo->eType & SbxBYREF ) != 0 )
                         {
-                            SbxVariable* pVar = xSbxParams->Get32( n );
+                            SbxVariable* pVar = xSbxParams->Get(n);
                             if ( pVar )
                             {
                                 SbxVariableRef xVar = pVar;
