@@ -32,7 +32,6 @@
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 
 #include <com/sun/star/lang/XMultiComponentFactory.hpp>
-#include <com/sun/star/lang/XServiceName.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
 
@@ -43,7 +42,6 @@
 
 #include <com/sun/star/script/ScriptEventDescriptor.hpp>
 #include <com/sun/star/script/provider/XScriptProviderSupplier.hpp>
-#include <com/sun/star/script/vba/XVBACompatibility.hpp>
 
 #include <com/sun/star/container/XNamed.hpp>
 
@@ -60,11 +58,7 @@
 #include <com/sun/star/awt/XListBox.hpp>
 
 #include <sfx2/objsh.hxx>
-#include <basic/sbstar.hxx>
 #include <basic/basmgr.hxx>
-#include <basic/sbmeth.hxx>
-#include <basic/sbmod.hxx>
-#include <basic/sbx.hxx>
 #include <filter/msfilter/msvbahelper.hxx>
 #include <vbahelper/vbareturntypes.hxx>
 
@@ -73,7 +67,7 @@
 #include <cppuhelper/supportsservice.hxx>
 #include <comphelper/evtmethodhelper.hxx>
 
-#include <list>
+#include <vector>
 #include <unordered_map>
 
 using namespace ::com::sun::star;
@@ -82,8 +76,8 @@ using namespace ::com::sun::star::uno;
 using namespace ::ooo::vba;
 
 // Some constants
-static const char DELIM[] = "::";
-static const sal_Int32 DELIMLEN = strlen(DELIM);
+const char DELIM[] = "::";
+const sal_Int32 DELIMLEN = strlen(DELIM);
 
 static bool isKeyEventOk( awt::KeyEvent& evt, const Sequence< Any >& params )
 {
@@ -178,7 +172,7 @@ struct TranslateInfo
 
 typedef std::unordered_map<
     OUString,
-    std::list< TranslateInfo > > EventInfoHash;
+    std::vector< TranslateInfo > > EventInfoHash;
 
 namespace {
 
@@ -279,14 +273,14 @@ static EventInfoHash& getEventTransInfo()
         while (i < nCount)
         {
             sEventInfo = pTransProp->sEventInfo;
-            std::list< TranslateInfo > infoList;
+            std::vector< TranslateInfo > infoList;
             do
             {
                 infoList.push_back( pTransProp->aTransInfo );
                 pTransProp++;
                 i++;
             }while(i < nCount && sEventInfo == pTransProp->sEventInfo);
-            tmp[sEventInfo] = infoList;
+            tmp[sEventInfo] = std::move(infoList);
         }
         return tmp;
     }();
@@ -388,7 +382,7 @@ ScriptEventHelper::~ScriptEventHelper()
 Sequence< OUString >
 ScriptEventHelper::getEventListeners() const
 {
-    std::list< OUString > eventMethods;
+    std::vector< OUString > eventMethods;
 
     Reference< beans::XIntrospection > xIntrospection = beans::theIntrospection::get( m_xCtx );
 
@@ -883,10 +877,9 @@ EventListener::firing_Impl(const ScriptEvent& evt, Any* pRet )
             break;
         }
 
-        OUString sTemp = sName.concat( rTxInfo.sVBAName );
         // see if we have a match for the handlerextension
         // where ScriptCode is methodname_handlerextension
-        OUString sToResolve = sMacroLoc.concat( sTemp );
+        OUString sToResolve = sMacroLoc + sName + rTxInfo.sVBAName;
 
         ooo::vba::MacroResolvedInfo aMacroResolvedInfo = ooo::vba::resolveVBAMacro( mpShell, sToResolve );
         if ( aMacroResolvedInfo.mbFound )
