@@ -12,7 +12,7 @@ class tdf126605(UITestCase):
    def test_run(self):
         self.ui_test.create_doc_in_start_center("impress")
         xTemplateDlg = self.xUITest.getTopFocusWindow()
-        xCancelBtn = xTemplateDlg.getChild("cancel")
+        xCancelBtn = xTemplateDlg.getChild("close")
         self.ui_test.close_dialog_through_button(xCancelBtn)
 
         xDoc = self.xUITest.getTopFocusWindow()
