@@ -31,6 +31,7 @@
 #include <sax/fshelper.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <sal/log.hxx>
+#include <tools/UnitConversion.hxx>
 #include <com/sun/star/animations/TransitionType.hpp>
 #include <com/sun/star/animations/TransitionSubType.hpp>
 #include <com/sun/star/beans/XPropertySetInfo.hpp>
@@ -46,6 +47,10 @@
 #include <com/sun/star/task/XStatusIndicator.hpp>
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
+#include <com/sun/star/presentation/XCustomPresentationSupplier.hpp>
+#include <com/sun/star/container/XIndexContainer.hpp>
+#include <com/sun/star/container/XNamed.hpp>
+#include <com/sun/star/presentation/XPresentationSupplier.hpp>
 
 #include <oox/export/utils.hxx>
 
@@ -67,6 +72,10 @@
                       FSNS(XML_xmlns, XML_p15), OUStringToOString(this->getNamespaceURL(OOX_NS(p15)), RTL_TEXTENCODING_UTF8).getStr(), \
                       FSNS(XML_xmlns, XML_mc),  OUStringToOString(this->getNamespaceURL(OOX_NS(mce)), RTL_TEXTENCODING_UTF8).getStr()
 
+// presentationPr namespace
+#define PPRNMSS       FSNS(XML_xmlns, XML_a),   OUStringToOString(this->getNamespaceURL(OOX_NS(dml)), RTL_TEXTENCODING_UTF8).getStr(), \
+                      FSNS(XML_xmlns, XML_r),   OUStringToOString(this->getNamespaceURL(OOX_NS(officeRel)), RTL_TEXTENCODING_UTF8).getStr(), \
+                      FSNS(XML_xmlns, XML_p),   OUStringToOString(this->getNamespaceURL(OOX_NS(ppt)), RTL_TEXTENCODING_UTF8).getStr()
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::animations;
@@ -368,7 +377,7 @@ void PowerPointExport::writeDocumentProperties()
     exportCustomFragments();
 }
 
-bool PowerPointExport::importDocument() throw()
+bool PowerPointExport::importDocument() noexcept
 {
     return false;
 }
@@ -383,7 +392,7 @@ bool PowerPointExport::exportDocument()
     //write document properties
     writeDocumentProperties();
 
-    addRelation(oox::getRelationship(Relationship::OFFICEDOCUMENT), "ppt/presentation.xml");
+    addRelation(oox::getRelationship(Relationship::OFFICEDOCUMENT), u"ppt/presentation.xml");
 
     OUString aMediaType;
     if (mbPptm)
@@ -413,7 +422,7 @@ bool PowerPointExport::exportDocument()
 
     addRelation(mPresentationFS->getOutputStream(),
                 oox::getRelationship(Relationship::THEME),
-                "theme/theme1.xml");
+                u"theme/theme1.xml");
 
     mPresentationFS->startElementNS(XML_p, XML_presentation, PNMSS);
 
@@ -435,6 +444,10 @@ bool PowerPointExport::exportDocument()
                                      XML_cx, OString::number(PPTtoEMU(maNotesPageSize.Width)),
                                      XML_cy, OString::number(PPTtoEMU(maNotesPageSize.Height)));
 
+    WriteCustomSlideShow();
+
+    WritePresentationProps();
+
     WriteAuthors();
 
     WriteVBA();
@@ -448,13 +461,72 @@ bool PowerPointExport::exportDocument()
 
     maShapeMap.clear();
     maAuthors.clear();
+    maRelId.clear();
 
     return true;
 }
 
 ::oox::ole::VbaProject* PowerPointExport::implCreateVbaProject() const
 {
-    return new ::oox::ole::VbaProject(getComponentContext(), getModel(), "Impress");
+    return new ::oox::ole::VbaProject(getComponentContext(), getModel(), u"Impress");
+}
+
+void PowerPointExport::WriteCustomSlideShow()
+{
+    Reference<XCustomPresentationSupplier> aXCPSup(mXModel, css::uno::UNO_QUERY);
+    if (aXCPSup.is() && aXCPSup->getCustomPresentations()->hasElements())
+    {
+        mPresentationFS->startElementNS(XML_p, XML_custShowLst);
+
+        Reference<XDrawPagesSupplier> xDPS(getModel(), uno::UNO_QUERY_THROW);
+        Reference<XDrawPages> xDrawPages(xDPS->getDrawPages(), uno::UNO_SET_THROW);
+        Reference<XNameContainer> aXNameCont(aXCPSup->getCustomPresentations());
+        const Sequence<OUString> aNameSeq(aXNameCont->getElementNames());
+
+        OUString sRelId;
+        sal_uInt32 nCustomShowIndex = 0;
+        sal_Int32 nSlideCount = xDrawPages->getCount();
+
+        for (OUString const& customShowName : aNameSeq)
+        {
+            mPresentationFS->startElementNS(XML_p, XML_custShow, XML_name, customShowName, XML_id,
+                                            OUString::number(nCustomShowIndex++));
+
+            mAny = aXNameCont->getByName(customShowName);
+            Reference<XIndexContainer> aXIContainer;
+            if (mAny >>= aXIContainer)
+            {
+                mPresentationFS->startElementNS(XML_p, XML_sldLst);
+
+                sal_Int32 nCustomShowSlideCount = aXIContainer->getCount();
+                for (sal_Int32 i = 0; i < nCustomShowSlideCount; ++i)
+                {
+                    Reference<XDrawPage> aXCustomShowDrawPage;
+                    aXIContainer->getByIndex(i) >>= aXCustomShowDrawPage;
+                    Reference<XNamed> aXName(aXCustomShowDrawPage, UNO_QUERY_THROW);
+                    OUString sCustomShowSlideName = aXName->getName();
+
+                    for (sal_Int32 j = 0; j < nSlideCount; ++j)
+                    {
+                        Reference<XDrawPage> xDrawPage;
+                        xDrawPages->getByIndex(j) >>= xDrawPage;
+                        Reference<XNamed> xNamed(xDrawPage, UNO_QUERY_THROW);
+                        OUString sSlideName = xNamed->getName();
+
+                        if (sCustomShowSlideName == sSlideName)
+                        {
+                            sRelId = maRelId[j];
+                            break;
+                        }
+                    }
+                    mPresentationFS->singleElementNS(XML_p, XML_sld, FSNS(XML_r, XML_id), sRelId);
+                }
+                mPresentationFS->endElementNS(XML_p, XML_sldLst);
+            }
+            mPresentationFS->endElementNS(XML_p, XML_custShow);
+        }
+        mPresentationFS->endElementNS(XML_p, XML_custShowLst);
+    }
 }
 
 void PowerPointExport::ImplWriteBackground(const FSHelperPtr& pFS, const Reference< XPropertySet >& rXPropSet)
@@ -952,7 +1024,7 @@ void PowerPointExport::WriteAuthors()
                       "application/vnd.openxmlformats-officedocument.presentationml.commentAuthors+xml");
     addRelation(mPresentationFS->getOutputStream(),
                 oox::getRelationship(Relationship::COMMENTAUTHORS),
-                "commentAuthors.xml");
+                u"commentAuthors.xml");
 
     pFS->startElementNS(XML_p, XML_cmAuthorLst,
                         FSNS(XML_xmlns, XML_p), getNamespaceURL(OOX_NS(ppt)));
@@ -987,6 +1059,31 @@ sal_Int32 PowerPointExport::GetAuthorIdAndLastIndex(const OUString& sAuthor, sal
     return maAuthors[ sAuthor ].nId;
 }
 
+void PowerPointExport::WritePresentationProps()
+{
+    Reference<XPresentationSupplier> xPresentationSupplier(mXModel, uno::UNO_QUERY);
+    if (xPresentationSupplier.is())
+    {
+        Reference<beans::XPropertySet> xPresentationProps(xPresentationSupplier->getPresentation(),
+                                                          uno::UNO_QUERY);
+        bool bEndlessVal = xPresentationProps->getPropertyValue("IsEndless").get<bool>();
+
+        FSHelperPtr pFS = openFragmentStreamWithSerializer(
+            "ppt/presProps.xml",
+            "application/vnd.openxmlformats-officedocument.presentationml.presProps+xml");
+
+        addRelation(mPresentationFS->getOutputStream(),
+                    oox::getRelationship(Relationship::PRESPROPS), u"presProps.xml");
+
+        pFS->startElementNS(XML_p, XML_presentationPr, PPRNMSS);
+
+        pFS->singleElementNS(XML_p, XML_showPr, XML_loop, sax_fastparser::UseIf("1", bEndlessVal),
+                             XML_showNarration, sax_fastparser::UseIf("1", bEndlessVal));
+
+        pFS->endElementNS(XML_p, XML_presentationPr);
+    }
+}
+
 bool PowerPointExport::WriteComments(sal_uInt32 nPageNum)
 {
     Reference< XAnnotationAccess > xAnnotationAccess(mXDrawPage, uno::UNO_QUERY);
@@ -996,11 +1093,8 @@ bool PowerPointExport::WriteComments(sal_uInt32 nPageNum)
 
         if (xAnnotationEnumeration->hasMoreElements())
         {
-            FSHelperPtr pFS = openFragmentStreamWithSerializer(OUStringBuffer()
-                              .append("ppt/comments/comment")
-                              .append(static_cast<sal_Int32>(nPageNum) + 1)
-                              .append(".xml")
-                              .makeStringAndClear(),
+            FSHelperPtr pFS = openFragmentStreamWithSerializer(
+                              "ppt/comments/comment" + OUString::number(nPageNum + 1) + ".xml",
                               "application/vnd.openxmlformats-officedocument.presentationml.comments+xml");
 
             pFS->startElementNS(XML_p, XML_cmLst,
@@ -1025,8 +1119,8 @@ bool PowerPointExport::WriteComments(sal_uInt32 nPageNum)
                                     XML_idx, OString::number(nLastIndex));
 
                 pFS->singleElementNS(XML_p, XML_pos,
-                                     XML_x, OString::number(static_cast<sal_Int64>((57600*aRealPoint2D.X + 1270)/2540.0)),
-                                     XML_y, OString::number(static_cast<sal_Int64>((57600*aRealPoint2D.Y + 1270)/2540.0)));
+                                     XML_x, OString::number(std::round(convertMm100ToMasterUnit(aRealPoint2D.X * 100))),
+                                     XML_y, OString::number(std::round(convertMm100ToMasterUnit(aRealPoint2D.Y * 100))));
 
                 pFS->startElementNS(XML_p, XML_text);
                 pFS->write(xText->getString());
@@ -1069,7 +1163,7 @@ void PowerPointExport::WriteVBA()
     comphelper::OStorageHelper::CopyInputToOutput(xMacrosStream, xOutputStream);
 
     // Write the relationship.
-    addRelation(mPresentationFS->getOutputStream(), oox::getRelationship(Relationship::VBAPROJECT), "vbaProject.bin");
+    addRelation(mPresentationFS->getOutputStream(), oox::getRelationship(Relationship::VBAPROJECT), u"vbaProject.bin");
 }
 
 void PowerPointExport::ImplWriteSlide(sal_uInt32 nPageNum, sal_uInt32 nMasterNum, sal_uInt16 /* nMode */,
@@ -1084,25 +1178,20 @@ void PowerPointExport::ImplWriteSlide(sal_uInt32 nPageNum, sal_uInt32 nMasterNum
     // add explicit relation of presentation to this slide
     OUString sRelId = addRelation(mPresentationFS->getOutputStream(),
                                   oox::getRelationship(Relationship::SLIDE),
-                                  OUStringBuffer()
-                                  .append("slides/slide")
-                                  .append(static_cast<sal_Int32>(nPageNum) + 1)
-                                  .append(".xml")
-                                  .makeStringAndClear());
+                                  OUString("slides/slide" + OUString::number(nPageNum + 1) +".xml"));
 
     mPresentationFS->singleElementNS(XML_p, XML_sldId,
                                      XML_id, OString::number(GetNewSlideId()),
                                      FSNS(XML_r, XML_id), sRelId);
 
+    maRelId.push_back(sRelId);
+
     if (nPageNum == mnPages - 1)
         mPresentationFS->endElementNS(XML_p, XML_sldIdLst);
 
-    FSHelperPtr pFS = openFragmentStreamWithSerializer(OUStringBuffer()
-                      .append("ppt/slides/slide")
-                      .append(static_cast<sal_Int32>(nPageNum) + 1)
-                      .append(".xml")
-                      .makeStringAndClear(),
-                      "application/vnd.openxmlformats-officedocument.presentationml.slide+xml");
+    FSHelperPtr pFS = openFragmentStreamWithSerializer(
+                        "ppt/slides/slide" + OUString::number(nPageNum + 1) + ".xml",
+                        "application/vnd.openxmlformats-officedocument.presentationml.slide+xml");
 
     if (mpSlidesFSArray.size() < mnPages)
         mpSlidesFSArray.resize(mnPages);
@@ -1139,21 +1228,15 @@ void PowerPointExport::ImplWriteSlide(sal_uInt32 nPageNum, sal_uInt32 nMasterNum
     // add implicit relation to slide layout
     addRelation(pFS->getOutputStream(),
                 oox::getRelationship(Relationship::SLIDELAYOUT),
-                OUStringBuffer()
-                .append("../slideLayouts/slideLayout")
-                .append(GetLayoutFileId(GetPPTXLayoutId(GetLayoutOffset(mXPagePropSet)), nMasterNum))
-                .append(".xml")
-                .makeStringAndClear());
+                OUString("../slideLayouts/slideLayout" +
+                    OUString::number(GetLayoutFileId(GetPPTXLayoutId(GetLayoutOffset(mXPagePropSet)), nMasterNum)) +
+                    ".xml"));
 
     if (WriteComments(nPageNum))
         // add implicit relation to slide comments
         addRelation(pFS->getOutputStream(),
                     oox::getRelationship(Relationship::COMMENTS),
-                    OUStringBuffer()
-                    .append("../comments/comment")
-                    .append(static_cast<sal_Int32>(nPageNum) + 1)
-                    .append(".xml")
-                    .makeStringAndClear());
+                    OUString("../comments/comment" + OUString::number(nPageNum + 1) + ".xml"));
 
     SAL_INFO("sd.eppt", "----------------");
 }
@@ -1165,12 +1248,11 @@ void PowerPointExport::ImplWriteNotes(sal_uInt32 nPageNum)
 
     SAL_INFO("sd.eppt", "write Notes " << nPageNum << "\n----------------");
 
-    FSHelperPtr pFS = openFragmentStreamWithSerializer(OUStringBuffer()
-                      .append("ppt/notesSlides/notesSlide")
-                      .append(static_cast<sal_Int32>(nPageNum) + 1)
-                      .append(".xml")
-                      .makeStringAndClear(),
-                      "application/vnd.openxmlformats-officedocument.presentationml.notesSlide+xml");
+    FSHelperPtr pFS = openFragmentStreamWithSerializer(
+                        "ppt/notesSlides/notesSlide" +
+                        OUString::number(nPageNum + 1) +
+                        ".xml",
+                        "application/vnd.openxmlformats-officedocument.presentationml.notesSlide+xml");
 
     pFS->startElementNS(XML_p, XML_notes, PNMSS);
 
@@ -1185,26 +1267,18 @@ void PowerPointExport::ImplWriteNotes(sal_uInt32 nPageNum)
     // add implicit relation to slide
     addRelation(pFS->getOutputStream(),
                 oox::getRelationship(Relationship::SLIDE),
-                OUStringBuffer()
-                .append("../slides/slide")
-                .append(static_cast<sal_Int32>(nPageNum) + 1)
-                .append(".xml")
-                .makeStringAndClear());
+                OUString("../slides/slide" + OUString::number(nPageNum + 1) + ".xml"));
 
     // add slide implicit relation to notes
     if (nPageNum < mpSlidesFSArray.size())
         addRelation(mpSlidesFSArray[ nPageNum ]->getOutputStream(),
                     oox::getRelationship(Relationship::NOTESSLIDE),
-                    OUStringBuffer()
-                    .append("../notesSlides/notesSlide")
-                    .append(static_cast<sal_Int32>(nPageNum) + 1)
-                    .append(".xml")
-                    .makeStringAndClear());
+                    OUString("../notesSlides/notesSlide" + OUString::number(nPageNum + 1) + ".xml"));
 
     // add implicit relation to notes master
     addRelation(pFS->getOutputStream(),
                 oox::getRelationship(Relationship::NOTESMASTER),
-                "../notesMasters/notesMaster1.xml");
+                u"../notesMasters/notesMaster1.xml");
 
     SAL_INFO("sd.eppt", "-----------------");
 }
@@ -1214,11 +1288,7 @@ void PowerPointExport::AddLayoutIdAndRelation(const FSHelperPtr& pFS, sal_Int32
     // add implicit relation of slide master to slide layout
     OUString sRelId = addRelation(pFS->getOutputStream(),
                                   oox::getRelationship(Relationship::SLIDELAYOUT),
-                                  OUStringBuffer()
-                                  .append("../slideLayouts/slideLayout")
-                                  .append(nLayoutFileId)
-                                  .append(".xml")
-                                  .makeStringAndClear());
+                                  OUString("../slideLayouts/slideLayout" + OUString::number(nLayoutFileId) + ".xml"));
 
     pFS->singleElementNS(XML_p, XML_sldLayoutId,
                          XML_id, OString::number(GetNewSlideMasterId()),
@@ -1235,11 +1305,7 @@ void PowerPointExport::ImplWriteSlideMaster(sal_uInt32 nPageNum, Reference< XPro
 
     OUString sRelId = addRelation(mPresentationFS->getOutputStream(),
                                   oox::getRelationship(Relationship::SLIDEMASTER),
-                                  OUStringBuffer()
-                                  .append("slideMasters/slideMaster")
-                                  .append(static_cast<sal_Int32>(nPageNum) + 1)
-                                  .append(".xml")
-                                  .makeStringAndClear());
+                                  OUString("slideMasters/slideMaster" + OUString::number(nPageNum + 1) + ".xml"));
 
     mPresentationFS->singleElementNS(XML_p, XML_sldMasterId,
                                      XML_id, OString::number(GetNewSlideMasterId()),
@@ -1249,11 +1315,8 @@ void PowerPointExport::ImplWriteSlideMaster(sal_uInt32 nPageNum, Reference< XPro
         mPresentationFS->endElementNS(XML_p, XML_sldMasterIdLst);
 
     FSHelperPtr pFS =
-        openFragmentStreamWithSerializer(OUStringBuffer()
-                                         .append("ppt/slideMasters/slideMaster")
-                                         .append(static_cast<sal_Int32>(nPageNum) + 1)
-                                         .append(".xml")
-                                         .makeStringAndClear(),
+        openFragmentStreamWithSerializer("ppt/slideMasters/slideMaster" +
+                                          OUString::number(nPageNum + 1) + ".xml",
                                          "application/vnd.openxmlformats-officedocument.presentationml.slideMaster+xml");
 
     // write theme per master
@@ -1262,11 +1325,7 @@ void PowerPointExport::ImplWriteSlideMaster(sal_uInt32 nPageNum, Reference< XPro
     // add implicit relation to the presentation theme
     addRelation(pFS->getOutputStream(),
                 oox::getRelationship(Relationship::THEME),
-                OUStringBuffer()
-                .append("../theme/theme")
-                .append(static_cast<sal_Int32>(nPageNum) + 1)
-                .append(".xml")
-                .makeStringAndClear());
+                OUString("../theme/theme" + OUString::number(nPageNum + 1) + ".xml"));
 
     pFS->startElementNS(XML_p, XML_sldMaster, PNMSS);
 
@@ -1356,21 +1415,14 @@ void PowerPointExport::ImplWritePPTXLayout(sal_Int32 nOffset, sal_uInt32 nMaster
         return;
 
     FSHelperPtr pFS
-        = openFragmentStreamWithSerializer(OUStringBuffer()
-                                           .append("ppt/slideLayouts/slideLayout")
-                                           .append(mnLayoutFileIdMax)
-                                           .append(".xml")
-                                           .makeStringAndClear(),
+        = openFragmentStreamWithSerializer("ppt/slideLayouts/slideLayout" +
+                                            OUString::number(mnLayoutFileIdMax) + ".xml",
                                            "application/vnd.openxmlformats-officedocument.presentationml.slideLayout+xml");
 
     // add implicit relation of slide layout to slide master
     addRelation(pFS->getOutputStream(),
                 oox::getRelationship(Relationship::SLIDEMASTER),
-                OUStringBuffer()
-                .append("../slideMasters/slideMaster")
-                .append(static_cast<sal_Int32>(nMasterNum) + 1)
-                .append(".xml")
-                .makeStringAndClear());
+                OUString("../slideMasters/slideMaster" + OUString::number(nMasterNum + 1) + ".xml"));
 
     pFS->startElementNS(XML_p, XML_sldLayout,
                         PNMSS,
@@ -1438,13 +1490,22 @@ ShapeExport& PowerPointShapeExport::WritePageShape(const Reference< XShape >& xS
 bool PowerPointShapeExport::WritePlaceholder(const Reference< XShape >& xShape, PlaceholderType ePlaceholder, bool bMaster)
 {
     SAL_INFO("sd.eppt", "WritePlaceholder " << bMaster << " " << ShapeExport::NonEmptyText(xShape));
-    if (bMaster && ShapeExport::NonEmptyText(xShape))
+    if (!xShape)
+        return false;
+    try
     {
-        WritePlaceholderShape(xShape, ePlaceholder);
+        Reference<XPropertySet> xShapeProps(xShape, UNO_QUERY);
+        if (xShapeProps->getPropertyValue("IsPresentationObject").get<bool>())
+        {
+            WritePlaceholderShape(xShape, ePlaceholder);
 
-        return true;
+            return true;
+        }
+    }
+    catch (Exception&)
+    {
+        return false;
     }
-
     return false;
 }
 
@@ -1494,8 +1555,15 @@ ShapeExport& PowerPointShapeExport::WritePlaceholderShape(const Reference< XShap
     default:
         SAL_INFO("sd.eppt", "warning: unhandled placeholder type: " << ePlaceholder);
     }
+
     SAL_INFO("sd.eppt", "write placeholder " << pType);
-    mpFS->singleElementNS(XML_p, XML_ph, XML_type, pType);
+
+    if ((mePageType == PageType::LAYOUT || mePageType == PageType::NORMAL)
+        && ePlaceholder == Outliner)
+        mpFS->singleElementNS(XML_p, XML_ph);
+    else
+        mpFS->singleElementNS(XML_p, XML_ph, XML_type, pType);
+
     mpFS->endElementNS(XML_p, XML_nvPr);
     mpFS->endElementNS(XML_p, XML_nvSpPr);
 
@@ -1505,7 +1573,25 @@ ShapeExport& PowerPointShapeExport::WritePlaceholderShape(const Reference< XShap
     WritePresetShape("rect");
     Reference< XPropertySet > xProps(xShape, UNO_QUERY);
     if (xProps.is())
+    {
         WriteBlipFill(xProps, "Graphic");
+        // Do not forget to export the visible properties.
+        WriteFill( xProps );
+        WriteOutline( xProps );
+        WriteShapeEffects( xProps );
+
+        bool bHas3DEffectinShape = false;
+        uno::Sequence<beans::PropertyValue> grabBag;
+        if (xProps->getPropertySetInfo()->hasPropertyByName("InteropGrabBag"))
+            xProps->getPropertyValue("InteropGrabBag") >>= grabBag;
+
+        for (auto const& it : std::as_const(grabBag))
+            if (it.Name == "3DEffectProperties")
+                bHas3DEffectinShape = true;
+
+        if( bHas3DEffectinShape)
+            WriteShape3DEffects( xProps );
+    }
     mpFS->endElementNS(XML_p, XML_spPr);
 
     WriteTextBox(xShape, XML_p);
@@ -1745,20 +1831,12 @@ void PowerPointExport::WriteDefaultColorSchemes(const FSHelperPtr& pFS)
             break;
         }
 
-        OUString sOpenColorScheme = OUStringBuffer()
-            .append("<a:")
-            .append(sName)
-            .append(">")
-            .makeStringAndClear();
+        OUString sOpenColorScheme = "<a:" + sName + ">";
         pFS->write(sOpenColorScheme);
 
         pFS->singleElementNS(XML_a, XML_srgbClr, XML_val, I32SHEX(nColor));
 
-        OUString sCloseColorScheme = OUStringBuffer()
-            .append("</a:")
-            .append(sName)
-            .append(">")
-            .makeStringAndClear();
+        OUString sCloseColorScheme = "</a:" + sName + ">";
         pFS->write(sCloseColorScheme);
     }
 }
@@ -1772,7 +1850,7 @@ bool PowerPointExport::WriteColorSchemes(const FSHelperPtr& pFS, const OUString&
         {
             uno::Reference<beans::XPropertySetInfo> xPropsInfo = xDocProps->getPropertySetInfo();
 
-            const OUString aGrabBagPropName = "InteropGrabBag";
+            static const OUStringLiteral aGrabBagPropName = u"InteropGrabBag";
             if (xPropsInfo.is() && xPropsInfo->hasPropertyByName(aGrabBagPropName))
             {
                 comphelper::SequenceAsHashMap aGrabBag(xDocProps->getPropertyValue(aGrabBagPropName));
@@ -1798,20 +1876,12 @@ bool PowerPointExport::WriteColorSchemes(const FSHelperPtr& pFS, const OUString&
                         }
                     }
 
-                    OUString sOpenColorScheme = OUStringBuffer()
-                        .append("<a:")
-                        .append(sName)
-                        .append(">")
-                        .makeStringAndClear();
+                    OUString sOpenColorScheme ="<a:" + sName + ">";
                     pFS->write(sOpenColorScheme);
 
                     pFS->singleElementNS(XML_a, XML_srgbClr, XML_val, I32SHEX(nColor));
 
-                    OUString sCloseColorScheme = OUStringBuffer()
-                        .append("</a:")
-                        .append(sName)
-                        .append(">")
-                        .makeStringAndClear();
+                    OUString sCloseColorScheme = "</a:" + sName + ">";
                     pFS->write(sCloseColorScheme);
                 }
 
@@ -1830,11 +1900,7 @@ bool PowerPointExport::WriteColorSchemes(const FSHelperPtr& pFS, const OUString&
 
 void PowerPointExport::WriteTheme(sal_Int32 nThemeNum)
 {
-    OUString sThemePath = OUStringBuffer()
-        .append("ppt/theme/theme")
-        .append(nThemeNum + 1)
-        .append(".xml")
-        .makeStringAndClear();
+    OUString sThemePath = "ppt/theme/theme" + OUString::number(nThemeNum + 1) + ".xml";
 
     FSHelperPtr pFS = openFragmentStreamWithSerializer(sThemePath,
                       "application/vnd.openxmlformats-officedocument.theme+xml");
@@ -1894,7 +1960,7 @@ void PowerPointExport::WriteNotesMaster()
 
     OUString sRelId = addRelation(mPresentationFS->getOutputStream(),
                                   oox::getRelationship(Relationship::NOTESMASTER),
-                                  "notesMasters/notesMaster1.xml");
+                                  u"notesMasters/notesMaster1.xml");
 
     mPresentationFS->singleElementNS(XML_p, XML_notesMasterId,
                                      FSNS(XML_r, XML_id), sRelId);
@@ -1910,11 +1976,7 @@ void PowerPointExport::WriteNotesMaster()
     // add implicit relation to the presentation theme
     addRelation(pFS->getOutputStream(),
                 oox::getRelationship(Relationship::THEME),
-                OUStringBuffer()
-                .append("../theme/theme")
-                .append(static_cast<sal_Int32>(mnMasterPages) + 1)
-                .append(".xml")
-                .makeStringAndClear());
+                OUString("../theme/theme" + OUString::number(mnMasterPages + 1) + ".xml"));
 
     pFS->startElementNS(XML_p, XML_notesMaster, PNMSS);
 
