@@ -40,20 +40,21 @@
 #include <sfx2/viewfrm.hxx>
 #include <tools/debug.hxx>
 #include "STLPropertySet.hxx"
-#include "CustomAnimationPane.hxx"
+#include <CustomAnimationPane.hxx>
 #include "CustomAnimationDialog.hxx"
-#include "CustomAnimationList.hxx"
+#include <CustomAnimationList.hxx>
 #include "motionpathtag.hxx"
 #include <CustomAnimationPreset.hxx>
-#include <createcustomanimationpanel.hxx>
 
 #include <comphelper/lok.hxx>
 #include <comphelper/sequence.hxx>
 #include <sfx2/frame.hxx>
 #include <sfx2/sidebar/Theme.hxx>
+#include <tools/diagnose_ex.h>
 
 #include <svx/unoapi.hxx>
 #include <svx/svxids.hrc>
+#include <svx/colorwindow.hxx>
 #include <DrawDocShell.hxx>
 #include <ViewShellBase.hxx>
 #include <DrawViewShell.hxx>
@@ -117,9 +118,8 @@ void fillRepeatComboBox(weld::ComboBox& rBox)
     rBox.append_text(aEndOfSlide);
 }
 
-CustomAnimationPane::CustomAnimationPane( Window* pParent, ViewShellBase& rBase,
-                                          const css::uno::Reference<css::frame::XFrame>& rxFrame )
-    : PanelLayout(pParent, "CustomAnimationsPanel", "modules/simpress/ui/customanimationspanel.ui", rxFrame)
+CustomAnimationPane::CustomAnimationPane( weld::Widget* pParent, ViewShellBase& rBase )
+    : PanelLayout(pParent, "CustomAnimationsPanel", "modules/simpress/ui/customanimationspanel.ui")
     , mrBase(rBase)
     // load resources
     , mxFTAnimation(m_xBuilder->weld_label("effectlabel"))
@@ -154,13 +154,18 @@ CustomAnimationPane::CustomAnimationPane( Window* pParent, ViewShellBase& rBase,
     , maLateInitTimer()
 {
     initialize();
-    m_pInitialFocusWidget = &mxCustomAnimationList->get_widget();
+}
+
+css::ui::LayoutSize CustomAnimationPane::GetHeightForWidth(const sal_Int32 /*nWidth*/)
+{
+    sal_Int32 nMinimumHeight = get_preferred_size().Height();
+    return css::ui::LayoutSize(nMinimumHeight, -1, nMinimumHeight);
 }
 
 void CustomAnimationPane::initialize()
 {
     mxLBAnimation->connect_changed(LINK(this, CustomAnimationPane, AnimationSelectHdl));
-    mxCustomAnimationList->setController( dynamic_cast<ICustomAnimationListController*> ( this ) );
+    mxCustomAnimationList->setController( static_cast<ICustomAnimationListController*> ( this ) );
     mxCustomAnimationList->set_size_request(mxCustomAnimationList->get_approximate_digit_width() * 15,
                                             mxCustomAnimationList->get_height_rows(8));
 
@@ -177,7 +182,7 @@ void CustomAnimationPane::initialize()
     mxPBMoveUp->connect_clicked( LINK( this, CustomAnimationPane, implClickHdl ) );
     mxPBMoveDown->connect_clicked( LINK( this, CustomAnimationPane, implClickHdl ) );
     mxPBPlay->connect_clicked( LINK( this, CustomAnimationPane, implClickHdl ) );
-    mxCBAutoPreview->connect_clicked( LINK( this, CustomAnimationPane, implClickHdl ) );
+    mxCBAutoPreview->connect_toggled( LINK( this, CustomAnimationPane, implToggleHdl ) );
     mxLBCategory->connect_changed( LINK(this, CustomAnimationPane, UpdateAnimationLB) );
     mxMFStartDelay->connect_value_changed( LINK(this, CustomAnimationPane, DelayModifiedHdl) );
     mxMFStartDelay->connect_focus_out(LINK( this, CustomAnimationPane, DelayLoseFocusHdl));
@@ -195,11 +200,9 @@ void CustomAnimationPane::initialize()
     }
     catch( Exception& )
     {
-        OSL_FAIL( "sd::CustomAnimationPane::CustomAnimationPane(), Exception caught!" );
+        TOOLS_WARN_EXCEPTION( "sd", "sd::CustomAnimationPane::CustomAnimationPane()" );
     }
 
-    // tdf#137637 keep user selection during initialization
-    ScopeLockGuard aGuard(maSelectionLock);
     // get current page and update custom animation list
     onChangeCurrentPage();
 
@@ -208,15 +211,9 @@ void CustomAnimationPane::initialize()
     maLateInitTimer.SetTimeout(100);
     maLateInitTimer.SetInvokeHandler(LINK(this, CustomAnimationPane, lateInitCallback));
     maLateInitTimer.Start();
-    UpdateLook();
 }
 
 CustomAnimationPane::~CustomAnimationPane()
-{
-    disposeOnce();
-}
-
-void CustomAnimationPane::dispose()
 {
     maLateInitTimer.Stop();
 
@@ -249,8 +246,6 @@ void CustomAnimationPane::dispose()
     mxLBCategory.reset();
     mxFTAnimation.reset();
     mxLBAnimation.reset();
-
-    PanelLayout::dispose();
 }
 
 void CustomAnimationPane::addUndo()
@@ -264,20 +259,6 @@ void CustomAnimationPane::addUndo()
     }
 }
 
-void CustomAnimationPane::StateChanged( StateChangedType nStateChange )
-{
-    Control::StateChanged( nStateChange );
-
-    if( nStateChange == StateChangedType::Visible )
-        updateMotionPathTags();
-}
-
-void CustomAnimationPane::KeyInput( const KeyEvent& rKEvt )
-{
-    if (mxCustomAnimationList)
-        mxCustomAnimationList->KeyInputHdl(rKEvt);
-}
-
 void CustomAnimationPane::addListener()
 {
     Link<tools::EventMultiplexerEvent&,void> aLink( LINK(this,CustomAnimationPane,EventMultiplexerListener) );
@@ -337,63 +318,63 @@ IMPL_LINK(CustomAnimationPane,EventMultiplexerListener,
     }
 }
 
-static sal_Int32 getPropertyType( const OUString& rProperty )
+static sal_Int32 getPropertyType( std::u16string_view rProperty )
 {
-    if ( rProperty == "Direction" )
+    if ( rProperty == u"Direction" )
         return nPropertyTypeDirection;
 
-    if ( rProperty == "Spokes" )
+    if ( rProperty == u"Spokes" )
         return nPropertyTypeSpokes;
 
-    if ( rProperty == "Zoom" )
+    if ( rProperty == u"Zoom" )
         return nPropertyTypeZoom;
 
-    if ( rProperty == "Accelerate" )
+    if ( rProperty == u"Accelerate" )
         return nPropertyTypeAccelerate;
 
-    if ( rProperty == "Decelerate" )
+    if ( rProperty == u"Decelerate" )
         return nPropertyTypeDecelerate;
 
-    if ( rProperty == "Color1" )
+    if ( rProperty == u"Color1" )
         return nPropertyTypeFirstColor;
 
-    if ( rProperty == "Color2" )
+    if ( rProperty == u"Color2" )
         return nPropertyTypeSecondColor;
 
-    if ( rProperty == "FillColor" )
+    if ( rProperty == u"FillColor" )
         return nPropertyTypeFillColor;
 
-    if ( rProperty == "ColorStyle" )
+    if ( rProperty == u"ColorStyle" )
         return nPropertyTypeColorStyle;
 
-    if ( rProperty == "AutoReverse" )
+    if ( rProperty == u"AutoReverse" )
         return nPropertyTypeAutoReverse;
 
-    if ( rProperty == "FontStyle" )
+    if ( rProperty == u"FontStyle" )
         return nPropertyTypeFont;
 
-    if ( rProperty == "CharColor" )
+    if ( rProperty == u"CharColor" )
         return nPropertyTypeCharColor;
 
-    if ( rProperty == "CharHeight" )
+    if ( rProperty == u"CharHeight" )
         return nPropertyTypeCharHeight;
 
-    if ( rProperty == "CharDecoration" )
+    if ( rProperty == u"CharDecoration" )
         return nPropertyTypeCharDecoration;
 
-    if ( rProperty == "LineColor" )
+    if ( rProperty == u"LineColor" )
         return nPropertyTypeLineColor;
 
-    if ( rProperty == "Rotate" )
+    if ( rProperty == u"Rotate" )
         return nPropertyTypeRotate;
 
-    if ( rProperty == "Transparency" )
+    if ( rProperty == u"Transparency" )
         return nPropertyTypeTransparency;
 
-    if ( rProperty == "Color" )
+    if ( rProperty == u"Color" )
         return nPropertyTypeColor;
 
-    if ( rProperty == "Scale" )
+    if ( rProperty == u"Scale" )
         return nPropertyTypeScale;
 
     return nPropertyTypeNone;
@@ -808,7 +789,7 @@ void CustomAnimationPane::updateMotionPathTags()
             pView = xViewShell->GetView();
     }
 
-    if( IsVisible() && mpMainSequence && pView )
+    if (mpMainSequence && pView)
     {
         bChanges = updateMotionPathImpl( *this, *pView, mpMainSequence->getBegin(), mpMainSequence->getEnd(), aTags, maMotionPathTags );
 
@@ -848,7 +829,7 @@ void CustomAnimationPane::onSelectionChanged()
     }
     catch( Exception& )
     {
-        OSL_FAIL( "sd::CustomAnimationPane::onSelectionChanged(), Exception caught!" );
+        TOOLS_WARN_EXCEPTION( "sd", "sd::CustomAnimationPane::onSelectionChanged()" );
     }
 }
 
@@ -876,19 +857,6 @@ void CustomAnimationPane::onContextMenu(const OString &rIdent)
     updateControls();
 }
 
-void CustomAnimationPane::DataChanged (const DataChangedEvent&)
-{
-    UpdateLook();
-}
-
-void CustomAnimationPane::UpdateLook()
-{
-    Color aBackground (
-        ::sfx2::sidebar::Theme::GetColor(
-            ::sfx2::sidebar::Theme::Color_PanelBackground));
-    SetBackground(aBackground);
-}
-
 static void addValue( const std::unique_ptr<STLPropertySet>& pSet, sal_Int32 nHandle, const Any& rValue )
 {
     switch( pSet->getPropertyState( nHandle ) )
@@ -959,11 +927,11 @@ Any CustomAnimationPane::getProperty1Value( sal_Int32 nType, const CustomAnimati
         }
 
     case nPropertyTypeFont:
-        return pEffect->getProperty( AnimationNodeType::SET, "CharFontName" , EValue::To );
+        return pEffect->getProperty( AnimationNodeType::SET, u"CharFontName" , EValue::To );
 
     case nPropertyTypeCharHeight:
         {
-            const OUString aAttributeName( "CharHeight" );
+            static const OUStringLiteral aAttributeName( u"CharHeight" );
             Any aValue( pEffect->getProperty( AnimationNodeType::SET, aAttributeName, EValue::To ) );
             if( !aValue.hasValue() )
                 aValue = pEffect->getProperty( AnimationNodeType::ANIMATE, aAttributeName, EValue::To );
@@ -974,7 +942,7 @@ Any CustomAnimationPane::getProperty1Value( sal_Int32 nType, const CustomAnimati
         return pEffect->getTransformationProperty( AnimationTransformType::ROTATE, EValue::By);
 
     case nPropertyTypeTransparency:
-        return pEffect->getProperty( AnimationNodeType::SET, "Opacity" , EValue::To );
+        return pEffect->getProperty( AnimationNodeType::SET, u"Opacity" , EValue::To );
 
     case nPropertyTypeScale:
         return pEffect->getTransformationProperty( AnimationTransformType::SCALE, EValue::By );
@@ -982,9 +950,9 @@ Any CustomAnimationPane::getProperty1Value( sal_Int32 nType, const CustomAnimati
     case nPropertyTypeCharDecoration:
         {
             Sequence< Any > aValues(3);
-            aValues[0] = pEffect->getProperty( AnimationNodeType::SET, "CharWeight" , EValue::To );
-            aValues[1] = pEffect->getProperty( AnimationNodeType::SET, "CharPosture" , EValue::To );
-            aValues[2] = pEffect->getProperty( AnimationNodeType::SET, "CharUnderline" , EValue::To );
+            aValues[0] = pEffect->getProperty( AnimationNodeType::SET, u"CharWeight" , EValue::To );
+            aValues[1] = pEffect->getProperty( AnimationNodeType::SET, u"CharPosture" , EValue::To );
+            aValues[2] = pEffect->getProperty( AnimationNodeType::SET, u"CharUnderline" , EValue::To );
             return makeAny( aValues );
         }
     }
@@ -1030,12 +998,12 @@ bool CustomAnimationPane::setProperty1Value( sal_Int32 nType, const CustomAnimat
         break;
 
     case nPropertyTypeFont:
-        bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, "CharFontName" , EValue::To, rValue );
+        bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, u"CharFontName" , EValue::To, rValue );
         break;
 
     case nPropertyTypeCharHeight:
         {
-            const OUString aAttributeName( "CharHeight" );
+            static const OUStringLiteral aAttributeName( u"CharHeight" );
             bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, aAttributeName, EValue::To, rValue );
             if( !bEffectChanged )
                 bEffectChanged = pEffect->setProperty( AnimationNodeType::ANIMATE, aAttributeName, EValue::To, rValue );
@@ -1046,7 +1014,7 @@ bool CustomAnimationPane::setProperty1Value( sal_Int32 nType, const CustomAnimat
         break;
 
     case nPropertyTypeTransparency:
-        bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, "Opacity" , EValue::To, rValue );
+        bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, u"Opacity" , EValue::To, rValue );
         break;
 
     case nPropertyTypeScale:
@@ -1057,9 +1025,9 @@ bool CustomAnimationPane::setProperty1Value( sal_Int32 nType, const CustomAnimat
         {
             Sequence< Any > aValues(3);
             rValue >>= aValues;
-            bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, "CharWeight" , EValue::To, aValues[0] );
-            bEffectChanged |= pEffect->setProperty( AnimationNodeType::SET, "CharPosture" , EValue::To, aValues[1] );
-            bEffectChanged |= pEffect->setProperty( AnimationNodeType::SET, "CharUnderline" , EValue::To, aValues[2] );
+            bEffectChanged = pEffect->setProperty( AnimationNodeType::SET, u"CharWeight" , EValue::To, aValues[0] );
+            bEffectChanged |= pEffect->setProperty( AnimationNodeType::SET, u"CharPosture" , EValue::To, aValues[1] );
+            bEffectChanged |= pEffect->setProperty( AnimationNodeType::SET, u"CharUnderline" , EValue::To, aValues[2] );
         }
         break;
 
@@ -1188,17 +1156,17 @@ std::unique_ptr<STLPropertySet> CustomAnimationPane::createSelectionSet()
                 addValue( pSet, nHandleProperty1Value, getProperty1Value( nType, pEffect ) );
             }
 
-            if( pDescriptor->hasProperty( "Accelerate" ) )
+            if( pDescriptor->hasProperty( u"Accelerate" ) )
             {
                 addValue( pSet, nHandleAccelerate, makeAny( pEffect->getAcceleration() ) );
             }
 
-            if( pDescriptor->hasProperty( "Decelerate" ) )
+            if( pDescriptor->hasProperty( u"Decelerate" ) )
             {
                 addValue( pSet, nHandleDecelerate, makeAny( pEffect->getDecelerate() ) );
             }
 
-            if( pDescriptor->hasProperty( "AutoReverse" ) )
+            if( pDescriptor->hasProperty( u"AutoReverse" ) )
             {
                 addValue( pSet, nHandleAutoReverse, makeAny( pEffect->getAutoReverse() ) );
             }
@@ -1662,7 +1630,7 @@ void CustomAnimationPane::onChangeCurrentPage()
     }
     catch( Exception& )
     {
-        OSL_FAIL( "sd::CustomAnimationPane::onChangeCurrentPage(), exception caught!" );
+        TOOLS_WARN_EXCEPTION( "sd", "sd::CustomAnimationPane::onChangeCurrentPage()" );
     }
 }
 
@@ -1721,7 +1689,7 @@ static bool getTextSelection( const Any& rSelection, Reference< XShape >& xShape
     }
     catch( Exception& )
     {
-        OSL_FAIL( "sd::CustomAnimationPane::getTextSelection(), exception caught!" );
+        TOOLS_WARN_EXCEPTION( "sd", "sd::CustomAnimationPane::getTextSelection()" );
     }
 
     return false;
@@ -2273,6 +2241,11 @@ sal_Int32 CustomAnimationPane::fillAnimationLB( bool bHasText )
     return nFirstEffect;
 }
 
+IMPL_LINK(CustomAnimationPane, implToggleHdl, weld::Toggleable&, rBtn, void)
+{
+    implControlHdl(&rBtn);
+}
+
 IMPL_LINK(CustomAnimationPane, implClickHdl, weld::Button&, rBtn, void)
 {
     implControlHdl(&rBtn);
@@ -2543,19 +2516,6 @@ void CustomAnimationPane::updatePathFromMotionPathTag( const rtl::Reference< Mot
     }
 }
 
-vcl::Window * createCustomAnimationPanel( vcl::Window* pParent, ViewShellBase& rBase, const css::uno::Reference<css::frame::XFrame>& rxFrame )
-{
-    vcl::Window* pWindow = nullptr;
-
-    DrawDocShell* pDocSh = rBase.GetDocShell();
-    if( pDocSh )
-    {
-        pWindow = VclPtr<CustomAnimationPane>::Create( pParent, rBase, rxFrame );
-    }
-
-    return pWindow;
-}
-
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
