@@ -45,7 +45,7 @@
 #include <svx/polypolygoneditor.hxx>
 #include <svx/svddrgmt.hxx>
 
-#include "CustomAnimationPane.hxx"
+#include <CustomAnimationPane.hxx>
 #include <View.hxx>
 #include "motionpathtag.hxx"
 #include <ViewShell.hxx>
@@ -445,7 +445,7 @@ bool MotionPathTag::MouseButtonDown( const MouseEvent& rMEvt, SmartHdl& rHdl )
         }
         else if( rMEvt.IsLeft() )
         {
-            OutputDevice* pOut = mrView.GetViewShell()->GetActiveWindow();
+            OutputDevice* pOut = mrView.GetViewShell()->GetActiveWindow()->GetOutDev();
             Point aMDPos( pOut->PixelToLogic( rMEvt.GetPosPixel() ) );
 
             if( !mrView.IsFrameDragSingles() && mrView.IsInsObjPointMode() && (rHdl.GetObjHdlNum() == SMART_TAG_HDL_NUM) )
@@ -686,7 +686,7 @@ bool MotionPathTag::OnMove( const KeyEvent& rKEvt )
 
     if(rKEvt.GetKeyCode().IsMod2())
     {
-        OutputDevice* pOut = mrView.GetViewShell()->GetActiveWindow();
+        OutputDevice* pOut = mrView.GetViewShell()->GetActiveWindow()->GetOutDev();
         Size aLogicSizeOnePixel = pOut ? pOut->PixelToLogic(Size(1,1)) : Size(100, 100);
         nX *= aLogicSizeOnePixel.Width();
         nY *= aLogicSizeOnePixel.Height();
@@ -1187,12 +1187,12 @@ Any SAL_CALL MotionPathTag::queryInterface( const css::uno::Type& aType )
     return Any();
 }
 
-void SAL_CALL MotionPathTag::acquire() throw ()
+void SAL_CALL MotionPathTag::acquire() noexcept
 {
     SimpleReferenceComponent::acquire();
 }
 
-void SAL_CALL MotionPathTag::release(  ) throw ()
+void SAL_CALL MotionPathTag::release(  ) noexcept
 {
     SimpleReferenceComponent::release();
 }
