@@ -31,16 +31,16 @@
 #include <DrawDocShell.hxx>
 #include <drawdoc.hxx>
 #include <sdpage.hxx>
-#include <sdmod.hxx>
-#include <optsitem.hxx>
 #include "PageMarginUtils.hxx"
 #include <strings.hrc>
 #include <pageformatpanel.hrc>
 #include <DrawViewShell.hxx>
+#include <svl/intitem.hxx>
 #include <svx/colorbox.hxx>
+#include <svx/dlgutil.hxx>
 #include <svx/drawitem.hxx>
+#include <svx/itemwin.hxx>
 #include <svx/pageitem.hxx>
-#include <tools/urlobj.hxx>
 #include <app.hrc>
 #include <editeng/paperinf.hxx>
 #include <svx/xflgrit.hxx>
@@ -62,10 +62,8 @@
 
 #include <editeng/sizeitem.hxx>
 #include <comphelper/lok.hxx>
-#include <LibreOfficeKit/LibreOfficeKitEnums.h>
 #include <unomodel.hxx>
 #include <sfx2/lokhelper.hxx>
-#include <boost/property_tree/ptree.hpp>
 
 using namespace ::com::sun::star;
 
@@ -88,22 +86,21 @@ enum eFillStyle
 }
 
 SlideBackground::SlideBackground(
-    Window * pParent,
+    weld::Widget* pParent,
     ViewShellBase& rBase,
     const css::uno::Reference<css::frame::XFrame>& rxFrame,
-    SfxBindings* pBindings
-     ) :
-    PanelLayout( pParent, "SlideBackgroundPanel", "modules/simpress/ui/sidebarslidebackground.ui", rxFrame ),
+    SfxBindings* pBindings) :
+    PanelLayout( pParent, "SlideBackgroundPanel", "modules/simpress/ui/sidebarslidebackground.ui" ),
     mrBase( rBase ),
     mxPaperSizeBox(new SvxPaperSizeListBox(m_xBuilder->weld_combo_box("paperformat"))),
     mxPaperOrientation(m_xBuilder->weld_combo_box("orientation")),
     mxMasterSlide(m_xBuilder->weld_combo_box("masterslide")),
     mxBackgroundLabel(m_xBuilder->weld_label("label3")),
     mxFillStyle(m_xBuilder->weld_combo_box("fillstyle")),
-    mxFillLB(new ColorListBox(m_xBuilder->weld_menu_button("fillattr"), GetFrameWeld())),
+    mxFillLB(new ColorListBox(m_xBuilder->weld_menu_button("fillattr"), [this]{ return GetFrameWeld(); })),
     mxFillAttr(m_xBuilder->weld_combo_box("fillattr1")),
-    mxFillGrad1(new ColorListBox(m_xBuilder->weld_menu_button("fillattr2"), GetFrameWeld())),
-    mxFillGrad2(new ColorListBox(m_xBuilder->weld_menu_button("fillattr3"), GetFrameWeld())),
+    mxFillGrad1(new ColorListBox(m_xBuilder->weld_menu_button("fillattr2"), [this]{ return GetFrameWeld(); })),
+    mxFillGrad2(new ColorListBox(m_xBuilder->weld_menu_button("fillattr3"), [this]{ return GetFrameWeld(); })),
     mxInsertImage(m_xBuilder->weld_button("button2")),
     mxDspMasterBackground(m_xBuilder->weld_check_button("displaymasterbackground")),
     mxDspMasterObjects(m_xBuilder->weld_check_button("displaymasterobjects")),
@@ -163,11 +160,6 @@ SlideBackground::SlideBackground(
     Initialize();
 }
 
-SlideBackground::~SlideBackground()
-{
-    disposeOnce();
-}
-
 bool SlideBackground::IsDraw()
 {
     return ( maContext == maDrawMasterContext ||
@@ -263,8 +255,8 @@ void SlideBackground::Initialize()
 
     mxFillStyle->set_active(static_cast< sal_Int32 >(NONE));
 
-    mxDspMasterBackground->connect_clicked(LINK(this, SlideBackground, DspBackground));
-    mxDspMasterObjects->connect_clicked(LINK(this,SlideBackground, DspObjects));
+    mxDspMasterBackground->connect_toggled(LINK(this, SlideBackground, DspBackground));
+    mxDspMasterObjects->connect_toggled(LINK(this, SlideBackground, DspObjects));
 
     //margins
     mxMarginSelectBox->connect_changed(LINK(this, SlideBackground, ModifyMarginHdl));
@@ -280,7 +272,7 @@ void SlideBackground::DumpAsPropertyTree(::tools::JsonWriter& rJsonWriter)
         mpBindings->Update(SID_ATTR_PAGE_SIZE);
     }
 
-    Control::DumpAsPropertyTree(rJsonWriter);
+    PanelLayout::DumpAsPropertyTree(rJsonWriter);
 }
 
 void SlideBackground::HandleContextChange(
@@ -309,6 +301,11 @@ void SlideBackground::HandleContextChange(
             mxFillStyle->hide();
             mxBackgroundLabel->hide();
             mxInsertImage->show();
+
+            mxFillLB->hide();
+            mxFillAttr->hide();
+            mxFillGrad1->hide();
+            mxFillGrad2->hide();
         }
         else if ( maContext == maImpressHandoutContext  || maContext == maImpressNotesContext )
         {
@@ -344,13 +341,15 @@ void SlideBackground::HandleContextChange(
             mxInsertImage->hide();
 
         // Need to do a relayouting, otherwise the panel size is not updated after show / hide controls
-        sfx2::sidebar::Panel* pPanel = dynamic_cast<sfx2::sidebar::Panel*>(GetParent());
-        if(pPanel)
-            pPanel->TriggerDeckLayouting();
+        if (m_pPanel)
+            m_pPanel->TriggerDeckLayouting();
+
     }
     else if ( IsDraw() )
     {
         mxMasterLabel->set_label(SdResId(STR_MASTERPAGE_LABEL));
+        mxDspMasterBackground->hide();
+        mxDspMasterObjects->hide();
 
         if (maContext == maDrawOtherContext)
         {
@@ -451,11 +450,6 @@ void SlideBackground::Update()
         default:
             break;
     }
-
-    // Need to do a relayouting, otherwise the panel size is not updated after show / hide controls
-    sfx2::sidebar::Panel* pPanel = dynamic_cast<sfx2::sidebar::Panel*>(GetParent());
-    if (pPanel)
-        pPanel->TriggerDeckLayouting();
 }
 
 void SlideBackground::UpdateMarginBox()
@@ -688,7 +682,7 @@ void SlideBackground::updateMasterSlideSelection()
     }
 }
 
-void SlideBackground::dispose()
+SlideBackground::~SlideBackground()
 {
     removeListener();
 
@@ -732,7 +726,6 @@ void SlideBackground::dispose()
     mpBitmapItem.reset();
     mpPageLRMarginItem.reset();
     mpPageULMarginItem.reset();
-    PanelLayout::dispose();
 }
 
 void SlideBackground::ExecuteMarginLRChange(const ::tools::Long mnPageLeftMargin, const ::tools::Long mnPageRightMargin)
@@ -818,11 +811,6 @@ OUString const & SlideBackground::GetPatternSetOrDefault()
     return mpBitmapItem->GetName();
 }
 
-void SlideBackground::DataChanged (const DataChangedEvent& /*rEvent*/)
-{
-
-}
-
 void SlideBackground::NotifyItemUpdate(
     const sal_uInt16 nSID,
     const SfxItemState eState,
@@ -1217,14 +1205,14 @@ IMPL_LINK_NOARG(SlideBackground, CloseMasterHdl, weld::Button&, void)
     GetBindings()->GetDispatcher()->Execute( SID_CLOSE_MASTER_VIEW, SfxCallMode::RECORD );
 }
 
-IMPL_LINK_NOARG(SlideBackground, DspBackground, weld::Button&, void)
+IMPL_LINK_NOARG(SlideBackground, DspBackground, weld::Toggleable&, void)
 {
     bool IsChecked = mxDspMasterBackground->get_active();
     const SfxBoolItem aBoolItem(SID_DISPLAY_MASTER_BACKGROUND, IsChecked);
     GetBindings()->GetDispatcher()->ExecuteList(SID_DISPLAY_MASTER_BACKGROUND, SfxCallMode::RECORD, { &aBoolItem });
 }
 
-IMPL_LINK_NOARG(SlideBackground, DspObjects, weld::Button&, void)
+IMPL_LINK_NOARG(SlideBackground, DspObjects, weld::Toggleable&, void)
 {
     bool IsChecked = mxDspMasterObjects->get_active();
     const SfxBoolItem aBoolItem(SID_DISPLAY_MASTER_OBJECTS,IsChecked);
