@@ -41,9 +41,11 @@
 #include <svx/ImageMapInfo.hxx>
 #include <unotools/streamwrap.hxx>
 #include <vcl/metaact.hxx>
+#include <vcl/TypeSerializer.hxx>
 #include <svx/svxids.hrc>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <svtools/embedhlp.hxx>
+#include <osl/diagnose.h>
 #include <DrawDocShell.hxx>
 #include <fupoor.hxx>
 #include <tablefunction.hxx>
@@ -305,7 +307,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
     // ImageMap?
     if( !pOwnData && aDataHelper.HasFormat( SotClipboardFormatId::SVIM ) )
     {
-        ::tools::SvRef<SotStorageStream> xStm;
+        ::tools::SvRef<SotTempStream> xStm;
 
         if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::SVIM, xStm ) )
         {
@@ -324,7 +326,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
         if( ( bIsRTF || aDataHelper.HasFormat( SotClipboardFormatId::RICHTEXT ) )
             && ! aDataHelper.HasFormat( SotClipboardFormatId::DRAWING ) )
         {
-            ::tools::SvRef<SotStorageStream> xStm;
+            ::tools::SvRef<SotTempStream> xStm;
 
             if( aDataHelper.GetSotStorageStream( bIsRTF ? SotClipboardFormatId::RTF : SotClipboardFormatId::RICHTEXT, xStm ) )
             {
@@ -668,7 +670,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
     if(!bReturn && CHECK_FORMAT_TRANS( SotClipboardFormatId::DRAWING ))
     {
-        ::tools::SvRef<SotStorageStream> xStm;
+        ::tools::SvRef<SotTempStream> xStm;
 
         if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::DRAWING, xStm ) )
         {
@@ -676,7 +678,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
             xShell->DoInitNew();
 
             SdDrawDocument* pModel = xShell->GetDoc();
-            pModel->InsertPage(pModel->AllocPage(false));
+            pModel->InsertPage(pModel->AllocPage(false).get());
 
             Reference< XComponent > xComponent = xShell->GetModel();
             xStm->Seek( 0 );
@@ -763,7 +765,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                                gradients (rectangles) in the gallery with corner
                                radius of 0. We should not use that on the
                                object. */
-                            aSet.ClearItem( SDRATTR_ECKENRADIUS );
+                            aSet.ClearItem( SDRATTR_CORNER_RADIUS );
 
                             const SdrGrafObj* pSdrGrafObj = dynamic_cast< const SdrGrafObj* >(pObj);
 
@@ -1193,14 +1195,15 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
     if(!bReturn && (!bLink || pPickObj) && CHECK_FORMAT_TRANS(SotClipboardFormatId::SVXB))
     {
-        ::tools::SvRef<SotStorageStream> xStm;
+        ::tools::SvRef<SotTempStream> xStm;
 
         if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::SVXB, xStm ) )
         {
             Point   aInsertPos( rPos );
             Graphic aGraphic;
 
-            ReadGraphic( *xStm, aGraphic );
+            TypeSerializer aSerializer(*xStm);
+            aSerializer.readGraphic(aGraphic);
 
             if( pOwnData && pOwnData->GetWorkDocument() )
             {
@@ -1382,7 +1385,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
     if(!bReturn && !bLink && CHECK_FORMAT_TRANS(SotClipboardFormatId::HTML))
     {
-        ::tools::SvRef<SotStorageStream> xStm;
+        ::tools::SvRef<SotTempStream> xStm;
 
         if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::HTML, xStm ) )
         {
@@ -1394,7 +1397,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
     if(!bReturn && !bLink && CHECK_FORMAT_TRANS(SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT))
     {
-        ::tools::SvRef<SotStorageStream> xStm;
+        ::tools::SvRef<SotTempStream> xStm;
         if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT, xStm ) )
         {
             OutlinerView* pOLV = GetTextEditOutlinerView();
@@ -1425,7 +1428,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
         bool bIsRTF = CHECK_FORMAT_TRANS(SotClipboardFormatId::RTF);
         if (bIsRTF || CHECK_FORMAT_TRANS(SotClipboardFormatId::RICHTEXT))
         {
-            ::tools::SvRef<SotStorageStream> xStm;
+            ::tools::SvRef<SotTempStream> xStm;
 
             if( aDataHelper.GetSotStorageStream( bIsRTF ? SotClipboardFormatId::RTF : SotClipboardFormatId::RICHTEXT, xStm ) )
             {
@@ -1523,18 +1526,18 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
     return bReturn;
 }
 
-bool View::PasteRTFTable( const ::tools::SvRef<SotStorageStream>& xStm, SdrPage* pPage, SdrInsertFlags nPasteOptions )
+bool View::PasteRTFTable( const ::tools::SvRef<SotTempStream>& xStm, SdrPage* pPage, SdrInsertFlags nPasteOptions )
 {
-    std::unique_ptr<SdDrawDocument> pModel(new SdDrawDocument( DocumentType::Impress, mpDocSh ));
-    pModel->NewOrLoadCompleted(DocCreationMode::New);
-    pModel->GetItemPool().SetDefaultMetric(MapUnit::Map100thMM);
-    pModel->InsertPage(pModel->AllocPage(false));
+    SdDrawDocument aModel( DocumentType::Impress, mpDocSh );
+    aModel.NewOrLoadCompleted(DocCreationMode::New);
+    aModel.GetItemPool().SetDefaultMetric(MapUnit::Map100thMM);
+    aModel.InsertPage(aModel.AllocPage(false).get());
 
-    Reference< XComponent > xComponent( new SdXImpressDocument( pModel.get(), true ) );
-    pModel->setUnoModel( Reference< XInterface >::query( xComponent ) );
+    Reference< XComponent > xComponent( new SdXImpressDocument( &aModel, true ) );
+    aModel.setUnoModel( Reference< XInterface >::query( xComponent ) );
 
-    CreateTableFromRTF( *xStm, pModel.get() );
-    bool bRet = Paste(*pModel, maDropPos, pPage, nPasteOptions);
+    CreateTableFromRTF( *xStm, &aModel );
+    bool bRet = Paste(aModel, maDropPos, pPage, nPasteOptions);
 
     xComponent->dispose();
     xComponent.clear();
