@@ -120,9 +120,7 @@ void OptimizerDialog::InitRoadmap()
         InsertRoadmapItem( 3, getString( STR_OLE_OBJECTS ), ITEM_ID_OLE_OPTIMIZATION );
         InsertRoadmapItem( 4, getString( STR_SUMMARY ), ITEM_ID_SUMMARY );
 
-        OUString const sURL("private:graphicrepository/" BMP_PRESENTATION_MINIMIZER);
-
-        xPropertySet->setPropertyValue( "ImageURL", Any( sURL ) );
+        xPropertySet->setPropertyValue( "ImageURL", Any( OUString("private:graphicrepository/" BMP_PRESENTATION_MINIMIZER) ) );
         xPropertySet->setPropertyValue( "Activated", Any( true ) );
         xPropertySet->setPropertyValue( "Complete", Any( true ) );
         xPropertySet->setPropertyValue( "CurrentItemID", Any( sal_Int16(ITEM_ID_INTRODUCTION) ) );
@@ -350,12 +348,12 @@ void ItemListener::itemStateChanged( const ItemEvent& Event )
     try
     {
         sal_Int16 nState;
-        OUString aControlName;
         Reference< XControl > xControl;
         Any aSource( Event.Source );
         if ( aSource >>= xControl )
         {
             Reference< XPropertySet > xPropertySet( xControl->getModel(), UNO_QUERY_THROW );
+            OUString aControlName;
             xPropertySet->getPropertyValue( "Name" ) >>= aControlName;
             PPPOptimizerTokenEnum eControl( TKGet( aControlName ) );
             switch( eControl )
