@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <string_view>
+
 #include <config_features.h>
 #include <rtl/character.hxx>
 #include <rtl/malformeduriexception.hxx>
@@ -145,10 +149,10 @@ bool ImplDdeService::MakeTopic( const OUString& rNm )
                     SfxCallMode::SYNCHRON,
                     { &aName, &aNewView, &aSilent });
 
-            if( dynamic_cast< const SfxViewFrameItem *>( pRet ) &&
-                static_cast<SfxViewFrameItem const *>(pRet)->GetFrame() &&
-                nullptr != ( pShell = static_cast<SfxViewFrameItem const *>(pRet)
-                    ->GetFrame()->GetObjectShell() ) )
+            if( auto const item = dynamic_cast< const SfxViewFrameItem *>( pRet );
+                item &&
+                item->GetFrame() &&
+                nullptr != ( pShell = item->GetFrame()->GetObjectShell() ) )
             {
                 SfxGetpApp()->AddDdeTopic( pShell );
                 bRet = true;
@@ -223,10 +227,10 @@ namespace {
     rCmd = "Open(\"d:\doc\doc.sdw\")"
     rEvent = "Open"
 */
-bool SfxAppEvent_Impl( const OUString& rCmd, const OUString& rEvent,
+bool SfxAppEvent_Impl( const OUString& rCmd, std::u16string_view rEvent,
                            ApplicationEvent::Type eType )
 {
-    OUString sEvent(rEvent + "(");
+    OUString sEvent(OUString::Concat(rEvent) + "(");
     if (rCmd.startsWithIgnoreAsciiCase(sEvent))
     {
         sal_Int32 start = sEvent.getLength();
@@ -297,11 +301,11 @@ bool SfxAppEvent_Impl( const OUString& rCmd, const OUString& rEvent,
     relevant SfxApplication subclass in BASIC syntax. Return values can
     not be transferred, unfortunately.
 */
-long SfxApplication::DdeExecute( const OUString&   rCmd )  // Expressed in our BASIC-Syntax
+bool SfxApplication::DdeExecute( const OUString&   rCmd )  // Expressed in our BASIC-Syntax
 {
     // Print or Open-Event?
-    if ( !( SfxAppEvent_Impl( rCmd, "Print", ApplicationEvent::Type::Print ) ||
-            SfxAppEvent_Impl( rCmd, "Open", ApplicationEvent::Type::Open ) ) )
+    if ( !( SfxAppEvent_Impl( rCmd, u"Print", ApplicationEvent::Type::Print ) ||
+            SfxAppEvent_Impl( rCmd, u"Open", ApplicationEvent::Type::Open ) ) )
     {
         // all others are BASIC
         StarBASIC* pBasic = GetBasic();
@@ -310,10 +314,10 @@ long SfxApplication::DdeExecute( const OUString&   rCmd )  // Expressed in our B
         if( !pRet )
         {
             SbxBase::ResetError();
-            return 0;
+            return false;
         }
     }
-    return 1;
+    return true;
 }
 
 /*  [Description]
@@ -323,7 +327,7 @@ long SfxApplication::DdeExecute( const OUString&   rCmd )  // Expressed in our B
 
     The base implementation does nothing and returns 0.
 */
-long SfxObjectShell::DdeExecute( const OUString&   rCmd )  // Expressed in our BASIC-Syntax
+bool SfxObjectShell::DdeExecute( const OUString&   rCmd )  // Expressed in our BASIC-Syntax
 {
 #if !HAVE_FEATURE_SCRIPTING
     (void) rCmd;
@@ -334,10 +338,10 @@ long SfxObjectShell::DdeExecute( const OUString&   rCmd )  // Expressed in our B
     if( !pRet )
     {
         SbxBase::ResetError();
-        return 0;
+        return false;
     }
 #endif
-    return 1;
+    return true;
 }
 
 /*  [Description]
@@ -418,7 +422,7 @@ bool SfxApplication::InitializeDde()
 
         // Config path as a topic because of multiple starts
         INetURLObject aOfficeLockFile( SvtPathOptions().GetUserConfigPath() );
-        aOfficeLockFile.insertName( "soffice.lck" );
+        aOfficeLockFile.insertName( u"soffice.lck" );
         OUString aService( SfxDdeServiceName_Impl(
                     aOfficeLockFile.GetMainURL(INetURLObject::DecodeMechanism::ToIUri) ) );
         aService = aService.toAsciiUpperCase();
@@ -537,8 +541,7 @@ bool SfxDdeDocTopic_Impl::Put( const DdeData* pData )
 
 bool SfxDdeDocTopic_Impl::Execute( const OUString* pStr )
 {
-    long nRet = pStr ? pSh->DdeExecute( *pStr ) : 0;
-    return 0 != nRet;
+    return pStr && pSh->DdeExecute( *pStr );
 }
 
 bool SfxDdeDocTopic_Impl::MakeItem( const OUString& rItem )
