@@ -485,9 +485,8 @@ SfxWorkWindow::SfxWorkWindow( vcl::Window *pWin, SfxFrame *pFrm, SfxFrame* pMast
 
     // create and initialize layout manager listener
     Reference< css::frame::XFrame > xFrame = GetFrameInterface();
-    LayoutManagerListener* pLayoutManagerListener = new LayoutManagerListener( this );
-    m_xLayoutManagerListener.set( static_cast< cppu::OWeakObject* >( pLayoutManagerListener ),
-                                  css::uno::UNO_QUERY );
+    rtl::Reference<LayoutManagerListener> pLayoutManagerListener = new LayoutManagerListener( this );
+    m_xLayoutManagerListener = pLayoutManagerListener;
     pLayoutManagerListener->setFrame( xFrame );
 
     SfxShell* pConfigShell = pFrm->GetCurrentViewFrame();
@@ -1319,9 +1318,6 @@ void SfxWorkWindow::UpdateChildWindows_Impl()
                             // The window ia within a SplitWindow
                             static_cast<SfxDockingWindow*>(pChildWin->GetWindow())->Reappear_Impl();
                     }
-
-                    if ( pCW->nInterfaceId != pChildWin->GetContextId() )
-                        pChildWin->CreateContext( pCW->nInterfaceId, GetBindings() );
                 }
             }
         }
@@ -1402,9 +1398,6 @@ void SfxWorkWindow::CreateChildWin_Impl( SfxChildWin_Impl *pCW, bool bSetFocus )
         // This happens already in the initialization of SfxDockingWindows!
     }
 
-    if ( pCW->nInterfaceId != pChildWin->GetContextId() )
-        pChildWin->CreateContext( pCW->nInterfaceId, GetBindings() );
-
     // Save the information in the INI file
     SaveStatus_Impl(pChildWin, pCW->aInfo);
 }
@@ -1755,7 +1748,6 @@ void SfxWorkWindow::ConfigChild_Impl(SfxChildIdentifier eChild,
 
 void SfxWorkWindow::SetChildWindowVisible_Impl( sal_uInt32 lId, bool bEnabled, SfxVisibilityFlags nMode )
 {
-    sal_uInt16 nInter = static_cast<sal_uInt16>( lId >> 16 );
     sal_uInt16 nId = static_cast<sal_uInt16>( lId & 0xFFFF );
 
     SfxChildWin_Impl *pCW=nullptr;
@@ -1783,8 +1775,6 @@ void SfxWorkWindow::SetChildWindowVisible_Impl( sal_uInt32 lId, bool bEnabled, S
     }
 
     pCW->nId = nId;
-    if ( nInter )
-        pCW->nInterfaceId = nInter;
     pCW->nVisibility = nMode;
     pCW->bEnable = bEnabled;
 }
