@@ -7,7 +7,6 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include <osl/file.hxx>
 #include <emojiview.hxx>
 #include <emojiviewitem.hxx>
 #include <rtl/bootstrap.hxx>
@@ -17,11 +16,13 @@
 #include <comphelper/processfactory.hxx>
 #include <vcl/event.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/weldutils.hxx>
 
 #include <orcus/json_document_tree.hpp>
 #include <orcus/config.hpp>
 #include <orcus/pstring.hpp>
 #include <string>
+#include <string_view>
 #include <fstream>
 
 using namespace ::com::sun::star;
@@ -65,12 +66,9 @@ EmojiView::EmojiView(std::unique_ptr<weld::ScrolledWindow> xWindow)
     : ThumbnailView(std::move(xWindow), nullptr)
 {
     // locate json data file
-    OUString aURL("$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER "/emojiconfig/emoji.json");
-    rtl::Bootstrap::expandMacros(aURL);
-
-    OUString aPath;
-    osl::FileBase::getSystemPathFromFileURL(aURL, aPath);
-    std::string strPath = OUStringToOString(aPath, RTL_TEXTENCODING_UTF8).getStr();
+    OUString sPath("$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER "/emojiconfig/emoji.json");
+    rtl::Bootstrap::expandMacros(sPath);
+    std::string strPath = OUStringToOString(sPath.subView(strlen("file://")), RTL_TEXTENCODING_UTF8).getStr();
 
     std::ifstream file(strPath);
     if(!file.is_open())
@@ -85,15 +83,12 @@ void EmojiView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
 {
     ThumbnailView::SetDrawingArea(pDrawingArea);
 
-    if (vcl::Window* pDefaultDevice = dynamic_cast<vcl::Window*>(Application::GetDefaultDevice()))
-    {
-        uno::Reference<uno::XComponentContext> xContext(comphelper::getProcessComponentContext());
-        OUString sFontName(officecfg::Office::Common::Misc::EmojiFont::get(xContext));
-        vcl::Font aFont = pDrawingArea->get_font();
-        aFont.SetFamilyName(sFontName);
-        OutputDevice& rDevice = pDrawingArea->get_ref_device();
-        pDefaultDevice->SetPointFont(rDevice, aFont);
-    }
+    uno::Reference<uno::XComponentContext> xContext(comphelper::getProcessComponentContext());
+    OUString sFontName(officecfg::Office::Common::Misc::EmojiFont::get(xContext));
+    vcl::Font aFont = pDrawingArea->get_font();
+    aFont.SetFamilyName(sFontName);
+    OutputDevice& rDevice = pDrawingArea->get_ref_device();
+    weld::SetPointFont(rDevice, aFont);
 
     mpItemAttrs->aFontSize.setX(ITEM_MAX_WIDTH - 2*ITEM_PADDING);
     mpItemAttrs->aFontSize.setY(ITEM_MAX_HEIGHT - 2*ITEM_PADDING);
@@ -143,15 +138,15 @@ void EmojiView::Populate()
                 // get values of parameters in AppendItem() function
                 if(emojiParam == "unicode")
                 {
-                    sTitle = OStringToOUString(OString( prop.string_value().get(), prop.string_value().size() ), RTL_TEXTENCODING_UTF8);
+                    sTitle = OStringToOUString(std::string_view( prop.string_value().get(), prop.string_value().size() ), RTL_TEXTENCODING_UTF8);
                 }
                 else if(emojiParam == "category")
                 {
-                    sCategory = OStringToOUString(OString( prop.string_value().get(), prop.string_value().size() ), RTL_TEXTENCODING_UTF8);
+                    sCategory = OStringToOUString(std::string_view( prop.string_value().get(), prop.string_value().size() ), RTL_TEXTENCODING_UTF8);
                 }
                 else if(emojiParam == "name")
                 {
-                    sName = OStringToOUString(OString( prop.string_value().get(), prop.string_value().size() ), RTL_TEXTENCODING_UTF8);
+                    sName = OStringToOUString(std::string_view( prop.string_value().get(), prop.string_value().size() ), RTL_TEXTENCODING_UTF8);
                 }
                 else if(emojiParam == "duplicate")
                 {
