@@ -24,7 +24,7 @@
 #include <tools/diagnose_ex.h>
 #include <unotools/historyoptions.hxx>
 #include <vcl/event.hxx>
-#include <vcl/pngread.hxx>
+#include <vcl/filter/PngImageReader.hxx>
 #include <vcl/ptrstyle.hxx>
 #include <vcl/svapp.hxx>
 #include <tools/stream.hxx>
@@ -138,10 +138,10 @@ RecentDocsView::RecentDocsView(std::unique_ptr<weld::ScrolledWindow> xWindow, st
     setItemMaxTextLength( 30 );
     setItemDimensions( mnItemMaxSize, mnItemMaxSize, gnTextHeight, gnItemPadding );
 
-    maFillColor = Color(officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsBackgroundColor::get());
-    maTextColor = Color(officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsTextColor::get());
-    maHighlightColor = Color(officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsHighlightColor::get());
-    maHighlightTextColor = Color(officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsHighlightTextColor::get());
+    maFillColor = Color(ColorTransparency, officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsBackgroundColor::get());
+    maTextColor = Color(ColorTransparency, officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsTextColor::get());
+    maHighlightColor = Color(ColorTransparency, officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsHighlightColor::get());
+    maHighlightTextColor = Color(ColorTransparency, officecfg::Office::Common::Help::StartCenter::StartCenterThumbnailsHighlightTextColor::get());
     mfHighlightTransparence = 0.25;
 
     UpdateColors();
@@ -158,33 +158,33 @@ RecentDocsView::~RecentDocsView()
     }
 }
 
-bool RecentDocsView::typeMatchesExtension(ApplicationType type, const OUString &rExt)
+bool RecentDocsView::typeMatchesExtension(ApplicationType type, std::u16string_view rExt)
 {
     bool bRet = false;
 
-    if (rExt == "odt" || rExt == "fodt" || rExt == "doc" || rExt == "docx" ||
-        rExt == "rtf" || rExt == "txt" || rExt == "odm" || rExt == "otm")
+    if (rExt == u"odt" || rExt == u"fodt" || rExt == u"doc" || rExt == u"docx" ||
+        rExt == u"rtf" || rExt == u"txt" || rExt == u"odm" || rExt == u"otm")
     {
         bRet = static_cast<bool>(type & ApplicationType::TYPE_WRITER);
     }
-    else if (rExt == "ods" || rExt == "fods" || rExt == "xls" || rExt == "xlsx")
+    else if (rExt == u"ods" || rExt == u"fods" || rExt == u"xls" || rExt == u"xlsx")
     {
         bRet = static_cast<bool>(type & ApplicationType::TYPE_CALC);
     }
-    else if (rExt == "odp" || rExt == "fodp" || rExt == "pps" || rExt == "ppt" ||
-            rExt == "pptx")
+    else if (rExt == u"odp" || rExt == u"fodp" || rExt == u"pps" || rExt == u"ppt" ||
+            rExt == u"pptx")
     {
         bRet = static_cast<bool>(type & ApplicationType::TYPE_IMPRESS);
     }
-    else if (rExt == "odg" || rExt == "fodg")
+    else if (rExt == u"odg" || rExt == u"fodg")
     {
         bRet = static_cast<bool>(type & ApplicationType::TYPE_DRAW);
     }
-    else if (rExt == "odb")
+    else if (rExt == u"odb")
     {
         bRet = static_cast<bool>(type & ApplicationType::TYPE_DATABASE);
     }
-    else if (rExt == "odf")
+    else if (rExt == u"odf")
     {
         bRet = static_cast<bool>(type & ApplicationType::TYPE_MATH);
     }
@@ -240,7 +240,7 @@ void RecentDocsView::Reload()
 {
     Clear();
 
-    Sequence< Sequence< PropertyValue > > aHistoryList = SvtHistoryOptions().GetList( ePICKLIST );
+    Sequence< Sequence< PropertyValue > > aHistoryList = SvtHistoryOptions().GetList( EHistoryType::PickList );
     for ( int i = 0; i < aHistoryList.getLength(); i++ )
     {
         const Sequence< PropertyValue >& rRecentEntry = aHistoryList[i];
@@ -267,8 +267,15 @@ void RecentDocsView::Reload()
                     comphelper::Base64::decode(aDecoded, aBase64);
 
                     SvMemoryStream aStream(aDecoded.getArray(), aDecoded.getLength(), StreamMode::READ);
-                    vcl::PNGReader aReader(aStream);
-                    aThumbnail = aReader.Read();
+                    vcl::PngImageReader aReader(aStream);
+                    aThumbnail = aReader.read();
+                } else
+                {
+                    INetURLObject aUrl(aURL);
+                    if (mnFileTypes & ApplicationType::TYPE_DATABASE && typeMatchesExtension(ApplicationType::TYPE_DATABASE, aUrl.getExtension()))
+                    {
+                        aThumbnail = BitmapEx(ThumbnailView::ItemHeight() > 192 ? SFX_THUMBNAIL_BASE_256 : SFX_THUMBNAIL_BASE_192);
+                    }
                 }
             }
         }
@@ -352,39 +359,39 @@ void RecentDocsView::Paint(vcl::RenderContext& rRenderContext, const tools::Rect
 {
     ThumbnailView::Paint(rRenderContext, aRect);
 
-    if (mItemList.empty())
+    if (!mItemList.empty())
+        return;
+
+    if (maWelcomeImage.IsEmpty())
     {
-        if (maWelcomeImage.IsEmpty())
-        {
-            const tools::Long aWidth(aRect.GetWidth() > aRect.getHeight() ? aRect.GetHeight()/2 : aRect.GetWidth()/2);
-            maWelcomeImage = SfxApplication::GetApplicationLogo(aWidth);
-        }
-
-        // No recent files to be shown yet. Show a welcome screen.
-        rRenderContext.Push(PushFlags::FONT | PushFlags::TEXTCOLOR);
-        SetMessageFont(rRenderContext);
-        rRenderContext.SetTextColor(maTextColor);
-
-        tools::Long nTextHeight = rRenderContext.GetTextHeight();
-
-        const Size& rImgSize = maWelcomeImage.GetSizePixel();
-        const Size& rSize = GetOutputSizePixel();
-
-        const int nX = (rSize.Width() - rImgSize.Width())/2;
-        int nY = (rSize.Height() - 3 * nTextHeight - rImgSize.Height())/2;
-        Point aImgPoint(nX, nY);
-        rRenderContext.DrawBitmapEx(aImgPoint, rImgSize, maWelcomeImage);
-
-        nY = nY + rImgSize.Height();
-        rRenderContext.DrawText(tools::Rectangle(0, nY + 1 * nTextHeight, rSize.Width(), nY + nTextHeight),
-                                maWelcomeLine1,
-                                DrawTextFlags::Center);
-        rRenderContext.DrawText(tools::Rectangle(0, nY + 2 * nTextHeight, rSize.Width(), rSize.Height()),
-                                maWelcomeLine2,
-                                DrawTextFlags::MultiLine | DrawTextFlags::WordBreak | DrawTextFlags::Center);
-
-        rRenderContext.Pop();
+        const tools::Long aWidth(aRect.GetWidth() > aRect.getHeight() ? aRect.GetHeight()/2 : aRect.GetWidth()/2);
+        maWelcomeImage = SfxApplication::GetApplicationLogo(aWidth);
     }
+
+    // No recent files to be shown yet. Show a welcome screen.
+    rRenderContext.Push(PushFlags::FONT | PushFlags::TEXTCOLOR);
+    SetMessageFont(rRenderContext);
+    rRenderContext.SetTextColor(maTextColor);
+
+    tools::Long nTextHeight = rRenderContext.GetTextHeight();
+
+    const Size& rImgSize = maWelcomeImage.GetSizePixel();
+    const Size& rSize = GetOutputSizePixel();
+
+    const int nX = (rSize.Width() - rImgSize.Width())/2;
+    int nY = (rSize.Height() - 3 * nTextHeight - rImgSize.Height())/2;
+    Point aImgPoint(nX, nY);
+    rRenderContext.DrawBitmapEx(aImgPoint, rImgSize, maWelcomeImage);
+
+    nY = nY + rImgSize.Height();
+    rRenderContext.DrawText(tools::Rectangle(0, nY + 1 * nTextHeight, rSize.Width(), nY + nTextHeight),
+                            maWelcomeLine1,
+                            DrawTextFlags::Center);
+    rRenderContext.DrawText(tools::Rectangle(0, nY + 2 * nTextHeight, rSize.Width(), rSize.Height()),
+                            maWelcomeLine2,
+                            DrawTextFlags::MultiLine | DrawTextFlags::WordBreak | DrawTextFlags::Center);
+
+    rRenderContext.Pop();
 }
 
 void RecentDocsView::LoseFocus()
