@@ -17,7 +17,6 @@
 #include <sfx2/templatelocalview.hxx>
 #include <tools/urlobj.hxx>
 #include <unotools/historyoptions.hxx>
-#include <vcl/svapp.hxx>
 #include <vcl/event.hxx>
 #include <vcl/ptrstyle.hxx>
 
@@ -90,7 +89,7 @@ RecentDocsViewItem::RecentDocsViewItem(sfx2::RecentDocsView &rView, const OUStri
 
         // create empty, and copy the default thumbnail in
         sal_uInt8 nAlpha = 255;
-        aThumbnail = BitmapEx(Bitmap(aThumbnailSize, 24), AlphaMask(aThumbnailSize, &nAlpha));
+        aThumbnail = BitmapEx(Bitmap(aThumbnailSize, vcl::PixelFormat::N24_BPP), AlphaMask(aThumbnailSize, &nAlpha));
 
         aThumbnail.CopyPixel(
                 ::tools::Rectangle(Point((aThumbnailSize.Width() - aExtSize.Width()) / 2, (aThumbnailSize.Height() - aExtSize.Height()) / 2), aExtSize),
@@ -164,7 +163,7 @@ void RecentDocsViewItem::MouseButtonUp(const MouseEvent& rMEvt)
     {
         if (getRemoveIconArea().IsInside(rMEvt.GetPosPixel()))
         {
-            SvtHistoryOptions().DeleteItem(ePICKLIST, maURL);
+            SvtHistoryOptions().DeleteItem(EHistoryType::PickList, maURL);
             mrParent.Reload();
             return;
         }
@@ -178,7 +177,6 @@ void RecentDocsViewItem::OpenDocument()
 {
     // show busy mouse pointer
     mrParentView.SetPointer(PointerStyle::Wait);
-    mrParentView.Disable();
 
     Reference<frame::XDispatch> xDispatch;
     css::util::URL aTargetURL;
