@@ -28,11 +28,10 @@
 #include <tools/diagnose_ex.h>
 #include <unotools/ucbstreamhelper.hxx>
 #include <vcl/svapp.hxx>
-#include <vcl/scrbar.hxx>
 #include <vcl/settings.hxx>
-#include <vcl/commandevent.hxx>
 #include <vcl/event.hxx>
-#include <vcl/pngread.hxx>
+#include <vcl/filter/PngImageReader.hxx>
+#include <vcl/weldutils.hxx>
 
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
@@ -140,8 +139,8 @@ BitmapEx ThumbnailView::readThumbnail(const OUString &msURL)
     {
         std::unique_ptr<SvStream> pStream (
             ::utl::UcbStreamHelper::CreateStream (xIStream));
-        vcl::PNGReader aReader (*pStream);
-        aThumbnail = aReader.Read ();
+        vcl::PngImageReader aReader (*pStream);
+        aThumbnail = aReader.read ();
     }
 
     // Note that the preview is returned without scaling it to the desired
@@ -361,7 +360,7 @@ void ThumbnailView::CalculateItemPositions(bool bScrollBarUsed)
         nScrollRatio = 0;
 
     // calculate ScrollBar width
-    tools::Long nScrBarWidth = mbAllowVScrollBar ? mxScrolledWindow->get_vscroll_width() : 0;
+    tools::Long nScrBarWidth = mbAllowVScrollBar ? mxScrolledWindow->get_scroll_thickness() : 0;
 
     // calculate maximum number of visible columns
     mnCols = static_cast<sal_uInt16>((aWinSize.Width()-nScrBarWidth) / mnItemWidth);
@@ -892,12 +891,9 @@ void ThumbnailView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
 {
     CustomWidgetController::SetDrawingArea(pDrawingArea);
 
-    if (vcl::Window* pDefaultDevice = dynamic_cast<vcl::Window*>(Application::GetDefaultDevice()))
-    {
-        OutputDevice& rDevice = pDrawingArea->get_ref_device();
-        pDefaultDevice->SetPointFont(rDevice, pDrawingArea->get_font());
-        mpItemAttrs->aFontAttr = getFontAttributeFromVclFont(mpItemAttrs->aFontSize, rDevice.GetFont(), false, true);
-    }
+    OutputDevice& rDevice = pDrawingArea->get_ref_device();
+    weld::SetPointFont(rDevice, pDrawingArea->get_font());
+    mpItemAttrs->aFontAttr = getFontAttributeFromVclFont(mpItemAttrs->aFontSize, rDevice.GetFont(), false, true);
 
     SetOutputSizePixel(pDrawingArea->get_preferred_size());
 }
