@@ -46,18 +46,14 @@ ThumbnailViewAcc::~ThumbnailViewAcc()
 {
 }
 
-namespace
-{
-    class theSfxValueSetAccUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSfxValueSetAccUnoTunnelId > {};
-}
-
 const uno::Sequence< sal_Int8 >& ThumbnailViewAcc::getUnoTunnelId()
 {
-    return theSfxValueSetAccUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theSfxValueSetAccUnoTunnelId;
+    return theSfxValueSetAccUnoTunnelId.getSeq();
 }
 
 ThumbnailViewAcc* ThumbnailViewAcc::getImplementation( const uno::Reference< uno::XInterface >& rxData )
-    throw()
+    noexcept
 {
     try
     {
@@ -177,7 +173,7 @@ uno::Reference< accessibility::XAccessibleRelationSet > SAL_CALL ThumbnailViewAc
 uno::Reference< accessibility::XAccessibleStateSet > SAL_CALL ThumbnailViewAcc::getAccessibleStateSet()
 {
     ThrowIfDisposed();
-    ::utl::AccessibleStateSetHelper* pStateSet = new ::utl::AccessibleStateSetHelper();
+    rtl::Reference<::utl::AccessibleStateSetHelper> pStateSet = new ::utl::AccessibleStateSetHelper();
 
     // Set some states.
     pStateSet->AddState (accessibility::AccessibleStateType::ENABLED);
@@ -550,18 +546,14 @@ void ThumbnailViewAcc::FireAccessibleEvent( short nEventId, const uno::Any& rOld
     }
 }
 
-namespace
-{
-    class theValueItemAccUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theValueItemAccUnoTunnelId > {};
-}
-
 const uno::Sequence< sal_Int8 >& ThumbnailViewItemAcc::getUnoTunnelId()
 {
-    return theValueItemAccUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theValueItemAccUnoTunnelId;
+    return theValueItemAccUnoTunnelId.getSeq();
 }
 
 ThumbnailViewItemAcc* ThumbnailViewItemAcc::getImplementation( const uno::Reference< uno::XInterface >& rxData )
-    throw()
+    noexcept
 {
     try
     {
@@ -694,7 +686,7 @@ uno::Reference< accessibility::XAccessibleRelationSet > SAL_CALL ThumbnailViewIt
 uno::Reference< accessibility::XAccessibleStateSet > SAL_CALL ThumbnailViewItemAcc::getAccessibleStateSet()
 {
     const SolarMutexGuard aSolarGuard;
-    ::utl::AccessibleStateSetHelper*    pStateSet = new ::utl::AccessibleStateSetHelper;
+    rtl::Reference<::utl::AccessibleStateSetHelper> pStateSet = new ::utl::AccessibleStateSetHelper;
 
     if( mpParent )
     {
