@@ -33,8 +33,6 @@
 #include <com/sun/star/task/XStatusIndicator.hpp>
 #include <com/sun/star/task/XStatusIndicatorFactory.hpp>
 #include <comphelper/processfactory.hxx>
-#include <comphelper/servicehelper.hxx>
-#include <com/sun/star/security/CertificateValidity.hpp>
 #include <com/sun/star/drawing/XDrawView.hpp>
 
 #include <com/sun/star/security/DocumentSignatureInformation.hpp>
@@ -61,6 +59,8 @@
 #include <vcl/weld.hxx>
 #include <comphelper/documentconstants.hxx>
 #include <comphelper/storagehelper.hxx>
+#include <comphelper/lok.hxx>
+#include <LibreOfficeKit/LibreOfficeKitEnums.h>
 #include <tools/link.hxx>
 
 #include <asyncfunc.hxx>
@@ -107,6 +107,8 @@
 
 #include <autoredactdialog.hxx>
 
+#include <boost/property_tree/json_parser.hpp>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::uno;
@@ -202,7 +204,7 @@ bool SfxInstanceCloseGuard_Impl::Init_Impl( const uno::Reference< util::XCloseab
         try
         {
             m_xPreventer = new SfxClosePreventer_Impl();
-            xCloseable->addCloseListener( m_xPreventer.get() );
+            xCloseable->addCloseListener( m_xPreventer );
             m_xCloseable = xCloseable;
             bResult = true;
         }
@@ -222,7 +224,7 @@ SfxInstanceCloseGuard_Impl::~SfxInstanceCloseGuard_Impl()
 
     try
     {
-        m_xCloseable->removeCloseListener( m_xPreventer.get() );
+        m_xCloseable->removeCloseListener( m_xPreventer );
     }
     catch( uno::Exception& )
     {
@@ -328,11 +330,11 @@ void SfxObjectShell::CheckOut( )
 
         // Remove the info bar
         SfxViewFrame* pViewFrame = GetFrame();
-        pViewFrame->RemoveInfoBar( "checkout" );
+        pViewFrame->RemoveInfoBar( u"checkout" );
     }
     catch ( const uno::RuntimeException& e )
     {
-        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetWindow().GetFrameWeld(),
+        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetFrameWeld(),
                                                   VclMessageType::Warning, VclButtonsType::Ok, e.Message));
         xBox->run();
     }
@@ -351,7 +353,7 @@ void SfxObjectShell::CancelCheckOut( )
     }
     catch ( const uno::RuntimeException& e )
     {
-        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetWindow().GetFrameWeld(),
+        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetFrameWeld(),
                                                   VclMessageType::Warning, VclButtonsType::Ok, e.Message));
         xBox->run();
     }
@@ -363,7 +365,7 @@ void SfxObjectShell::CheckIn( )
     {
         uno::Reference< document::XCmisDocument > xCmisDoc( GetModel(), uno::UNO_QUERY_THROW );
         // Pop up dialog to ask for comment and major
-        SfxCheckinDialog checkinDlg(GetFrame()->GetWindow().GetFrameWeld());
+        SfxCheckinDialog checkinDlg(GetFrame()->GetFrameWeld());
         if (checkinDlg.run() == RET_OK)
         {
             xCmisDoc->checkIn(checkinDlg.IsMajor(), checkinDlg.GetComment());
@@ -374,7 +376,7 @@ void SfxObjectShell::CheckIn( )
     }
     catch ( const uno::RuntimeException& e )
     {
-        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetWindow().GetFrameWeld(),
+        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetFrameWeld(),
                                                   VclMessageType::Warning, VclButtonsType::Ok, e.Message));
         xBox->run();
     }
@@ -389,7 +391,7 @@ uno::Sequence< document::CmisVersion > SfxObjectShell::GetCmisVersions( ) const
     }
     catch ( const uno::RuntimeException& e )
     {
-        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetWindow().GetFrameWeld(),
+        std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetFrame()->GetFrameWeld(),
                                                   VclMessageType::Warning, VclButtonsType::Ok, e.Message));
         xBox->run();
     }
@@ -443,6 +445,27 @@ uno::Reference<security::XCertificate> SfxObjectShell::GetSignPDFCertificate() c
     return uno::Reference<security::XCertificate>(it->second, uno::UNO_QUERY);
 }
 
+static void sendErrorToLOK(ErrCode error)
+{
+    if (error.GetClass() == ErrCodeClass::NONE)
+        return;
+
+    boost::property_tree::ptree aTree;
+    aTree.put("code", error);
+    aTree.put("kind", "");
+    aTree.put("cmd", "");
+
+    std::unique_ptr<ErrorInfo> pInfo = ErrorInfo::GetErrorInfo(error);
+    OUString aErr;
+    if (ErrorStringFactory::CreateString(pInfo.get(), aErr))
+        aTree.put("message", aErr.toUtf8());
+
+    std::stringstream aStream;
+    boost::property_tree::write_json(aStream, aTree);
+
+    SfxViewShell::Current()->libreOfficeKitViewCallback(LOK_CALLBACK_ERROR, aStream.str().c_str());
+}
+
 void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 {
     weld::Window* pDialogParent = rReq.GetFrameWeld();
@@ -452,7 +475,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
         if (!pFrame)
             pFrame = SfxViewFrame::GetFirst(this);
         if (pFrame)
-            pDialogParent = pFrame->GetWindow().GetFrameWeld();
+            pDialogParent = pFrame->GetFrameWeld();
     }
 
     sal_uInt16 nId = rReq.GetSlot();
@@ -515,7 +538,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
     bool bIsPDFExport = false;
     bool bIsAutoRedact = false;
-    std::vector<std::pair<RedactionTarget*, OUString>> aRedactionTargets;
+    std::vector<std::pair<RedactionTarget, OUString>> aRedactionTargets;
     switch(nId)
     {
         case SID_VERSION:
@@ -988,8 +1011,13 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             // may be nErrorCode should be shown in future
             if ( lErr != ERRCODE_IO_ABORT )
             {
-                SfxErrorContext aEc(ERRCTX_SFX_SAVEASDOC,GetTitle());
-                ErrorHandler::HandleError(lErr, pDialogParent);
+                if (comphelper::LibreOfficeKit::isActive())
+                    sendErrorToLOK(lErr);
+                else
+                {
+                    SfxErrorContext aEc(ERRCTX_SFX_SAVEASDOC,GetTitle());
+                    ErrorHandler::HandleError(lErr, pDialogParent);
+                }
             }
 
             if (nId == SID_DIRECTEXPORTDOCASPDF &&
@@ -1084,7 +1112,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 {
                     SfxViewFrame *pFrame = GetFrame();
                     if (pFrame)
-                        pFrame->RemoveInfoBar("readonly");
+                        pFrame->RemoveInfoBar(u"readonly");
                     SetReadOnlyUI(false);
                 }
             }
@@ -1155,7 +1183,11 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
             SetModified( false );
             ErrCode lErr = GetErrorCode();
-            ErrorHandler::HandleError(lErr, pDialogParent);
+
+            if (comphelper::LibreOfficeKit::isActive())
+                sendErrorToLOK(lErr);
+            else
+                ErrorHandler::HandleError(lErr, pDialogParent);
 
             rReq.SetReturnValue( SfxBoolItem(0, true) );
             rReq.Done();
@@ -1431,12 +1463,12 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
                     }
 
                     // new info bar
-                    if ( !pFrame->HasInfoBarWithID("signature") )
+                    if ( !pFrame->HasInfoBarWithID(u"signature") )
                     {
                         if ( !sMessage.isEmpty() )
                         {
                             auto pInfoBar = pFrame->AppendInfoBar("signature", "", sMessage, aInfobarType);
-                            if (pInfoBar == nullptr || pInfoBar->IsDisposed())
+                            if (pInfoBar == nullptr || pInfoBar->isDisposed())
                                 return;
                             weld::Button& rBtn = pInfoBar->addButton();
                             rBtn.set_label(SfxResId(STR_SIGNATURE_SHOW));
@@ -1446,9 +1478,9 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
                     else // info bar exists already
                     {
                         if ( eState == SignatureState::NOSIGNATURES )
-                            pFrame->RemoveInfoBar("signature");
+                            pFrame->RemoveInfoBar(u"signature");
                         else
-                            pFrame->UpdateInfoBar("signature", "", sMessage, aInfobarType);
+                            pFrame->UpdateInfoBar(u"signature", "", sMessage, aInfobarType);
                     }
                 }
 
@@ -1700,6 +1732,7 @@ uno::Sequence< security::DocumentSignatureInformation > SfxObjectShell::GetDocum
         }
         catch( css::uno::Exception& )
         {
+            TOOLS_WARN_EXCEPTION("sfx.doc", "Failed to get document signature information");
         }
     }
 
@@ -1744,7 +1777,7 @@ bool SfxObjectShell::PrepareForSigning(weld::Window* pDialogParent)
     OUString aODFVersion(comphelper::OStorageHelper::GetODFVersionFromStorage(GetStorage()));
 
     if ( IsModified() || !GetMedium() || GetMedium()->GetName().isEmpty()
-      || (GetMedium()->GetFilter()->IsOwnFormat() && aODFVersion.compareTo(ODFVER_012_TEXT) < 0 && !bHasSign))
+      || (GetMedium()->GetFilter()->IsOwnFormat() && aODFVersion.compareTo(u"" ODFVER_012_TEXT) < 0 && !bHasSign))
     {
         // the document might need saving ( new, modified or in ODF1.1 format without signature )
 
@@ -1926,7 +1959,7 @@ bool SfxObjectShell::SignDocumentContentUsingCertificate(const Reference<XCertif
     OUString aODFVersion(comphelper::OStorageHelper::GetODFVersionFromStorage(GetStorage()));
 
     if (IsModified() || !GetMedium() || GetMedium()->GetName().isEmpty()
-      || (GetMedium()->GetFilter()->IsOwnFormat() && aODFVersion.compareTo(ODFVER_012_TEXT) < 0 && !bHasSign))
+      || (GetMedium()->GetFilter()->IsOwnFormat() && aODFVersion.compareTo(u"" ODFVER_012_TEXT) < 0 && !bHasSign))
     {
         if (nVersion >= SvtSaveOptions::ODFSVER_012)
         {
@@ -2030,14 +2063,10 @@ void SfxObjectShell::SignScriptingContent(weld::Window* pDialogParent)
     AfterSigning(bSignSuccess, true);
 }
 
-namespace
-{
-    class theSfxObjectShellUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSfxObjectShellUnoTunnelId > {};
-}
-
 const uno::Sequence<sal_Int8>& SfxObjectShell::getUnoTunnelId()
 {
-    return theSfxObjectShellUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theSfxObjectShellUnoTunnelId;
+    return theSfxObjectShellUnoTunnelId.getSeq();
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
