@@ -21,6 +21,7 @@
 #include <inettbc.hxx>
 
 #include <com/sun/star/uno/Any.h>
+#include <com/sun/star/awt/XTopWindow.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
@@ -28,7 +29,6 @@
 #include <unotools/historyoptions.hxx>
 #include <vcl/toolbox.hxx>
 #include <vcl/svapp.hxx>
-#include <toolkit/helper/vclunohelper.hxx>
 #include <osl/file.hxx>
 #include <rtl/ustring.hxx>
 
@@ -49,7 +49,7 @@ using namespace ::com::sun::star::task;
 
 SFX_IMPL_TOOLBOX_CONTROL(SfxURLToolBoxControl_Impl,SfxStringItem)
 
-SfxURLToolBoxControl_Impl::SfxURLToolBoxControl_Impl( sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox& rBox )
+SfxURLToolBoxControl_Impl::SfxURLToolBoxControl_Impl( sal_uInt16 nSlotId, ToolBoxItemId nId, ToolBox& rBox )
     : SfxToolBoxControl( nSlotId, nId, rBox )
     , m_bModified(false)
 {
@@ -71,6 +71,8 @@ public:
         : InterimItemWindow(pParent, "sfx/ui/urlbox.ui", "URLBox")
         , m_xWidget(new SvtURLBox(m_xBuilder->weld_combo_box("urlbox")))
     {
+        InitControlBase(m_xWidget->getWidget());
+
         m_xWidget->connect_key_press(LINK(this, URLBoxItemWindow, KeyInputHdl));
 
         int nWidth = GetDesktopRectPixel().GetWidth() > 800 ? 300 : 225;
@@ -88,13 +90,6 @@ public:
         InterimItemWindow::dispose();
     }
 
-    virtual void GetFocus() override
-    {
-        if (m_xWidget)
-            m_xWidget->grab_focus();
-        InterimItemWindow::GetFocus();
-    }
-
     void set_sensitive(bool bSensitive)
     {
         Enable(bSensitive);
@@ -125,7 +120,6 @@ SvtURLBox* SfxURLToolBoxControl_Impl::GetURLBox() const
 void SfxURLToolBoxControl_Impl::OpenURL( const OUString& rName ) const
 {
     OUString aName;
-    OUString aFilter;
 
     INetURLObject aObj( rName );
     if ( aObj.GetProtocol() == INetProtocol::NotValid )
@@ -156,15 +150,6 @@ void SfxURLToolBoxControl_Impl::OpenURL( const OUString& rName ) const
     aArgs[1].Name = "FileName";
     aArgs[1].Value <<= aName;
 
-    if ( !aFilter.isEmpty() )
-    {
-        aArgs.realloc( 4 );
-        aArgs[2].Name = "FilterOptions";
-        aArgs[2].Value <<= OUString();
-        aArgs[3].Name = "FilterName";
-        aArgs[3].Value <<= aFilter;
-    }
-
     SfxURLToolBoxControl_Impl::ExecuteInfo* pExecuteInfo = new SfxURLToolBoxControl_Impl::ExecuteInfo;
     pExecuteInfo->xDispatch     = xDispatch;
     pExecuteInfo->aTargetURL    = aTargetURL;
@@ -218,22 +203,23 @@ IMPL_LINK_NOARG(SfxURLToolBoxControl_Impl, OpenHdl, weld::ComboBox&, bool)
 
     Reference< XDesktop2 > xDesktop = Desktop::create( m_xContext );
     Reference< XFrame > xFrame = xDesktop->getActiveFrame();
-    if ( xFrame.is() )
-    {
-        VclPtr<vcl::Window> pWin = VCLUnoHelper::GetWindow( xFrame->getContainerWindow() );
-        if ( pWin )
-        {
-            pWin->GrabFocus();
-            pWin->ToTop( ToTopFlags::RestoreWhenMin );
-        }
-    }
+    if (!xFrame.is())
+        return true;
 
+    auto xWin = xFrame->getContainerWindow();
+    if (!xWin)
+        return true;
+    xWin->setFocus();
+    Reference<css::awt::XTopWindow> xTop(xWin, UNO_QUERY);
+    if (!xTop)
+        return true;
+    xTop->toFront();
     return true;
 }
 
 void SfxURLToolBoxControl_Impl::StateChanged
 (
-    sal_uInt16              nSID,
+    sal_uInt16          nSID,
     SfxItemState        eState,
     const SfxPoolItem*  pState
 )
@@ -257,7 +243,7 @@ void SfxURLToolBoxControl_Impl::StateChanged
         SvtURLBox* pURLBox = GetURLBox();
         pURLBox->clear();
 
-        const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > lList = SvtHistoryOptions().GetList(ePICKLIST);
+        const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > lList = SvtHistoryOptions().GetList(EHistoryType::PickList);
         for (const css::uno::Sequence< css::beans::PropertyValue >& lProps : lList)
         {
             for (const auto& rProp : lProps)
