@@ -16,10 +16,10 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include <sfx2/sidebar/ContextList.hxx>
+#include <sidebar/ContextList.hxx>
 #include <sfx2/sidebar/Context.hxx>
 
-namespace sfx2 { namespace sidebar {
+namespace sfx2::sidebar {
 
 ContextList::ContextList()
     : maEntries()
@@ -99,6 +99,6 @@ void ContextList::ToggleVisibilityForContext( const Context &rContext, const boo
         pEntry->mbIsInitiallyVisible = bVisible;
 }
 
-} } // end of namespace sfx2::sidebar
+} // end of namespace sfx2::sidebar
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
