@@ -21,31 +21,47 @@
 
 namespace sfx2::sidebar {
 
-TitleBar::TitleBar(vcl::Window* pParentWindow,
-                   const OUString& rUIXMLDescription, const OString& rID,
-                   Theme::ThemeItem eThemeItem)
-    : InterimItemWindow(pParentWindow, rUIXMLDescription, rID)
-    , mxAddonImage(m_xBuilder->weld_image("addonimage"))
-    , mxToolBox(m_xBuilder->weld_toolbar("toolbar"))
+TitleBar::TitleBar(weld::Builder& rBuilder, Theme::ThemeItem eThemeItem)
+    : mrBuilder(rBuilder)
+    , mxTitlebar(rBuilder.weld_container("titlebar"))
+    , mxAddonImage(rBuilder.weld_image("addonimage"))
+    , mxToolBox(rBuilder.weld_toolbar("toolbar"))
     , meThemeItem(eThemeItem)
 {
-    Color aBgColor = Theme::GetColor(meThemeItem);
-    m_xContainer->set_background(aBgColor);
-    mxToolBox->set_background(aBgColor);
+    SetBackground();
 
     mxToolBox->connect_clicked(LINK(this, TitleBar, SelectionHandler));
 }
 
-TitleBar::~TitleBar()
+void TitleBar::SetBackground()
 {
-    disposeOnce();
+    Color aColor(Theme::GetColor(meThemeItem));
+    mxTitlebar->set_background(aColor);
+    mxToolBox->set_background(aColor);
 }
 
-void TitleBar::dispose()
+void TitleBar::DataChanged()
 {
-    mxToolBox.reset();
-    mxAddonImage.reset();
-    InterimItemWindow::dispose();
+    SetBackground();
+}
+
+TitleBar::~TitleBar()
+{
+}
+
+Size TitleBar::get_preferred_size() const
+{
+    return mxTitlebar->get_preferred_size();
+}
+
+void TitleBar::Show(bool bShow)
+{
+    mxTitlebar->set_visible(bShow);
+}
+
+bool TitleBar::GetVisible() const
+{
+    return mxTitlebar->get_visible();
 }
 
 void TitleBar::SetIcon(const css::uno::Reference<css::graphic::XGraphic>& rIcon)
@@ -54,11 +70,6 @@ void TitleBar::SetIcon(const css::uno::Reference<css::graphic::XGraphic>& rIcon)
     mxAddonImage->set_visible(rIcon.is());
 }
 
-void TitleBar::DataChanged (const DataChangedEvent& /*rEvent*/)
-{
-    m_xContainer->set_background(Theme::GetColor(meThemeItem));
-}
-
 IMPL_LINK_NOARG(TitleBar, SelectionHandler, const OString&, void)
 {
     HandleToolBoxItemClick();
