@@ -65,7 +65,7 @@ uno::Sequence< OUString > SAL_CALL SfxUnoDecks::getElementNames()
 
         deckList.realloc(aDecks.size());
 
-        long n = 0;
+        tools::Long n = 0;
 
         for (const auto& rDeck : aDecks)
         {
