@@ -66,7 +66,7 @@ sal_uInt16 SfxStatusBarControl::convertAwtToVCLMouseButtons( sal_Int16 nAwtMouse
 }
 
 
-svt::StatusbarController* SfxStatusBarControllerFactory(
+rtl::Reference<svt::StatusbarController> SfxStatusBarControllerFactory(
     const uno::Reference< frame::XFrame >& rFrame,
     StatusBar* pStatusBar,
     unsigned short nID,
@@ -104,7 +104,7 @@ svt::StatusbarController* SfxStatusBarControllerFactory(
         sal_uInt16 nSlotId = pSlot->GetSlotId();
         if ( nSlotId > 0 )
         {
-            OString aCmd = OStringLiteral(".uno:") + pSlot->GetUnoName();
+            OString aCmd = OString::Concat(".uno:") + pSlot->GetUnoName();
             pStatusBar->SetHelpId( nSlotId, aCmd );
             return SfxStatusBarControl::CreateControl( nSlotId, nID, pStatusBar, pModule );
         }
@@ -158,12 +158,12 @@ SfxStatusBarControl::~SfxStatusBarControl()
 
 
 // XInterface
-void SAL_CALL SfxStatusBarControl::acquire() throw()
+void SAL_CALL SfxStatusBarControl::acquire() noexcept
 {
     OWeakObject::acquire();
 }
 
-void SAL_CALL SfxStatusBarControl::release() throw()
+void SAL_CALL SfxStatusBarControl::release() noexcept
 {
     OWeakObject::release();
 }
@@ -340,7 +340,7 @@ void SAL_CALL SfxStatusBarControl::paint(
     if ( pOutDev )
     {
         ::tools::Rectangle aRect = VCLRectangle( rOutputRectangle );
-        UserDrawEvent aUserDrawEvent(nullptr, pOutDev, aRect, pBar->GetCurItemId());
+        UserDrawEvent aUserDrawEvent(pOutDev, aRect, pBar->GetCurItemId());
         Paint( aUserDrawEvent );
     }
 }
@@ -516,7 +516,7 @@ void SfxStatusBarControl::Paint
 }
 
 
-SfxStatusBarControl* SfxStatusBarControl::CreateControl
+rtl::Reference<SfxStatusBarControl> SfxStatusBarControl::CreateControl
 (
     sal_uInt16     nSlotID,
     sal_uInt16     nStbId,
