@@ -258,7 +258,7 @@ void SAL_CALL CSysShExec::execute( const OUString& aCommand, const OUString& aPa
                 if (PathResolve(path, nullptr, PRF_VERIFYEXISTS | PRF_REQUIREABSOLUTE) == 0)
                 {
                     throw css::lang::IllegalArgumentException(
-                        OUStringLiteral(u"XSystemShellExecute.execute, PathResolve(") + o3tl::toU(path)
+                        OUString::Concat(u"XSystemShellExecute.execute, PathResolve(") + o3tl::toU(path)
                             + ") failed",
                         {}, 0);
                 }
@@ -271,32 +271,34 @@ void SAL_CALL CSysShExec::execute( const OUString& aCommand, const OUString& aPa
                 if (SHGetFileInfoW(path, 0, &info, sizeof info, SHGFI_ATTRIBUTES) == 0)
                 {
                     throw css::lang::IllegalArgumentException(
-                        OUStringLiteral(u"XSystemShellExecute.execute, SHGetFileInfoW(") + o3tl::toU(path) + ") failed", {},
+                        OUString::Concat(u"XSystemShellExecute.execute, SHGetFileInfoW(") + o3tl::toU(path) + ") failed", {},
                         0);
                 }
                 if ((info.dwAttributes & SFGAO_LINK) == 0) {
                     break;
                 }
                 sal::systools::COMReference<IShellLinkW> link;
-                auto e2 = CoCreateInstance(
-                    CLSID_ShellLink, nullptr, CLSCTX_INPROC_SERVER, IID_IShellLinkW,
-                    reinterpret_cast<LPVOID *>(&link));
-                if (FAILED(e2)) {
+                try
+                {
+                    link.CoCreateInstance(CLSID_ShellLink, nullptr, CLSCTX_INPROC_SERVER);
+                }
+                catch (sal::systools::ComError& e)
+                {
                     throw css::lang::IllegalArgumentException(
                         ("XSystemShellExecute.execute, CoCreateInstance failed with "
-                         + OUString::number(e2)),
+                         + OUString::number(e.GetHresult())),
                         {}, 0);
                 }
                 sal::systools::COMReference<IPersistFile> file;
                 try {
-                    file = link.QueryInterface<IPersistFile>(IID_IPersistFile);
+                    file = link.QueryInterface<IPersistFile>(sal::systools::COM_QUERY_THROW);
                 } catch(sal::systools::ComError & e3) {
                     throw css::lang::IllegalArgumentException(
                         ("XSystemShellExecute.execute, QueryInterface failed with: "
                          + o3tl::runtimeToOUString(e3.what())),
                         {}, 0);
                 }
-                e2 = file->Load(path, STGM_READ);
+                HRESULT e2 = file->Load(path, STGM_READ);
                 if (FAILED(e2)) {
                     throw css::lang::IllegalArgumentException(
                         ("XSystemShellExecute.execute, IPersistFile.Load failed with "
