@@ -18,19 +18,15 @@
  */
 
 
-#include <cppuhelper/exc_hlp.hxx>
-
 #include <com/sun/star/awt/MouseButton.hpp>
 #include <com/sun/star/awt/MouseEvent.hpp>
 
-#include <sal/log.hxx>
 #include <basegfx/point/b2dpoint.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <cppcanvas/basegfxfactory.hxx>
 #include <tools/diagnose_ex.h>
 
-#include <activity.hxx>
 #include <slideshowcontext.hxx>
 #include "userpaintoverlay.hxx"
 #include <mouseeventhandler.hxx>
@@ -43,10 +39,8 @@
 
 using namespace ::com::sun::star;
 
-namespace slideshow
+namespace slideshow::internal
 {
-    namespace internal
-    {
         class PaintOverlayHandler : public MouseEventHandler,
                                     public ViewEventHandler,
                     public UserPaintEventHandler
@@ -447,7 +441,7 @@ namespace slideshow
                                             const SlideShowContext&  rContext,
                                             const PolyPolygonVector& rPolygons,
                                             bool                     bActive ) :
-            mpHandler( new PaintOverlayHandler( rStrokeColor,
+            mpHandler( std::make_shared<PaintOverlayHandler>( rStrokeColor,
                                                 nStrokeWidth,
                                                 rContext.mrScreenUpdater,
                                                 rContext.mrViewContainer,
@@ -486,7 +480,6 @@ namespace slideshow
                 TOOLS_WARN_EXCEPTION("slideshow", "");
             }
         }
-    }
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
