@@ -392,11 +392,12 @@ sub create_package
             chdir $localfrom;
 
             if ( $ENV{'MACOSX_CODESIGNING_IDENTITY'} ) {
-                my @lp_sign = ('codesign', '--verbose', '--sign', $ENV{'MACOSX_CODESIGNING_IDENTITY'}, '--deep', $appfolder);
-                if (system(@lp_sign) == 0) {
-                    $infoline = "Success: \"@lp_sign\" executed successfully!\n";
+                my $lp_sign = "codesign --verbose --sign $ENV{'MACOSX_CODESIGNING_IDENTITY'} --deep '$appfolder'" ;
+                my $output = `$lp_sign 2>&1`;
+                unless ($?) {
+                    $infoline = "Success: \"$lp_sign\" executed successfully!\n";
                 } else {
-                    $infoline = "ERROR: Could not codesign the languagepack using \"@lp_sign\"!\n";
+                    $infoline = "ERROR: Could not codesign the languagepack using \"$lp_sign\"!\n$output\n";
                 }
                 push( @installer::globals::logfileinfo, $infoline);
             }
@@ -409,13 +410,12 @@ sub create_package
             {
                 $systemcall = "$ENV{'SRCDIR'}/solenv/bin/macosx-codesign-app-bundle $localtempdir/$folder/$volume_name_classic_app.app";
                 print "... $systemcall ...\n";
-                my $returnvalue = system($systemcall);
                 $infoline = "Systemcall: $systemcall\n";
                 push( @installer::globals::logfileinfo, $infoline);
-
-                if ($returnvalue)
+                my $output = `$systemcall 2>&1`;
+                if ($?)
                 {
-                    $infoline = "ERROR: Could not execute \"$systemcall\"!\n";
+                    $infoline = "ERROR: Could not execute \"$systemcall\"!\n$output\n";
                     push( @installer::globals::logfileinfo, $infoline);
                 }
                 else
