@@ -99,7 +99,6 @@ private:
     SfxBindings m_aBindings;
     std::unique_ptr<SfxDispatcher> m_pDispatcher;
     VclPtr<SmCmdBoxWindow> m_pSmCmdBoxWindow;
-    VclPtr<SmEditWindow> m_pEditWindow;
     SmDocShellRef m_xDocShRef;
     SmViewShell *m_pViewShell;
 };
@@ -130,14 +129,12 @@ void Test::setUp()
     m_aBindings.EnterRegistrations();
     m_pSmCmdBoxWindow.reset(VclPtr<SmCmdBoxWindow>::Create(&m_aBindings, nullptr, nullptr));
     m_aBindings.LeaveRegistrations();
-    m_pEditWindow = VclPtr<SmEditWindow>::Create(*m_pSmCmdBoxWindow);
-    m_pViewShell = m_pEditWindow->GetView();
+    m_pViewShell = m_pSmCmdBoxWindow->GetView();
     CPPUNIT_ASSERT_MESSAGE("Should have a SmViewShell", m_pViewShell);
 }
 
 void Test::tearDown()
 {
-    m_pEditWindow.disposeAndClear();
     m_pSmCmdBoxWindow.disposeAndClear();
     m_pDispatcher.reset();
     m_xDocShRef->DoClose();
@@ -179,54 +176,55 @@ void Test::testSmTmpDeviceRestoreFont()
 
 void Test::editMarker()
 {
+    SmEditWindow& rEditWindow = m_pSmCmdBoxWindow->GetEditWindow();
     {
         OUString sMarkedText("<?> under <?> under <?>");
-        m_pEditWindow->SetText(sMarkedText);
-        m_pEditWindow->Flush();
-        OUString sFinalText = m_pEditWindow->GetText();
+        rEditWindow.SetText(sMarkedText);
+        rEditWindow.Flush();
+        OUString sFinalText = rEditWindow.GetText();
         CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be equal text", sMarkedText, sFinalText);
     }
 
     {
         ESelection aSelection;
 
-        m_pEditWindow->SelNextMark();
-        m_pEditWindow->Delete();
-        m_pEditWindow->InsertText("a");
+        rEditWindow.SelNextMark();
+        rEditWindow.Delete();
+        rEditWindow.InsertText("a");
 
-        m_pEditWindow->SelNextMark();
-        m_pEditWindow->SelNextMark();
-        m_pEditWindow->Delete();
-        m_pEditWindow->InsertText("c");
+        rEditWindow.SelNextMark();
+        rEditWindow.SelNextMark();
+        rEditWindow.Delete();
+        rEditWindow.InsertText("c");
 
         // should be safe i.e. do nothing
-        m_pEditWindow->SelNextMark();
-        aSelection = m_pEditWindow->GetSelection();
+        rEditWindow.SelNextMark();
+        aSelection = rEditWindow.GetSelection();
         CPPUNIT_ASSERT_EQUAL(sal_Int32(0), aSelection.nStartPara);
         CPPUNIT_ASSERT_EQUAL(sal_Int32(19), aSelection.nStartPos);
         CPPUNIT_ASSERT_EQUAL(sal_Int32(0), aSelection.nEndPara);
         CPPUNIT_ASSERT_EQUAL(sal_Int32(19), aSelection.nEndPos);
 
-        m_pEditWindow->SelPrevMark();
-        m_pEditWindow->Delete();
-        m_pEditWindow->InsertText("b");
+        rEditWindow.SelPrevMark();
+        rEditWindow.Delete();
+        rEditWindow.InsertText("b");
 
         // tdf#106116: should be safe i.e. do nothing
-        m_pEditWindow->SelPrevMark();
-        aSelection = m_pEditWindow->GetSelection();
+        rEditWindow.SelPrevMark();
+        aSelection = rEditWindow.GetSelection();
         CPPUNIT_ASSERT_EQUAL(sal_Int32(0), aSelection.nStartPara);
         CPPUNIT_ASSERT_EQUAL(sal_Int32(9), aSelection.nStartPos);
         CPPUNIT_ASSERT_EQUAL(sal_Int32(0), aSelection.nEndPara);
         CPPUNIT_ASSERT_EQUAL(sal_Int32(9), aSelection.nEndPos);
 
-        m_pEditWindow->Flush();
-        OUString sFinalText = m_pEditWindow->GetText();
+        rEditWindow.Flush();
+        OUString sFinalText = rEditWindow.GetText();
         CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be a under b under c", OUString("a under b under c"), sFinalText);
     }
 
     {
-        m_pEditWindow->SetText(OUString());
-        m_pEditWindow->Flush();
+        rEditWindow.SetText(OUString());
+        rEditWindow.Flush();
     }
 }
 
@@ -234,31 +232,39 @@ void Test::editFailure()
 {
     m_xDocShRef->SetText("color a b over {a/}");
 
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
 
     CPPUNIT_ASSERT_MESSAGE("Should be a SmParseError::ColorExpected",
-        pErrorDesc && pErrorDesc->m_eType == SmParseError::ColorExpected);
+        pErrorDesc);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be a SmParseError::ColorExpected",
+        SmParseError::ColorExpected, pErrorDesc->m_eType);
 
-    pErrorDesc = m_xDocShRef->GetParser().PrevError();
+    pErrorDesc = m_xDocShRef->GetParser()->PrevError();
 
     CPPUNIT_ASSERT_MESSAGE("Should be a SmParseError::UnexpectedChar",
-        pErrorDesc && pErrorDesc->m_eType == SmParseError::UnexpectedChar);
+        pErrorDesc);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be a SmParseError::UnexpectedChar",
+        SmParseError::UnexpectedChar, pErrorDesc->m_eType);
 
-    pErrorDesc = m_xDocShRef->GetParser().PrevError();
+    pErrorDesc = m_xDocShRef->GetParser()->PrevError();
 
     CPPUNIT_ASSERT_MESSAGE("Should be a SmParseError::RgroupExpected",
-        pErrorDesc && pErrorDesc->m_eType == SmParseError::RgroupExpected);
+        pErrorDesc);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be a SmParseError::RgroupExpected",
+        SmParseError::RgroupExpected, pErrorDesc->m_eType);
 
-    const SmErrorDesc *pLastErrorDesc = m_xDocShRef->GetParser().PrevError();
+    const SmErrorDesc *pLastErrorDesc = m_xDocShRef->GetParser()->PrevError();
 
     CPPUNIT_ASSERT_MESSAGE("Should be three syntax errors",
-        pLastErrorDesc && pLastErrorDesc == pErrorDesc);
+        pLastErrorDesc);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be three syntax errors",
+        pErrorDesc, pLastErrorDesc);
 }
 
 void Test::ParseErrorUnexpectedToken()
 {
     m_xDocShRef->SetText("\\foo");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::UnexpectedToken expected",
                            SmParseError::UnexpectedToken, pErrorDesc->m_eType);
@@ -267,7 +273,7 @@ void Test::ParseErrorUnexpectedToken()
 void Test::ParseErrorPoundExpected()
 {
     m_xDocShRef->SetText("matrix {1#2##a##b#c}");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::PoundExpected expected",
                            SmParseError::PoundExpected, pErrorDesc->m_eType);
@@ -276,7 +282,7 @@ void Test::ParseErrorPoundExpected()
 void Test::ParseErrorColorExpected()
 {
     m_xDocShRef->SetText("color 42 x");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::ColorExpected expected",
                            SmParseError::ColorExpected, pErrorDesc->m_eType);
@@ -285,7 +291,7 @@ void Test::ParseErrorColorExpected()
 void Test::ParseErrorLgroupExpected()
 {
     m_xDocShRef->SetText("stack 42");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::LgroupExpected expected",
                            SmParseError::LgroupExpected, pErrorDesc->m_eType);
@@ -294,7 +300,7 @@ void Test::ParseErrorLgroupExpected()
 void Test::ParseErrorRgroupExpected()
 {
     m_xDocShRef->SetText("stack {a#b#c)");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::RgroupExpected expected",
                            SmParseError::RgroupExpected, pErrorDesc->m_eType);
@@ -303,7 +309,7 @@ void Test::ParseErrorRgroupExpected()
 void Test::ParseErrorLbraceExpected()
 {
     m_xDocShRef->SetText("left 42");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::LbraceExpected expected",
                            SmParseError::LbraceExpected, pErrorDesc->m_eType);
@@ -312,7 +318,7 @@ void Test::ParseErrorLbraceExpected()
 void Test::ParseErrorRbraceExpected()
 {
     m_xDocShRef->SetText("left ( foo right x");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::RbraceExpected expected",
                            SmParseError::RbraceExpected, pErrorDesc->m_eType);
@@ -321,7 +327,7 @@ void Test::ParseErrorRbraceExpected()
 void Test::ParseErrorParentMismatch()
 {
     m_xDocShRef->SetText("lbrace foo rceil");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::ParentMismatch expected",
                            SmParseError::ParentMismatch, pErrorDesc->m_eType);
@@ -330,7 +336,7 @@ void Test::ParseErrorParentMismatch()
 void Test::ParseErrorRightExpected()
 {
     m_xDocShRef->SetText("left ( x mline y )");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::RightExpected expected",
                            SmParseError::RightExpected, pErrorDesc->m_eType);
@@ -339,7 +345,7 @@ void Test::ParseErrorRightExpected()
 void Test::ParseErrorFontExpected()
 {
     m_xDocShRef->SetText("font small bar");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::FontExpected expected",
                            SmParseError::FontExpected, pErrorDesc->m_eType);
@@ -348,7 +354,7 @@ void Test::ParseErrorFontExpected()
 void Test::ParseErrorSizeExpected()
 {
     m_xDocShRef->SetText("size small baz");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::SizeExpected expected",
                            SmParseError::SizeExpected, pErrorDesc->m_eType);
@@ -357,7 +363,7 @@ void Test::ParseErrorSizeExpected()
 void Test::ParseErrorDoubleAlign()
 {
     m_xDocShRef->SetText("alignl alignc x");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::DoubleAlign expected",
                            SmParseError::DoubleAlign, pErrorDesc->m_eType);
@@ -366,7 +372,7 @@ void Test::ParseErrorDoubleAlign()
 void Test::ParseErrorDoubleSubsupscript()
 {
     m_xDocShRef->SetText("x_y_z");
-    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser().NextError();
+    const SmErrorDesc *pErrorDesc = m_xDocShRef->GetParser()->NextError();
     CPPUNIT_ASSERT(pErrorDesc);
     CPPUNIT_ASSERT_EQUAL_MESSAGE("SmParseError::DoubleSubsupscript expected",
                            SmParseError::DoubleSubsupscript, pErrorDesc->m_eType);
@@ -428,12 +434,13 @@ void Test::editUndoRedo()
 
 void Test::replacePlaceholder()
 {
+    SmEditWindow& rEditWindow = m_pSmCmdBoxWindow->GetEditWindow();
     // Test the placeholder replacement. In this case, testing 'a + b', it
     // should return '+a + b' when selecting '+<?>' in ElementsDock
-    m_pEditWindow->SetText("a + b");
-    m_pEditWindow->SelectAll();
-    m_pEditWindow->InsertText("+<?>");
-    OUString sFinalText = m_pEditWindow->GetText();
+    rEditWindow.SetText("a + b");
+    rEditWindow.SelectAll();
+    rEditWindow.InsertText("+<?>");
+    OUString sFinalText = rEditWindow.GetText();
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Should be '+a + b'", OUString("+a + b"), sFinalText);
 }
 
