@@ -21,10 +21,8 @@
 #include <svgdocument.hxx>
 #include <svggradientstopnode.hxx>
 
-namespace svgio
+namespace svgio::svgreader
 {
-    namespace svgreader
-    {
         void SvgGradientNode::tryToFindLink()
         {
             if(!mpXLink && !maXLink.isEmpty())
@@ -48,13 +46,13 @@ namespace svgio
             maR(),
             maFx(),
             maFy(),
-            maGradientUnits(objectBoundingBox),
+            maGradientUnits(SvgUnits::objectBoundingBox),
             maSpreadMethod(drawinglayer::primitive2d::SpreadMethod::Pad),
             mbResolvingLink(false),
             maXLink(),
             mpXLink(nullptr)
         {
-            OSL_ENSURE(aType == SVGTokenLinearGradient || aType == SVGTokenRadialGradient, "SvgGradientNode should only be used for Linear and Radial gradient (!)");
+            OSL_ENSURE(aType == SVGToken::LinearGradient || aType == SVGToken::RadialGradient, "SvgGradientNode should only be used for Linear and Radial gradient (!)");
         }
 
         SvgGradientNode::~SvgGradientNode()
@@ -65,7 +63,7 @@ namespace svgio
         const SvgStyleAttributes* SvgGradientNode::getSvgStyleAttributes() const
         {
             return checkForCssStyle(
-                SVGTokenLinearGradient == getType() ? OUString("linearGradient") : OUString("radialGradient"),
+                SVGToken::LinearGradient == getType() ? OUString("linearGradient") : OUString("radialGradient"),
                 maSvgStyleAttributes);
         }
 
@@ -80,12 +78,12 @@ namespace svgio
             // parse own
             switch(aSVGToken)
             {
-                case SVGTokenStyle:
+                case SVGToken::Style:
                 {
                     readLocalCssStyle(aContent);
                     break;
                 }
-                case SVGTokenX1:
+                case SVGToken::X1:
                 {
                     SvgNumber aNum;
 
@@ -95,7 +93,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenY1:
+                case SVGToken::Y1:
                 {
                     SvgNumber aNum;
 
@@ -105,7 +103,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenX2:
+                case SVGToken::X2:
                 {
                     SvgNumber aNum;
 
@@ -115,7 +113,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenY2:
+                case SVGToken::Y2:
                 {
                     SvgNumber aNum;
 
@@ -125,7 +123,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenCx:
+                case SVGToken::Cx:
                 {
                     SvgNumber aNum;
 
@@ -135,7 +133,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenCy:
+                case SVGToken::Cy:
                 {
                     SvgNumber aNum;
 
@@ -145,7 +143,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenFx:
+                case SVGToken::Fx:
                 {
                     SvgNumber aNum;
 
@@ -155,7 +153,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenFy:
+                case SVGToken::Fy:
                 {
                     SvgNumber aNum;
 
@@ -165,7 +163,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenR:
+                case SVGToken::R:
                 {
                     SvgNumber aNum;
 
@@ -178,22 +176,22 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenGradientUnits:
+                case SVGToken::GradientUnits:
                 {
                     if(!aContent.isEmpty())
                     {
                         if(aContent.match(commonStrings::aStrUserSpaceOnUse))
                         {
-                            setGradientUnits(userSpaceOnUse);
+                            setGradientUnits(SvgUnits::userSpaceOnUse);
                         }
                         else if(aContent.match(commonStrings::aStrObjectBoundingBox))
                         {
-                            setGradientUnits(objectBoundingBox);
+                            setGradientUnits(SvgUnits::objectBoundingBox);
                         }
                     }
                     break;
                 }
-                case SVGTokenSpreadMethod:
+                case SVGToken::SpreadMethod:
                 {
                     if(!aContent.isEmpty())
                     {
@@ -212,7 +210,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenGradientTransform:
+                case SVGToken::GradientTransform:
                 {
                     const basegfx::B2DHomMatrix aMatrix(readTransform(aContent, *this));
 
@@ -222,7 +220,7 @@ namespace svgio
                     }
                     break;
                 }
-                case SVGTokenXlinkHref:
+                case SVGToken::XlinkHref:
                 {
                     const sal_Int32 nLen(aContent.getLength());
 
@@ -270,7 +268,7 @@ namespace svgio
                             const SvgNumber aOffset(pCandidate->getOffset());
                             double fOffset(0.0);
 
-                            if(Unit_percent == aOffset.getUnit())
+                            if(SvgUnit::percent == aOffset.getUnit())
                             {
                                 // percent is not relative to distances in ColorStop context, solve locally
                                 fOffset = aOffset.getNumber() * 0.01;
@@ -323,7 +321,7 @@ namespace svgio
             }
 
             // default is 0%
-            return SvgNumber(0.0, Unit_percent);
+            return SvgNumber(0.0, SvgUnit::percent);
         }
 
         SvgNumber SvgGradientNode::getY1() const
@@ -344,7 +342,7 @@ namespace svgio
             }
 
             // default is 0%
-            return SvgNumber(0.0, Unit_percent);
+            return SvgNumber(0.0, SvgUnit::percent);
         }
 
         SvgNumber SvgGradientNode::getX2() const
@@ -365,7 +363,7 @@ namespace svgio
             }
 
             // default is 100%
-            return SvgNumber(100.0, Unit_percent);
+            return SvgNumber(100.0, SvgUnit::percent);
         }
 
         SvgNumber SvgGradientNode::getY2() const
@@ -386,7 +384,7 @@ namespace svgio
             }
 
             // default is 0%
-            return SvgNumber(0.0, Unit_percent);
+            return SvgNumber(0.0, SvgUnit::percent);
         }
 
         SvgNumber SvgGradientNode::getCx() const
@@ -407,7 +405,7 @@ namespace svgio
             }
 
             // default is 50%
-            return SvgNumber(50.0, Unit_percent);
+            return SvgNumber(50.0, SvgUnit::percent);
         }
 
         SvgNumber SvgGradientNode::getCy() const
@@ -428,7 +426,7 @@ namespace svgio
             }
 
             // default is 50%
-            return SvgNumber(50.0, Unit_percent);
+            return SvgNumber(50.0, SvgUnit::percent);
         }
 
         SvgNumber SvgGradientNode::getR() const
@@ -449,7 +447,7 @@ namespace svgio
             }
 
             // default is 50%
-            return SvgNumber(50.0, Unit_percent);
+            return SvgNumber(50.0, SvgUnit::percent);
         }
 
         const SvgNumber* SvgGradientNode::getFx() const
@@ -522,7 +520,6 @@ namespace svgio
             }
         }
 
-    } // end of namespace svgreader
-} // end of namespace svgio
+} // end of namespace svgio::svgreader
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
