@@ -21,9 +21,10 @@
 #include <unotools/intlwrapper.hxx>
 #include <unotools/syslocale.hxx>
 #include <osl/diagnose.h>
+#include <sal/log.hxx>
 #include <libxml/xmlwriter.h>
 #include <typeinfo>
-#include <boost/property_tree/json_parser.hpp>
+#include <boost/property_tree/ptree.hpp>
 
 //////////////////////////////////////////////////////////////////////////////
 // list of classes derived from SfxPoolItem
@@ -43,7 +44,6 @@
 // class SvxBrushItem : public SfxPoolItem
 // class SvxBulletItem : public SfxPoolItem
 // class SvxColorItem : public SfxPoolItem
-//    class SvxBackgroundColorItem : public SvxColorItem
 // class SvxFontHeightItem : public SfxPoolItem
 // class SvxFieldItem : public SfxPoolItem
 // class SvxFontListItem : public SfxPoolItem
@@ -482,6 +482,9 @@ SfxPoolItem::~SfxPoolItem()
 
 bool SfxPoolItem::operator==(const SfxPoolItem& rCmp) const
 {
+    SAL_WARN_IF(typeid(rCmp) != typeid(*this), "svl",
+                "comparing different pool item subclasses " << typeid(rCmp).name() << " && "
+                                                            << typeid(*this).name());
     assert(typeid(rCmp) == typeid(*this) && "comparing different pool item subclasses");
     (void)rCmp;
     return true;
@@ -535,17 +538,18 @@ bool SfxPoolItem::GetPresentation(
 
 void SfxPoolItem::dumpAsXml(xmlTextWriterPtr pWriter) const
 {
-    xmlTextWriterStartElement(pWriter, BAD_CAST("SfxPoolItem"));
-    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("whichId"),
-                                BAD_CAST(OString::number(Which()).getStr()));
-    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("typeName"), BAD_CAST(typeid(*this).name()));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("SfxPoolItem"));
+    (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("whichId"),
+                                      BAD_CAST(OString::number(Which()).getStr()));
+    (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("typeName"),
+                                      BAD_CAST(typeid(*this).name()));
     OUString rText;
     IntlWrapper aIntlWrapper(SvtSysLocale().GetUILanguageTag());
     if (GetPresentation(SfxItemPresentation::Complete, MapUnit::Map100thMM, MapUnit::Map100thMM,
                         rText, aIntlWrapper))
-        xmlTextWriterWriteAttribute(pWriter, BAD_CAST("presentation"),
-                                    BAD_CAST(rText.toUtf8().getStr()));
-    xmlTextWriterEndElement(pWriter);
+        (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("presentation"),
+                                          BAD_CAST(rText.toUtf8().getStr()));
+    (void)xmlTextWriterEndElement(pWriter);
 }
 
 boost::property_tree::ptree SfxPoolItem::dumpAsJSON() const
@@ -587,10 +591,10 @@ bool SfxVoidItem::GetPresentation(SfxItemPresentation /*ePresentation*/, MapUnit
 
 void SfxVoidItem::dumpAsXml(xmlTextWriterPtr pWriter) const
 {
-    xmlTextWriterStartElement(pWriter, BAD_CAST("SfxVoidItem"));
-    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("whichId"),
-                                BAD_CAST(OString::number(Which()).getStr()));
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("SfxVoidItem"));
+    (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("whichId"),
+                                      BAD_CAST(OString::number(Which()).getStr()));
+    (void)xmlTextWriterEndElement(pWriter);
 }
 
 SfxVoidItem* SfxVoidItem::Clone(SfxItemPool*) const { return new SfxVoidItem(*this); }
