@@ -156,8 +156,8 @@ CPPUNIT_TEST_FIXTURE(Test, testAttributeValues)
     HtmlWriter aHtml(aStream);
     aHtml.prettyPrint(false);
     aHtml.start("abc");
-    aHtml.attribute("one", OString("one"));
-    aHtml.attribute("two", OUString("two"));
+    aHtml.attribute("one", "one");
+    aHtml.attribute("two", u"two");
     aHtml.attribute("three", sal_Int32(12));
     aHtml.end();
 
@@ -181,6 +181,23 @@ CPPUNIT_TEST_FIXTURE(Test, testCharacters)
     CPPUNIT_ASSERT_EQUAL(OString("<abc>hello</abc>"), aString);
 }
 
+CPPUNIT_TEST_FIXTURE(Test, testExactElementEnd)
+{
+    SvMemoryStream aStream;
+
+    HtmlWriter aHtml(aStream);
+    aHtml.prettyPrint(false);
+    aHtml.start("start");
+    aHtml.start("a");
+    CPPUNIT_ASSERT(aHtml.end("a"));
+    aHtml.start("b");
+    CPPUNIT_ASSERT(!aHtml.end("c"));
+    CPPUNIT_ASSERT(aHtml.end("start"));
+
+    OString aString = extractFromStream(aStream);
+    CPPUNIT_ASSERT_EQUAL(OString("<start><a/><b/></start>"), aString);
+}
+
 CPPUNIT_PLUGIN_IMPLEMENT();
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
