@@ -18,7 +18,6 @@
 
 #include <svtools/editbrowsebox.hxx>
 #include <vcl/svapp.hxx>
-#include <vcl/virdev.hxx>
 
 namespace svt
 {
@@ -33,9 +32,6 @@ namespace svt
         m_xWidget->connect_key_press(LINK(this, ControlBase, KeyInputHdl));
         m_xWidget->connect_focus_in(LINK(this, ControlBase, FocusInHdl));
         m_xWidget->connect_focus_out(LINK(this, ControlBase, FocusOutHdl));
-        m_xWidget->connect_mouse_press(LINK(this, ControlBase, MousePressHdl));
-        m_xWidget->connect_mouse_release(LINK(this, ControlBase, MouseReleaseHdl));
-        m_xWidget->connect_mouse_move(LINK(this, ControlBase, MouseMoveHdl));
     }
 
     void ComboBoxControl::dispose()
@@ -123,9 +119,6 @@ namespace svt
         m_xWidget->connect_key_press(LINK(this, ControlBase, KeyInputHdl));
         m_xWidget->connect_focus_in(LINK(this, ControlBase, FocusInHdl));
         m_xWidget->connect_focus_out(LINK(this, ControlBase, FocusOutHdl));
-        m_xWidget->connect_mouse_press(LINK(this, ControlBase, MousePressHdl));
-        m_xWidget->connect_mouse_release(LINK(this, ControlBase, MouseReleaseHdl));
-        m_xWidget->connect_mouse_move(LINK(this, ControlBase, MouseMoveHdl));
     }
 
     void ListBoxControl::dispose()
@@ -196,9 +189,6 @@ namespace svt
         m_xBox->connect_key_press(LINK(this, ControlBase, KeyInputHdl));
         m_xBox->connect_focus_in(LINK(this, ControlBase, FocusInHdl));
         m_xBox->connect_focus_out(LINK(this, ControlBase, FocusOutHdl));
-        m_xBox->connect_mouse_press(LINK(this, ControlBase, MousePressHdl));
-        m_xBox->connect_mouse_release(LINK(this, ControlBase, MouseReleaseHdl));
-        m_xBox->connect_mouse_move(LINK(this, ControlBase, MouseMoveHdl));
         m_xBox->connect_toggled(LINK(this, CheckBoxControl, OnToggle));
     }
 
@@ -241,10 +231,10 @@ namespace svt
         OnToggle(*m_xBox);
     }
 
-    IMPL_LINK_NOARG(CheckBoxControl, OnToggle, weld::ToggleButton&, void)
+    IMPL_LINK_NOARG(CheckBoxControl, OnToggle, weld::Toggleable&, void)
     {
         m_aModeState.ButtonToggled(*m_xBox);
-        m_aClickLink.Call(*m_xBox);
+        m_aToggleLink.Call(*m_xBox);
         CallModifyHdls();
     }
 
@@ -352,9 +342,6 @@ namespace svt
         m_pEntry->connect_key_press(LINK(this, ControlBase, KeyInputHdl));
         m_pEntry->connect_focus_in(LINK(this, ControlBase, FocusInHdl));
         connect_focus_out(LINK(this, ControlBase, FocusOutHdl));
-        m_pEntry->connect_mouse_press(LINK(this, ControlBase, MousePressHdl));
-        m_pEntry->connect_mouse_release(LINK(this, ControlBase, MouseReleaseHdl));
-        m_pEntry->connect_mouse_move(LINK(this, ControlBase, MouseMoveHdl));
     }
 
     bool ControlBase::ProcessKey(const KeyEvent& rKEvt)
@@ -375,28 +362,9 @@ namespace svt
 
     IMPL_LINK_NOARG(ControlBase, FocusOutHdl, weld::Widget&, void)
     {
-        m_aFocusOutHdl.Call(nullptr);
         static_cast<BrowserDataWin*>(GetParent())->GetParent()->ChildFocusOut();
     }
 
-    IMPL_LINK(ControlBase, MousePressHdl, const MouseEvent&, rEvent, bool)
-    {
-        m_aMousePressHdl.Call(rEvent);
-        return false;
-    }
-
-    IMPL_LINK(ControlBase, MouseReleaseHdl, const MouseEvent&, rEvent, bool)
-    {
-        m_aMouseReleaseHdl.Call(rEvent);
-        return false;
-    }
-
-    IMPL_LINK(ControlBase, MouseMoveHdl, const MouseEvent&, rEvent, bool)
-    {
-        m_aMouseMoveHdl.Call(rEvent);
-        return false;
-    }
-
     void EditControlBase::dispose()
     {
         m_pEntry = nullptr;
@@ -533,7 +501,7 @@ namespace svt
         }
     }
 
-    IMPL_LINK(DateControl, ToggleHdl, weld::ToggleButton&, rButton, void)
+    IMPL_LINK(DateControl, ToggleHdl, weld::Toggleable&, rButton, void)
     {
         if (rButton.get_active())
             m_xCalendar->set_date(static_cast<weld::DateFormatter&>(get_formatter()).GetDate());
@@ -671,9 +639,6 @@ namespace svt
         m_xWidget->connect_key_press(LINK(this, ControlBase, KeyInputHdl));
         m_xWidget->connect_focus_in(LINK(this, ControlBase, FocusInHdl));
         m_xWidget->connect_focus_out(LINK(this, ControlBase, FocusOutHdl));
-        m_xWidget->connect_mouse_press(LINK(this, ControlBase, MousePressHdl));
-        m_xWidget->connect_mouse_release(LINK(this, ControlBase, MouseReleaseHdl));
-        m_xWidget->connect_mouse_move(LINK(this, ControlBase, MouseMoveHdl));
         // so any the natural size doesn't have an effect
         m_xWidget->set_size_request(1, 1);
     }
