@@ -32,13 +32,13 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::beans;
 
 
-const char cReplacement[] = "Replacement";
-const char cFontPairs[] = "FontPairs";
+constexpr OUStringLiteral cReplacement = u"Replacement";
+constexpr OUStringLiteral cFontPairs = u"FontPairs";
 
-const char cReplaceFont[]   = "ReplaceFont";
-const char cSubstituteFont[]= "SubstituteFont";
-const char cOnScreenOnly[]  = "OnScreenOnly";
-const char cAlways[]        = "Always";
+constexpr OUStringLiteral cReplaceFont = u"ReplaceFont";
+constexpr OUStringLiteral cSubstituteFont= u"SubstituteFont";
+constexpr OUStringLiteral cOnScreenOnly = u"OnScreenOnly";
+constexpr OUStringLiteral cAlways = u"Always";
 
 typedef std::vector<SubstitutionStruct> SubstitutionStructArr;
 
