@@ -44,8 +44,6 @@
 #include <tools/debug.hxx>
 #include <osl/file.hxx>
 #include <osl/mutex.hxx>
-#include <vcl/event.hxx>
-#include <vcl/svapp.hxx>
 #include <unotools/historyoptions.hxx>
 #include <unotools/pathoptions.hxx>
 #include <ucbhelper/commandenvironment.hxx>
@@ -142,7 +140,7 @@ SvtMatchContext_Impl::~SvtMatchContext_Impl()
 void SvtMatchContext_Impl::FillPicklist(std::vector<OUString>& rPickList)
 {
     // Read the history of picks
-    Sequence< Sequence< PropertyValue > > seqPicklist = SvtHistoryOptions().GetList( ePICKLIST );
+    Sequence< Sequence< PropertyValue > > seqPicklist = SvtHistoryOptions().GetList( EHistoryType::PickList );
     sal_uInt32 nCount = seqPicklist.getLength();
 
     for( sal_uInt32 nItem=0; nItem < nCount; nItem++ )
@@ -319,31 +317,20 @@ void SvtMatchContext_Impl::ReadFolder( const OUString& rURL,
                                                      uno::Reference< XProgressHandler >() ),
                       comphelper::getProcessComponentContext() );
         uno::Reference< XResultSet > xResultSet;
-        Sequence< OUString > aProps(2);
-        OUString* pProps = aProps.getArray();
-        pProps[0] = "Title";
-        pProps[1] = "IsFolder";
 
         try
         {
             ResultSetInclude eInclude = INCLUDE_FOLDERS_AND_DOCUMENTS;
             if ( bOnlyDirectories )
                 eInclude = INCLUDE_FOLDERS_ONLY;
-            uno::Reference< XDynamicResultSet > xDynResultSet = aCnt.createDynamicCursor( aProps, eInclude );
+            uno::Reference< XDynamicResultSet > xDynResultSet = aCnt.createDynamicCursor( { "Title", "IsFolder" }, eInclude );
 
             uno::Reference < XAnyCompareFactory > xCompare;
             uno::Reference < XSortedDynamicResultSetFactory > xSRSFac =
                 SortedDynamicResultSetFactory::create( ::comphelper::getProcessComponentContext() );
 
-            Sequence< NumberedSortingInfo > aSortInfo( 2 );
-            NumberedSortingInfo* pInfo = aSortInfo.getArray();
-            pInfo[ 0 ].ColumnIndex = 2;
-            pInfo[ 0 ].Ascending   = false;
-            pInfo[ 1 ].ColumnIndex = 1;
-            pInfo[ 1 ].Ascending   = true;
-
             uno::Reference< XDynamicResultSet > xDynamicResultSet =
-                xSRSFac->createSortedDynamicResultSet( xDynResultSet, aSortInfo, xCompare );
+                xSRSFac->createSortedDynamicResultSet( xDynResultSet, { { 2, false }, { 1, true } }, xCompare );
 
             if ( xDynamicResultSet.is() )
             {
@@ -610,8 +597,8 @@ void SvtMatchContext_Impl::doExecute()
                                 aMatch = aCurObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
                             else
                             {
-                                aCurObj.SetMark( "" );
-                                aCurObj.SetParam( "" );
+                                aCurObj.SetMark( u"" );
+                                aCurObj.SetParam( u"" );
                                 aCurObj.SetURLPath( "" );
                                 aMatch = aCurObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
                             }
@@ -629,8 +616,8 @@ void SvtMatchContext_Impl::doExecute()
                             aMatch = aCurObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
                         else
                         {
-                            aCurObj.SetMark( "" );
-                            aCurObj.SetParam( "" );
+                            aCurObj.SetMark( u"" );
+                            aCurObj.SetParam( u"" );
                             aCurObj.SetURLPath( "" );
                             aMatch = aCurObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
                         }
@@ -930,7 +917,7 @@ void SvtURLBox::UpdatePicklistForSmartProtocol_Impl()
         return;
 
     // read history pick list
-    const Sequence< Sequence< PropertyValue > > seqPicklist = SvtHistoryOptions().GetList( ePICKLIST );
+    const Sequence< Sequence< PropertyValue > > seqPicklist = SvtHistoryOptions().GetList( EHistoryType::PickList );
     INetURLObject aCurObj;
 
     for( const Sequence< PropertyValue >& rPropertySet : seqPicklist )
@@ -1133,7 +1120,7 @@ void FilterMatch::createWildCardFilterList(const OUString& _rFilterList,::std::v
     else
     {
         // no filter is given -> match all
-        _rFilters.emplace_back("*" );
+        _rFilters.emplace_back(u"*" );
     }
 }
 
