@@ -84,12 +84,8 @@ SalLayoutGlyphs* lcl_GetRulerTextGlyphs(const vcl::RenderContext& rRenderContext
     if (!pLayout)
         return nullptr;
 
-    const SalLayoutGlyphs* pGlyphs = pLayout->GetGlyphs();
-    if (!pGlyphs)
-        return nullptr;
-
     // Remember the calculation result.
-    rTextGlyphs = *pGlyphs;
+    rTextGlyphs = pLayout->GetGlyphs();
 
     return &rTextGlyphs;
 }
@@ -235,7 +231,7 @@ void Ruler::ImplInit( WinBits nWinBits )
 
     // Setup the default size
     tools::Rectangle aRect;
-    GetTextBoundRect( aRect, "0123456789" );
+    GetOutDev()->GetTextBoundRect( aRect, "0123456789" );
     tools::Long nDefHeight = aRect.GetHeight() + RULER_OFF * 2 + ruler_tab.textoff * 2 + mnBorderWidth;
 
     Size aDefSize;
@@ -249,7 +245,7 @@ void Ruler::ImplInit( WinBits nWinBits )
 
 Ruler::Ruler( vcl::Window* pParent, WinBits nWinStyle ) :
     Window( pParent, nWinStyle & WB_3DLOOK ),
-    maVirDev( VclPtr<VirtualDevice>::Create(*this) ),
+    maVirDev( VclPtr<VirtualDevice>::Create(*GetOutDev()) ),
     maMapMode( MapUnit::Map100thMM ),
     mpSaveData(new ImplRulerData),
     mpData(nullptr),
@@ -414,7 +410,7 @@ void Ruler::ImplInvertLines(vcl::RenderContext& rRenderContext)
                 aTempRect.SetLeft( aTempRect.Right() - RULER_OFF + 1 );
             }
             rRenderContext.Erase(aTempRect);
-            Invert(aRect);
+            GetOutDev()->Invert(aRect);
         }
     }
     mnUpdateFlags = 0;
@@ -467,9 +463,9 @@ void Ruler::ImplDrawTicks(vcl::RenderContext& rRenderContext, tools::Long nMin,
     {
         vcl::Font aFont = rRenderContext.GetFont();
         if (mnWinStyle & WB_RIGHT_ALIGNED)
-            aFont.SetOrientation(Degree10(2700));
+            aFont.SetOrientation(2700_deg10);
         else
-            aFont.SetOrientation(Degree10(900));
+            aFont.SetOrientation(900_deg10);
         rRenderContext.SetFont(aFont);
         nTickWidth = aPixSize.Height();
     }
@@ -860,9 +856,10 @@ static void ImplDrawRulerTab(vcl::RenderContext& rRenderContext, const Point& rP
     // drawn become asymmetric due to the +1 offsets
     sal_uInt16 DPIOffset = rRenderContext.GetDPIScaleFactor() - 1;
 
-    tools::Rectangle aRect1;
-    tools::Rectangle aRect2;
-    tools::Rectangle aRect3;
+    // A tabstop is drawn using three rectangles
+    tools::Rectangle aRect1; // A horizontal short line
+    tools::Rectangle aRect2; // A vertical short line
+    tools::Rectangle aRect3; // A small square
 
     aRect3.SetEmpty();
 
@@ -991,7 +988,7 @@ void Ruler::ApplySettings(vcl::RenderContext& rRenderContext)
 
     ApplyControlFont(rRenderContext, aFont);
 
-    ApplyControlForeground(*this, rStyleSettings.GetDarkShadowColor());
+    ApplyControlForeground(*GetOutDev(), rStyleSettings.GetDarkShadowColor());
     SetTextFillColor();
 
     Color aColor;
@@ -1011,12 +1008,12 @@ void Ruler::ImplInitSettings(bool bFont, bool bForeground, bool bBackground)
         Size aSize(adjustSize(aFont.GetFontSize().Width()), adjustSize(aFont.GetFontSize().Height()));
         aFont.SetFontSize(aSize);
 
-        ApplyControlFont(*this, aFont);
+        ApplyControlFont(*GetOutDev(), aFont);
     }
 
     if (bForeground || bFont)
     {
-        ApplyControlForeground(*this, rStyleSettings.GetDarkShadowColor());
+        ApplyControlForeground(*GetOutDev(), rStyleSettings.GetDarkShadowColor());
         SetTextFillColor();
     }
 
@@ -1025,7 +1022,7 @@ void Ruler::ImplInitSettings(bool bFont, bool bForeground, bool bBackground)
         Color aColor;
         svtools::ColorConfig aColorConfig;
         aColor = aColorConfig.GetColorValue(svtools::APPBACKGROUND).nColor;
-        ApplyControlBackground(*this, aColor);
+        ApplyControlBackground(*GetOutDev(), aColor);
     }
 
     maVirDev->SetSettings( GetSettings() );
@@ -1033,7 +1030,7 @@ void Ruler::ImplInitSettings(bool bFont, bool bForeground, bool bBackground)
     vcl::Font aFont = GetFont();
 
     if (mnWinStyle & WB_VERT)
-        aFont.SetOrientation(Degree10(900));
+        aFont.SetOrientation(900_deg10);
 
     maVirDev->SetFont(aFont);
     maVirDev->SetTextColor(GetTextColor());
@@ -1412,7 +1409,7 @@ void Ruler::ImplUpdate( bool bMustCalc )
     }
 }
 
-bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
+bool Ruler::ImplDoHitTest( const Point& rPos, RulerSelection* pHitTest,
                          bool bRequireStyle, RulerIndentStyle nRequiredStyle ) const
 {
     sal_Int32   i;
@@ -1728,7 +1725,7 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
         else
             aPos.setX( RULER_OFF + 1 );
 
-        if ( ImplHitTest( aPos, pHitTest, bRequiredStyle, nRequiredStyle ) )
+        if ( ImplDoHitTest( aPos, pHitTest, bRequiredStyle, nRequiredStyle ) )
         {
             if ( (pHitTest->eType == eDragType) || (eDragType == RulerType::DontKnow) )
                 return true;
@@ -1744,7 +1741,7 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
         else
             aPos.setX( mnWidth - RULER_OFF - 1 );
 
-        if ( ImplHitTest( aPos, pHitTest, bRequiredStyle, nRequiredStyle ) )
+        if ( ImplDoHitTest( aPos, pHitTest, bRequiredStyle, nRequiredStyle ) )
         {
             if ( (pHitTest->eType == eDragType) || (eDragType == RulerType::DontKnow) )
                 return true;
@@ -1759,7 +1756,7 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
         else
             aPos.setX( RULER_OFF + (mnVirHeight / 2) );
 
-        if ( ImplHitTest( aPos, pHitTest ) )
+        if ( ImplDoHitTest( aPos, pHitTest ) )
         {
             if ( (pHitTest->eType == eDragType) || (eDragType == RulerType::DontKnow) )
                 return true;
@@ -1934,27 +1931,27 @@ void Ruler::MouseButtonDown( const MouseEvent& rMEvt )
     }
     else
     {
-        std::unique_ptr<RulerSelection> pHitTest(new RulerSelection);
-        bool bHitTestResult = ImplHitTest(aMousePos, pHitTest.get());
+        RulerSelection aHitTest;
+        bool bHitTestResult = ImplDoHitTest(aMousePos, &aHitTest);
 
         if ( nMouseClicks == 1 )
         {
             if ( bHitTestResult )
             {
-                ImplStartDrag( pHitTest.get(), nMouseModifier );
+                ImplStartDrag( &aHitTest, nMouseModifier );
             }
             else
             {
                 // calculate position inside of ruler area
-                if ( pHitTest->eType == RulerType::DontKnow )
+                if ( aHitTest.eType == RulerType::DontKnow )
                 {
-                    mnDragPos = pHitTest->nPos;
+                    mnDragPos = aHitTest.nPos;
                     Click();
                     mnDragPos = 0;
 
                     // call HitTest again as a click, for example, could set a new tab
-                    if ( ImplHitTest(aMousePos, pHitTest.get()) )
-                        ImplStartDrag(pHitTest.get(), nMouseModifier);
+                    if ( ImplDoHitTest(aMousePos, &aHitTest) )
+                        ImplStartDrag(&aHitTest, nMouseModifier);
                 }
             }
         }
@@ -1962,10 +1959,10 @@ void Ruler::MouseButtonDown( const MouseEvent& rMEvt )
         {
             if (bHitTestResult)
             {
-                mnDragPos    = pHitTest->nPos;
-                mnDragAryPos = pHitTest->nAryPos;
+                mnDragPos    = aHitTest.nPos;
+                mnDragAryPos = aHitTest.nAryPos;
             }
-            meDragType = pHitTest->eType;
+            meDragType = aHitTest.eType;
 
             DoubleClick();
 
@@ -1986,7 +1983,7 @@ void Ruler::MouseMove( const MouseEvent& rMEvt )
 
     maHoverSelection.eType = RulerType::DontKnow;
 
-    if (ImplHitTest( rMEvt.GetPosPixel(), mxCurrentHitTest.get() ))
+    if (ImplDoHitTest( rMEvt.GetPosPixel(), mxCurrentHitTest.get() ))
     {
         maHoverSelection = *mxCurrentHitTest;
 
@@ -2250,7 +2247,7 @@ bool Ruler::StartDocDrag( const MouseEvent& rMEvt, RulerType eDragType )
             if (!IsReallyVisible())
             {
                 // set mpData for ImplDocHitTest()
-                ImplFormat(*this);
+                ImplFormat(*GetOutDev());
             }
 
             Invalidate(InvalidateFlags::NoErase);
@@ -2309,7 +2306,7 @@ void Ruler::CancelDrag()
     }
 }
 
-RulerType Ruler::GetType( const Point& rPos, sal_uInt16* pAryPos )
+RulerType Ruler::GetRulerType( const Point& rPos, sal_uInt16* pAryPos )
 {
     RulerSelection aHitTest;
 
@@ -2319,7 +2316,7 @@ RulerType Ruler::GetType( const Point& rPos, sal_uInt16* pAryPos )
         Invalidate(InvalidateFlags::NoErase);
     }
 
-    (void)ImplHitTest(rPos, &aHitTest);
+    (void)ImplDoHitTest(rPos, &aHitTest);
 
     // return values
     if ( pAryPos )
@@ -2764,8 +2761,8 @@ uno::Reference< XAccessible > Ruler::CreateAccessible()
             aStr = SvtResId(STR_SVT_ACC_RULER_VERT_NAME);
         }
         mxAccContext = new SvtRulerAccessible( xAccParent, *this, aStr );
-        SetAccessible(mxAccContext.get());
-        return mxAccContext.get();
+        SetAccessible(mxAccContext);
+        return mxAccContext;
     }
     else
         return uno::Reference< XAccessible >();
