@@ -67,26 +67,26 @@
 
 using namespace ::com::sun::star;
 
-static sal_Int16 GetFilterFormat(const OUString& rExt)
+static sal_Int16 GetFilterFormat(std::u16string_view rExt)
 {
     sal_Int16 nFormat = FORMAT_UNKNOWN;
-    if ( rExt == "JPG" )
+    if ( rExt == u"JPG" )
         nFormat = FORMAT_JPG;
-    else if ( rExt == "PNG" )
+    else if ( rExt == u"PNG" )
         nFormat = FORMAT_PNG;
-    else if ( rExt == "BMP" )
+    else if ( rExt == u"BMP" )
         nFormat = FORMAT_BMP;
-    else if ( rExt == "GIF" )
+    else if ( rExt == u"GIF" )
         nFormat = FORMAT_GIF;
-    else if ( rExt == "TIF" )
+    else if ( rExt == u"TIF" )
         nFormat = FORMAT_TIF;
-    else if ( rExt == "WMF" )
+    else if ( rExt == u"WMF" )
         nFormat = FORMAT_WMF;
-    else if ( rExt == "EMF" )
+    else if ( rExt == u"EMF" )
         nFormat = FORMAT_EMF;
-    else if ( rExt == "EPS" )
+    else if ( rExt == u"EPS" )
         nFormat = FORMAT_EPS;
-    else if ( rExt == "SVG" )
+    else if ( rExt == u"SVG" )
         nFormat = FORMAT_SVG;
     return nFormat;
 }
@@ -192,8 +192,8 @@ uno::Sequence< beans::PropertyValue > ExportDialog::GetFilterData( bool bUpdateC
         pFilterOptions = new FilterConfigItem( &aFilterData );
     }
 
-    const OUString sLogicalWidth("LogicalWidth");
-    const OUString sLogicalHeight("LogicalHeight");
+    static const OUStringLiteral sLogicalWidth(u"LogicalWidth");
+    static const OUStringLiteral sLogicalHeight(u"LogicalHeight");
     if ( mbIsPixelFormat )
     {
         pFilterOptions->WriteInt32("PixelWidth", maSize.Width );
@@ -333,10 +333,9 @@ awt::Size ExportDialog::GetOriginalSize()
         aTransformation.m11 = aViewTransformation.get(1,1);
         aTransformation.m12 = aViewTransformation.get(1,2);
 
-        const OUString sViewTransformation( "ViewTransformation" );
         uno::Sequence< beans::PropertyValue > aViewInformation( 1 );
         aViewInformation[ 0 ].Value <<= aTransformation;
-        aViewInformation[ 0 ].Name  = sViewTransformation;
+        aViewInformation[ 0 ].Name  = "ViewTransformation";
 
         if ( mxShape.is() )
             aShapesRange = GetShapeRangeForXShape( mxShape, xPrimitiveFactory, aViewInformation );
@@ -601,6 +600,8 @@ ExportDialog::ExportDialog(FltCallDialogParameter& rPara,
     , mxRbBinary(m_xBuilder->weld_radio_button("binarycb"))
     , mxRbText(m_xBuilder->weld_radio_button("textcb"))
     , mxEPSGrid(m_xBuilder->weld_widget("epsgrid"))
+    , mxModifyDimension(m_xBuilder->weld_radio_button("modifydimensionscb"))
+    , mxModifyResolution(m_xBuilder->weld_radio_button("modifyresolutioncb"))
     , mxCbEPSPreviewTIFF(m_xBuilder->weld_check_button("tiffpreviewcb"))
     , mxCbEPSPreviewEPSI(m_xBuilder->weld_check_button("epsipreviewcb"))
     , mxRbEPSLevel1(m_xBuilder->weld_radio_button("level1rb"))
@@ -684,6 +685,9 @@ ExportDialog::ExportDialog(FltCallDialogParameter& rPara,
 
     mxCbSaveTransparency->connect_toggled( LINK( this, ExportDialog, UpdateHdl ) );
 
+    mxModifyDimension->connect_toggled( LINK( this, ExportDialog, UpdateLock ) );
+    mxModifyResolution->connect_toggled( LINK( this, ExportDialog, UpdateLock ) );
+
     mxCbEPSPreviewTIFF->connect_toggled( LINK( this, ExportDialog, UpdateHdl ) );
     mxCbEPSPreviewEPSI->connect_toggled( LINK( this, ExportDialog, UpdateHdl ) );
 
@@ -868,7 +872,7 @@ static OUString ImpValueOfInKB( sal_Int64 rVal )
     fVal /= ( 1 << 10 );
     fVal += 0.05;
     OUStringBuffer aVal( OUString::number( fVal ) );
-    sal_Int32 nX( OUString( aVal.getStr() ).indexOf( '.' ) );
+    sal_Int32 nX( aVal.indexOf( '.' ) );
     if ( nX > 0 )
         aVal.setLength( nX + 2 );
     return aVal.makeStringAndClear();
@@ -988,11 +992,29 @@ IMPL_LINK_NOARG(ExportDialog, SelectListBoxHdl, weld::ComboBox&, void)
     updateControls();
 }
 
-IMPL_LINK_NOARG(ExportDialog, UpdateHdl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(ExportDialog, UpdateHdl, weld::Toggleable&, void)
 {
     updateControls();
 }
 
+IMPL_LINK_NOARG(ExportDialog, UpdateLock, weld::Toggleable&, void)
+{
+    if (mxModifyResolution->get_active())
+    {
+        mxMfSizeY->set_sensitive(false);
+        mxMfSizeX->set_sensitive(false);
+        mxNfResolution->set_sensitive(true);
+    }
+    else
+    {
+        mxMfSizeY->set_sensitive(true);
+        mxMfSizeX->set_sensitive(true);
+        mxNfResolution->set_sensitive(false);
+    }
+    updateControls();
+}
+
+
 IMPL_LINK_NOARG(ExportDialog, UpdateHdlMtfSizeX, weld::SpinButton&, void)
 {
     double fRatio = static_cast< double >( maOriginalSize.Height ) / maOriginalSize.Width;
