@@ -18,7 +18,6 @@
  */
 
 #include <sal/config.h>
-#include <sal/log.hxx>
 
 #include <osl/file.hxx>
 #include <svtools/templatefoldercache.hxx>
@@ -708,7 +707,7 @@ namespace svt
         }
 
         // append our name
-        aStorageURL.Append( ".templdir.cache" );
+        aStorageURL.Append( u".templdir.cache" );
 
         // open the stream
         m_pCacheStream = UcbStreamHelper::CreateStream( aStorageURL.GetMainURL( INetURLObject::DecodeMechanism::ToIUri ),
