@@ -75,7 +75,7 @@ CPPUNIT_TEST_FIXTURE(SdrTest, testShadowScaleOrigin)
 {
     // Load a document containing a custom shape.
     test::Directories aDirectories;
-    OUString aURL = aDirectories.getURLFromSrc("svx/qa/unit/data/shadow-scale-origin.pptx");
+    OUString aURL = aDirectories.getURLFromSrc(u"svx/qa/unit/data/shadow-scale-origin.pptx");
     getComponent() = loadFromDesktop(aURL);
     uno::Reference<drawing::XDrawPagesSupplier> xDrawPagesSupplier(getComponent(), uno::UNO_QUERY);
     uno::Reference<drawing::XDrawPage> xDrawPage(xDrawPagesSupplier->getDrawPages()->getByIndex(0),
@@ -86,22 +86,22 @@ CPPUNIT_TEST_FIXTURE(SdrTest, testShadowScaleOrigin)
     // Examine the created primitives.
     drawinglayer::Primitive2dXmlDump aDumper;
     xmlDocUniquePtr pDocument = aDumper.dumpAndParse(xPrimitiveSequence);
-    double fShadowX = getXPath(pDocument, "//shadow/transform", "xy13").toDouble();
-    double fShadowY = getXPath(pDocument, "//shadow/transform", "xy23").toDouble();
+    sal_Int32 fShadowX = getXPath(pDocument, "//shadow/transform", "xy13").toInt32();
+    sal_Int32 fShadowY = getXPath(pDocument, "//shadow/transform", "xy23").toInt32();
     // Without the accompanying fix in place, this test would have failed with:
     // - Expected: -705
     // - Actual  : -158
     // i.e. the shadow origin was not the top right corner for scaling (larger x position, so it was
     // visible on the right of the shape as well).
-    CPPUNIT_ASSERT_EQUAL(-705., std::round(fShadowX));
-    CPPUNIT_ASSERT_EQUAL(-685., std::round(fShadowY));
+    CPPUNIT_ASSERT_EQUAL(sal_Int32(-705), fShadowX);
+    CPPUNIT_ASSERT_EQUAL(sal_Int32(-684), fShadowY);
 }
 
 CPPUNIT_TEST_FIXTURE(SdrTest, testZeroWidthTextWrap)
 {
     // Load a document containing a 0-width shape with text.
     test::Directories aDirectories;
-    OUString aURL = aDirectories.getURLFromSrc("svx/qa/unit/data/0-width-text-wrap.pptx");
+    OUString aURL = aDirectories.getURLFromSrc(u"svx/qa/unit/data/0-width-text-wrap.pptx");
     getComponent() = loadFromDesktop(aURL);
     uno::Reference<drawing::XDrawPagesSupplier> xDrawPagesSupplier(getComponent(), uno::UNO_QUERY);
     uno::Reference<drawing::XDrawPage> xDrawPage(xDrawPagesSupplier->getDrawPages()->getByIndex(0),
@@ -118,30 +118,6 @@ CPPUNIT_TEST_FIXTURE(SdrTest, testZeroWidthTextWrap)
     // i.e. the text on the only shape on the slide had 12 lines, not a single one.
     assertXPath(pDocument, "//textsimpleportion", 1);
 }
-
-CPPUNIT_TEST_FIXTURE(SdrTest, testSlideBackground)
-{
-    // Given a document with a slide what has a linked background image:
-    test::Directories aDirectories;
-    OUString aURL = aDirectories.getURLFromSrc(u"svx/qa/unit/data/slide-background.odp");
-    getComponent() = loadFromDesktop(aURL);
-    uno::Reference<drawing::XDrawPagesSupplier> xDrawPagesSupplier(getComponent(), uno::UNO_QUERY);
-    uno::Reference<drawing::XDrawPage> xDrawPage(xDrawPagesSupplier->getDrawPages()->getByIndex(0),
-                                                 uno::UNO_QUERY);
-
-    // When rendering that document:
-    drawinglayer::primitive2d::Primitive2DContainer xPrimitiveSequence
-        = renderPageToPrimitives(xDrawPage);
-
-    // Then make sure that the background has a bitmap:
-    drawinglayer::Primitive2dXmlDump aDumper;
-    xmlDocUniquePtr pDocument = aDumper.dumpAndParse(xPrimitiveSequence);
-    // Without the accompanying fix in place, this test would have failed with:
-    // - Expected: 1
-    // - Actual  : 0
-    // i.e. the rendering did not find the bitmap.
-    assertXPath(pDocument, "//bitmap", 1);
-}
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
