@@ -38,7 +38,6 @@
 #include <com/sun/star/container/XChild.hpp>
 #include <comphelper/types.hxx>
 #include <o3tl/safeint.hxx>
-#include <o3tl/sorted_vector.hxx>
 #include <rtl/ustring.hxx>
 #include <tools/debug.hxx>
 #include <svx/SvxShapeTypes.hxx>
@@ -110,7 +109,7 @@ void ChildrenManagerImpl::Init()
 }
 
 
-tools::Long ChildrenManagerImpl::GetChildCount() const throw ()
+tools::Long ChildrenManagerImpl::GetChildCount() const noexcept
 {
     return maVisibleChildren.size();
 }
@@ -794,6 +793,20 @@ uno::Reference<XAccessible>
 */
 void ChildrenManagerImpl::UpdateSelection()
 {
+    Reference<frame::XController> xController(maShapeTreeInfo.GetController());
+    Reference<view::XSelectionSupplier> xSelectionSupplier (
+        xController, uno::UNO_QUERY);
+
+    // Try to cast the selection both to a multi selection and to a single
+    // selection.
+    Reference<container::XIndexAccess> xSelectedShapeAccess;
+    Reference<drawing::XShape> xSelectedShape;
+    if (xSelectionSupplier.is())
+    {
+        xSelectedShapeAccess.set( xSelectionSupplier->getSelection(), uno::UNO_QUERY);
+        xSelectedShape.set( xSelectionSupplier->getSelection(), uno::UNO_QUERY);
+    }
+
     // Remember the current and new focused shape.
     AccessibleShape* pCurrentlyFocusedShape = nullptr;
     AccessibleShape* pNewFocusedShape = nullptr;
@@ -802,101 +815,73 @@ void ChildrenManagerImpl::UpdateSelection()
     VEC_SHAPE vecSelect;
     int nAddSelect=0;
     bool bHasSelectedShape=false;
-    if (!maVisibleChildren.empty())
+    for (const auto& rChild : maVisibleChildren)
     {
-        Reference<frame::XController> xController(maShapeTreeInfo.GetController());
-        Reference<view::XSelectionSupplier> xSelectionSupplier (
-            xController, uno::UNO_QUERY);
-
-        // Try to cast the selection both to a multi selection and to a single
-        // selection.
-        Reference<container::XIndexAccess> xSelectedShapeAccess;
-        Reference<drawing::XShape> xSelectedShape;
-        if (xSelectionSupplier.is())
+        AccessibleShape* pAccessibleShape = rChild.GetAccessibleShape();
+        if (rChild.mxAccessibleShape.is() && rChild.mxShape.is() && pAccessibleShape!=nullptr)
         {
-            xSelectedShapeAccess.set( xSelectionSupplier->getSelection(), uno::UNO_QUERY);
-            xSelectedShape.set( xSelectionSupplier->getSelection(), uno::UNO_QUERY);
-        }
+            short nRole = pAccessibleShape->getAccessibleRole();
+            bool bDrawShape = (
+                nRole == AccessibleRole::GRAPHIC ||
+                nRole == AccessibleRole::EMBEDDED_OBJECT ||
+                nRole == AccessibleRole::SHAPE ||
+                nRole == AccessibleRole::IMAGE_MAP ||
+                nRole == AccessibleRole::TABLE_CELL ||
+                nRole == AccessibleRole::TABLE );
+            bool bShapeIsSelected = false;
 
-        // tdf#139220 to quickly find if a given drawing::XShape is selected
-        o3tl::sorted_vector<css::uno::Reference<css::drawing::XShape>> aSortedSelectedShapes;
-        if (!xSelectedShape.is() && xSelectedShapeAccess.is())
-        {
-            sal_Int32 nCount = xSelectedShapeAccess->getCount();
-            aSortedSelectedShapes.reserve(nCount);
-            for (sal_Int32 i = 0; i < nCount; ++i)
+            // Look up the shape in the (single or multi-) selection.
+            if (xSelectedShape.is())
             {
-                css::uno::Reference<css::drawing::XShape> xShape(xSelectedShapeAccess->getByIndex(i), uno::UNO_QUERY);
-                aSortedSelectedShapes.insert(xShape);
-            }
-        }
-
-        for (const auto& rChild : maVisibleChildren)
-        {
-            AccessibleShape* pAccessibleShape = rChild.GetAccessibleShape();
-            if (rChild.mxAccessibleShape.is() && rChild.mxShape.is() && pAccessibleShape!=nullptr)
-            {
-                short nRole = pAccessibleShape->getAccessibleRole();
-                bool bDrawShape = (
-                    nRole == AccessibleRole::GRAPHIC ||
-                    nRole == AccessibleRole::EMBEDDED_OBJECT ||
-                    nRole == AccessibleRole::SHAPE ||
-                    nRole == AccessibleRole::IMAGE_MAP ||
-                    nRole == AccessibleRole::TABLE_CELL ||
-                    nRole == AccessibleRole::TABLE );
-                bool bShapeIsSelected = false;
-
-                // Look up the shape in the (single or multi-) selection.
-                if (xSelectedShape.is())
+                if  (rChild.mxShape == xSelectedShape)
                 {
-                    if  (rChild.mxShape == xSelectedShape)
-                    {
-                        bShapeIsSelected = true;
-                        pNewFocusedShape = pAccessibleShape;
-                    }
+                    bShapeIsSelected = true;
+                    pNewFocusedShape = pAccessibleShape;
                 }
-                else if (!aSortedSelectedShapes.empty())
-                {
-                    if (aSortedSelectedShapes.find(rChild.mxShape) != aSortedSelectedShapes.end())
+            }
+            else if (xSelectedShapeAccess.is())
+            {
+                sal_Int32 nCount=xSelectedShapeAccess->getCount();
+                for (sal_Int32 i=0; i<nCount&&!bShapeIsSelected; i++)
+                    if (xSelectedShapeAccess->getByIndex(i) == rChild.mxShape)
                     {
                         bShapeIsSelected = true;
                         // In a multi-selection no shape has the focus.
-                        if (aSortedSelectedShapes.size() == 1)
+                        if (nCount == 1)
                             pNewFocusedShape = pAccessibleShape;
                     }
-                }
+            }
 
-                // Set or reset the SELECTED state.
-                if (bShapeIsSelected)
+            // Set or reset the SELECTED state.
+            if (bShapeIsSelected)
+            {
+                if (pAccessibleShape->SetState (AccessibleStateType::SELECTED))
                 {
-                    if (pAccessibleShape->SetState (AccessibleStateType::SELECTED))
+                    if (bDrawShape)
                     {
-                        if (bDrawShape)
-                        {
-                            vecSelect.emplace_back(pAccessibleShape,true);
-                            ++nAddSelect;
-                        }
-                    }
-                    else
-                    {//Selected not change,has selected shape before
-                        bHasSelectedShape=true;
+                        vecSelect.emplace_back(pAccessibleShape,true);
+                        ++nAddSelect;
                     }
                 }
                 else
-                    //pAccessibleShape->ResetState (AccessibleStateType::SELECTED);
+                {//Selected not change,has selected shape before
+                    bHasSelectedShape=true;
+                }
+            }
+            else
+                //pAccessibleShape->ResetState (AccessibleStateType::SELECTED);
+            {
+                if(pAccessibleShape->ResetState (AccessibleStateType::SELECTED))
                 {
-                    if(pAccessibleShape->ResetState (AccessibleStateType::SELECTED))
+                    if(bDrawShape)
                     {
-                        if(bDrawShape)
-                        {
-                            vecSelect.emplace_back(pAccessibleShape,false);
-                        }
+                        vecSelect.emplace_back(pAccessibleShape,false);
                     }
                 }
-                // Does the shape have the current selection?
-                if (pAccessibleShape->GetState (AccessibleStateType::FOCUSED))
-                    pCurrentlyFocusedShape = pAccessibleShape;
             }
+            // Does the shape have the current selection?
+            if (pAccessibleShape->GetState (AccessibleStateType::FOCUSED))
+                pCurrentlyFocusedShape = pAccessibleShape;
         }
     }
 
