@@ -18,13 +18,13 @@
  */
 
 #include "EnhancedCustomShape3d.hxx"
+#include <o3tl/unit_conversion.hxx>
 #include <svx/deflt3d.hxx>
 #include <svx/svdmodel.hxx>
 #include <tools/poly.hxx>
 #include <svx/svditer.hxx>
 #include <svx/svdobj.hxx>
 #include <svx/svdoashp.hxx>
-#include <svl/poolitem.hxx>
 #include <svl/itemset.hxx>
 #include <svx/xfillit0.hxx>
 #include <svx/xlineit0.hxx>
@@ -263,7 +263,8 @@ SdrObject* EnhancedCustomShape3d::Create3DObject(
     if ( rSdrObjCustomShape.getSdrModelFromSdrObject().GetScaleUnit() != MapUnit::Map100thMM )
     {
         DBG_ASSERT( rSdrObjCustomShape.getSdrModelFromSdrObject().GetScaleUnit() == MapUnit::MapTwip, "EnhancedCustomShape3d::Current MapMode is Unsupported" );
-        fMap *= 1440.0 / 2540.0;
+        // But we could use MapToO3tlUnit from <tools/UnitConversion> ... ?
+        fMap *= o3tl::convert(1.0, o3tl::Length::mm100, o3tl::Length::twip);
         pMap = &fMap;
     }
 
@@ -272,10 +273,10 @@ SdrObject* EnhancedCustomShape3d::Create3DObject(
         bool bIsMirroredX(rSdrObjCustomShape.IsMirroredX());
         bool bIsMirroredY(rSdrObjCustomShape.IsMirroredY());
         tools::Rectangle aSnapRect(rSdrObjCustomShape.GetLogicRect());
-        tools::Long nObjectRotation(rSdrObjCustomShape.GetRotateAngle());
+        Degree100 nObjectRotation(rSdrObjCustomShape.GetRotateAngle());
         if ( nObjectRotation )
         {
-            double a = (36000 - nObjectRotation) * F_PI18000;
+            double a = (36000 - nObjectRotation.get()) * F_PI18000;
             tools::Long dx = aSnapRect.Right() - aSnapRect.Left();
             tools::Long dy = aSnapRect.Bottom()- aSnapRect.Top();
             Point aP( aSnapRect.TopLeft() );
