@@ -343,7 +343,7 @@ void FrameSelectorImpl::InitArrowImageList()
     assert(SAL_N_ELEMENTS(aImageIds) == 16);
     for (size_t i = 0; i < SAL_N_ELEMENTS(aImageIds); ++i)
     {
-        BitmapEx aBmpEx(aImageIds[i]);
+        BitmapEx aBmpEx { OUString(aImageIds[i]) };
         aBmpEx.Replace(pColorAry1, pColorAry2, 3);
         maArrows.emplace_back(aBmpEx);
     }
@@ -695,11 +695,8 @@ void FrameSelectorImpl::DrawAllFrameBorders()
             *mpVirDev,
             aNewViewInformation2D));
 
-    if (pProcessor2D)
-    {
-        pProcessor2D->process(maArray.CreateB2DPrimitiveArray());
-        pProcessor2D.reset();
-    }
+    pProcessor2D->process(maArray.CreateB2DPrimitiveArray());
+    pProcessor2D.reset();
 }
 
 void FrameSelectorImpl::DrawVirtualDevice()
@@ -1030,7 +1027,7 @@ Reference< XAccessible > FrameSelector::CreateAccessible()
 {
     if( !mxAccess.is() )
         mxAccess = new a11y::AccFrameSelector(*this);
-    return mxAccess.get();
+    return mxAccess;
 }
 
 rtl::Reference< a11y::AccFrameSelectorChild > FrameSelector::GetChildAccessible( FrameBorderType eBorder )
@@ -1049,7 +1046,7 @@ rtl::Reference< a11y::AccFrameSelectorChild > FrameSelector::GetChildAccessible(
 
 Reference< XAccessible > FrameSelector::GetChildAccessible( sal_Int32 nIndex )
 {
-    return GetChildAccessible( GetEnabledBorderType( nIndex ) ).get();
+    return GetChildAccessible( GetEnabledBorderType( nIndex ) );
 }
 
 Reference< XAccessible > FrameSelector::GetChildAccessible( const Point& rPos )
