@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <basegfx/matrix/b2dhommatrix.hxx>
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/accessibility/XAccessible.hpp>
@@ -24,6 +25,10 @@
 #include <com/sun/star/accessibility/XAccessibleContext.hpp>
 #include <com/sun/star/accessibility/XAccessibleEventBroadcaster.hpp>
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
+#include <com/sun/star/lang/XServiceInfo.hpp>
+#include <cppuhelper/supportsservice.hxx>
+#include <drawinglayer/processor2d/baseprocessor2d.hxx>
+#include <drawinglayer/processor2d/processor2dtools.hxx>
 #include <editeng/eeitem.hxx>
 #include <editeng/fhgtitem.hxx>
 #include <editeng/fontitem.hxx>
@@ -34,23 +39,73 @@
 #include <osl/diagnose.h>
 #include <svl/itemset.hxx>
 #include <sal/log.hxx>
+#include <svx/sdr/overlay/overlayselection.hxx>
+#include <svtools/optionsdrawinglayer.hxx>
 #include <svx/AccessibleTextHelper.hxx>
 #include <svx/weldeditview.hxx>
 #include <tools/diagnose_ex.h>
 #include <unotools/accessiblestatesethelper.hxx>
+#include <vcl/canvastools.hxx>
 #include <vcl/cursor.hxx>
 #include <vcl/event.hxx>
 #include <vcl/ptrstyle.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/window.hxx>
 #include <vcl/uitest/uiobject.hxx>
 
-WeldEditView::WeldEditView() {}
+void WeldEditView::SetText(const OUString& rStr) { GetEditEngine()->SetText(rStr); }
+
+OUString WeldEditView::GetText() const { return GetEditEngine()->GetText(); }
+
+void WeldEditView::SetModifyHdl(const Link<LinkParamNone*, void>& rLink)
+{
+    GetEditEngine()->SetModifyHdl(rLink);
+}
+
+EditView* WeldEditView::GetEditView() const { return m_xEditView.get(); }
+
+EditEngine* WeldEditView::GetEditEngine() const { return m_xEditEngine.get(); }
+
+bool WeldEditView::HasSelection() const
+{
+    EditView* pEditView = GetEditView();
+    return pEditView && pEditView->HasSelection();
+}
+
+void WeldEditView::Delete()
+{
+    if (EditView* pEditView = GetEditView())
+        pEditView->DeleteSelected();
+}
+
+void WeldEditView::Cut()
+{
+    if (EditView* pEditView = GetEditView())
+        pEditView->Cut();
+}
+
+void WeldEditView::Copy()
+{
+    if (EditView* pEditView = GetEditView())
+        pEditView->Copy();
+}
+
+void WeldEditView::Paste()
+{
+    if (EditView* pEditView = GetEditView())
+        pEditView->Paste();
+}
+
+WeldEditView::WeldEditView()
+    : m_bAcceptsTab(false)
+{
+}
 
 // tdf#127033 want to use UI font so override makeEditEngine to enable that
 void WeldEditView::makeEditEngine()
 {
-    SfxItemPool* pItemPool = EditEngine::CreatePool();
+    rtl::Reference<SfxItemPool> pItemPool = EditEngine::CreatePool();
 
     vcl::Font aAppFont(Application::GetSettings().GetStyleSettings().GetAppFont());
 
@@ -71,64 +126,133 @@ void WeldEditView::makeEditEngine()
     pItemPool->SetPoolDefaultItem(
         SvxFontHeightItem(aAppFont.GetFontHeight() * 20, 100, EE_CHAR_FONTHEIGHT_CTL));
 
-    m_xEditEngine.reset(new EditEngine(pItemPool));
+    m_xEditEngine.reset(new EditEngine(pItemPool.get()));
 }
 
 void WeldEditView::Resize()
 {
-    if (m_xEditView)
+    if (EditView* pEditView = GetEditView())
     {
         OutputDevice& rDevice = GetDrawingArea()->get_ref_device();
         Size aOutputSize(rDevice.PixelToLogic(GetOutputSizePixel()));
-        Size aSize(aOutputSize);
-        m_xEditEngine->SetPaperSize(aSize);
-        m_xEditView->SetOutputArea(tools::Rectangle(Point(0, 0), aOutputSize));
+        // Resizes the edit engine to adjust to the size of the output area
+        pEditView->SetOutputArea(tools::Rectangle(Point(0, 0), aOutputSize));
+        GetEditEngine()->SetPaperSize(aOutputSize);
+        pEditView->ShowCursor();
+
+        const tools::Long nMaxVisAreaStart
+            = pEditView->GetEditEngine()->GetTextHeight() - aOutputSize.Height();
+        tools::Rectangle aVisArea(pEditView->GetVisArea());
+        if (aVisArea.Top() > nMaxVisAreaStart)
+        {
+            aVisArea.SetTop(std::max<tools::Long>(nMaxVisAreaStart, 0));
+            aVisArea.SetSize(aOutputSize);
+            pEditView->SetVisArea(aVisArea);
+            pEditView->ShowCursor();
+        }
+
+        EditViewScrollStateChange();
     }
     weld::CustomWidgetController::Resize();
 }
 
 void WeldEditView::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
 {
-    rRenderContext.Push(PushFlags::ALL);
-    rRenderContext.SetClipRegion();
-
     const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
     Color aBgColor = rStyleSettings.GetWindowColor();
 
     rRenderContext.SetBackground(aBgColor);
+    if (EditView* pEditView = GetEditView())
+        pEditView->SetBackgroundColor(aBgColor);
+
+    DoPaint(rRenderContext, rRect);
+}
+
+void WeldEditView::DoPaint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
+{
+    rRenderContext.Push(PushFlags::ALL);
+    rRenderContext.SetClipRegion();
 
     std::vector<tools::Rectangle> aLogicRects;
 
-    if (m_xEditView)
+    if (EditView* pEditView = GetEditView())
     {
-        m_xEditView->SetBackgroundColor(aBgColor);
-
-        m_xEditView->Paint(rRect, &rRenderContext);
+        pEditView->Paint(rRect, &rRenderContext);
 
         if (HasFocus())
         {
-            m_xEditView->ShowCursor(false);
-            vcl::Cursor* pCursor = m_xEditView->GetCursor();
+            pEditView->ShowCursor(false);
+            vcl::Cursor* pCursor = pEditView->GetCursor();
             pCursor->DrawToDevice(rRenderContext);
         }
 
         // get logic selection
-        m_xEditView->GetSelectionRectangles(aLogicRects);
+        pEditView->GetSelectionRectangles(aLogicRects);
     }
 
-    rRenderContext.SetLineColor();
-    rRenderContext.SetFillColor(COL_BLACK);
-    rRenderContext.SetRasterOp(RasterOp::Invert);
+    if (!aLogicRects.empty())
+    {
+        std::vector<basegfx::B2DRange> aLogicRanges;
+        aLogicRanges.reserve(aLogicRects.size());
 
-    for (const auto& rSelectionRect : aLogicRects)
-        rRenderContext.DrawRect(rSelectionRect);
+        tools::Long nMinX(LONG_MAX), nMaxX(0), nMinY(LONG_MAX), nMaxY(0);
+        for (const auto& aRect : aLogicRects)
+        {
+            nMinX = std::min(nMinX, aRect.Left());
+            nMinY = std::min(nMinY, aRect.Top());
+            nMaxX = std::max(nMaxX, aRect.Right());
+            nMaxY = std::max(nMaxY, aRect.Bottom());
+        }
+
+        const Size aLogicPixel(rRenderContext.PixelToLogic(Size(1, 1)));
+        for (const auto& aRect : aLogicRects)
+        {
+            // Extend each range by one pixel so multiple lines touch each
+            // other if adjacent, so the whole set is drawn with a single
+            // border around the lot. But keep the selection within the
+            // original max extents.
+            auto nTop = aRect.Top();
+            if (nTop > nMinY)
+                nTop -= aLogicPixel.Height();
+            auto nBottom = aRect.Bottom();
+            if (nBottom < nMaxY)
+                nBottom += aLogicPixel.Height();
+            auto nLeft = aRect.Left();
+            if (nLeft > nMinX)
+                nLeft -= aLogicPixel.Width();
+            auto nRight = aRect.Right();
+            if (nRight < nMaxX)
+                nRight += aLogicPixel.Width();
+
+            aLogicRanges.emplace_back(nLeft, nTop, nRight, nBottom);
+        }
+
+        // get the system's highlight color
+        const SvtOptionsDrawinglayer aSvtOptionsDrawinglayer;
+        const Color aHighlight(aSvtOptionsDrawinglayer.getHilightColor());
+
+        sdr::overlay::OverlaySelection aCursorOverlay(sdr::overlay::OverlayType::Transparent,
+                                                      aHighlight, aLogicRanges, true);
+
+        const drawinglayer::geometry::ViewInformation2D aViewInformation2D(
+            basegfx::B2DHomMatrix(), rRenderContext.GetViewTransformation(),
+            vcl::unotools::b2DRectangleFromRectangle(rRect), nullptr, 0.0,
+            css::uno::Sequence<css::beans::PropertyValue>());
+
+        std::unique_ptr<drawinglayer::processor2d::BaseProcessor2D> xProcessor(
+            drawinglayer::processor2d::createProcessor2DFromOutputDevice(rRenderContext,
+                                                                         aViewInformation2D));
+
+        xProcessor->process(aCursorOverlay.getOverlayObjectPrimitive2DSequence());
+    }
 
     rRenderContext.Pop();
 }
 
 bool WeldEditView::MouseMove(const MouseEvent& rMEvt)
 {
-    return m_xEditView && m_xEditView->MouseMove(rMEvt);
+    EditView* pEditView = GetEditView();
+    return pEditView && pEditView->MouseMove(rMEvt);
 }
 
 bool WeldEditView::MouseButtonDown(const MouseEvent& rMEvt)
@@ -136,41 +260,46 @@ bool WeldEditView::MouseButtonDown(const MouseEvent& rMEvt)
     if (!IsMouseCaptured())
         CaptureMouse();
 
-    if (!HasFocus() && CanFocus())
+    if (!HasFocus())
     {
         GrabFocus();
         GetFocus();
     }
 
-    return m_xEditView && m_xEditView->MouseButtonDown(rMEvt);
+    EditView* pEditView = GetEditView();
+    return pEditView && pEditView->MouseButtonDown(rMEvt);
 }
 
 bool WeldEditView::MouseButtonUp(const MouseEvent& rMEvt)
 {
     if (IsMouseCaptured())
         ReleaseMouse();
-    return m_xEditView && m_xEditView->MouseButtonUp(rMEvt);
+    EditView* pEditView = GetEditView();
+    return pEditView && pEditView->MouseButtonUp(rMEvt);
 }
 
 bool WeldEditView::KeyInput(const KeyEvent& rKEvt)
 {
+    EditView* pEditView = GetEditView();
+
     sal_uInt16 nKey = rKEvt.GetKeyCode().GetCode();
 
-    if (nKey == KEY_TAB)
+    if (nKey == KEY_TAB && !GetAcceptsTab())
     {
         return false;
     }
-    else if (m_xEditView && !m_xEditView->PostKeyEvent(rKEvt))
+    else if (pEditView && !pEditView->PostKeyEvent(rKEvt))
     {
         if (rKEvt.GetKeyCode().IsMod1() && !rKEvt.GetKeyCode().IsMod2())
         {
             if (nKey == KEY_A)
             {
-                sal_Int32 nPar = m_xEditEngine->GetParagraphCount();
+                EditEngine* pEditEngine = GetEditEngine();
+                sal_Int32 nPar = pEditEngine->GetParagraphCount();
                 if (nPar)
                 {
-                    sal_Int32 nLen = m_xEditEngine->GetTextLen(nPar - 1);
-                    m_xEditView->SetSelection(ESelection(0, 0, nPar - 1, nLen));
+                    sal_Int32 nLen = pEditEngine->GetTextLen(nPar - 1);
+                    pEditView->SetSelection(ESelection(0, 0, nPar - 1, nLen));
                 }
                 return true;
             }
@@ -184,10 +313,15 @@ bool WeldEditView::KeyInput(const KeyEvent& rKEvt)
 
 bool WeldEditView::Command(const CommandEvent& rCEvt)
 {
-    if (!m_xEditView)
+    EditView* pEditView = GetEditView();
+    if (!pEditView)
         return false;
-    m_xEditView->Command(rCEvt);
-    return true;
+    return pEditView->Command(rCEvt);
+}
+
+Point WeldEditView::EditViewPointerPosPixel() const
+{
+    return GetDrawingArea()->get_pointer_position();
 }
 
 class WeldEditAccessible;
@@ -371,9 +505,10 @@ public:
 };
 }
 
-typedef cppu::WeakImplHelper<
-    css::accessibility::XAccessible, css::accessibility::XAccessibleComponent,
-    css::accessibility::XAccessibleContext, css::accessibility::XAccessibleEventBroadcaster>
+typedef cppu::WeakImplHelper<css::lang::XServiceInfo, css::accessibility::XAccessible,
+                             css::accessibility::XAccessibleComponent,
+                             css::accessibility::XAccessibleContext,
+                             css::accessibility::XAccessibleEventBroadcaster>
     WeldEditAccessibleBaseClass;
 
 class WeldEditAccessible : public WeldEditAccessibleBaseClass
@@ -495,22 +630,11 @@ public:
 
         css::awt::Point aScreenLoc(0, 0);
 
-        css::uno::Reference<css::accessibility::XAccessible> xParent(getAccessibleParent());
-        if (xParent)
+        if (weld::DrawingArea* pDrawingArea = m_pController->GetDrawingArea())
         {
-            css::uno::Reference<css::accessibility::XAccessibleContext> xParentContext(
-                xParent->getAccessibleContext());
-            css::uno::Reference<css::accessibility::XAccessibleComponent> xParentComponent(
-                xParentContext, css::uno::UNO_QUERY);
-            OSL_ENSURE(xParentComponent.is(),
-                       "WeldEditAccessible::getLocationOnScreen: no parent component!");
-            if (xParentComponent.is())
-            {
-                css::awt::Point aParentScreenLoc(xParentComponent->getLocationOnScreen());
-                css::awt::Point aOwnRelativeLoc(getLocation());
-                aScreenLoc.X = aParentScreenLoc.X + aOwnRelativeLoc.X;
-                aScreenLoc.Y = aParentScreenLoc.Y + aOwnRelativeLoc.Y;
-            }
+            Point aPos = pDrawingArea->get_accessible_location_on_screen();
+            aScreenLoc.X = aPos.X();
+            aScreenLoc.Y = aPos.Y();
         }
 
         return aScreenLoc;
@@ -660,9 +784,8 @@ public:
         SAL_CALL getAccessibleStateSet() override
     {
         SolarMutexGuard aGuard;
-        ::utl::AccessibleStateSetHelper* pStateSet = new ::utl::AccessibleStateSetHelper;
-
-        css::uno::Reference<css::accessibility::XAccessibleStateSet> xStateSet(pStateSet);
+        rtl::Reference<::utl::AccessibleStateSetHelper> pStateSet
+            = new ::utl::AccessibleStateSetHelper;
 
         if (!m_pController || !m_xTextHelper)
             pStateSet->AddState(css::accessibility::AccessibleStateType::DEFUNC);
@@ -685,7 +808,7 @@ public:
                 pStateSet->AddState(css::accessibility::AccessibleStateType::OPAQUE);
         }
 
-        return xStateSet;
+        return pStateSet;
     }
 
     virtual css::lang::Locale SAL_CALL getLocale() override
@@ -710,13 +833,26 @@ public:
             return;
         m_xTextHelper->RemoveEventListener(rListener);
     }
+
+    virtual OUString SAL_CALL getImplementationName() override { return "WeldEditAccessible"; }
+
+    virtual sal_Bool SAL_CALL supportsService(const OUString& rServiceName) override
+    {
+        return cppu::supportsService(this, rServiceName);
+    }
+
+    virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames() override
+    {
+        return { "css::accessibility::Accessible", "css::accessibility::AccessibleComponent",
+                 "css::accessibility::AccessibleContext" };
+    }
 };
 
 css::uno::Reference<css::accessibility::XAccessible> WeldEditView::CreateAccessible()
 {
     if (!m_xAccessible.is())
         m_xAccessible.set(new WeldEditAccessible(this));
-    return css::uno::Reference<css::accessibility::XAccessible>(m_xAccessible.get());
+    return m_xAccessible;
 }
 
 WeldEditView::~WeldEditView()
@@ -1434,29 +1570,40 @@ void WeldEditView::SetDrawingArea(weld::DrawingArea* pDrawingArea)
 
     pDrawingArea->set_cursor(PointerStyle::Text);
 
+    InitAccessible();
+}
+
+void WeldEditView::InitAccessible()
+{
     if (m_xAccessible.is())
-        m_xAccessible->Init(m_xEditEngine.get(), m_xEditView.get());
+        m_xAccessible->Init(GetEditEngine(), GetEditView());
 }
 
 int WeldEditView::GetSurroundingText(OUString& rSurrounding)
 {
-    if (!m_xEditView)
+    EditView* pEditView = GetEditView();
+    if (!pEditView)
         return -1;
-    rSurrounding = m_xEditView->GetSurroundingText();
-    return m_xEditView->GetSurroundingTextSelection().Min();
+    rSurrounding = pEditView->GetSurroundingText();
+    return pEditView->GetSurroundingTextSelection().Min();
 }
 
 bool WeldEditView::DeleteSurroundingText(const Selection& rRange)
 {
-    if (!m_xEditView)
+    EditView* pEditView = GetEditView();
+    if (!pEditView)
         return false;
-    return m_xEditView->DeleteSurroundingText(rRange);
+    return pEditView->DeleteSurroundingText(rRange);
 }
 
 void WeldEditView::GetFocus()
 {
-    if (m_xEditView)
-        m_xEditView->ShowCursor(false);
+    EditView* pEditView = GetEditView();
+    if (pEditView)
+    {
+        pEditView->ShowCursor(false);
+        Invalidate(); // redraw with cursor
+    }
 
     weld::CustomWidgetController::GetFocus();
 
@@ -1483,7 +1630,17 @@ void WeldEditView::LoseFocus()
     }
 }
 
-bool WeldEditView::CanFocus() const { return true; }
+css::uno::Reference<css::datatransfer::dnd::XDropTarget> WeldEditView::GetDropTarget()
+{
+    if (!m_xDropTarget)
+        m_xDropTarget = weld::CustomWidgetController::GetDropTarget();
+    return m_xDropTarget;
+}
+
+css::uno::Reference<css::datatransfer::clipboard::XClipboard> WeldEditView::GetClipboard() const
+{
+    return weld::CustomWidgetController::GetClipboard();
+}
 
 namespace
 {
