@@ -71,6 +71,44 @@ FmFormObj::FmFormObj(SdrModel& rSdrModel)
     impl_checkRefDevice_nothrow();
 }
 
+FmFormObj::FmFormObj(SdrModel& rSdrModel, FmFormObj const & rSource)
+:   SdrUnoObj(rSdrModel, rSource)
+    ,m_nPos(-1)
+    ,m_pLastKnownRefDevice(nullptr)
+{
+    // Stuff that old SetModel also did:
+    impl_checkRefDevice_nothrow();
+
+    // If UnoControlModel is part of an event environment,
+    // events may assigned to it.
+    Reference< XFormComponent >  xContent(rSource.xUnoControlModel, UNO_QUERY);
+    if (xContent.is())
+    {
+        Reference< XEventAttacherManager >  xManager(xContent->getParent(), UNO_QUERY);
+        Reference< XIndexAccess >  xManagerAsIndex(xManager, UNO_QUERY);
+        if (xManagerAsIndex.is())
+        {
+            sal_Int32 nPos = getElementPos( xManagerAsIndex, xContent );
+            if ( nPos >= 0 )
+                aEvts = xManager->getScriptEvents( nPos );
+        }
+    }
+    else
+        aEvts = rSource.aEvts;
+
+    Reference< XChild >  xSourceAsChild(rSource.GetUnoControlModel(), UNO_QUERY);
+    if (!xSourceAsChild.is())
+        return;
+
+    Reference< XInterface >  xSourceContainer = xSourceAsChild->getParent();
+
+    m_xEnvironmentHistory = css::form::Forms::create( comphelper::getProcessComponentContext() );
+
+    ensureModelEnv(xSourceContainer, m_xEnvironmentHistory);
+    m_aEventsHistory = aEvts;
+        // if we were clone there was a call to operator=, so aEvts are exactly the events we need here...
+}
+
 FmFormObj::~FmFormObj()
 {
 
@@ -122,10 +160,10 @@ void FmFormObj::impl_checkRefDevice_nothrow( bool _force )
         Reference< XPropertySet > xModelProps( GetUnoControlModel(), UNO_QUERY_THROW );
         Reference< XPropertySetInfo > xPropertyInfo( xModelProps->getPropertySetInfo(), UNO_SET_THROW );
 
-        static const char sRefDevicePropName[] = "ReferenceDevice";
+        static constexpr OUStringLiteral sRefDevicePropName = u"ReferenceDevice";
         if ( xPropertyInfo->hasPropertyByName( sRefDevicePropName ) )
         {
-            VCLXDevice* pUnoRefDevice = new VCLXDevice;
+            rtl::Reference<VCLXDevice> pUnoRefDevice = new VCLXDevice;
             pUnoRefDevice->SetOutputDevice( m_pLastKnownRefDevice );
             Reference< XDevice > xRefDevice( pUnoRefDevice );
             xModelProps->setPropertyValue( sRefDevicePropName, makeAny( xRefDevice ) );
@@ -148,7 +186,7 @@ void FmFormObj::impl_isolateControlModel_nothrow()
             Reference< XIndexContainer> xParent( xControlModel->getParent(), UNO_QUERY );
             if ( xParent.is() )
             {
-                sal_Int32 nPos = getElementPos( xParent.get(), xControlModel );
+                sal_Int32 nPos = getElementPos( xParent, xControlModel );
                 xParent->removeByIndex( nPos );
             }
         }
@@ -322,66 +360,11 @@ SdrObjKind FmFormObj::GetObjIdentifier() const
     return OBJ_UNO;
 }
 
-void FmFormObj::clonedFrom(const FmFormObj* _pSource)
-{
-    DBG_ASSERT(_pSource != nullptr, "FmFormObj::clonedFrom : invalid source !");
-    if (m_xEnvironmentHistory.is())
-       m_xEnvironmentHistory->dispose();
-
-    m_xEnvironmentHistory = nullptr;
-    m_aEventsHistory.realloc(0);
-
-    Reference< XChild >  xSourceAsChild(_pSource->GetUnoControlModel(), UNO_QUERY);
-    if (!xSourceAsChild.is())
-        return;
-
-    Reference< XInterface >  xSourceContainer = xSourceAsChild->getParent();
-
-    m_xEnvironmentHistory = css::form::Forms::create( comphelper::getProcessComponentContext() );
-
-    ensureModelEnv(xSourceContainer, m_xEnvironmentHistory);
-    m_aEventsHistory = aEvts;
-        // if we were clone there was a call to operator=, so aEvts are exactly the events we need here...
-}
-
-
 FmFormObj* FmFormObj::CloneSdrObject(SdrModel& rTargetModel) const
 {
-    FmFormObj* pFormObject = CloneHelper< FmFormObj >(rTargetModel);
-    DBG_ASSERT(pFormObject != nullptr, "FmFormObj::Clone : invalid clone !");
-    if (pFormObject)
-        pFormObject->clonedFrom(this);
-
-    return pFormObject;
+    return new FmFormObj(rTargetModel, *this);
 }
 
-
-FmFormObj& FmFormObj::operator= (const FmFormObj& rObj)
-{
-    if( this == &rObj )
-        return *this;
-    SdrUnoObj::operator= (rObj);
-
-    // If UnoControlModel is part of an event environment,
-    // events may assigned to it.
-    Reference< XFormComponent >  xContent(rObj.xUnoControlModel, UNO_QUERY);
-    if (xContent.is())
-    {
-        Reference< XEventAttacherManager >  xManager(xContent->getParent(), UNO_QUERY);
-        Reference< XIndexAccess >  xManagerAsIndex(xManager, UNO_QUERY);
-        if (xManagerAsIndex.is())
-        {
-            sal_Int32 nPos = getElementPos( xManagerAsIndex, xContent );
-            if ( nPos >= 0 )
-                aEvts = xManager->getScriptEvents( nPos );
-        }
-    }
-    else
-        aEvts = rObj.aEvts;
-    return *this;
-}
-
-
 void FmFormObj::NbcReformatText()
 {
     impl_checkRefDevice_nothrow();
