@@ -56,8 +56,8 @@ namespace sdr::contact
             const basegfx::B2DHomMatrix aObjectMatrix(
                 basegfx::utils::createScaleShearXRotateTranslateB2DHomMatrix(
                     aObjectRange.getWidth(), aObjectRange.getHeight(),
-                    rGeoStat.nShearAngle ? tan((36000 - rGeoStat.nShearAngle) * F_PI18000) : 0.0,
-                    rGeoStat.nRotationAngle ? (36000 - rGeoStat.nRotationAngle) * F_PI18000 : 0.0,
+                    -rGeoStat.mfTanShearAngle,
+                    rGeoStat.nRotationAngle ? (36000 - rGeoStat.nRotationAngle.get()) * F_PI18000 : 0.0,
                     aObjectRange.getMinX(), aObjectRange.getMinY()));
 
             // create primitive data
