@@ -224,8 +224,11 @@ void ViewObjectContact::ActionChanged()
         // invalidate current valid range
         GetObjectContact().InvalidatePartOfView(maObjectRange);
 
-        // reset ObjectRange, it needs to be recalculated
-        maObjectRange.reset();
+        // reset gridOffset, it needs to be recalculated
+        if (GetObjectContact().supportsGridOffsets())
+            resetGridOffset();
+        else
+            maObjectRange.reset();
     }
 
     // register at OC for lazy invalidate
@@ -343,45 +346,45 @@ drawinglayer::primitive2d::Primitive2DContainer const & ViewObjectContact::getPr
     }
 
     // local up-to-date checks. New list different from local one?
-    if(mxPrimitive2DSequence != xNewPrimitiveSequence)
+    if(mxPrimitive2DSequence == xNewPrimitiveSequence)
+        return mxPrimitive2DSequence;
+
+    // has changed, copy content
+    const_cast< ViewObjectContact* >(this)->mxPrimitive2DSequence = std::move(xNewPrimitiveSequence);
+
+    // check for animated stuff
+    const_cast< ViewObjectContact* >(this)->checkForPrimitive2DAnimations();
+
+    // always update object range when PrimitiveSequence changes
+    const drawinglayer::geometry::ViewInformation2D& rViewInformation2D(GetObjectContact().getViewInformation2D());
+    const_cast< ViewObjectContact* >(this)->maObjectRange = mxPrimitive2DSequence.getB2DRange(rViewInformation2D);
+
+    // check and eventually embed to GridOffset transform primitive
+    if(GetObjectContact().supportsGridOffsets())
     {
-        // has changed, copy content
-        const_cast< ViewObjectContact* >(this)->mxPrimitive2DSequence = xNewPrimitiveSequence;
+        const basegfx::B2DVector& rGridOffset(getGridOffset());
 
-        // check for animated stuff
-        const_cast< ViewObjectContact* >(this)->checkForPrimitive2DAnimations();
-
-        // always update object range when PrimitiveSequence changes
-        const drawinglayer::geometry::ViewInformation2D& rViewInformation2D(GetObjectContact().getViewInformation2D());
-        const_cast< ViewObjectContact* >(this)->maObjectRange = mxPrimitive2DSequence.getB2DRange(rViewInformation2D);
-
-        // check and eventually embed to GridOffset transform primitive
-        if(GetObjectContact().supportsGridOffsets())
+        if(0.0 != rGridOffset.getX() || 0.0 != rGridOffset.getY())
         {
-            const basegfx::B2DVector& rGridOffset(getGridOffset());
+            const basegfx::B2DHomMatrix aTranslateGridOffset(
+                basegfx::utils::createTranslateB2DHomMatrix(
+                    rGridOffset));
+            const drawinglayer::primitive2d::Primitive2DReference aEmbed(
+                 new drawinglayer::primitive2d::TransformPrimitive2D(
+                    aTranslateGridOffset,
+                    mxPrimitive2DSequence));
 
-            if(0.0 != rGridOffset.getX() || 0.0 != rGridOffset.getY())
-            {
-                const basegfx::B2DHomMatrix aTranslateGridOffset(
-                    basegfx::utils::createTranslateB2DHomMatrix(
-                        rGridOffset));
-                const drawinglayer::primitive2d::Primitive2DReference aEmbed(
-                    new drawinglayer::primitive2d::TransformPrimitive2D(
-                        aTranslateGridOffset,
-                        mxPrimitive2DSequence));
-
-                // Set values at local data. So for now, the mechanism is to reset some of the
-                // defining things (mxPrimitive2DSequence, maGridOffset) and re-create the
-                // buffered data (including maObjectRange). It *could* be changed to keep
-                // the unmodified PrimitiveSequence and only update the GridOffset, but this
-                // would require a 2nd instance of maObjectRange and mxPrimitive2DSequence. I
-                // started doing so, but it just makes the code more complicated. For now,
-                // just allow re-creation of the PrimitiveSequence (and removing buffered
-                // decomposed content of it). May be optimized, though. OTOH it only happens
-                // in calc which traditionally does not have a huge amount of DrawObjects anyways.
-                const_cast< ViewObjectContact* >(this)->mxPrimitive2DSequence = drawinglayer::primitive2d::Primitive2DContainer { aEmbed };
-                const_cast< ViewObjectContact* >(this)->maObjectRange.transform(aTranslateGridOffset);
-            }
+            // Set values at local data. So for now, the mechanism is to reset some of the
+            // defining things (mxPrimitive2DSequence, maGridOffset) and re-create the
+            // buffered data (including maObjectRange). It *could* be changed to keep
+            // the unmodified PrimitiveSequence and only update the GridOffset, but this
+            // would require a 2nd instance of maObjectRange and mxPrimitive2DSequence. I
+            // started doing so, but it just makes the code more complicated. For now,
+            // just allow re-creation of the PrimitiveSequence (and removing buffered
+            // decomposed content of it). May be optimized, though. OTOH it only happens
+            // in calc which traditionally does not have a huge amount of DrawObjects anyways.
+            const_cast< ViewObjectContact* >(this)->mxPrimitive2DSequence = drawinglayer::primitive2d::Primitive2DContainer { aEmbed };
+            const_cast< ViewObjectContact* >(this)->maObjectRange.transform(aTranslateGridOffset);
         }
     }
 
