@@ -58,7 +58,6 @@
 #include <svx/xbtmpit.hxx>
 #include <svl/itempool.hxx>
 #include <vcl/svapp.hxx>
-#include <vcl/GraphicLoader.hxx>
 #include <basegfx/range/b2drange.hxx>
 #include <svx/svx3ditems.hxx>
 #include <com/sun/star/drawing/ProjectionMode.hpp>
@@ -70,6 +69,7 @@
 #include <svx/svdmodel.hxx>
 #include <svx/xflbmsli.hxx>
 #include <editeng/editstat.hxx>
+#include <osl/diagnose.h>
 #include <drawinglayer/attribute/fillhatchattribute.hxx>
 #include <drawinglayer/attribute/fillgradientattribute.hxx>
 #include <sdr/attribute/sdreffectstextattribute.hxx>
@@ -83,8 +83,6 @@
 #include <sdr/attribute/sdrfilltextattribute.hxx>
 #include <com/sun/star/drawing/LineCap.hpp>
 
-#include <sal/log.hxx>
-
 using namespace com::sun::star;
 
 namespace drawinglayer
@@ -222,7 +220,7 @@ namespace drawinglayer
             Color aColor(rSet.Get(SDRATTR_GLOW_COLOR).GetColorValue());
             sal_uInt16 nTransparency(rSet.Get(SDRATTR_GLOW_TRANSPARENCY).GetValue());
             if (nTransparency)
-                aColor.SetTransparency(std::round(nTransparency / 100.0 * 255.0));
+                aColor.SetAlpha(255 - std::round(nTransparency / 100.0 * 255.0));
 
             attribute::SdrGlowAttribute glowAttr{ nRadius, aColor };
             return glowAttr;
@@ -647,8 +645,7 @@ namespace drawinglayer::primitive2d
                         static_cast<double>(rGradient.GetYOffset()) * 0.01,
                         static_cast<double>(rGradient.GetAngle().get()) * F_PI1800,
                         basegfx::BColor(fStartLum, fStartLum, fStartLum),
-                        basegfx::BColor(fEndLum, fEndLum, fEndLum),
-                        0);
+                        basegfx::BColor(fEndLum, fEndLum, fEndLum));
                 }
             }
 
@@ -659,13 +656,6 @@ namespace drawinglayer::primitive2d
         {
             Graphic aGraphic(rSet.Get(XATTR_FILLBITMAP).GetGraphicObject().GetGraphic());
 
-            OUString aOriginURL = aGraphic.getOriginURL();
-            if (aGraphic.GetType() == GraphicType::Default && !aOriginURL.isEmpty())
-            {
-                aGraphic = vcl::graphic::loadFromURL(aGraphic.getOriginURL());
-                aGraphic.setOriginURL(aOriginURL);
-            }
-
             if(GraphicType::Bitmap != aGraphic.GetType() && GraphicType::GdiMetafile != aGraphic.GetType())
             {
                 // no content if not bitmap or metafile
