@@ -34,6 +34,7 @@
 #include <vcl/settings.hxx>
 
 #include <i18nlangtag/languagetag.hxx>
+#include <o3tl/temporary.hxx>
 #include <tools/debug.hxx>
 #include <tools/urlobj.hxx>
 #include <unotools/ucbstreamhelper.hxx>
@@ -169,7 +170,7 @@ void NBOTypeMgrBase::SetItems(const SfxItemSet* pArg) {
     }
 }
 
-void NBOTypeMgrBase::ImplLoad(const OUString& filename)
+void NBOTypeMgrBase::ImplLoad(std::u16string_view filename)
 {
     bIsLoading = true;
     MapUnit      eOldCoreUnit=eCoreUnit;
@@ -193,7 +194,7 @@ void NBOTypeMgrBase::ImplLoad(const OUString& filename)
                     if (aFmt.GetBulletFont()) {
                         vcl::Font aFont(*aFmt.GetBulletFont());
                         Color c=aFont.GetColor();
-                        c.SetTransparency(0xFF);
+                        c.SetAlpha(0);
                         aFont.SetColor(c);
                         aFmt.SetBulletFont(&aFont);
                         aNum.SetLevel(i, aFmt);
@@ -207,7 +208,7 @@ void NBOTypeMgrBase::ImplLoad(const OUString& filename)
     eCoreUnit = eOldCoreUnit;
     bIsLoading = false;
 }
-void NBOTypeMgrBase::ImplStore(const OUString& filename)
+void NBOTypeMgrBase::ImplStore(std::u16string_view filename)
 {
     if (bIsLoading) return;
     MapUnit      eOldCoreUnit=eCoreUnit;
@@ -339,8 +340,7 @@ void BulletsTypeMgr::ApplyNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uInt1
             aFmt.SetBulletFont(&rActBulletFont);
             aFmt.SetBulletChar(cChar);
             aFmt.SetCharFormatName(sBulletCharFormatName);
-            aFmt.SetPrefix( "" );
-            aFmt.SetSuffix( "" );
+            aFmt.SetListFormat( "" );
             if (isResetSize) aFmt.SetBulletRelSize(45);
             aNum.SetLevel(i, aFmt);
         }
@@ -378,7 +378,7 @@ NumberingTypeMgr::NumberingTypeMgr()
 {
     Init();
     maDefaultNumberSettingsArr = maNumberSettingsArr;
-    ImplLoad("standard.syb");
+    ImplLoad(u"standard.syb");
 }
 
 NumberingTypeMgr::~NumberingTypeMgr()
@@ -502,7 +502,7 @@ void NumberingTypeMgr::RelplaceNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_
     if (!_pSet->bIsCustomized) {
         _pSet->sDescription = GetDescription(nIndex,true);
     }
-    ImplStore("standard.syb");
+    ImplStore(u"standard.syb");
 }
 
 void NumberingTypeMgr::ApplyNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uInt16 mLevel, bool isDefault, bool isResetSize)
@@ -523,9 +523,7 @@ void NumberingTypeMgr::ApplyNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uIn
             SvxNumberFormat aFmt(aNum.GetLevel(i));
             if (eNewType!=aFmt.GetNumberingType()) isResetSize=true;
             aFmt.SetNumberingType(eNewType);
-            aFmt.SetPrefix(_pSet->pNumSetting->sPrefix);
-            aFmt.SetSuffix(_pSet->pNumSetting->sSuffix);
-
+            aFmt.SetListFormat(_pSet->pNumSetting->sPrefix, _pSet->pNumSetting->sSuffix, i);
             aFmt.SetCharFormatName(sNumCharFmtName);
             if (isResetSize) aFmt.SetBulletRelSize(100);
             aNum.SetLevel(i, aFmt);
@@ -571,7 +569,7 @@ OutlineTypeMgr::OutlineTypeMgr()
     }
     //Initial the first time to store the default value. Then do it again for customized value
     Init();
-    ImplLoad("standard.syc");
+    ImplLoad(u"standard.syc");
 }
 
 namespace {
@@ -650,8 +648,8 @@ sal_uInt16 OutlineTypeMgr::GetNBOIndexForNumRule(SvxNumRule& aNum,sal_uInt16 /*m
             {
                 sal_UCS4 cChar = aFmt.GetBulletChar();
 
-                sal_Int32 nIndexUtf16 = 0;
-                sal_UCS4 ccChar = _pSet->sBulletChar.iterateCodePoints(&nIndexUtf16);
+                sal_UCS4 ccChar
+                    = _pSet->sBulletChar.iterateCodePoints(&o3tl::temporary(sal_Int32(0)));
 
                 if ( !((cChar == ccChar) &&
                     _pSet->eLabelFollowedBy == aFmt.GetLabelFollowedBy() &&
@@ -763,7 +761,7 @@ void OutlineTypeMgr::RelplaceNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uI
     if (!pItemArr->bIsCustomized) {
         pItemArr->sDescription = GetDescription(nIndex,true);
     }
-    ImplStore("standard.syc");
+    ImplStore(u"standard.syc");
 }
 
 void OutlineTypeMgr::ApplyNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uInt16 /*mLevel*/, bool isDefault, bool isResetSize)
@@ -828,8 +826,8 @@ void OutlineTypeMgr::ApplyNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uInt1
             sal_UCS4 cChar = 0;
             if( !pLevelSettings->sBulletChar.isEmpty() )
             {
-                sal_Int32 nIndexUtf16 = 0;
-                cChar = pLevelSettings->sBulletChar.iterateCodePoints(&nIndexUtf16);
+                cChar
+                    = pLevelSettings->sBulletChar.iterateCodePoints(&o3tl::temporary(sal_Int32(0)));
             }
             if( AllSettings::GetLayoutRTL() )
             {
@@ -871,8 +869,7 @@ void OutlineTypeMgr::ApplyNumRule(SvxNumRule& aNum, sal_uInt16 nIndex, sal_uInt1
             aFmt.SetFirstLineIndent(pLevelSettings->nNumAlignAt);
             aFmt.SetIndentAt(pLevelSettings->nNumIndentAt);
         }
-        aFmt.SetPrefix(pLevelSettings->sPrefix);
-        aFmt.SetSuffix(pLevelSettings->sSuffix);
+        aFmt.SetListFormat(pLevelSettings->sPrefix, pLevelSettings->sSuffix, i);
         aNum.SetLevel(i, aFmt);
     }
 }
