@@ -54,8 +54,8 @@ void SdrTextObj::AddToHdlList(SdrHdlList& rHdlList) const
             case 6: aPnt=maRect.BottomCenter(); eKind=SdrHdlKind::Lower; break;
             case 7: aPnt=maRect.BottomRight();  eKind=SdrHdlKind::LowerRight; break;
         }
-        if (aGeo.nShearAngle!=0) ShearPoint(aPnt,maRect.TopLeft(),aGeo.nTan);
-        if (aGeo.nRotationAngle!=0) RotatePoint(aPnt,maRect.TopLeft(),aGeo.nSin,aGeo.nCos);
+        if (aGeo.nShearAngle) ShearPoint(aPnt,maRect.TopLeft(),aGeo.mfTanShearAngle);
+        if (aGeo.nRotationAngle) RotatePoint(aPnt,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
         std::unique_ptr<SdrHdl> pH(new SdrHdl(aPnt,eKind));
         pH->SetObj(const_cast<SdrTextObj*>(this));
         pH->SetRotationAngle(aGeo.nRotationAngle);
@@ -79,9 +79,9 @@ tools::Rectangle SdrTextObj::ImpDragCalcRect(const SdrDragStat& rDrag) const
     bool bBigOrtho=bEcke && bOrtho && rDrag.GetView()->IsBigOrtho();
     Point aPos(rDrag.GetNow());
     // Unrotate:
-    if (aGeo.nRotationAngle!=0) RotatePoint(aPos,aTmpRect.TopLeft(),-aGeo.nSin,aGeo.nCos);
+    if (aGeo.nRotationAngle) RotatePoint(aPos,aTmpRect.TopLeft(),-aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
     // Unshear:
-    if (aGeo.nShearAngle!=0) ShearPoint(aPos,aTmpRect.TopLeft(),-aGeo.nTan);
+    if (aGeo.nShearAngle) ShearPoint(aPos,aTmpRect.TopLeft(),-aGeo.mfTanShearAngle);
 
     bool bLft=(eHdl==SdrHdlKind::UpperLeft || eHdl==SdrHdlKind::Left  || eHdl==SdrHdlKind::LowerLeft);
     bool bRgt=(eHdl==SdrHdlKind::UpperRight || eHdl==SdrHdlKind::Right || eHdl==SdrHdlKind::LowerRight);
@@ -92,12 +92,12 @@ tools::Rectangle SdrTextObj::ImpDragCalcRect(const SdrDragStat& rDrag) const
     if (bTop) aTmpRect.SetTop(aPos.Y() );
     if (bBtm) aTmpRect.SetBottom(aPos.Y() );
     if (bOrtho) { // Ortho
-        long nWdt0=maRect.Right() -maRect.Left();
-        long nHgt0=maRect.Bottom()-maRect.Top();
-        long nXMul=aTmpRect.Right() -aTmpRect.Left();
-        long nYMul=aTmpRect.Bottom()-aTmpRect.Top();
-        long nXDiv=nWdt0;
-        long nYDiv=nHgt0;
+        tools::Long nWdt0=maRect.Right() -maRect.Left();
+        tools::Long nHgt0=maRect.Bottom()-maRect.Top();
+        tools::Long nXMul=aTmpRect.Right() -aTmpRect.Left();
+        tools::Long nYMul=aTmpRect.Bottom()-aTmpRect.Top();
+        tools::Long nXDiv=nWdt0;
+        tools::Long nYDiv=nHgt0;
         bool bXNeg=(nXMul<0)!=(nXDiv<0);
         bool bYNeg=(nYMul<0)!=(nYDiv<0);
         nXMul=std::abs(nXMul);
@@ -113,26 +113,26 @@ tools::Rectangle SdrTextObj::ImpDragCalcRect(const SdrDragStat& rDrag) const
         if (bEcke) { // corner point handles
             bool bUseX=(aXFact<aYFact) != bBigOrtho;
             if (bUseX) {
-                long nNeed=long(BigInt(nHgt0)*BigInt(nXMul)/BigInt(nXDiv));
+                tools::Long nNeed=tools::Long(BigInt(nHgt0)*BigInt(nXMul)/BigInt(nXDiv));
                 if (bYNeg) nNeed=-nNeed;
                 if (bTop) aTmpRect.SetTop(aTmpRect.Bottom()-nNeed );
                 if (bBtm) aTmpRect.SetBottom(aTmpRect.Top()+nNeed );
             } else {
-                long nNeed=long(BigInt(nWdt0)*BigInt(nYMul)/BigInt(nYDiv));
+                tools::Long nNeed=tools::Long(BigInt(nWdt0)*BigInt(nYMul)/BigInt(nYDiv));
                 if (bXNeg) nNeed=-nNeed;
                 if (bLft) aTmpRect.SetLeft(aTmpRect.Right()-nNeed );
                 if (bRgt) aTmpRect.SetRight(aTmpRect.Left()+nNeed );
             }
         } else { // apex handles
             if ((bLft || bRgt) && nXDiv!=0) {
-                long nHgt0b=maRect.Bottom()-maRect.Top();
-                long nNeed=long(BigInt(nHgt0b)*BigInt(nXMul)/BigInt(nXDiv));
+                tools::Long nHgt0b=maRect.Bottom()-maRect.Top();
+                tools::Long nNeed=tools::Long(BigInt(nHgt0b)*BigInt(nXMul)/BigInt(nXDiv));
                 aTmpRect.AdjustTop( -((nNeed-nHgt0b)/2) );
                 aTmpRect.SetBottom(aTmpRect.Top()+nNeed );
             }
             if ((bTop || bBtm) && nYDiv!=0) {
-                long nWdt0b=maRect.Right()-maRect.Left();
-                long nNeed=long(BigInt(nWdt0b)*BigInt(nYMul)/BigInt(nYDiv));
+                tools::Long nWdt0b=maRect.Right()-maRect.Left();
+                tools::Long nNeed=tools::Long(BigInt(nWdt0b)*BigInt(nYMul)/BigInt(nYDiv));
                 aTmpRect.AdjustLeft( -((nNeed-nWdt0b)/2) );
                 aTmpRect.SetRight(aTmpRect.Left()+nNeed );
             }
@@ -155,10 +155,10 @@ bool SdrTextObj::applySpecialDrag(SdrDragStat& rDrag)
         Point aNewPos(aNewRect.TopLeft());
 
         if(aGeo.nShearAngle)
-            ShearPoint(aNewPos,maRect.TopLeft(),aGeo.nTan);
+            ShearPoint(aNewPos,maRect.TopLeft(),aGeo.mfTanShearAngle);
 
         if(aGeo.nRotationAngle)
-            RotatePoint(aNewPos,maRect.TopLeft(),aGeo.nSin,aGeo.nCos);
+            RotatePoint(aNewPos,maRect.TopLeft(),aGeo.mfSinRotationAngle,aGeo.mfCosRotationAngle);
 
         aNewRect.SetPos(aNewPos);
     }
@@ -197,9 +197,9 @@ bool SdrTextObj::MovCreate(SdrDragStat& rStat)
     rStat.SetActionRect(aRect1);
     maRect = aRect1; // for ObjName
     SetBoundRectDirty();
-    bSnapRectDirty=true;
-    if (dynamic_cast<const SdrRectObj *>(this) != nullptr) {
-        static_cast<SdrRectObj*>(this)->SetXPolyDirty();
+    m_bSnapRectDirty=true;
+    if (auto pRectObj = dynamic_cast<SdrRectObj *>(this)) {
+        pRectObj->SetXPolyDirty();
     }
     return true;
 }
@@ -212,8 +212,8 @@ bool SdrTextObj::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
     AdaptTextMinSize();
 
     SetRectsDirty();
-    if (dynamic_cast<const SdrRectObj *>(this) != nullptr) {
-        static_cast<SdrRectObj*>(this)->SetXPolyDirty();
+    if (auto pRectObj = dynamic_cast<SdrRectObj *>(this)) {
+        pRectObj->SetXPolyDirty();
     }
     return (eCmd==SdrCreateCmd::ForceEnd || rStat.GetPointCount()>=2);
 }
