@@ -31,6 +31,7 @@
 
 #include <editeng/unoedsrc.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/window.hxx>
 
 #include <unotools/accessiblestatesethelper.hxx>
 #include <comphelper/string.hxx>
@@ -78,7 +79,7 @@ void AccessibleCell::Init()
     {
         // non-empty text -> use full-fledged edit source right away
 
-        mpText.reset( new AccessibleTextHelper( std::make_unique<SvxTextEditSource>(mxCell->GetObject(), mxCell.get(), *pView, *pWindow) ) );
+        mpText.reset( new AccessibleTextHelper( std::make_unique<SvxTextEditSource>(mxCell->GetObject(), mxCell.get(), *pView, *pWindow->GetOutDev()) ) );
         if( mxCell.is() && mxCell->IsActiveCell() )
             mpText->SetFocus();
         mpText->SetEventSource(this);
@@ -133,13 +134,13 @@ Any SAL_CALL AccessibleCell::queryInterface( const Type& aType )
 }
 
 
-void SAL_CALL AccessibleCell::acquire(  ) throw ()
+void SAL_CALL AccessibleCell::acquire(  ) noexcept
 {
     AccessibleCellBase::acquire();
 }
 
 
-void SAL_CALL AccessibleCell::release(  ) throw ()
+void SAL_CALL AccessibleCell::release(  ) noexcept
 {
     AccessibleCellBase::release();
 }
@@ -550,7 +551,7 @@ OUString AccessibleCell::getCellName( sal_Int32 nCol, sal_Int32 nRow )
                 static_cast<sal_uInt16>(nCol)));
         aBuf.append(comphelper::string::reverseString(aStr.makeStringAndClear()));
     }
-    aBuf.append( OUString::number(nRow+1) );
+    aBuf.append(nRow+1);
     return aBuf.makeStringAndClear();
 }
 
