@@ -44,8 +44,8 @@ namespace svx
 {
 
 const sal_Int32 gSkewList[] = { 135, 90, 45, 180, 0, -360, -135, -90, -45 };
-const char g_sExtrusionDirection[] = ".uno:ExtrusionDirection";
-const char g_sExtrusionProjection[] = ".uno:ExtrusionProjection";
+constexpr OUStringLiteral g_sExtrusionDirection = u".uno:ExtrusionDirection";
+constexpr OUStringLiteral g_sExtrusionProjection = u".uno:ExtrusionProjection";
 
 const std::u16string_view aLightOffBmps[] =
 {
@@ -126,7 +126,7 @@ ExtrusionDirectionWindow::ExtrusionDirectionWindow(
 
     for (sal_uInt16 i = DIRECTION_NW; i <= DIRECTION_SE; ++i)
     {
-        maImgDirection[i] = Image(StockImage::Yes, aDirectionBmps[i]);
+        maImgDirection[i] = Image(StockImage::Yes, OUString(aDirectionBmps[i]));
     }
 
     mxDirectionSet->SetSelectHdl( LINK( this, ExtrusionDirectionWindow, SelectValueSetHdl ) );
@@ -142,8 +142,7 @@ ExtrusionDirectionWindow::ExtrusionDirectionWindow(
     mxDirectionSet->GetDrawingArea()->set_size_request(aSize.Width(), aSize.Height());
     mxDirectionSet->SetOutputSizePixel(aSize);
 
-    mxPerspective->connect_clicked(LINK(this, ExtrusionDirectionWindow, SelectToolbarMenuHdl));
-    mxParallel->connect_clicked(LINK(this, ExtrusionDirectionWindow, SelectToolbarMenuHdl));
+    mxPerspective->connect_toggled(LINK(this, ExtrusionDirectionWindow, SelectToolbarMenuHdl));
 
     AddStatusListener( g_sExtrusionDirection );
     AddStatusListener( g_sExtrusionProjection );
@@ -233,7 +232,7 @@ IMPL_LINK_NOARG(ExtrusionDirectionWindow, SelectValueSetHdl, ValueSet*, void)
     mxControl->EndPopupMode();
 }
 
-IMPL_LINK_NOARG(ExtrusionDirectionWindow, SelectToolbarMenuHdl, weld::Button&, void)
+IMPL_LINK_NOARG(ExtrusionDirectionWindow, SelectToolbarMenuHdl, weld::Toggleable&, void)
 {
     int nProjection = mxPerspective->get_active() ? 0 : 1;
 
@@ -278,7 +277,7 @@ void SAL_CALL ExtrusionDirectionControl::initialize( const css::uno::Sequence< c
     svt::PopupWindowController::initialize( aArguments );
 
     ToolBox* pToolBox = nullptr;
-    sal_uInt16 nId = 0;
+    ToolBoxItemId nId;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
 }
@@ -349,7 +348,7 @@ ExtrusionDepthWindow::ExtrusionDepthWindow(svt::PopupWindowController* pControl,
     mxDepth3->connect_toggled(LINK(this, ExtrusionDepthWindow, SelectHdl));
     mxDepth4->connect_toggled(LINK(this, ExtrusionDepthWindow, SelectHdl));
     mxInfinity->connect_toggled(LINK(this, ExtrusionDepthWindow, SelectHdl));
-    mxCustom->connect_clicked(LINK(this, ExtrusionDepthWindow, ClickHdl));
+    mxCustom->connect_toggled(LINK(this, ExtrusionDepthWindow, SelectHdl));
 
     AddStatusListener( gsExtrusionDepth );
     AddStatusListener( gsMetricUnit );
@@ -444,12 +443,7 @@ void ExtrusionDepthWindow::statusChanged(
     }
 }
 
-IMPL_LINK_NOARG(ExtrusionDepthWindow, ClickHdl, weld::Button&, void)
-{
-    SelectHdl(*mxCustom);
-}
-
-IMPL_LINK(ExtrusionDepthWindow, SelectHdl, weld::ToggleButton&, rButton, void)
+IMPL_LINK(ExtrusionDepthWindow, SelectHdl, weld::Toggleable&, rButton, void)
 {
     if (mbSettingValue || !rButton.get_active())
         return;
@@ -534,7 +528,7 @@ void SAL_CALL ExtrusionDepthController::initialize( const css::uno::Sequence< cs
     svt::PopupWindowController::initialize( aArguments );
 
     ToolBox* pToolBox = nullptr;
-    sal_uInt16 nId = 0;
+    ToolBoxItemId nId;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
 }
@@ -563,8 +557,8 @@ com_sun_star_comp_svx_ExtrusionDepthController_get_implementation(
 }
 
 
-const char g_sExtrusionLightingDirection[] = ".uno:ExtrusionLightingDirection";
-const char g_sExtrusionLightingIntensity[] = ".uno:ExtrusionLightingIntensity";
+constexpr OUStringLiteral g_sExtrusionLightingDirection = u".uno:ExtrusionLightingDirection";
+constexpr OUStringLiteral g_sExtrusionLightingIntensity = u".uno:ExtrusionLightingIntensity";
 
 ExtrusionLightingWindow::ExtrusionLightingWindow(svt::PopupWindowController* pControl,
                                                  weld::Widget* pParent)
@@ -582,10 +576,10 @@ ExtrusionLightingWindow::ExtrusionLightingWindow(svt::PopupWindowController* pCo
     {
         if( i != FROM_FRONT )
         {
-            maImgLightingOff[i] = Image(StockImage::Yes, aLightOffBmps[i]);
-            maImgLightingOn[i] = Image(StockImage::Yes, aLightOnBmps[i]);
+            maImgLightingOff[i] = Image(StockImage::Yes, OUString(aLightOffBmps[i]));
+            maImgLightingOn[i] = Image(StockImage::Yes, OUString(aLightOnBmps[i]));
         }
-        maImgLightingPreview[i] = Image(StockImage::Yes, aLightPreviewBmps[i]);
+        maImgLightingPreview[i] = Image(StockImage::Yes, OUString(aLightPreviewBmps[i]));
     }
 
     mxLightingSet->SetHelpId( HID_VALUESET_EXTRUSION_LIGHTING );
@@ -609,9 +603,9 @@ ExtrusionLightingWindow::ExtrusionLightingWindow(svt::PopupWindowController* pCo
     mxLightingSet->GetDrawingArea()->set_size_request(aSize.Width(), aSize.Height());
     mxLightingSet->SetOutputSizePixel(aSize);
 
-    mxBright->connect_clicked(LINK(this, ExtrusionLightingWindow, SelectToolbarMenuHdl));
-    mxNormal->connect_clicked(LINK(this, ExtrusionLightingWindow, SelectToolbarMenuHdl));
-    mxDim->connect_clicked(LINK(this, ExtrusionLightingWindow, SelectToolbarMenuHdl));
+    mxBright->connect_toggled(LINK(this, ExtrusionLightingWindow, SelectToolbarMenuHdl));
+    mxNormal->connect_toggled(LINK(this, ExtrusionLightingWindow, SelectToolbarMenuHdl));
+    mxDim->connect_toggled(LINK(this, ExtrusionLightingWindow, SelectToolbarMenuHdl));
 
     AddStatusListener( g_sExtrusionLightingDirection );
     AddStatusListener( g_sExtrusionLightingIntensity );
@@ -715,8 +709,11 @@ IMPL_LINK_NOARG(ExtrusionLightingWindow, SelectValueSetHdl, ValueSet*, void)
     mxControl->EndPopupMode();
 }
 
-IMPL_LINK_NOARG(ExtrusionLightingWindow, SelectToolbarMenuHdl, weld::Button&, void)
+IMPL_LINK(ExtrusionLightingWindow, SelectToolbarMenuHdl, weld::Toggleable&, rButton, void)
 {
+    if (!rButton.get_active())
+        return;
+
     int nLevel;
     if (mxBright->get_active())
         nLevel = 0;
@@ -766,7 +763,7 @@ void SAL_CALL ExtrusionLightingControl::initialize( const css::uno::Sequence< cs
     svt::PopupWindowController::initialize( aArguments );
 
     ToolBox* pToolBox = nullptr;
-    sal_uInt16 nId = 0;
+    ToolBoxItemId nId;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
 }
@@ -795,7 +792,7 @@ com_sun_star_comp_svx_ExtrusionLightingControl_get_implementation(
 }
 
 
-const char g_sExtrusionSurface[] = ".uno:ExtrusionSurface";
+constexpr OUStringLiteral g_sExtrusionSurface = u".uno:ExtrusionSurface";
 
 ExtrusionSurfaceWindow::ExtrusionSurfaceWindow(svt::PopupWindowController* pControl, weld::Widget* pParent)
     : WeldToolbarPopup(pControl->getFrameInterface(), pParent, "svx/ui/surfacewindow.ui", "SurfaceWindow")
@@ -805,10 +802,10 @@ ExtrusionSurfaceWindow::ExtrusionSurfaceWindow(svt::PopupWindowController* pCont
     , mxPlastic(m_xBuilder->weld_radio_button("plastic"))
     , mxMetal(m_xBuilder->weld_radio_button("metal"))
 {
-    mxWireFrame->connect_clicked(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
-    mxMatt->connect_clicked(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
-    mxPlastic->connect_clicked(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
-    mxMetal->connect_clicked(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
+    mxWireFrame->connect_toggled(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
+    mxMatt->connect_toggled(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
+    mxPlastic->connect_toggled(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
+    mxMetal->connect_toggled(LINK(this, ExtrusionSurfaceWindow, SelectHdl));
 
     AddStatusListener( g_sExtrusionSurface );
 }
@@ -849,8 +846,11 @@ void ExtrusionSurfaceWindow::statusChanged(
     }
 }
 
-IMPL_LINK_NOARG(ExtrusionSurfaceWindow, SelectHdl, weld::Button&, void)
+IMPL_LINK(ExtrusionSurfaceWindow, SelectHdl, weld::Toggleable&, rButton, void)
 {
+    if (!rButton.get_active())
+        return;
+
     sal_Int32 nSurface;
     if (mxWireFrame->get_active())
         nSurface = 0;
@@ -904,7 +904,7 @@ void SAL_CALL ExtrusionSurfaceControl::initialize( const css::uno::Sequence< css
     svt::PopupWindowController::initialize( aArguments );
 
     ToolBox* pToolBox = nullptr;
-    sal_uInt16 nId = 0;
+    ToolBoxItemId nId;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
 }
