@@ -41,7 +41,6 @@
 #include <svx/xflgrit.hxx>
 #include <svx/xflhtit.hxx>
 #include <svx/xbtmpit.hxx>
-#include <boost/property_tree/ptree.hpp>
 #include <memory>
 
 using namespace ::com::sun::star;
@@ -54,7 +53,7 @@ SFX_IMPL_TOOLBOX_CONTROL( SvxFillToolBoxControl, XFillStyleItem );
 
 SvxFillToolBoxControl::SvxFillToolBoxControl(
     sal_uInt16 nSlotId,
-    sal_uInt16 nId,
+    ToolBoxItemId nId,
     ToolBox& rTbx )
     : SfxToolBoxControl( nSlotId, nId, rTbx )
     , mpStyleItem()
@@ -385,10 +384,10 @@ void SvxFillToolBoxControl::Update()
                         }
                         aTmpStr = TMP_STR_BEGIN + aString + TMP_STR_END;
 
-                        XGradientList aGradientList( "", ""/*TODO?*/ );
-                        aGradientList.Insert(std::make_unique<XGradientEntry>(mpFillGradientItem->GetGradientValue(), aTmpStr));
-                        aGradientList.SetDirty( false );
-                        const BitmapEx aBmp = aGradientList.GetUiBitmap( 0 );
+                        rtl::Reference<XGradientList> xGradientList = new XGradientList( "", ""/*TODO?*/ );
+                        xGradientList->Insert(std::make_unique<XGradientEntry>(mpFillGradientItem->GetGradientValue(), aTmpStr));
+                        xGradientList->SetDirty( false );
+                        const BitmapEx aBmp = xGradientList->GetUiBitmap( 0 );
 
                         if (!aBmp.IsEmpty())
                         {
@@ -396,7 +395,7 @@ void SvxFillToolBoxControl::Update()
                             const Size aBmpSize(aBmp.GetSizePixel());
                             pVD->SetOutputSizePixel(aBmpSize, false);
                             pVD->DrawBitmapEx(Point(), aBmp);
-                            mpLbFillAttr->append("", aGradientList.Get(0)->GetName(), *pVD);
+                            mpLbFillAttr->append("", xGradientList->Get(0)->GetName(), *pVD);
                             mpLbFillAttr->set_active(mpLbFillAttr->get_count() - 1);
                         }
                     }
@@ -448,10 +447,10 @@ void SvxFillToolBoxControl::Update()
                         }
                         aTmpStr = TMP_STR_BEGIN + aString + TMP_STR_END;
 
-                        XHatchList aHatchList( "", ""/*TODO?*/ );
-                        aHatchList.Insert(std::make_unique<XHatchEntry>(mpHatchItem->GetHatchValue(), aTmpStr));
-                        aHatchList.SetDirty( false );
-                        const BitmapEx & aBmp = aHatchList.GetUiBitmap( 0 );
+                        rtl::Reference<XHatchList> xHatchList = new XHatchList( "", ""/*TODO?*/ );
+                        xHatchList->Insert(std::make_unique<XHatchEntry>(mpHatchItem->GetHatchValue(), aTmpStr));
+                        xHatchList->SetDirty( false );
+                        const BitmapEx & aBmp = xHatchList->GetUiBitmap( 0 );
 
                         if( !aBmp.IsEmpty() )
                         {
@@ -459,7 +458,7 @@ void SvxFillToolBoxControl::Update()
                             const Size aBmpSize(aBmp.GetSizePixel());
                             pVD->SetOutputSizePixel(aBmpSize, false);
                             pVD->DrawBitmapEx(Point(), aBmp);
-                            mpLbFillAttr->append("", aHatchList.GetHatch(0)->GetName(), *pVD);
+                            mpLbFillAttr->append("", xHatchList->GetHatch(0)->GetName(), *pVD);
                             mpLbFillAttr->set_active(mpLbFillAttr->get_count() - 1);
                         }
                     }
@@ -700,11 +699,10 @@ IMPL_LINK_NOARG(SvxFillToolBoxControl, SelectFillTypeHdl, weld::ComboBox&, void)
         {
             mpLbFillAttr->hide();
             mpToolBoxColor->show();
+            const ::Color aColor = mpColorItem->GetColorValue();
+            const XFillColorItem aXFillColorItem( "", aColor );
             if (pSh)
             {
-                const ::Color aColor = mpColorItem ? mpColorItem->GetColorValue() : COL_AUTO;
-                const XFillColorItem aXFillColorItem( "", aColor );
-
                 // #i122676# change FillStyle and Color in one call
                 pSh->GetDispatcher()->ExecuteList(
                     SID_ATTR_FILL_COLOR, SfxCallMode::RECORD,
