@@ -59,8 +59,8 @@ class FontHeightToolBoxControl : public svt::ToolboxController,
 
         // XInterface
         virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-        virtual void SAL_CALL acquire() throw () override;
-        virtual void SAL_CALL release() throw () override;
+        virtual void SAL_CALL acquire() noexcept override;
+        virtual void SAL_CALL release() noexcept override;
 
         // XServiceInfo
         virtual OUString SAL_CALL getImplementationName() override;
@@ -255,7 +255,7 @@ void SvxFontSizeBox_Base::UpdateFont(const css::awt::FontDescriptor& rCurrentFon
 {
     // filling up the sizes list
     auto nOldVal = m_xWidget->get_value(); // memorize old value
-    std::unique_ptr<FontList> xFontList(new FontList(Application::GetDefaultDevice()));
+    FontList aFontList(Application::GetDefaultDevice());
 
     if (!rCurrentFont.Name.isEmpty())
     {
@@ -263,11 +263,11 @@ void SvxFontSizeBox_Base::UpdateFont(const css::awt::FontDescriptor& rCurrentFon
         aFontMetric.SetFamilyName(rCurrentFont.Name);
         aFontMetric.SetStyleName(rCurrentFont.StyleName);
         aFontMetric.SetFontHeight(rCurrentFont.Height);
-        m_xWidget->Fill(&aFontMetric, xFontList.get());
+        m_xWidget->Fill(&aFontMetric, &aFontList);
     }
     else
     {
-        m_xWidget->Fill(nullptr, xFontList.get());
+        m_xWidget->Fill(nullptr, &aFontList);
     }
     m_xWidget->set_value(nOldVal); // restore old value
     m_aCurText = m_xWidget->get_active_text(); // memorize to reset at ESC
@@ -381,12 +381,12 @@ css::uno::Any SAL_CALL FontHeightToolBoxControl::queryInterface( const css::uno:
     return ::cppu::queryInterface( aType, static_cast< lang::XServiceInfo* >( this ));
 }
 
-void SAL_CALL FontHeightToolBoxControl::acquire() throw ()
+void SAL_CALL FontHeightToolBoxControl::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL FontHeightToolBoxControl::release() throw ()
+void SAL_CALL FontHeightToolBoxControl::release() noexcept
 {
     ToolboxController::release();
 }
@@ -448,7 +448,7 @@ void SAL_CALL FontHeightToolBoxControl::statusChanged(
         else
         {
             ToolBox* pToolBox = nullptr;
-            sal_uInt16 nId = 0;
+            ToolBoxItemId nId;
             if (getToolboxId(nId, &pToolBox))
                 pToolBox->EnableItem(nId, rEvent.IsEnabled);
         }
