@@ -66,12 +66,12 @@ using namespace css;
 
 namespace {
 
-const char COMMAND_FINDTEXT[] = ".uno:FindText";
-const char COMMAND_DOWNSEARCH[] = ".uno:DownSearch";
-const char COMMAND_UPSEARCH[] = ".uno:UpSearch";
-const char COMMAND_FINDALL[] = ".uno:FindAll";
-const char COMMAND_MATCHCASE[] = ".uno:MatchCase";
-const char COMMAND_SEARCHFORMATTED[] = ".uno:SearchFormattedDisplayString";
+constexpr OUStringLiteral COMMAND_FINDTEXT = u".uno:FindText";
+constexpr OUStringLiteral COMMAND_DOWNSEARCH = u".uno:DownSearch";
+constexpr OUStringLiteral COMMAND_UPSEARCH = u".uno:UpSearch";
+constexpr OUStringLiteral COMMAND_FINDALL = u".uno:FindAll";
+constexpr OUStringLiteral COMMAND_MATCHCASE = u".uno:MatchCase";
+constexpr OUStringLiteral COMMAND_SEARCHFORMATTED = u".uno:SearchFormattedDisplayString";
 
 const sal_Int32       REMEMBER_SIZE = 10;
 
@@ -135,7 +135,7 @@ void impl_executeSearch( const css::uno::Reference< css::uno::XComponentContext
         ToolBox::ImplToolItems::size_type nItemCount = pToolBox->GetItemCount();
         for ( ToolBox::ImplToolItems::size_type i=0; i<nItemCount; ++i )
         {
-            sal_uInt16 id = pToolBox->GetItemId(i);
+            ToolBoxItemId id = pToolBox->GetItemId(i);
             OUString sItemCommand = pToolBox->GetItemCommand(id);
             if ( sItemCommand == COMMAND_FINDTEXT )
             {
@@ -288,7 +288,7 @@ IMPL_LINK(FindTextFieldControl, KeyInputHdl, const KeyEvent&, rKeyEvent, bool)
             aValue >>= xLayoutManager;
             if (xLayoutManager.is())
             {
-                const OUString sResourceURL( "private:resource/toolbar/findbar" );
+                static const OUStringLiteral sResourceURL( u"private:resource/toolbar/findbar" );
                 xLayoutManager->hideElement( sResourceURL );
                 xLayoutManager->destroyElement( sResourceURL );
             }
@@ -298,11 +298,10 @@ IMPL_LINK(FindTextFieldControl, KeyInputHdl, const KeyEvent&, rKeyEvent, bool)
     else if ( bMod1 && nCode == KEY_F )
         m_xWidget->select_entry_region(0, -1);
 
-    // Execute the search when Return, Ctrl-G or F3 pressed
-    else if ( KEY_RETURN == nCode || (bMod1 && (KEY_G == nCode)) || (KEY_F3 == nCode) )
+    // Execute the search when Ctrl-G or F3 pressed (in addition to ActivateHdl conditions)
+    else if ( (bMod1 && (KEY_G == nCode)) || (KEY_F3 == nCode) )
     {
         ActivateFind(bShift);
-        m_xWidget->grab_focus();
         bRet = true;
     }
     else
@@ -324,8 +323,11 @@ void FindTextFieldControl::ActivateFind(bool bShift)
     ToolBox* pToolBox = static_cast<ToolBox*>(pWindow);
 
     impl_executeSearch(m_xContext, m_xFrame, pToolBox, bShift);
+
+    m_xWidget->grab_focus();
 }
 
+// Execute the search when activated, typically due to "Return"
 IMPL_LINK_NOARG(FindTextFieldControl, ActivateHdl, weld::ComboBox&, bool)
 {
     if (isDisposed())
@@ -529,8 +531,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -557,9 +559,9 @@ private:
 
     VclPtr<FindTextFieldControl> m_pFindTextFieldControl;
 
-    sal_uInt16 m_nDownSearchId;
-    sal_uInt16 m_nUpSearchId;
-    sal_uInt16 m_nFindAllId;
+    ToolBoxItemId m_nDownSearchId;
+    ToolBoxItemId m_nUpSearchId;
+    ToolBoxItemId m_nFindAllId;
 
 };
 
@@ -582,12 +584,12 @@ css::uno::Any SAL_CALL FindTextToolbarController::queryInterface( const css::uno
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL FindTextToolbarController::acquire() throw ()
+void SAL_CALL FindTextToolbarController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL FindTextToolbarController::release() throw ()
+void SAL_CALL FindTextToolbarController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -707,8 +709,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -749,12 +751,12 @@ css::uno::Any SAL_CALL UpDownSearchToolboxController::queryInterface( const css:
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL UpDownSearchToolboxController::acquire() throw ()
+void SAL_CALL UpDownSearchToolboxController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL UpDownSearchToolboxController::release() throw ()
+void SAL_CALL UpDownSearchToolboxController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -825,8 +827,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -867,12 +869,12 @@ css::uno::Any SAL_CALL MatchCaseToolboxController::queryInterface( const css::un
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL MatchCaseToolboxController::acquire() throw ()
+void SAL_CALL MatchCaseToolboxController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL MatchCaseToolboxController::release() throw ()
+void SAL_CALL MatchCaseToolboxController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -941,8 +943,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -983,12 +985,12 @@ css::uno::Any SAL_CALL SearchFormattedToolboxController::queryInterface( const c
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL SearchFormattedToolboxController::acquire() throw ()
+void SAL_CALL SearchFormattedToolboxController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL SearchFormattedToolboxController::release() throw ()
+void SAL_CALL SearchFormattedToolboxController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -1057,8 +1059,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -1095,12 +1097,12 @@ css::uno::Any SAL_CALL FindAllToolboxController::queryInterface( const css::uno:
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL FindAllToolboxController::acquire() throw ()
+void SAL_CALL FindAllToolboxController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL FindAllToolboxController::release() throw ()
+void SAL_CALL FindAllToolboxController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -1164,8 +1166,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -1202,12 +1204,12 @@ css::uno::Any SAL_CALL ExitSearchToolboxController::queryInterface( const css::u
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL ExitSearchToolboxController::acquire() throw ()
+void SAL_CALL ExitSearchToolboxController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL ExitSearchToolboxController::release() throw ()
+void SAL_CALL ExitSearchToolboxController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -1262,7 +1264,7 @@ void SAL_CALL ExitSearchToolboxController::execute( sal_Int16 /*KeyModifier*/ )
         aValue >>= xLayoutManager;
         if (xLayoutManager.is())
         {
-            const OUString sResourceURL( "private:resource/toolbar/findbar" );
+            static const OUStringLiteral sResourceURL( u"private:resource/toolbar/findbar" );
             xLayoutManager->hideElement( sResourceURL );
             xLayoutManager->destroyElement( sResourceURL );
         }
@@ -1282,8 +1284,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw () override;
-    virtual void SAL_CALL release() throw () override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -1323,12 +1325,12 @@ css::uno::Any SAL_CALL SearchLabelToolboxController::queryInterface( const css::
     return ::cppu::queryInterface( aType, static_cast< css::lang::XServiceInfo* >( this ) );
 }
 
-void SAL_CALL SearchLabelToolboxController::acquire() throw ()
+void SAL_CALL SearchLabelToolboxController::acquire() noexcept
 {
     ToolboxController::acquire();
 }
 
-void SAL_CALL SearchLabelToolboxController::release() throw ()
+void SAL_CALL SearchLabelToolboxController::release() noexcept
 {
     ToolboxController::release();
 }
@@ -1385,7 +1387,7 @@ void SAL_CALL SearchLabelToolboxController::statusChanged( const css::frame::Fea
 css::uno::Reference< css::awt::XWindow > SAL_CALL SearchLabelToolboxController::createItemWindow( const css::uno::Reference< css::awt::XWindow >& Parent )
 {
     ToolBox* pToolBox = nullptr;
-    sal_uInt16 nId = 0;
+    ToolBoxItemId nId;
     if (getToolboxId(nId, &pToolBox))
         pToolBox->SetItemWindowNonInteractive(nId, true);
 
@@ -1409,8 +1411,8 @@ public:
 
     // XInterface
     virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType ) override;
-    virtual void SAL_CALL acquire() throw() override;
-    virtual void SAL_CALL release() throw() override;
+    virtual void SAL_CALL acquire() noexcept override;
+    virtual void SAL_CALL release() noexcept override;
 
     // XServiceInfo
     virtual OUString SAL_CALL getImplementationName() override;
@@ -1459,12 +1461,12 @@ css::uno::Any SAL_CALL FindbarDispatcher::queryInterface( const css::uno::Type&
     return OWeakObject::queryInterface( aType );
 }
 
-void SAL_CALL FindbarDispatcher::acquire() throw()
+void SAL_CALL FindbarDispatcher::acquire() noexcept
 {
     OWeakObject::acquire();
 }
 
-void SAL_CALL FindbarDispatcher::release() throw()
+void SAL_CALL FindbarDispatcher::release() noexcept
 {
     OWeakObject::release();
 }
@@ -1532,7 +1534,7 @@ void SAL_CALL FindbarDispatcher::dispatch( const css::util::URL& aURL, const css
     if (!xLayoutManager.is())
         return;
 
-    const OUString sResourceURL( "private:resource/toolbar/findbar" );
+    static const OUStringLiteral sResourceURL( u"private:resource/toolbar/findbar" );
     css::uno::Reference< css::ui::XUIElement > xUIElement = xLayoutManager->getElement(sResourceURL);
     if (!xUIElement.is())
     {
@@ -1554,7 +1556,7 @@ void SAL_CALL FindbarDispatcher::dispatch( const css::util::URL& aURL, const css
     ToolBox::ImplToolItems::size_type nItemCount = pToolBox->GetItemCount();
     for ( ToolBox::ImplToolItems::size_type i=0; i<nItemCount; ++i )
     {
-        sal_uInt16 id = pToolBox->GetItemId(i);
+        ToolBoxItemId id = pToolBox->GetItemId(i);
         OUString sItemCommand = pToolBox->GetItemCommand(id);
         if ( sItemCommand == COMMAND_FINDTEXT )
         {
