@@ -151,8 +151,8 @@ static void SetFontWorkShapeTypeState( SdrView const * pSdrView, SfxItemSet& rSe
         SdrObject* pObj = rMarkList.GetMark( i )->GetMarkedSdrObj();
         if( dynamic_cast<const SdrObjCustomShape*>( pObj) !=  nullptr )
         {
-            const SdrCustomShapeGeometryItem aGeometryItem( pObj->GetMergedItem( SDRATTR_CUSTOMSHAPE_GEOMETRY ) );
-            const Any* pAny = aGeometryItem.GetPropertyValueByName( "Type" );
+            const SdrCustomShapeGeometryItem & rGeometryItem( pObj->GetMergedItem( SDRATTR_CUSTOMSHAPE_GEOMETRY ) );
+            const Any* pAny = rGeometryItem.GetPropertyValueByName( "Type" );
             if( pAny )
             {
                 OUString aType;
@@ -205,33 +205,34 @@ FontworkBar::~FontworkBar()
 }
 
 namespace svx {
-bool checkForSelectedFontWork( SdrView const * pSdrView, sal_uInt32& nCheckStatus )
+bool checkForFontWork( SdrObject* pObj )
 {
-    if ( nCheckStatus & 2 )
-        return ( nCheckStatus & 1 ) != 0;
+    static constexpr OUStringLiteral sTextPath = u"TextPath";
+    bool bFound = false;
 
-    static const char sTextPath[] = "TextPath";
+    if( dynamic_cast<const SdrObjCustomShape*>( pObj) !=  nullptr )
+    {
+        const SdrCustomShapeGeometryItem & rGeometryItem( pObj->GetMergedItem( SDRATTR_CUSTOMSHAPE_GEOMETRY ) );
+        const Any* pAny = rGeometryItem.GetPropertyValueByName( sTextPath, sTextPath );
+        if( pAny )
+            *pAny >>= bFound;
+    }
 
+    return bFound;
+}
+
+bool checkForSelectedFontWork( SdrView const * pSdrView )
+{
     const SdrMarkList& rMarkList = pSdrView->GetMarkedObjectList();
     const size_t nCount = rMarkList.GetMarkCount();
     bool bFound = false;
     for(size_t i=0; (i<nCount) && !bFound ; ++i)
     {
         SdrObject* pObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
-        if( dynamic_cast<const SdrObjCustomShape*>( pObj) !=  nullptr )
-        {
-            const SdrCustomShapeGeometryItem aGeometryItem( pObj->GetMergedItem( SDRATTR_CUSTOMSHAPE_GEOMETRY ) );
-            const Any* pAny = aGeometryItem.GetPropertyValueByName( sTextPath, sTextPath );
-            if( pAny )
-                *pAny >>= bFound;
-        }
+        bFound = checkForFontWork(pObj);
     }
-    if ( bFound )
-        nCheckStatus |= 1;
-    nCheckStatus |= 2;
     return bFound;
 }
-}
 
 static void impl_execute( SfxRequest const & rReq, SdrCustomShapeGeometryItem& rGeometryItem, SdrObject* pObj )
 {
@@ -302,19 +303,19 @@ static void impl_execute( SfxRequest const & rReq, SdrCustomShapeGeometryItem& r
 
 static void GetGeometryForCustomShape( SdrCustomShapeGeometryItem& rGeometryItem, const OUString& rCustomShape )
 {
-    const OUString sType( "Type" );
+    static const OUStringLiteral sType( u"Type" );
 
     css::beans::PropertyValue aPropVal;
     aPropVal.Name = sType;
     aPropVal.Value <<= rCustomShape;
     rGeometryItem.SetPropertyValue( aPropVal );
 
-    const OUString sAdjustmentValues( "AdjustmentValues" );
-    const OUString sCoordinateOrigin( "CoordinateOrigin" );
-    const OUString sCoordinateSize( "CoordinateSize" );
-    const OUString sEquations( "Equations" );
-    const OUString sHandles( "Handles" );
-    const OUString sPath( "Path" );
+    static const OUStringLiteral sAdjustmentValues( u"AdjustmentValues" );
+    static const OUStringLiteral sCoordinateOrigin( u"CoordinateOrigin" );
+    static const OUStringLiteral sCoordinateSize( u"CoordinateSize" );
+    static const OUStringLiteral sEquations( u"Equations" );
+    static const OUStringLiteral sHandles( u"Handles" );
+    static const OUStringLiteral sPath( u"Path" );
     rGeometryItem.ClearPropertyValue( sAdjustmentValues );
     rGeometryItem.ClearPropertyValue( sCoordinateOrigin );
     rGeometryItem.ClearPropertyValue( sCoordinateSize );
@@ -415,8 +416,8 @@ void FontworkBar::execute( SdrView& rSdrView, SfxRequest const & rReq, SfxBindin
     {
         case SID_FONTWORK_GALLERY_FLOATER:
         {
-            FontWorkGalleryDialog aDlg(rReq.GetFrameWeld(), rSdrView);
-            aDlg.run();
+            std::shared_ptr<FontWorkGalleryDialog> pDlg = std::make_shared<FontWorkGalleryDialog>(rReq.GetFrameWeld(), rSdrView);
+            weld::DialogController::runAsync(pDlg, [](int){});
         }
         break;
 
@@ -436,7 +437,7 @@ void FontworkBar::execute( SdrView& rSdrView, SfxRequest const & rReq, SfxBindin
                 for( size_t i = 0; i < nCount; ++i )
                 {
                     SdrObject* pObj = rMarkList.GetMark( i )->GetMarkedSdrObj();
-                    if( dynamic_cast<const SdrObjCustomShape*>( pObj) !=  nullptr )
+                    if( auto pCustomShape = dynamic_cast<SdrObjCustomShape*>( pObj) )
                     {
                         const bool bUndo = rSdrView.IsUndoEnabled();
 
@@ -450,7 +451,7 @@ void FontworkBar::execute( SdrView& rSdrView, SfxRequest const & rReq, SfxBindin
                         GetGeometryForCustomShape( aGeometryItem, aCustomShape );
                         pObj->SetMergedItem( aGeometryItem );
 
-                        Reference< drawing::XShape > aXShape = GetXShapeForSdrObject( static_cast<SdrObjCustomShape*>(pObj) );
+                        Reference< drawing::XShape > aXShape = GetXShapeForSdrObject( pCustomShape );
                         if ( aXShape.is() )
                         {
                             Reference< drawing::XEnhancedCustomShapeDefaulter > xDefaulter( aXShape, UNO_QUERY );
@@ -539,51 +540,24 @@ void FontworkBar::execute( SdrView& rSdrView, SfxRequest const & rReq, SfxBindin
 
 void FontworkBar::getState( SdrView const * pSdrView, SfxItemSet& rSet )
 {
-    sal_uInt32 nCheckStatus = 0;
-
-    if ( rSet.GetItemState( SID_FONTWORK_ALIGNMENT_FLOATER ) != SfxItemState::UNKNOWN )
+    if ( checkForSelectedFontWork( pSdrView ) )
     {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
-            rSet.DisableItem( SID_FONTWORK_ALIGNMENT_FLOATER );
+        SetAlignmentState( pSdrView, rSet );
+        SetCharacterSpacingState( pSdrView, rSet );
+        SetKernCharacterPairsState( pSdrView, rSet );
+        SetFontWorkShapeTypeState( pSdrView, rSet );
     }
-    if ( rSet.GetItemState( SID_FONTWORK_ALIGNMENT ) != SfxItemState::UNKNOWN )
+    else
     {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
-            rSet.DisableItem( SID_FONTWORK_ALIGNMENT );
-        else
-            SetAlignmentState( pSdrView, rSet );
-    }
-    if ( rSet.GetItemState( SID_FONTWORK_CHARACTER_SPACING_FLOATER ) != SfxItemState::UNKNOWN )
-    {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
-            rSet.DisableItem( SID_FONTWORK_CHARACTER_SPACING_FLOATER );
-    }
-    if ( rSet.GetItemState( SID_FONTWORK_CHARACTER_SPACING ) != SfxItemState::UNKNOWN )
-    {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
-            rSet.DisableItem( SID_FONTWORK_CHARACTER_SPACING );
-        else
-            SetCharacterSpacingState( pSdrView, rSet );
-    }
-    if ( rSet.GetItemState( SID_FONTWORK_KERN_CHARACTER_PAIRS ) != SfxItemState::UNKNOWN )
-    {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
-            rSet.DisableItem( SID_FONTWORK_KERN_CHARACTER_PAIRS );
-        else
-            SetKernCharacterPairsState( pSdrView, rSet );
-    }
-    if ( rSet.GetItemState( SID_FONTWORK_SAME_LETTER_HEIGHTS ) != SfxItemState::UNKNOWN )
-    {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus ) )
-            rSet.DisableItem( SID_FONTWORK_SAME_LETTER_HEIGHTS );
-    }
-    if ( rSet.GetItemState( SID_FONTWORK_SHAPE_TYPE ) != SfxItemState::UNKNOWN )
-    {
-        if ( !checkForSelectedFontWork( pSdrView, nCheckStatus  ) )
-            rSet.DisableItem( SID_FONTWORK_SHAPE_TYPE );
-        else
-            SetFontWorkShapeTypeState( pSdrView, rSet );
+        rSet.DisableItem( SID_FONTWORK_ALIGNMENT_FLOATER );
+        rSet.DisableItem( SID_FONTWORK_ALIGNMENT );
+        rSet.DisableItem( SID_FONTWORK_CHARACTER_SPACING_FLOATER );
+        rSet.DisableItem( SID_FONTWORK_CHARACTER_SPACING );
+        rSet.DisableItem( SID_FONTWORK_KERN_CHARACTER_PAIRS );
+        rSet.DisableItem( SID_FONTWORK_SAME_LETTER_HEIGHTS );
+        rSet.DisableItem( SID_FONTWORK_SHAPE_TYPE );
     }
 }
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
