@@ -43,7 +43,6 @@
 #include <xmloff/MarkerStyle.hxx>
 #include <xmloff/xmlictxt.hxx>
 #include <svx/xmlgrhlp.hxx>
-#include <xmloff/attrlist.hxx>
 
 #include <xmlxtimp.hxx>
 #include <tools/diagnose_ex.h>
@@ -152,22 +151,22 @@ css::uno::Reference< css::xml::sax::XFastContextHandler >
         switch( meContext )
         {
         case SvxXMLTableImportContextEnum::Color:
-            importColor( xFastList.get(), aAny, aName );
+            importColor( xFastList, aAny, aName );
             break;
         case SvxXMLTableImportContextEnum::Marker:
-            importMarker( xFastList.get(), aAny, aName  );
+            importMarker( xFastList, aAny, aName  );
             break;
         case SvxXMLTableImportContextEnum::Dash:
-            importDash( xFastList.get(), aAny, aName  );
+            importDash( xFastList, aAny, aName  );
             break;
         case SvxXMLTableImportContextEnum::Hatch:
-            importHatch( xFastList.get(), aAny, aName  );
+            importHatch( xFastList, aAny, aName  );
             break;
         case SvxXMLTableImportContextEnum::Gradient:
-            importGradient( xFastList.get(), aAny, aName  );
+            importGradient( xFastList, aAny, aName  );
             break;
         case SvxXMLTableImportContextEnum::Bitmap:
-            importBitmap( xFastList.get(), aAny, aName  );
+            importBitmap( xFastList, aAny, aName  );
             break;
         }
 
@@ -313,7 +312,7 @@ SvxXMLXTableImport::SvxXMLXTableImport(
                         XML_NAMESPACE_DRAW );
 }
 
-SvxXMLXTableImport::~SvxXMLXTableImport() throw ()
+SvxXMLXTableImport::~SvxXMLXTableImport() noexcept
 {
 }
 
@@ -329,7 +328,7 @@ static void openStorageStream( xml::sax::InputSource *pParserInput,
 bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
                                const uno::Reference < embed::XStorage > &xStorage,
                                const uno::Reference< XNameContainer >& xTable,
-                               bool *bOptLoadedFromStorage ) throw()
+                               bool *bOptLoadedFromStorage ) noexcept
 {
     bool bRet = true;
     rtl::Reference<SvXMLGraphicHelper> xGraphicHelper;
