@@ -8,10 +8,10 @@
  */
 
 #include <memory>
+#include <string_view>
 
 #include <swmodeltestbase.hxx>
 
-#include <com/sun/star/awt/XBitmap.hpp>
 #include <com/sun/star/awt/FontSlant.hpp>
 #include <com/sun/star/awt/FontUnderline.hpp>
 #include <com/sun/star/awt/FontWeight.hpp>
@@ -29,7 +29,6 @@
 #include <com/sun/star/text/WritingMode2.hpp>
 #include <com/sun/star/text/XBookmarksSupplier.hpp>
 #include <com/sun/star/text/XFootnote.hpp>
-#include <com/sun/star/text/XPageCursor.hpp>
 #include <com/sun/star/text/XTextColumns.hpp>
 #include <com/sun/star/text/XTextFrame.hpp>
 #include <com/sun/star/text/XTextFramesSupplier.hpp>
@@ -49,7 +48,6 @@
 #include <com/sun/star/text/XFootnotesSupplier.hpp>
 #include <com/sun/star/text/XTextDocument.hpp>
 #include <com/sun/star/text/XDocumentIndexesSupplier.hpp>
-#include <com/sun/star/util/XModifiable.hpp>
 #include <com/sun/star/text/XEndnotesSupplier.hpp>
 #include <com/sun/star/beans/XPropertyState.hpp>
 
@@ -75,7 +73,8 @@ public:
 
     virtual std::unique_ptr<Resetter> preTest(const char* filename) override
     {
-        if (OString(filename) == "smartart.docx" || OString(filename) == "strict-smartart.docx" )
+        if (filename == std::string_view("smartart.docx")
+            || filename == std::string_view("strict-smartart.docx") )
         {
             std::unique_ptr<Resetter> pResetter(new Resetter(
                 [] () {
@@ -98,12 +97,12 @@ protected:
 
 protected:
     /// Copy&paste helper.
-    bool paste(const OUString& rFilename, const uno::Reference<text::XTextRange>& xTextRange)
+    bool paste(std::u16string_view rFilename, const uno::Reference<text::XTextRange>& xTextRange)
     {
         uno::Reference<document::XFilter> xFilter(m_xSFactory->createInstance("com.sun.star.comp.Writer.WriterFilter"), uno::UNO_QUERY_THROW);
         uno::Reference<document::XImporter> xImporter(xFilter, uno::UNO_QUERY_THROW);
         xImporter->setTargetDocument(mxComponent);
-        std::unique_ptr<SvStream> pStream = utl::UcbStreamHelper::CreateStream(m_directories.getURLFromSrc("/sw/qa/extras/ooxmlexport/data/") + rFilename, StreamMode::READ);
+        std::unique_ptr<SvStream> pStream = utl::UcbStreamHelper::CreateStream(m_directories.getURLFromSrc(u"/sw/qa/extras/ooxmlexport/data/") + rFilename, StreamMode::READ);
         uno::Reference<io::XStream> xStream(new utl::OStreamWrapper(std::move(pStream)));
         uno::Sequence<beans::PropertyValue> aDescriptor(comphelper::InitPropertySequence(
         {
@@ -137,11 +136,8 @@ DECLARE_OOXMLEXPORT_TEST(testSmartart, "smartart.docx")
     CPPUNIT_ASSERT_EQUAL(sal_Int32(style::ParagraphAdjust_CENTER), nValue); // Paragraph properties are imported
 }
 
-DECLARE_OOXMLEXPORT_TEST(testFdo69548, "fdo69548.docx")
+DECLARE_OOXMLEXPORT_EXPORTONLY_TEST(testFdo69548, "fdo69548.docx")
 {
-    if (!mbExported)
-        return;
-
     // The problem was that the last space in target URL was removed
     CPPUNIT_ASSERT_EQUAL(OUString("#this_is_a_bookmark"), getProperty<OUString>(getRun(getParagraph(1), 1), "HyperLinkURL"));
 }
@@ -455,10 +451,8 @@ DECLARE_OOXMLEXPORT_TEST(testPictureWithSchemeColor, "picture-with-schemecolor.d
     BitmapEx aBitmap(aVclGraphic.GetBitmapEx());
     CPPUNIT_ASSERT_EQUAL(tools::Long(341), aBitmap.GetSizePixel().Width());
     CPPUNIT_ASSERT_EQUAL(tools::Long(181), aBitmap.GetSizePixel().Height());
-    Color aColor(aBitmap.GetPixelColor(120, 30));
-    CPPUNIT_ASSERT_EQUAL(aColor, Color( 0xb1, 0xc8, 0xdd ));
-    aColor = aBitmap.GetPixelColor(260, 130);
-    CPPUNIT_ASSERT_EQUAL(aColor, Color( 0xb1, 0xc8, 0xdd ));
+    CPPUNIT_ASSERT_EQUAL(Color( 0xad, 0xc5, 0xdb ), aBitmap.GetPixelColor(120, 30));
+    CPPUNIT_ASSERT_EQUAL(Color( 0xad, 0xc5, 0xdb ), aBitmap.GetPixelColor(260, 130));
 }
 
 DECLARE_OOXMLEXPORT_TEST(testFdo69656, "Table_cell_auto_width_fdo69656.docx")
@@ -519,7 +513,7 @@ DECLARE_OOXMLEXPORT_TEST(testStrict, "strict.docx")
     getParagraphOfText(1, xHeaderText, "This is a header.");
 
     // Picture was missing.
-    uno::Reference<lang::XServiceInfo> xServiceInfo(getShapeByName("Picture 2"), uno::UNO_QUERY);
+    uno::Reference<lang::XServiceInfo> xServiceInfo(getShapeByName(u"Picture 2"), uno::UNO_QUERY);
     CPPUNIT_ASSERT(xServiceInfo->supportsService("com.sun.star.text.TextGraphicObject"));
 
     // SmartArt was missing.
@@ -692,7 +686,9 @@ DECLARE_OOXMLEXPORT_TEST(testBnc875718, "bnc875718.docx")
     // is not SwXBodyText but rather SwXHeadFootText
     uno::Reference<text::XTextFramesSupplier> xTextFramesSupplier(mxComponent, uno::UNO_QUERY);
     uno::Reference<container::XIndexAccess> xIndexAccess(xTextFramesSupplier->getTextFrames(), uno::UNO_QUERY);
-    for( int i = 0;
+    // The sample bugdoc has 3 footer.xml and has a textframe in each. The first one is hidden
+    // and it has no text in its anchored text range: it is anchored to body text. Ignoring...
+    for( int i = 1;
          i < xIndexAccess->getCount();
          ++i )
     {
@@ -704,6 +700,7 @@ DECLARE_OOXMLEXPORT_TEST(testBnc875718, "bnc875718.docx")
     // Also check that the footer contents are not in the body text.
     uno::Reference<text::XTextDocument> textDocument(mxComponent, uno::UNO_QUERY);
     uno::Reference<text::XText> text = textDocument->getText();
+    CPPUNIT_ASSERT(text); //Do not crash on empty content
     CPPUNIT_ASSERT_EQUAL( OUString( "Text" ), text->getString());
 }
 
@@ -883,10 +880,10 @@ DECLARE_OOXMLEXPORT_TEST(testTdf65955_2, "tdf65955_2.odt")
 
 DECLARE_OOXMLEXPORT_TEST(testChtOutlineNumberingOoxml, "chtoutline.docx")
 {
-    const sal_Unicode aExpectedNumbering[] = { 0x7b2c, ' ', '1', ' ', 0x7ae0 };
+    static constexpr OUStringLiteral aExpectedNumbering = u"\u7b2c 1 \u7ae0";
 
     uno::Reference<beans::XPropertySet> xPara(getParagraph(1), uno::UNO_QUERY);
-    CPPUNIT_ASSERT_EQUAL(OUString(aExpectedNumbering,SAL_N_ELEMENTS(aExpectedNumbering)),
+    CPPUNIT_ASSERT_EQUAL(OUString(aExpectedNumbering),
         getProperty<OUString>(xPara, "ListLabelString"));
 }
 
@@ -1099,7 +1096,7 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf94374)
     uno::Reference<text::XTextRange> xText = xTextDocument->getText();
     uno::Reference<text::XTextRange> xEnd = xText->getEnd();
     // This failed: it wasn't possible to insert a DOCX document into an existing Writer one.
-    CPPUNIT_ASSERT(paste("tdf94374.docx", xEnd));
+    CPPUNIT_ASSERT(paste(u"tdf94374.docx", xEnd));
 }
 
 DECLARE_OOXMLEXPORT_TEST(testTdf83300, "tdf83300.docx")
@@ -1334,12 +1331,10 @@ DECLARE_OOXMLEXPORT_TEST( testTdf107359, "tdf107359-char-pitch.docx" )
     CPPUNIT_ASSERT_EQUAL( sal_Int32(convertTwipToMm100(24 * 20)), nBaseWidth );
 }
 
-DECLARE_OOXMLEXPORT_TEST(testTdf77236_MissingSolidFill, "tdf77236_MissingSolidFill.docx")
+DECLARE_OOXMLEXPORT_EXPORTONLY_TEST(testTdf77236_MissingSolidFill, "tdf77236_MissingSolidFill.docx")
 {
     // tdf#77236: solidFill of VML shape was not exported if the colors of line and style were the same
     xmlDocUniquePtr pXmlDoc = parseExport("word/document.xml");
-    if (!pXmlDoc)
-        return;
     assertXPath(pXmlDoc, "//mc:Choice/w:drawing/wp:inline/a:graphic/a:graphicData/wps:wsp/wps:spPr/a:ln/a:solidFill", 1);
 }
 
