@@ -31,6 +31,18 @@
 #include <com/sun/star/text/RubyPosition.hpp>
 #include <com/sun/star/text/XTextColumns.hpp>
 #include <com/sun/star/text/HoriOrientation.hpp>
+#include <com/sun/star/text/XTextDocument.hpp>
+#include <com/sun/star/text/XTextFramesSupplier.hpp>
+#include <com/sun/star/text/XTextTable.hpp>
+#include <com/sun/star/text/XLineNumberingProperties.hpp>
+#include <com/sun/star/text/XTextFieldsSupplier.hpp>
+#include <com/sun/star/text/XTextTablesSupplier.hpp>
+#include <com/sun/star/text/XBookmarksSupplier.hpp>
+
+#include <comphelper/sequenceashashmap.hxx>
+#include <tools/UnitConversion.hxx>
+
+using namespace css;
 
 class Test : public SwModelTestBase
 {
@@ -43,26 +55,16 @@ public:
     bool mustTestImportOf(const char* filename) const override
     {
         // Don't test the first import of these, for some reason those tests fail
-        const char* aBlacklist[] = {
+        const char* aDenylist[] = {
             "math-eqarray.rtf",         "math-escaping.rtf", "math-lim.rtf",
             "math-mso2007.rtf",         "math-nary.rtf",     "math-rad.rtf",
             "math-vertical-stacks.rtf", "math-runs.rtf",
         };
-        std::vector<const char*> vBlacklist(aBlacklist, aBlacklist + SAL_N_ELEMENTS(aBlacklist));
+        std::vector<const char*> vDenylist(aDenylist, aDenylist + SAL_N_ELEMENTS(aDenylist));
 
         // If the testcase is stored in some other format, it's pointless to test.
         return (OString(filename).endsWith(".rtf")
-                && std::find(vBlacklist.begin(), vBlacklist.end(), filename) == vBlacklist.end());
-    }
-
-    virtual void postLoad(const char* pFilename) override
-    {
-        if (OString(pFilename) == "tdf90421.fodt")
-        {
-            // Change the hyperlink, so its URL is empty.
-            uno::Reference<beans::XPropertySet> xRun(getRun(getParagraph(1), 2), uno::UNO_QUERY);
-            xRun->setPropertyValue("HyperLinkURL", uno::makeAny(OUString()));
-        }
+                && std::find(vDenylist.begin(), vDenylist.end(), filename) == vDenylist.end());
     }
 };
 
@@ -200,56 +202,54 @@ DECLARE_RTFEXPORT_TEST(testCommentsNested, "comments-nested.odt")
 DECLARE_RTFEXPORT_TEST(testMathAccents, "math-accents.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected("acute {a} grave {a} check {a} breve {a} circle {a} widevec {a} "
-                             "widetilde {a} widehat {a} dot {a} widevec {a} widevec {a} widetilde "
-                             "{a} underline {a}");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(
+        OUString("acute {a} grave {a} check {a} breve {a} circle {a} widevec {a} "
+                 "widetilde {a} widehat {a} dot {a} widevec {a} widevec {a} widetilde "
+                 "{a} underline {a}"),
+        aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathEqarray, "math-eqarray.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected(
-        "y = left lbrace stack { 0 , x < 0 # 1 , x = 0 # {x} ^ {2} , x > 0 } right none");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(
+        OUString("y = left lbrace stack { 0 , x < 0 # 1 , x = 0 # {x} ^ {2} , x > 0 } right none"),
+        aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathD, "math-d.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected("left (x mline y mline z right ) left (1 right ) left [2 right ] left "
-                             "ldbracket 3 right rdbracket left lline 4 right rline left ldline 5 "
-                             "right rdline left langle 6 right rangle left langle a mline b right "
-                             "rangle left ({x} over {y} right )");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(
+        OUString("left (x mline y mline z right ) left (1 right ) left [2 right ] left "
+                 "ldbracket 3 right rdbracket left lline 4 right rline left ldline 5 "
+                 "right rdline left langle 6 right rangle left langle a mline b right "
+                 "rangle left ({x} over {y} right )"),
+        aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathEscaping, "math-escaping.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected(u"\u00E1 \\{");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(OUString(u"\u00E1 \\{"), aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathLim, "math-lim.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected(u"lim from {x \u2192 1} {x}");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(OUString(u"lim from {x \u2192 1} {x}"), aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathMatrix, "math-matrix.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected("left [matrix {1 # 2 ## 3 # 4} right ]");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(OUString("left [matrix {1 # 2 ## 3 # 4} right ]"), aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathBox, "math-mbox.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected("a");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(OUString("a"), aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathMso2007, "math-mso2007.rtf")
@@ -301,8 +301,8 @@ DECLARE_RTFEXPORT_TEST(testMathMso2007, "math-mso2007.rtf")
 DECLARE_RTFEXPORT_TEST(testMathNary, "math-nary.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected("lllint from {1} to {2} {x + 1} prod from {a} {b} sum to {2} {x}");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(
+        OUString("lllint from {1} to {2} {x + 1} prod from {a} {b} sum to {2} {x}"), aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathLimupp, "math-limupp.rtf")
@@ -341,10 +341,11 @@ DECLARE_RTFEXPORT_TEST(testMathSepchr, "math-sepchr.rtf")
 DECLARE_RTFEXPORT_TEST(testMathSubscripts, "math-subscripts.rtf")
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString const aExpected("{x} ^ {y} + {e} ^ {x} {x} ^ {b} {x} rsub {b} {a} rsub {c} rsup {b} "
-                             "{x} lsub {2} lsup {1} {{x csup {6} csub {3}} lsub {4} lsup {5}} rsub "
-                             "{2} rsup {1}");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(
+        OUString("{x} ^ {y} + {e} ^ {x} {x} ^ {b} {x} rsub {b} {a} rsub {c} rsup {b} "
+                 "{x} lsub {2} lsup {1} {{x csup {6} csub {3}} lsub {4} lsup {5}} rsub "
+                 "{2} rsup {1}"),
+        aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testMathVerticalstacks, "math-vertical-stacks.rtf")
@@ -391,8 +392,7 @@ DECLARE_RTFEXPORT_TEST(testFdo77979, "fdo77979.odt")
 {
     CPPUNIT_ASSERT_EQUAL(1, getPages());
     // font name is encoded with \fcharset of font
-    OUString aExpected(u"\u5FAE\u8F6F\u96C5\u9ED1");
-    CPPUNIT_ASSERT_EQUAL(aExpected,
+    CPPUNIT_ASSERT_EQUAL(OUString(u"\u5FAE\u8F6F\u96C5\u9ED1"),
                          getProperty<OUString>(getRun(getParagraph(1), 1), "CharFontName"));
 }
 
@@ -488,8 +488,8 @@ DECLARE_RTFEXPORT_TEST(testFdo61507, "fdo61507.rtf")
         mxComponent, uno::UNO_QUERY);
     uno::Reference<document::XDocumentProperties> xDocumentProperties(
         xDocumentPropertiesSupplier->getDocumentProperties());
-    OUString aExpected(u"\u00C9\u00C1\u0150\u0170\u222D");
-    CPPUNIT_ASSERT_EQUAL(aExpected, xDocumentProperties->getTitle());
+    CPPUNIT_ASSERT_EQUAL(OUString(u"\u00C9\u00C1\u0150\u0170\u222D"),
+                         xDocumentProperties->getTitle());
 
     // Only "Hello.", no additional characters.
     CPPUNIT_ASSERT_EQUAL(6, getLength());
@@ -520,9 +520,10 @@ DECLARE_RTFEXPORT_TEST(testMnor, "mnor.rtf")
 {
     // \mnor wasn't handled, leading to missing quotes around "divF" and so on.
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected(
-        u"iiint from {V} to <?> {\"divF\"} dV = llint from {S} to <?> {\"F\" \u2219 \"n\" dS}");
-    CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
+    CPPUNIT_ASSERT_EQUAL(
+        OUString(
+            u"iiint from {V} to <?> {\"divF\"} dV = llint from {S} to <?> {\"F\" \u2219 \"n\" dS}"),
+        aActual);
 }
 
 DECLARE_RTFEXPORT_TEST(testI120928, "i120928.rtf")
@@ -671,7 +672,7 @@ DECLARE_RTFEXPORT_TEST(testFdo66682, "fdo66682.rtf")
             aListFormat = rProp.Value.get<OUString>();
     }
     // Suffix was '\0' instead of ' '.
-    CPPUNIT_ASSERT_EQUAL(OUString(" %1 "), aListFormat);
+    CPPUNIT_ASSERT_EQUAL(OUString(" %1% "), aListFormat);
 }
 
 DECLARE_RTFEXPORT_TEST(testParaShadow, "para-shadow.rtf")
@@ -679,7 +680,7 @@ DECLARE_RTFEXPORT_TEST(testParaShadow, "para-shadow.rtf")
     // The problem was that \brdrsh was ignored.
     table::ShadowFormat aShadow
         = getProperty<table::ShadowFormat>(getParagraph(2), "ParaShadowFormat");
-    CPPUNIT_ASSERT_EQUAL(COL_BLACK, Color(aShadow.Color));
+    CPPUNIT_ASSERT_EQUAL(COL_BLACK, Color(ColorTransparency, aShadow.Color));
     CPPUNIT_ASSERT_EQUAL(table::ShadowLocation_BOTTOM_RIGHT, aShadow.Location);
     CPPUNIT_ASSERT_EQUAL(sal_Int16(convertTwipToMm100(60)), aShadow.ShadowWidth);
 }
@@ -722,7 +723,7 @@ DECLARE_RTFEXPORT_TEST(testCharacterBorder, "charborder.odt")
     {
         const table::ShadowFormat aShadow
             = getProperty<table::ShadowFormat>(xRun, "CharShadowFormat");
-        CPPUNIT_ASSERT_EQUAL(COL_BLACK, Color(aShadow.Color));
+        CPPUNIT_ASSERT_EQUAL(COL_BLACK, Color(ColorTransparency, aShadow.Color));
         CPPUNIT_ASSERT_EQUAL(table::ShadowLocation_BOTTOM_RIGHT, aShadow.Location);
         CPPUNIT_ASSERT_EQUAL(sal_Int16(318), aShadow.ShadowWidth);
     }
@@ -1008,17 +1009,19 @@ DECLARE_RTFEXPORT_TEST(testTdf80708, "tdf80708.rtf")
                              .getLength());
 }
 
-DECLARE_RTFEXPORT_TEST(testTdf90421, "tdf90421.fodt")
+CPPUNIT_TEST_FIXTURE(Test, testHyperlinkWithoutURL)
 {
-    if (mbExported)
-    {
-        SvMemoryStream aMemoryStream;
-        SvFileStream aStream(maTempFile.GetURL(), StreamMode::READ);
-        aStream.ReadStream(aMemoryStream);
-        OString aData(static_cast<const char*>(aMemoryStream.GetData()), aMemoryStream.GetSize());
-        // This was some positive number, i.e. we exported a hyperlink with an empty URL.
-        CPPUNIT_ASSERT_EQUAL(static_cast<sal_Int32>(-1), aData.indexOf("HYPERLINK"));
-    }
+    load(mpTestDocumentPath, "tdf90421.fodt");
+    // Change the hyperlink, so its URL is empty.
+    uno::Reference<beans::XPropertySet> xRun(getRun(getParagraph(1), 2), uno::UNO_QUERY);
+    xRun->setPropertyValue("HyperLinkURL", uno::makeAny(OUString()));
+    reload(mpFilter, "gutter-left.rtf");
+    SvMemoryStream aMemoryStream;
+    SvFileStream aStream(maTempFile.GetURL(), StreamMode::READ);
+    aStream.ReadStream(aMemoryStream);
+    OString aData(static_cast<const char*>(aMemoryStream.GetData()), aMemoryStream.GetSize());
+    // This was some positive number, i.e. we exported a hyperlink with an empty URL.
+    CPPUNIT_ASSERT_EQUAL(static_cast<sal_Int32>(-1), aData.indexOf("HYPERLINK"));
 }
 
 DECLARE_RTFEXPORT_TEST(testTdf92521, "tdf92521.odt")
@@ -1132,8 +1135,8 @@ DECLARE_RTFEXPORT_TEST(testCustomDocProps, "custom-doc-props.rtf")
     // Test roundtrip of date in general, and year/month/day in particular.
     util::DateTime aDate = getProperty<util::DateTime>(xUserDefinedProperties, "d");
     CPPUNIT_ASSERT_EQUAL(static_cast<sal_Int16>(2016), aDate.Year);
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(1), aDate.Month);
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(30), aDate.Day);
+    CPPUNIT_ASSERT_EQUAL(o3tl::narrowing<sal_uInt16>(1), aDate.Month);
+    CPPUNIT_ASSERT_EQUAL(o3tl::narrowing<sal_uInt16>(30), aDate.Day);
 
     // Test real number.
     CPPUNIT_ASSERT_EQUAL(3.14, getProperty<double>(xUserDefinedProperties, "pi"));
