@@ -8,6 +8,7 @@
  */
 
 #include <memory>
+#include <string_view>
 #include <swmodeltestbase.hxx>
 
 #include <com/sun/star/awt/FontWeight.hpp>
@@ -55,7 +56,7 @@ public:
     virtual std::unique_ptr<Resetter> preTest(const char* filename) override
     {
         m_aSavedSettings = Application::GetSettings();
-        if (OString(filename) == "fdo72031.rtf")
+        if (filename == std::string_view("fdo72031.rtf"))
         {
             std::unique_ptr<Resetter> pResetter(
                 new Resetter([this]() { Application::SetSettings(this->m_aSavedSettings); }));
@@ -127,7 +128,7 @@ CPPUNIT_TEST_FIXTURE(Test, testFdo62044)
     uno::Reference<text::XTextDocument> xTextDocument(mxComponent, uno::UNO_QUERY);
     uno::Reference<text::XTextRange> xText = xTextDocument->getText();
     uno::Reference<text::XTextRange> xEnd = xText->getEnd();
-    paste("rtfexport/data/fdo62044-paste.rtf", xEnd);
+    paste(u"rtfexport/data/fdo62044-paste.rtf", xEnd);
 
     uno::Reference<beans::XPropertySet> xPropertySet(
         getStyles("ParagraphStyles")->getByName("Heading 1"), uno::UNO_QUERY);
@@ -812,7 +813,7 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf90260Nopar)
     uno::Reference<text::XTextDocument> xTextDocument(mxComponent, uno::UNO_QUERY);
     uno::Reference<text::XTextRange> xText = xTextDocument->getText();
     uno::Reference<text::XTextRange> xEnd = xText->getEnd();
-    paste("rtfexport/data/tdf90260-nopar.rtf", xEnd);
+    paste(u"rtfexport/data/tdf90260-nopar.rtf", xEnd);
     CPPUNIT_ASSERT_EQUAL(1, getParagraphs());
 }
 
@@ -958,7 +959,7 @@ CPPUNIT_TEST_FIXTURE(Test, testClassificatonPasteLevels)
     // Classified source and classified destination, but internal only has a
     // higher level than confidential: nothing should happen.
     OUString aOld = xText->getString();
-    paste("rtfexport/data/classification-yes.rtf", xEnd);
+    paste(u"rtfexport/data/classification-yes.rtf", xEnd);
     CPPUNIT_ASSERT_EQUAL(aOld, xText->getString());
 }
 
