@@ -17,14 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+
+#include <algorithm>
+#include <format.hxx>
 #include <frame.hxx>
 #include <hintids.hxx>
 #include <hints.hxx>
-#include <swcache.hxx>
-#include <swfntcch.hxx>
-#include <tools/debug.hxx>
+#include <osl/diagnose.hxx>
 #include <sal/log.hxx>
-#include <algorithm>
+#include <tools/debug.hxx>
+
 #ifdef DBG_UTIL
 #include <sal/backtrace.hxx>
 #endif
@@ -33,11 +35,6 @@ namespace sw
 {
     bool ListenerEntry::GetInfo(SfxPoolItem& rInfo) const
         { return m_pToTell == nullptr || m_pToTell->GetInfo( rInfo ); }
-    void ListenerEntry::Modify(const SfxPoolItem *const pOldValue,
-                               const SfxPoolItem *const pNewValue)
-    {
-        SwClientNotify(*GetRegisteredIn(), sw::LegacyModifyHint(pOldValue, pNewValue));
-    }
     void ListenerEntry::SwClientNotify(const SwModify& rModify, const SfxHint& rHint)
     {
         if (auto pLegacyHint = dynamic_cast<const sw::LegacyModifyHint*>(&rHint))
@@ -46,18 +43,17 @@ namespace sw
             {
                 auto pModifyChanged = CheckRegistration(pLegacyHint->m_pOld);
                 if (pModifyChanged)
-                    m_pToTell->SwClientNotifyCall(rModify, *pModifyChanged);
+                    m_pToTell->SwClientNotify(rModify, *pModifyChanged);
             }
             else if (m_pToTell)
-                m_pToTell->SwClientNotifyCall(rModify, rHint);
+                m_pToTell->SwClientNotify(rModify, rHint);
         }
         else if (m_pToTell)
-            m_pToTell->SwClientNotifyCall(rModify, rHint);
+            m_pToTell->SwClientNotify(rModify, rHint);
     }
 }
 
 sw::LegacyModifyHint::~LegacyModifyHint() {}
-sw::ModifyChangedHint::~ModifyChangedHint() {}
 
 SwClient::SwClient(SwClient&& o) noexcept
     : m_pRegisteredIn(nullptr)
@@ -78,19 +74,19 @@ SwClient::~SwClient()
         m_pRegisteredIn->Remove( this );
 }
 
-std::unique_ptr<sw::ModifyChangedHint> SwClient::CheckRegistration( const SfxPoolItem* pOld )
+std::optional<sw::ModifyChangedHint> SwClient::CheckRegistration( const SfxPoolItem* pOld )
 {
     DBG_TESTSOLARMUTEX();
     // this method only handles notification about dying SwModify objects
     if( !pOld || pOld->Which() != RES_OBJECTDYING )
-        return nullptr;
+        return {};
 
     assert(dynamic_cast<const SwPtrMsgPoolItem*>(pOld));
     const SwPtrMsgPoolItem* pDead = static_cast<const SwPtrMsgPoolItem*>(pOld);
     if(pDead->pObject != m_pRegisteredIn)
     {
         // we should only care received death notes from objects we are following
-        return nullptr;
+        return {};
     }
     // I've got a notification from the object I know
     SwModify* pAbove = m_pRegisteredIn->GetRegisteredIn();
@@ -105,15 +101,26 @@ std::unique_ptr<sw::ModifyChangedHint> SwClient::CheckRegistration( const SfxPoo
         // destroy connection
         EndListeningAll();
     }
-    return std::unique_ptr<sw::ModifyChangedHint>(new sw::ModifyChangedHint(pAbove));
+    return sw::ModifyChangedHint(pAbove);
+}
+
+void SwClient::CheckRegistrationFormat(SwFormat& rOld)
+{
+    assert(GetRegisteredIn() == &rOld);
+    auto pNew = rOld.DerivedFrom();
+    SAL_INFO("sw.core", "reparenting " << typeid(*this).name() << " at " << this << " from " << typeid(rOld).name() << " at " << &rOld << " to "  << typeid(*pNew).name() << " at " << pNew);
+    assert(pNew);
+    pNew->Add(this);
+    const SwFormatChg aOldFormat(&rOld);
+    const SwFormatChg aNewFormat(pNew);
+    const sw::LegacyModifyHint aHint(&aOldFormat, &aNewFormat);
+    SwClientNotify(rOld, aHint);
 }
 
 void SwClient::SwClientNotify(const SwModify&, const SfxHint& rHint)
 {
-    if (auto pLegacyHint = dynamic_cast<const sw::LegacyModifyHint*>(&rHint))
-    {
-        Modify(pLegacyHint->m_pOld, pLegacyHint->m_pNew);
-    }
+    if(auto pLegacyHint = dynamic_cast<const sw::LegacyModifyHint*>(&rHint))
+        CheckRegistration(pLegacyHint->m_pOld);
 };
 
 void SwClient::StartListeningToSameModifyAs(const SwClient& other)
@@ -130,59 +137,23 @@ void SwClient::EndListeningAll()
         m_pRegisteredIn->Remove(this);
 }
 
-void SwClient::Modify(SfxPoolItem const*const pOldValue, SfxPoolItem const*const /*pNewValue*/)
-{
-    CheckRegistration( pOldValue );
-}
-
-void SwModify::SetInDocDTOR()
-{
-    // If the document gets destroyed anyway, just tell clients to
-    // forget me so that they don't try to get removed from my list
-    // later when they also get destroyed
-    SwIterator<SwClient,SwModify> aIter(*this);
-    for(SwClient* pClient = aIter.First(); pClient; pClient = aIter.Next())
-        pClient->m_pRegisteredIn = nullptr;
-    m_pWriterListeners = nullptr;
-}
-
 SwModify::~SwModify()
 {
     DBG_TESTSOLARMUTEX();
     OSL_ENSURE( !IsModifyLocked(), "Modify destroyed but locked." );
 
-    if ( IsInCache() )
-        SwFrame::GetCache().Delete( this );
-
-    if ( IsInSwFntCache() )
-        pSwFontCache->Delete( this );
-
     // notify all clients that they shall remove themselves
     SwPtrMsgPoolItem aDyObject( RES_OBJECTDYING, this );
-    NotifyClients( &aDyObject, &aDyObject );
+    SwModify::SwClientNotify(*this, sw::LegacyModifyHint(&aDyObject, &aDyObject));
 
-    // remove all clients that have not done themselves
-    // mba: possibly a hotfix for forgotten base class calls?!
-    while( m_pWriterListeners )
-        static_cast<SwClient*>(m_pWriterListeners)->CheckRegistration( &aDyObject );
-}
-
-void SwModify::NotifyClients( const SfxPoolItem* pOldValue, const SfxPoolItem* pNewValue )
-{
-    DBG_TESTSOLARMUTEX();
-    if ( IsInCache() || IsInSwFntCache() )
+    const bool hasListenersOnDeath = m_pWriterListeners;
+    (void)hasListenersOnDeath;
+    while(m_pWriterListeners)
     {
-        const sal_uInt16 nWhich = pOldValue ? pOldValue->Which() :
-                                        pNewValue ? pNewValue->Which() : 0;
-        CheckCaching( nWhich );
+        SAL_WARN("sw.core", "lost a client of type: " << typeid(*m_pWriterListeners).name() << " at " << m_pWriterListeners << " still registered on type: " << typeid(*this).name() << " at " << this << ".");
+        static_cast<SwClient*>(m_pWriterListeners)->CheckRegistration(&aDyObject);
     }
-
-    if ( !m_pWriterListeners || IsModifyLocked() )
-        return;
-
-    LockModify();
-    CallSwClientNotify( sw::LegacyModifyHint{ pOldValue, pNewValue } );
-    UnlockModify();
+    assert(!hasListenersOnDeath);
 }
 
 bool SwModify::GetInfo( SfxPoolItem& rInfo ) const
@@ -286,38 +257,6 @@ SwClient* SwModify::Remove( SwClient* pDepend )
     return pDepend;
 }
 
-void SwModify::CheckCaching( const sal_uInt16 nWhich )
-{
-    if( isCHRATR( nWhich ) )
-    {
-        SetInSwFntCache( false );
-    }
-    else
-    {
-        switch( nWhich )
-        {
-        case RES_OBJECTDYING:
-        case RES_FMT_CHG:
-        case RES_ATTRSET_CHG:
-            SetInSwFntCache( false );
-            [[fallthrough]];
-        case RES_UL_SPACE:
-        case RES_LR_SPACE:
-        case RES_BOX:
-        case RES_SHADOW:
-        case RES_FRM_SIZE:
-        case RES_KEEP:
-        case RES_BREAK:
-            if( IsInCache() )
-            {
-                SwFrame::GetCache().Delete( this );
-                SetInCache( false );
-            }
-            break;
-        }
-    }
-}
-
 sw::WriterMultiListener::WriterMultiListener(SwClient& rToTell)
     : m_rToTell(rToTell)
 {}
@@ -328,7 +267,7 @@ sw::WriterMultiListener::~WriterMultiListener()
 void sw::WriterMultiListener::StartListening(SwModify* pDepend)
 {
     EndListening(nullptr);
-    m_vDepends.emplace_back(ListenerEntry(&m_rToTell, pDepend));
+    m_vDepends.emplace_back(&m_rToTell, pDepend);
 }
 
 
@@ -359,6 +298,20 @@ void sw::WriterMultiListener::EndListeningAll()
 
 sw::ClientIteratorBase* sw::ClientIteratorBase::s_pClientIters = nullptr;
 
+void SwModify::SwClientNotify(const SwModify&, const SfxHint& rHint)
+{
+    if(dynamic_cast<const sw::LegacyModifyHint*>(&rHint))
+    {
+        DBG_TESTSOLARMUTEX();
+        if(IsModifyLocked())
+            return;
+
+        LockModify();
+        CallSwClientNotify(rHint);
+        UnlockModify();
+    }
+}
+
 void SwModify::CallSwClientNotify( const SfxHint& rHint ) const
 {
     DBG_TESTSOLARMUTEX();
@@ -378,6 +331,6 @@ void sw::ClientNotifyAttrChg(SwModify& rModify, const SwAttrSet& aSet, SwAttrSet
     const SwAttrSetChg aChgOld(aSet, aOld);
     const SwAttrSetChg aChgNew(aSet, aNew);
     const sw::LegacyModifyHint aHint(&aChgOld, &aChgNew);
-    rModify.SwClientNotifyCall(rModify, aHint);
+    rModify.SwClientNotify(rModify, aHint);
 }
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
