@@ -17,25 +17,26 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <doc.hxx>
 #include <DocumentSettingManager.hxx> //For SwFmt::getIDocumentSettingAccess()
 #include <IDocumentTimerAccess.hxx>
+#include <doc.hxx>
 #include <fmtcolfunc.hxx>
-#include <frame.hxx>
 #include <format.hxx>
+#include <frame.hxx>
+#include <frmatr.hxx>
 #include <hintids.hxx>
 #include <hints.hxx>
-#include <swcache.hxx>
-#include <frmatr.hxx>
+#include <o3tl/unit_conversion.hxx>
+#include <osl/diagnose.h>
+#include <sal/log.hxx>
 #include <svl/grabbagitem.hxx>
 #include <svx/sdr/attribute/sdrallfillattributeshelper.hxx>
 #include <svx/unobrushitemhelper.hxx>
 #include <svx/xdef.hxx>
-#include <sal/log.hxx>
+#include <swcache.hxx>
 
 using namespace com::sun::star;
 
-
 SwFormat::SwFormat( SwAttrPool& rPool, const char* pFormatNm,
               const sal_uInt16* pWhichRanges, SwFormat *pDrvdFrame,
               sal_uInt16 nFormatWhich ) :
@@ -79,6 +80,7 @@ SwFormat::SwFormat( SwAttrPool& rPool, const OUString& rFormatNm,
 }
 
 SwFormat::SwFormat( const SwFormat& rFormat ) :
+    sw::BorderCacheOwner(),
     m_aFormatName( rFormat.m_aFormatName ),
     m_aSet( rFormat.m_aSet ),
     m_nWhichId( rFormat.m_nWhichId ),
@@ -110,12 +112,7 @@ SwFormat &SwFormat::operator=(const SwFormat& rFormat)
     m_nPoolHelpId = rFormat.GetPoolHelpId();
     m_nPoolHlpFileId = rFormat.GetPoolHlpFileId();
 
-    if ( IsInCache() )
-    {
-        SwFrame::GetCache().Delete( this );
-        SetInCache( false );
-    }
-    SetInSwFntCache( false );
+    InvalidateInSwCache(RES_OBJECTDYING);
 
     // copy only array with attributes delta
     SwAttrSet aOld( *m_aSet.GetPool(), m_aSet.GetRanges() ),
@@ -177,12 +174,8 @@ void SwFormat::SetName( const OUString& rNewName, bool bBroadcast )
 void SwFormat::CopyAttrs( const SwFormat& rFormat )
 {
     // copy only array with attributes delta
-    if ( IsInCache() )
-    {
-        SwFrame::GetCache().Delete( this );
-        SetInCache( false );
-    }
-    SetInSwFntCache( false );
+    InvalidateInSwCache(RES_ATTRSET_CHG);
+    InvalidateInSwFntCache(RES_ATTRSET_CHG);
 
     // special treatments for some attributes
     SwAttrSet* pChgSet = const_cast<SwAttrSet*>(&rFormat.m_aSet);
@@ -214,115 +207,115 @@ SwFormat::~SwFormat()
 {
     // This happens at an ObjectDying message. Thus put all dependent
     // ones on DerivedFrom.
-    if( !HasWriterListeners() )
+    if(!HasWriterListeners())
         return;
 
     m_bFormatInDTOR = true;
-
-    SwFormat* pParentFormat = DerivedFrom();
-    if( !pParentFormat )
+    
+    if(!DerivedFrom())
     {
-        SAL_WARN(
-            "sw.core",
-            "~SwFormat: parent format missing from: " << GetName() );
-    }
-    else
-    {
-        SwFormatChg aOldFormat( this );
-        SwFormatChg aNewFormat( pParentFormat );
-        SwIterator<SwClient,SwFormat> aIter(*this);
-        for(SwClient* pClient = aIter.First(); pClient && pParentFormat; pClient = aIter.Next())
-        {
-            SAL_INFO("sw.core", "reparenting " << typeid(*pClient).name() << " at " << pClient << " from " << typeid(*this).name() << " at " << this << " to "  << typeid(*pParentFormat).name() << " at " << pParentFormat);
-            pParentFormat->Add( pClient );
-            const sw::LegacyModifyHint aHint(&aOldFormat, &aNewFormat);
-            pClient->SwClientNotifyCall(*this, aHint);
-        }
+        SwFormat::ResetFormatAttr(RES_PAGEDESC);
+        SAL_WARN("sw.core", "~SwFormat: format still has clients on death, but parent format is missing: " << GetName());
+        return;
     }
+    SwIterator<SwClient,SwFormat> aIter(*this);
+    for(SwClient* pClient = aIter.First(); pClient; pClient = aIter.Next())
+        pClient->CheckRegistrationFormat(*this);
+    assert(!HasWriterListeners());
 }
 
-void SwFormat::Modify( const SfxPoolItem* pOldValue, const SfxPoolItem* pNewValue )
+void SwFormat::SwClientNotify(const SwModify&, const SfxHint& rHint)
 {
-    std::unique_ptr<SwAttrSetChg> pOldClientChg, pNewClientChg;
-    auto aDependArgs = std::pair<const SfxPoolItem*, const SfxPoolItem*>(pOldValue, pNewValue);
-    bool bPassToDepends = true;
-    const sal_uInt16 nWhich = pOldValue ? pOldValue->Which()
-            : pNewValue ? pNewValue->Which()
-            : 0;
-    switch( nWhich )
-    {
-    case 0:     break;          // Which-Id of 0?
+    auto pLegacy = dynamic_cast<const sw::LegacyModifyHint*>(&rHint);
+    if(!pLegacy)
+        return;
 
-    case RES_OBJECTDYING:
-        // NB: this still notifies depends even if pNewValue is nullptr, which seems non-obvious
-        if (pNewValue)
+    std::unique_ptr<SwAttrSetChg> pOldClientChg, pNewClientChg;
+    auto pDependsHint = std::make_unique<sw::LegacyModifyHint>(pLegacy->m_pOld, pLegacy->m_pNew);
+    const sal_uInt16 nWhich = pLegacy->GetWhich();
+    InvalidateInSwCache(nWhich);
+    switch(nWhich)
+    {
+        case 0:
+            break;
+        case RES_OBJECTDYING:
         {
+            // NB: this still notifies depends even if pLegacy->m_pNew is nullptr, which seems non-obvious
+            if(!pLegacy->m_pNew)
+                break;
             // If the dying object is the parent format of this format so
             // attach this to the parent of the parent
-            SwFormat* pFormat = static_cast<SwFormat*>(static_cast<const SwPtrMsgPoolItem*>(pNewValue)->pObject);
+            SwFormat* pFormat = static_cast<SwFormat*>(pLegacy->m_pNew->StaticWhichCast(RES_OBJECTDYING).pObject);
 
             // do not move if this is the topmost format
-            if( GetRegisteredIn() && GetRegisteredIn() == pFormat )
+            if(GetRegisteredIn() && GetRegisteredIn() == pFormat)
             {
-                if( pFormat->GetRegisteredIn() )
+                if(pFormat->GetRegisteredIn())
                 {
                     // if parent so register in new parent
-                    pFormat->DerivedFrom()->Add( this );
-                    m_aSet.SetParent( &DerivedFrom()->m_aSet );
+                    pFormat->DerivedFrom()->Add(this);
+                    m_aSet.SetParent(&DerivedFrom()->m_aSet);
                 }
                 else
                 {
                     // otherwise de-register at least from dying one
                     EndListeningAll();
-                    m_aSet.SetParent( nullptr );
+                    m_aSet.SetParent(nullptr);
                 }
             }
+            break;
         }
-        break;
-    case RES_ATTRSET_CHG:
-        // NB: this still notifies depends even if this condition is not met, which seems non-obvious
-        if (pOldValue && pNewValue && static_cast<const SwAttrSetChg*>(pOldValue)->GetTheChgdSet() != &m_aSet)
+        case RES_ATTRSET_CHG:
         {
-            // pass only those that are not set...
-            pNewClientChg.reset( new SwAttrSetChg(*static_cast<const SwAttrSetChg*>(pNewValue)) );
-            pNewClientChg->GetChgSet()->Differentiate( m_aSet );
-            if(pNewClientChg->Count()) // ... if any
+            // NB: this still notifies depends even if this condition is not met, which seems non-obvious
+            auto pOldAttrSetChg = static_cast<const SwAttrSetChg*>(pLegacy->m_pOld);
+            auto pNewAttrSetChg = static_cast<const SwAttrSetChg*>(pLegacy->m_pNew);
+            if (pOldAttrSetChg && pNewAttrSetChg && pOldAttrSetChg->GetTheChgdSet() != &m_aSet)
             {
-                pOldClientChg.reset( new SwAttrSetChg(*static_cast<const SwAttrSetChg*>(pOldValue)) );
-                pOldClientChg->GetChgSet()->Differentiate( m_aSet );
-                aDependArgs = std::pair<const SfxPoolItem*, const SfxPoolItem*>(pOldClientChg.get(), pNewClientChg.get());
+                // pass only those that are not set...
+                pNewClientChg.reset(new SwAttrSetChg(*pNewAttrSetChg));
+                pNewClientChg->GetChgSet()->Differentiate(m_aSet);
+                if(pNewClientChg->Count()) // ... if any
+                {
+                    pOldClientChg.reset(new SwAttrSetChg(*pOldAttrSetChg));
+                    pOldClientChg->GetChgSet()->Differentiate(m_aSet);
+                    pDependsHint.reset(new sw::LegacyModifyHint(pOldClientChg.get(), pNewClientChg.get()));
+                }
+                else
+                    pDependsHint.reset(nullptr);
             }
-            else
-                bPassToDepends = false;
+            break;
         }
-        break;
-    case RES_FMT_CHG:
-        // if the format parent will be moved so register my attribute set at
-        // the new one
+        case RES_FMT_CHG:
+        {
+            // if the format parent will be moved so register my attribute set at
+            // the new one
 
-        // skip my own Modify
-        // NB: this still notifies depends even if this condition is not met, which seems non-obvious
-        if ( pOldValue && pNewValue &&
-            static_cast<const SwFormatChg*>(pOldValue)->pChangedFormat != this &&
-            static_cast<const SwFormatChg*>(pNewValue)->pChangedFormat == GetRegisteredIn() )
-        {
-            // attach Set to new parent
-            m_aSet.SetParent( DerivedFrom() ? &DerivedFrom()->m_aSet : nullptr );
+            // skip my own Modify
+            // NB: this still notifies depends even if this condition is not met, which seems non-obvious
+            auto pOldFormatChg = static_cast<const SwFormatChg*>(pLegacy->m_pOld);
+            auto pNewFormatChg = static_cast<const SwFormatChg*>(pLegacy->m_pNew);
+            if(pOldFormatChg && pNewFormatChg && pOldFormatChg->pChangedFormat != this && pNewFormatChg->pChangedFormat == GetRegisteredIn())
+            {
+                // attach Set to new parent
+                m_aSet.SetParent(DerivedFrom() ? &DerivedFrom()->m_aSet : nullptr);
+            }
+            break;
         }
-        break;
-    default:
-        {
+        default:
             // attribute is defined in this format
-            if( SfxItemState::SET == m_aSet.GetItemState( nWhich, false ))
+            if(SfxItemState::SET == m_aSet.GetItemState(nWhich, false))
             {
                 // DropCaps might come into this block
-                OSL_ENSURE( RES_PARATR_DROP == nWhich, "Modify was sent without sender" );
-                bPassToDepends = false;
+                SAL_WARN_IF(RES_PARATR_DROP != nWhich, "sw.core", "Hint was sent without sender");
+                pDependsHint.reset(nullptr);
             }
-        }
     }
-    if(bPassToDepends)
-        NotifyClients(aDependArgs.first, aDependArgs.second);
+    if(pDependsHint)
+    {
+        InvalidateInSwFntCache(pDependsHint->GetWhich());
+        SwModify::SwClientNotify(*this, *pDependsHint);
+    }
 }
 
 bool SwFormat::SetDerivedFrom(SwFormat *pDerFrom)
@@ -354,12 +347,8 @@ bool SwFormat::SetDerivedFrom(SwFormat *pDerFrom)
             || (Which()==RES_FLYFRMFMT && pDerFrom->Which()==RES_FRMFMT)
             );
 
-    if ( IsInCache() )
-    {
-        SwFrame::GetCache().Delete( this );
-        SetInCache( false );
-    }
-    SetInSwFntCache( false );
+    InvalidateInSwCache(RES_ATTRSET_CHG);
+    InvalidateInSwFntCache(RES_ATTRSET_CHG);
 
     pDerFrom->Add( this );
     m_aSet.SetParent( &pDerFrom->m_aSet );
@@ -454,17 +443,15 @@ SfxItemState SwFormat::GetBackgroundState(std::unique_ptr<SvxBrushItem>& rItem)
     const SfxPoolItem* pItem = nullptr;
     SfxItemState eRet = m_aSet.GetItemState(RES_BACKGROUND, true, &pItem);
     if (pItem)
-        rItem.reset(static_cast<SvxBrushItem*>(pItem->Clone()));
+        rItem.reset(&pItem->Clone()->StaticWhichCast(RES_BACKGROUND));
     return eRet;
 }
 
 bool SwFormat::SetFormatAttr( const SfxPoolItem& rAttr )
 {
-    if ( IsInCache() || IsInSwFntCache() )
-    {
-        const sal_uInt16 nWhich = rAttr.Which();
-        CheckCaching( nWhich );
-    }
+    const sal_uInt16 nWhich = rAttr.Which();
+    InvalidateInSwFntCache( nWhich );
+    InvalidateInSwCache( nWhich );
 
     bool bRet = false;
 
@@ -473,7 +460,7 @@ bool SwFormat::SetFormatAttr( const SfxPoolItem& rAttr )
         // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
         SAL_INFO("sw.core", "Do no longer use SvxBrushItem, instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST] FillAttributes (simple fallback is in place and used)");
         SfxItemSet aTempSet(*m_aSet.GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{});
-        const SvxBrushItem& rSource = static_cast< const SvxBrushItem& >(rAttr);
+        const SvxBrushItem& rSource = rAttr.StaticWhichCast(RES_BACKGROUND);
 
         // fill a local ItemSet with the attributes corresponding as good as possible
         // to the new fill properties [XATTR_FILL_FIRST .. XATTR_FILL_LAST] and set these
@@ -544,12 +531,8 @@ bool SwFormat::SetFormatAttr( const SfxItemSet& rSet )
     if( !rSet.Count() )
         return false;
 
-    if ( IsInCache() )
-    {
-        SwFrame::GetCache().Delete( this );
-        SetInCache( false );
-    }
-    SetInSwFntCache( false );
+    InvalidateInSwCache(RES_ATTRSET_CHG);
+    InvalidateInSwFntCache(RES_ATTRSET_CHG);
 
     bool bRet = false;
 
@@ -577,7 +560,7 @@ bool SwFormat::SetFormatAttr( const SfxItemSet& rSet )
             // copy all items to be set anyways to a local ItemSet with is also prepared for the new
             // fill attribute ranges [XATTR_FILL_FIRST .. XATTR_FILL_LAST]. Add the attributes
             // corresponding as good as possible to the new fill properties and set the whole ItemSet
-            const SvxBrushItem& rSource(static_cast< const SvxBrushItem& >(*pSource));
+            const SvxBrushItem& rSource(pSource->StaticWhichCast(RES_BACKGROUND));
             setSvxBrushItemAsFillAttributesToTargetSet(rSource, aTempSet);
 
             if(IsModifyLocked())
@@ -646,11 +629,10 @@ bool SwFormat::ResetFormatAttr( sal_uInt16 nWhich1, sal_uInt16 nWhich2 )
     if( !nWhich2 || nWhich2 < nWhich1 )
         nWhich2 = nWhich1; // then set to 1st ID, only this item
 
-    if ( IsInCache() || IsInSwFntCache() )
-    {
-        for( sal_uInt16 n = nWhich1; n < nWhich2; ++n )
-            CheckCaching( n );
-    }
+    for( sal_uInt16 n = nWhich1; n < nWhich2; ++n )
+        InvalidateInSwFntCache( n );
+    for( sal_uInt16 n = nWhich1; n < nWhich2 && IsInCache(); ++n )
+        InvalidateInSwCache( n );
 
     // if Modify is locked then no modifications will be sent
     if( IsModifyLocked() )
@@ -672,12 +654,8 @@ sal_uInt16 SwFormat::ResetAllFormatAttr()
     if( !m_aSet.Count() )
         return 0;
 
-    if ( IsInCache() )
-    {
-        SwFrame::GetCache().Delete( this );
-        SetInCache( false );
-    }
-    SetInSwFntCache( false );
+    InvalidateInSwCache(RES_ATTRSET_CHG);
+    InvalidateInSwFntCache(RES_ATTRSET_CHG);
 
     // if Modify is locked then no modifications will be sent
     if( IsModifyLocked() )
@@ -696,12 +674,8 @@ void SwFormat::DelDiffs( const SfxItemSet& rSet )
     if( !m_aSet.Count() )
         return;
 
-    if ( IsInCache() )
-    {
-        SwFrame::GetCache().Delete( this );
-        SetInCache( false );
-    }
-    SetInSwFntCache( false );
+    InvalidateInSwCache(RES_ATTRSET_CHG);
+    InvalidateInSwFntCache(RES_ATTRSET_CHG);
 
     // if Modify is locked then no modifications will be sent
     if( IsModifyLocked() )
@@ -717,6 +691,13 @@ void SwFormat::DelDiffs( const SfxItemSet& rSet )
         sw::ClientNotifyAttrChg(*this, m_aSet, aOld, aNew);
 }
 
+void SwFormat::SetPageFormatToDefault()
+{
+    const sal_Int32 nSize = o3tl::convert(2, o3tl::Length::cm, o3tl::Length::twip);
+    SetFormatAttr(SvxLRSpaceItem(nSize, nSize, nSize, 0, RES_LR_SPACE));
+    SetFormatAttr(SvxULSpaceItem(nSize, nSize, RES_UL_SPACE));
+}
+
 /** SwFormat::IsBackgroundTransparent
 
     Virtual method to determine, if background of format is transparent.
