@@ -27,6 +27,7 @@
 #include <pam.hxx>
 #include <swserv.hxx>
 #include <sfx2/linkmgr.hxx>
+#include <sfx2/viewsh.hxx>
 #include <UndoBookmark.hxx>
 #include <unobookmark.hxx>
 #include <xmloff/odffields.hxx>
@@ -41,11 +42,8 @@
 #include <DocumentContentOperationsManager.hxx>
 #include <comphelper/lok.hxx>
 #include <txtfrm.hxx>
-#include <view.hxx>
 #include <LibreOfficeKit/LibreOfficeKitEnums.h>
-#include <wrtsh.hxx>
 #include <rtl/strbuf.hxx>
-#include <sfx2/lokhelper.hxx>
 #include <strings.hrc>
 
 using namespace ::sw::mark;
@@ -299,24 +297,24 @@ namespace sw::mark
 
     void MarkBase::dumpAsXml(xmlTextWriterPtr pWriter) const
     {
-        xmlTextWriterStartElement(pWriter, BAD_CAST("MarkBase"));
-        xmlTextWriterWriteAttribute(pWriter, BAD_CAST("name"), BAD_CAST(m_aName.toUtf8().getStr()));
-        xmlTextWriterStartElement(pWriter, BAD_CAST("markPos"));
+        (void)xmlTextWriterStartElement(pWriter, BAD_CAST("MarkBase"));
+        (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("name"), BAD_CAST(m_aName.toUtf8().getStr()));
+        (void)xmlTextWriterStartElement(pWriter, BAD_CAST("markPos"));
         GetMarkPos().dumpAsXml(pWriter);
-        xmlTextWriterEndElement(pWriter);
+        (void)xmlTextWriterEndElement(pWriter);
         if (IsExpanded())
         {
-            xmlTextWriterStartElement(pWriter, BAD_CAST("otherMarkPos"));
+            (void)xmlTextWriterStartElement(pWriter, BAD_CAST("otherMarkPos"));
             GetOtherMarkPos().dumpAsXml(pWriter);
-            xmlTextWriterEndElement(pWriter);
+            (void)xmlTextWriterEndElement(pWriter);
         }
-        xmlTextWriterEndElement(pWriter);
+        (void)xmlTextWriterEndElement(pWriter);
     }
 
     MarkBase::~MarkBase()
     { }
 
-    OUString MarkBase::GenerateNewName(const OUString& rPrefix)
+    OUString MarkBase::GenerateNewName(std::u16string_view rPrefix)
     {
         static bool bHack = (getenv("LIBO_ONEWAY_STABLE_ODF_EXPORT") != nullptr);
 
@@ -356,15 +354,15 @@ namespace sw::mark
     }
 
     NavigatorReminder::NavigatorReminder(const SwPaM& rPaM)
-        : MarkBase(rPaM, MarkBase::GenerateNewName("__NavigatorReminder__"))
+        : MarkBase(rPaM, MarkBase::GenerateNewName(u"__NavigatorReminder__"))
     { }
 
     UnoMark::UnoMark(const SwPaM& aPaM)
-        : MarkBase(aPaM, MarkBase::GenerateNewName("__UnoMark__"))
+        : MarkBase(aPaM, MarkBase::GenerateNewName(u"__UnoMark__"))
     { }
 
     DdeBookmark::DdeBookmark(const SwPaM& aPaM)
-        : MarkBase(aPaM, MarkBase::GenerateNewName("__DdeLink__"))
+        : MarkBase(aPaM, MarkBase::GenerateNewName(u"__DdeLink__"))
     { }
 
     void DdeBookmark::SetRefObject(SwServerObject* pObj)
@@ -487,7 +485,7 @@ namespace sw::mark
     }
 
     Fieldmark::Fieldmark(const SwPaM& rPaM)
-        : MarkBase(rPaM, MarkBase::GenerateNewName("__Fieldmark__"))
+        : MarkBase(rPaM, MarkBase::GenerateNewName(u"__Fieldmark__"))
     {
         if(!IsExpanded())
             SetOtherMarkPos(GetMarkPos());
@@ -528,20 +526,20 @@ namespace sw::mark
 
     void Fieldmark::dumpAsXml(xmlTextWriterPtr pWriter) const
     {
-        xmlTextWriterStartElement(pWriter, BAD_CAST("Fieldmark"));
-        xmlTextWriterWriteAttribute(pWriter, BAD_CAST("fieldname"), BAD_CAST(m_aFieldname.toUtf8().getStr()));
-        xmlTextWriterWriteAttribute(pWriter, BAD_CAST("fieldHelptext"), BAD_CAST(m_aFieldHelptext.toUtf8().getStr()));
+        (void)xmlTextWriterStartElement(pWriter, BAD_CAST("Fieldmark"));
+        (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("fieldname"), BAD_CAST(m_aFieldname.toUtf8().getStr()));
+        (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("fieldHelptext"), BAD_CAST(m_aFieldHelptext.toUtf8().getStr()));
         MarkBase::dumpAsXml(pWriter);
-        xmlTextWriterStartElement(pWriter, BAD_CAST("parameters"));
+        (void)xmlTextWriterStartElement(pWriter, BAD_CAST("parameters"));
         for (auto& rParam : m_vParams)
         {
-            xmlTextWriterStartElement(pWriter, BAD_CAST("parameter"));
-            xmlTextWriterWriteAttribute(pWriter, BAD_CAST("name"), BAD_CAST(rParam.first.toUtf8().getStr()));
-            xmlTextWriterWriteAttribute(pWriter, BAD_CAST("value"), BAD_CAST(comphelper::anyToString(rParam.second).toUtf8().getStr()));
-            xmlTextWriterEndElement(pWriter);
+            (void)xmlTextWriterStartElement(pWriter, BAD_CAST("parameter"));
+            (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("name"), BAD_CAST(rParam.first.toUtf8().getStr()));
+            (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("value"), BAD_CAST(comphelper::anyToString(rParam.second).toUtf8().getStr()));
+            (void)xmlTextWriterEndElement(pWriter);
         }
-        xmlTextWriterEndElement(pWriter);
-        xmlTextWriterEndElement(pWriter);
+        (void)xmlTextWriterEndElement(pWriter);
+        (void)xmlTextWriterEndElement(pWriter);
     }
 
     TextFieldmark::TextFieldmark(const SwPaM& rPaM, const OUString& rName)
@@ -650,12 +648,6 @@ namespace sw::mark
         m_pButton.disposeAndClear();
     }
 
-    void FieldmarkWithDropDownButton::HideButton()
-    {
-        if(m_pButton)
-            m_pButton->Show(false);
-    }
-
     void FieldmarkWithDropDownButton::RemoveButton()
     {
         if(m_pButton)
@@ -669,7 +661,6 @@ namespace sw::mark
 
     DropDownFieldmark::~DropDownFieldmark()
     {
-        SendLOKMessage("hide");
     }
 
     void DropDownFieldmark::ShowButton(SwEditWin* pEditWin)
@@ -680,19 +671,11 @@ namespace sw::mark
                 m_pButton = VclPtr<DropDownFormFieldButton>::Create(pEditWin, *this);
             m_pButton->CalcPosAndSize(m_aPortionPaintArea);
             m_pButton->Show();
-            SendLOKMessage("show");
         }
     }
 
-    void DropDownFieldmark::HideButton()
-    {
-        SendLOKMessage("hide");
-        FieldmarkWithDropDownButton::HideButton();
-    }
-
     void DropDownFieldmark::RemoveButton()
     {
-        SendLOKMessage("hide");
         FieldmarkWithDropDownButton::RemoveButton();
     }
 
@@ -703,73 +686,58 @@ namespace sw::mark
         {
             m_pButton->Show();
             m_pButton->CalcPosAndSize(m_aPortionPaintArea);
-            SendLOKMessage("show");
         }
     }
 
-    void DropDownFieldmark::SendLOKMessage(const OString& sAction)
+    void DropDownFieldmark::SendLOKShowMessage(SfxViewShell* pViewShell)
     {
-        const SfxViewShell* pViewShell = SfxViewShell::Current();
-        if (!pViewShell || pViewShell->isLOKMobilePhone())
-        {
-              return;
-        }
-
         if (!comphelper::LibreOfficeKit::isActive())
             return;
 
-        if (!m_pButton)
-          return;
+        if (!pViewShell || pViewShell->isLOKMobilePhone())
+            return;
 
-        SwEditWin* pEditWin = dynamic_cast<SwEditWin*>(m_pButton->GetParent());
-        if (!pEditWin)
+        if (m_aPortionPaintArea.IsEmpty())
             return;
 
         OStringBuffer sPayload;
-        if (sAction == "show")
+        sPayload = OString::Concat("{\"action\": \"show\","
+                   " \"type\": \"drop-down\", \"textArea\": \"") +
+                   m_aPortionPaintArea.SVRect().toString() + "\",";
+        // Add field params to the message
+        sPayload.append(" \"params\": { \"items\": [");
+
+        // List items
+        auto pParameters = this->GetParameters();
+        auto pListEntriesIter = pParameters->find(ODF_FORMDROPDOWN_LISTENTRY);
+        css::uno::Sequence<OUString> vListEntries;
+        if (pListEntriesIter != pParameters->end())
         {
-            if(m_aPortionPaintArea.IsEmpty())
-                return;
-
-            sPayload = OStringLiteral("{\"action\": \"show\","
-                       " \"type\": \"drop-down\", \"textArea\": \"") +
-                       m_aPortionPaintArea.SVRect().toString() + "\",";
-            // Add field params to the message
-            sPayload.append(" \"params\": { \"items\": [");
-
-            // List items
-            auto pParameters = this->GetParameters();
-            auto pListEntriesIter = pParameters->find(ODF_FORMDROPDOWN_LISTENTRY);
-            css::uno::Sequence<OUString> vListEntries;
-            if (pListEntriesIter != pParameters->end())
-            {
-                pListEntriesIter->second >>= vListEntries;
-                for (const OUString& sItem : std::as_const(vListEntries))
-                    sPayload.append("\"" + OUStringToOString(sItem, RTL_TEXTENCODING_UTF8) + "\", ");
-                sPayload.setLength(sPayload.getLength() - 2);
-            }
-            sPayload.append("], ");
-
-            // Selected item
-            auto pSelectedItemIter = pParameters->find(ODF_FORMDROPDOWN_RESULT);
-            sal_Int32 nSelection = -1;
-            if (pSelectedItemIter != pParameters->end())
-            {
-                pSelectedItemIter->second >>= nSelection;
-            }
-            sPayload.append("\"selected\": \"" + OString::number(nSelection) + "\", ");
-
-            // Placeholder text
-            sPayload.append("\"placeholderText\": \"" + OUStringToOString(SwResId(STR_DROP_DOWN_EMPTY_LIST), RTL_TEXTENCODING_UTF8) + "\"}}");
+            pListEntriesIter->second >>= vListEntries;
+            for (const OUString& sItem : std::as_const(vListEntries))
+                sPayload.append("\"" + OUStringToOString(sItem, RTL_TEXTENCODING_UTF8) + "\", ");
+            sPayload.setLength(sPayload.getLength() - 2);
         }
-        else
+        sPayload.append("], ");
+
+        // Selected item
+        auto pSelectedItemIter = pParameters->find(ODF_FORMDROPDOWN_RESULT);
+        sal_Int32 nSelection = -1;
+        if (pSelectedItemIter != pParameters->end())
         {
-            sPayload = "{\"action\": \"hide\", \"type\": \"drop-down\"}";
-        }
-        if (sPayload.toString() != m_sLastSentLOKMsg) {
-            m_sLastSentLOKMsg = sPayload.toString();
-            pViewShell->libreOfficeKitViewCallback(LOK_CALLBACK_FORM_FIELD_BUTTON, m_sLastSentLOKMsg.getStr());
+            pSelectedItemIter->second >>= nSelection;
         }
+        sPayload.append("\"selected\": \"" + OString::number(nSelection) + "\", ");
+
+        // Placeholder text
+        sPayload.append("\"placeholderText\": \"" + OUStringToOString(SwResId(STR_DROP_DOWN_EMPTY_LIST), RTL_TEXTENCODING_UTF8) + "\"}}");
+        pViewShell->libreOfficeKitViewCallback(LOK_CALLBACK_FORM_FIELD_BUTTON, sPayload.toString().getStr());
+    }
+
+    void DropDownFieldmark::SendLOKHideMessage(SfxViewShell* pViewShell)
+    {
+        OString sPayload = "{\"action\": \"hide\", \"type\": \"drop-down\"}";
+        pViewShell->libreOfficeKitViewCallback(LOK_CALLBACK_FORM_FIELD_BUTTON, sPayload.getStr());
     }
 
     DateFieldmark::DateFieldmark(const SwPaM& rPaM)
