@@ -35,13 +35,13 @@
 #include <fmtflcnt.hxx>
 #include <ndtxt.hxx>
 #include <unoframe.hxx>
-#include <docary.hxx>
 #include <textboxhelper.hxx>
 #include <ndindex.hxx>
 #include <pam.hxx>
 #include <frameformats.hxx>
 #include <com/sun/star/embed/EmbedStates.hpp>
 #include <svx/svdobj.hxx>
+#include <osl/diagnose.h>
 
 using namespace ::com::sun::star;
 
@@ -135,7 +135,7 @@ SwFrameFormat *DocumentLayoutManager::MakeLayoutFormat( RndStdIds eRequest, cons
                 m_rDoc.GetNodes().MakeTextSection
                 ( aTmpIdx,
                   bHeader ? SwHeaderStartNode : SwFooterStartNode,
-                  m_rDoc.getIDocumentStylePoolAccess().GetTextCollFromPool(static_cast<sal_uInt16>( bHeader
+                  m_rDoc.getIDocumentStylePoolAccess().GetTextCollFromPool(o3tl::narrowing<sal_uInt16>( bHeader
                                      ? ( eRequest == RndStdIds::HEADERL
                                          ? RES_POOLCOLL_HEADERL
                                          : eRequest == RndStdIds::HEADERR
