@@ -59,7 +59,6 @@
 #include <node2lay.hxx>
 #include <SwStyleNameMapper.hxx>
 #include <breakit.hxx>
-#include <scriptinfo.hxx>
 #include <calbck.hxx>
 #include <ToxTextGenerator.hxx>
 #include <ToxTabStopTokenHandler.hxx>
@@ -68,6 +67,7 @@
 #include <tools/globname.hxx>
 #include <com/sun/star/embed/XEmbeddedObject.hpp>
 #include <o3tl/safeint.hxx>
+#include <osl/diagnose.h>
 
 #include <memory>
 
@@ -229,11 +229,8 @@ const SwTOXMark& SwDoc::GotoTOXMark( const SwTOXMark& rCurTOXMark,
                                     SwTOXSearch eDir, bool bInReadOnly )
 {
     const SwTextTOXMark* pMark = rCurTOXMark.GetTextTOXMark();
-    OSL_ENSURE(pMark, "pMark==0 invalid TextTOXMark");
 
-    const SwTextNode *pTOXSrc = pMark->GetpTextNd();
-
-    CompareNodeContent aAbsIdx( pTOXSrc->GetIndex(), pMark->GetStart() );
+    CompareNodeContent aAbsIdx(pMark ? pMark->GetpTextNd()->GetIndex() : 0, pMark ? pMark->GetStart() : 0);
     CompareNodeContent aPrevPos( 0, 0 );
     CompareNodeContent aNextPos( ULONG_MAX, SAL_MAX_INT32 );
     CompareNodeContent aMax( 0, 0 );
@@ -256,7 +253,7 @@ const SwTOXMark& SwDoc::GotoTOXMark( const SwTOXMark& rCurTOXMark,
         if (!pMark)
             continue;
 
-        pTOXSrc = pMark->GetpTextNd();
+        SwTextNode const*const pTOXSrc = pMark->GetpTextNd();
         if (!pTOXSrc)
             continue;
 
@@ -982,6 +979,7 @@ void SwTOXBaseSection::Update(const SfxItemSet* pAttr,
 
     // Sort the List of all TOC Marks and TOC Sections
     std::vector<SwTextFormatColl*> aCollArr( GetTOXForm().GetFormMax(), nullptr );
+    std::unordered_map<OUString, int> markURLs;
     SwNodeIndex aInsPos( *pFirstEmptyNd, 1 );
     for( size_t nCnt = 0; nCnt < m_aSortArr.size(); ++nCnt )
     {
@@ -1034,7 +1032,7 @@ void SwTOXBaseSection::Update(const SfxItemSet* pAttr,
                                 sw::DefaultToxTabStopTokenHandler::TABSTOPS_RELATIVE_TO_INDENT :
                                 sw::DefaultToxTabStopTokenHandler::TABSTOPS_RELATIVE_TO_PAGE);
         sw::ToxTextGenerator ttgn(GetTOXForm(), tabStopTokenHandler);
-        ttgn.GenerateText(GetFormat()->GetDoc(), m_aSortArr, nCnt, nRange, pLayout);
+        ttgn.GenerateText(GetFormat()->GetDoc(), markURLs, m_aSortArr, nCnt, nRange, pLayout);
         nCnt += nRange - 1;
     }
 
@@ -1522,7 +1520,7 @@ void SwTOXBaseSection::UpdateContent( SwTOXElement eMyType,
                 std::unique_ptr<SwTOXPara> pNew( MakeSwTOXSortTabBase<SwTOXPara>(
                         pLayout, *pCNd, eMyType,
                             ( USHRT_MAX != nSetLevel )
-                            ? static_cast<sal_uInt16>(nSetLevel)
+                            ? o3tl::narrowing<sal_uInt16>(nSetLevel)
                             : FORM_ALPHA_DELIMITER ) );
                 InsertSorted( std::move(pNew) );
             }
@@ -1572,7 +1570,7 @@ void SwTOXBaseSection::UpdateTable(const SwTextNode* pOwnChapterNode,
                             if( pOutlNd->GetTextColl()->IsAssignedToListLevelOfOutlineStyle())
                             {
                                 const int nTmp = pOutlNd->GetTextColl()->GetAttrOutlineLevel();
-                                pNew->SetLevel(static_cast<sal_uInt16>(nTmp));
+                                pNew->SetLevel(o3tl::narrowing<sal_uInt16>(nTmp));
                             }
                         }
                     }
@@ -1719,7 +1717,9 @@ void SwTOXBaseSection::UpdatePageNum_( SwTextNode* pNd,
                                     const SwTOXInternational& rIntl )
 {
     // collect starts end ends of main entry character style
-    std::unique_ptr< std::vector<sal_uInt16> > xCharStyleIdx(pMainEntryNums ? new std::vector<sal_uInt16> : nullptr);
+    std::optional< std::vector<sal_uInt16> > xCharStyleIdx;
+    if (pMainEntryNums)
+        xCharStyleIdx.emplace();
 
     OUString sSrchStr
         = OUStringChar(C_NUM_REPL) + SwTOXMark::S_PAGE_DELI + OUStringChar(C_NUM_REPL);
