@@ -666,7 +666,8 @@ OUString SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVecto
 
             if (rMyNFormat.HasListFormat())
             {
-                OUString sLevelFormat = rMyNFormat.GetListFormat();
+                OUString sLevelFormat = rMyNFormat.GetListFormat(bInclStrings);
+
                 // In this case we are ignoring GetIncludeUpperLevels: we put all
                 // level numbers requested by level format
                 for (SwNumberTree::tNumberVector::size_type i=0; i <= nLevel; ++i)
