@@ -33,11 +33,14 @@
 #include <editeng/memberids.h>
 #include <svx/svdoashp.hxx>
 #include <svx/svdpage.hxx>
-#include <svx/swframetypes.hxx>
 #include <svl/itemiter.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 #include <sal/log.hxx>
 #include <tools/UnitConversion.hxx>
+#include <svx/swframetypes.hxx>
+#include <drawdoc.hxx>
+#include <IDocumentUndoRedo.hxx>
+#include <DocumentDrawModelManager.hxx>
 
 #include <com/sun/star/document/XActionLockable.hpp>
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
@@ -60,7 +63,7 @@ void SwTextBoxHelper::create(SwFrameFormat* pShape, bool bCopyText)
     if (pShape->GetAttrSet().HasItem(RES_CNTNT) && pShape->GetOtherTextBoxFormat())
         return;
 
-    // Store the current text conent of the shape
+    // Store the current text content of the shape
     OUString sCopyableText;
 
     if (bCopyText)
@@ -135,6 +138,7 @@ void SwTextBoxHelper::create(SwFrameFormat* pShape, bool bCopyText)
         pShape->SetFormatAttr(aSet);
     }
 
+    DoTextBoxZOrderCorrection(pShape);
     // Also initialize the properties, which are not constant, but inherited from the shape's ones.
     uno::Reference<drawing::XShape> xShape(pShape->FindRealSdrObject()->getUnoShape(),
                                            uno::UNO_QUERY);
@@ -165,47 +169,22 @@ void SwTextBoxHelper::create(SwFrameFormat* pShape, bool bCopyText)
     if (xShapePropertySet->getPropertyValue(UNO_NAME_TEXT_WRITINGMODE) >>= eMode)
         syncProperty(pShape, RES_FRAMEDIR, 0, uno::makeAny(sal_Int16(eMode)));
 
-    const SwFormatAnchor& rAnch = pShape->GetAnchor();
-    if (!((rAnch.GetAnchorId() == RndStdIds::FLY_AT_PAGE && rAnch.GetPageNum() != 0)
-          || ((rAnch.GetAnchorId() == RndStdIds::FLY_AT_PARA
-               || rAnch.GetAnchorId() == RndStdIds::FLY_AT_CHAR)
-              && rAnch.GetContentAnchor())))
+    // Check if the shape had text before and move it to the new textframe
+    if (!bCopyText || sCopyableText.isEmpty())
         return;
 
-    SfxItemSet aTxFrmSet(pFormat->GetDoc()->GetAttrPool(), aFrameFormatSetRange);
-
-    if (rAnch.GetAnchorId() == RndStdIds::FLY_AT_CHAR
-        || rAnch.GetAnchorId() == RndStdIds::FLY_AT_PARA)
-        aTxFrmSet.Put(rAnch);
-
-    SwFormatVertOrient aVOri(pFormat->GetVertOrient());
-    SwFormatHoriOrient aHOri(pFormat->GetHoriOrient());
-    aVOri.SetVertOrient(pShape->GetVertOrient().GetVertOrient());
-    aHOri.SetHoriOrient(pShape->GetHoriOrient().GetHoriOrient());
-    aVOri.SetRelationOrient(pShape->GetVertOrient().GetRelationOrient());
-    aHOri.SetRelationOrient(pShape->GetHoriOrient().GetRelationOrient());
-    aTxFrmSet.Put(aVOri);
-    aTxFrmSet.Put(aHOri);
-
-    if (aTxFrmSet.Count())
-        pFormat->SetFormatAttr(aTxFrmSet);
-
-    // Check if the shape had text before and move it to the new textframe
-    if (bCopyText && !sCopyableText.isEmpty())
+    auto pSdrShape = pShape->FindRealSdrObject();
+    if (pSdrShape)
     {
-        auto pSdrShape = pShape->FindRealSdrObject();
-        if (pSdrShape)
-        {
-            auto pSourceText = dynamic_cast<SdrTextObj*>(pSdrShape);
-            uno::Reference<text::XTextRange> xDestText(xRealTextFrame, uno::UNO_QUERY);
+        auto pSourceText = dynamic_cast<SdrTextObj*>(pSdrShape);
+        uno::Reference<text::XTextRange> xDestText(xRealTextFrame, uno::UNO_QUERY);
 
-            xDestText->setString(sCopyableText);
+        xDestText->setString(sCopyableText);
 
-            if (pSourceText)
-                pSourceText->SetText(OUString());
+        if (pSourceText)
+            pSourceText->SetText(OUString());
 
-            pShape->GetDoc()->getIDocumentState().SetModified();
-        }
+        pShape->GetDoc()->getIDocumentState().SetModified();
     }
 }
 
@@ -441,7 +420,7 @@ tools::Rectangle SwTextBoxHelper::getTextRectangle(SwFrameFormat* pShape, bool b
     return aRet;
 }
 
-void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, const OUString& rPropertyName,
+void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, std::u16string_view rPropertyName,
                                    const css::uno::Any& rValue)
 {
     // Textframes does not have valid horizontal adjust property, so map it to paragraph adjust property
@@ -460,7 +439,8 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, const OUString& rPrope
         uno::Reference<beans::XPropertySet> xFrameParaProps(xCursor, uno::UNO_QUERY);
 
         // And simply map the property
-        switch (rValue.get<drawing::TextHorizontalAdjust>())
+        const auto eValue = rValue.get<drawing::TextHorizontalAdjust>();
+        switch (eValue)
         {
             case drawing::TextHorizontalAdjust::TextHorizontalAdjust_CENTER:
                 xFrameParaProps->setPropertyValue(
@@ -478,12 +458,15 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, const OUString& rPrope
                     uno::makeAny(style::ParagraphAdjust::ParagraphAdjust_RIGHT)); //1
                 break;
             default:
+                SAL_WARN("sw.core",
+                         "SwTextBoxHelper::syncProperty: unhandled TextHorizontalAdjust: "
+                             << static_cast<sal_Int32>(eValue));
                 break;
         }
         return;
     }
 
-    if (rPropertyName == "CustomShapeGeometry")
+    if (rPropertyName == u"CustomShapeGeometry")
     {
         // CustomShapeGeometry changes the textbox position offset and size, so adjust both.
         syncProperty(pShape, RES_FRM_SIZE, MID_FRMSIZE_SIZE, uno::Any());
@@ -528,6 +511,11 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, const OUString& rPrope
                 case -270:
                     nDirection = text::WritingMode2::BT_LR;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled property value: "
+                                        "CustomShapeGeometry:TextPreRotateAngle: "
+                                            << nAngle);
+                    break;
             }
 
             if (nDirection)
@@ -557,6 +545,9 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, const OUString& rPrope
         else if (rValue >>= eMode2)
             syncProperty(pShape, RES_FRAMEDIR, 0, uno::makeAny(eMode2));
     }
+    else
+        SAL_INFO("sw.core", "SwTextBoxHelper::syncProperty: unhandled property: "
+                                << static_cast<OUString>(rPropertyName));
 }
 
 void SwTextBoxHelper::getProperty(SwFrameFormat const* pShape, sal_uInt16 nWID, sal_uInt8 nMemberID,
@@ -586,9 +577,28 @@ void SwTextBoxHelper::getProperty(SwFrameFormat const* pShape, sal_uInt16 nWID,
         case MID_CHAIN_NAME:
             rValue <<= pFormat->GetName();
             break;
+        default:
+            SAL_WARN("sw.core", "SwTextBoxHelper::getProperty: unhandled member-id: "
+                                    << o3tl::narrowing<sal_uInt16>(nMemberID));
+            break;
     }
 }
 
+css::uno::Any SwTextBoxHelper::getProperty(SwFrameFormat const* pShape, OUString sPropName)
+{
+    if (!pShape)
+        return uno::Any();
+
+    SwFrameFormat* pFormat = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT);
+    if (!pFormat)
+        return uno::Any();
+
+    uno::Reference<beans::XPropertySet> const xPropertySet(
+        SwXTextFrame::CreateXTextFrame(*pFormat->GetDoc(), pFormat), uno::UNO_QUERY);
+
+    return xPropertySet->getPropertyValue(sPropName);
+}
+
 void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_uInt8 nMemberID,
                                    const css::uno::Any& rValue)
 {
@@ -616,12 +626,20 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                     aPropertyName = UNO_NAME_HORI_ORIENT;
                     break;
                 case MID_HORIORIENT_RELATION:
-                    aPropertyName = UNO_NAME_HORI_ORIENT_RELATION;
+                    if (pShape->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR)
+                        aPropertyName = UNO_NAME_HORI_ORIENT_RELATION;
+                    else
+                        return;
                     break;
                 case MID_HORIORIENT_POSITION:
                     aPropertyName = UNO_NAME_HORI_ORIENT_POSITION;
                     bAdjustX = true;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
         case RES_LR_SPACE:
@@ -634,6 +652,11 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                 case MID_R_MARGIN:
                     aPropertyName = UNO_NAME_RIGHT_MARGIN;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
         }
@@ -644,17 +667,28 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                     aPropertyName = UNO_NAME_VERT_ORIENT;
                     break;
                 case MID_VERTORIENT_RELATION:
-                    aPropertyName = UNO_NAME_VERT_ORIENT_RELATION;
+                    if (pShape->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR)
+                        aPropertyName = UNO_NAME_VERT_ORIENT_RELATION;
+                    else
+                        return;
                     break;
                 case MID_VERTORIENT_POSITION:
                     aPropertyName = UNO_NAME_VERT_ORIENT_POSITION;
                     bAdjustY = true;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
         case RES_FRM_SIZE:
             switch (nMemberID)
             {
+                case MID_FRMSIZE_WIDTH_TYPE:
+                    aPropertyName = UNO_NAME_WIDTH_TYPE;
+                    break;
                 case MID_FRMSIZE_IS_AUTO_HEIGHT:
                     aPropertyName = UNO_NAME_FRAME_ISAUTOMATIC_HEIGHT;
                     break;
@@ -675,113 +709,18 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
             {
                 case MID_ANCHOR_ANCHORTYPE:
                 {
-                    uno::Reference<beans::XPropertySet> const xPropertySet(
-                        SwXTextFrame::CreateXTextFrame(*pFormat->GetDoc(), pFormat),
-                        uno::UNO_QUERY);
-                    // Surround (Wrap) has to be THROUGH always:
-                    xPropertySet->setPropertyValue(UNO_NAME_SURROUND,
-                                                   uno::makeAny(text::WrapTextMode_THROUGH));
-                    // Use At_Char anchor instead of As_Char anchoring:
-                    if (aValue.get<text::TextContentAnchorType>()
-                        == text::TextContentAnchorType::TextContentAnchorType_AS_CHARACTER)
-                    {
-                        if (const auto aPos = pShape->GetAnchor().GetContentAnchor())
-                        {
-                            xPropertySet->setPropertyValue(
-                                UNO_NAME_ANCHOR_TYPE,
-                                uno::makeAny(text::TextContentAnchorType::
-                                                 TextContentAnchorType_AT_CHARACTER));
-                            xPropertySet->setPropertyValue(
-                                UNO_NAME_HORI_ORIENT_RELATION,
-                                uno::makeAny(text::RelOrientation::CHAR));
+                    setWrapThrough(pShape);
+                    changeAnchor(pShape);
+                    doTextBoxPositioning(pShape);
 
-                            auto pAnch = pFormat->GetAnchor();
-                            pAnch.SetAnchor(pShape->GetAnchor().GetContentAnchor());
-                            tools::Rectangle aRect(getTextRectangle(pShape, false));
-
-                            SwFormatHoriOrient aNewHOri(pFormat->GetHoriOrient());
-                            aNewHOri.SetPos(aRect.getX());
-
-                            SwFormatVertOrient aNewVOri(pFormat->GetVertOrient());
-                            aNewVOri.SetPos(aRect.getY());
-
-                            pFormat->SetFormatAttr(pAnch);
-                            // tdf#140598: Do not apply wrong rectangle position.
-                            if (aRect.TopLeft() != Point(0, 0))
-                            {
-                                pFormat->SetFormatAttr(aNewHOri);
-                                pFormat->SetFormatAttr(aNewVOri);
-                            }
-                            else
-                                SAL_WARN("sw.core",
-                                         "SwTextBoxHelper::syncProperty: Repositioning failed!");
-                        }
-
-                        return;
-                    }
-                    else // Otherwise copy the anchor type of the shape
-                    {
-                        // tdf#140828: Do not keep CHAR rel-orientation:
-                        xPropertySet->setPropertyValue(UNO_NAME_HORI_ORIENT_RELATION,
-                                                       uno::Any(text::RelOrientation::FRAME));
-                        xPropertySet->setPropertyValue(UNO_NAME_ANCHOR_TYPE, aValue);
-                    }
-                    // After anchoring the position must be set as well:
-                    if (aValue.get<text::TextContentAnchorType>()
-                        == text::TextContentAnchorType::TextContentAnchorType_AT_PAGE)
-                    {
-                        if (pShape->GetAnchor().GetPageNum())
-                            xPropertySet->setPropertyValue(
-                                UNO_NAME_ANCHOR_PAGE_NO,
-                                uno::makeAny(pShape->GetAnchor().GetPageNum()));
-                        else
-                        {
-                            SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: Invalid Page Num!");
-                            return;
-                        }
-                    }
-
-                    // At-Content Anchors have to be synced:
-                    if (aValue.get<text::TextContentAnchorType>()
-                            == text::TextContentAnchorType::TextContentAnchorType_AT_PARAGRAPH
-                        || aValue.get<text::TextContentAnchorType>()
-                               == text::TextContentAnchorType::TextContentAnchorType_AT_CHARACTER)
-                    {
-                        // If the shape has content...
-                        if (auto aPos = pShape->GetAnchor().GetContentAnchor())
-                        {
-                            SwFormatAnchor aAnch(pFormat->GetAnchor());
-                            // ...set it for the textframe too.
-                            aAnch.SetAnchor(aPos);
-                            pFormat->SetFormatAttr(aAnch);
-                        }
-                        else
-                            SAL_WARN("sw.core",
-                                     "SwTextBoxHelper::syncProperty: Anchor without content!");
-                    }
-                    // And the repositioning:
-                    if (pShape->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR)
-                    {
-                        tools::Rectangle aRect(getTextRectangle(pShape, false));
-
-                        // tdf#140598: Do not apply wrong rectangle position.
-                        if (aRect.TopLeft() != Point(0, 0))
-                        {
-                            SwFormatHoriOrient aNewHOri(pShape->GetHoriOrient());
-                            aNewHOri.SetPos(aNewHOri.GetPos() + aRect.getX());
-                            SwFormatVertOrient aNewVOri(pShape->GetVertOrient());
-                            aNewVOri.SetPos(aNewVOri.GetPos() + aRect.getY());
-
-                            pFormat->SetFormatAttr(aNewHOri);
-                            pFormat->SetFormatAttr(aNewVOri);
-                        }
-                        else
-                            SAL_WARN("sw.core",
-                                     "SwTextBoxHelper::syncProperty: Repositioning failed!");
-                    }
                     return;
                 }
                 break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
         case FN_TEXT_RANGE:
@@ -806,6 +745,11 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                 case MID_CHAIN_NEXTNAME:
                     aPropertyName = UNO_NAME_CHAIN_NEXT_NAME;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
         case RES_TEXT_VERT_ADJUST:
@@ -826,6 +770,11 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                 case BOTTOM_BORDER_DISTANCE:
                     aPropertyName = UNO_NAME_BOTTOM_BORDER_DISTANCE;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
         case RES_OPAQUE:
@@ -840,8 +789,18 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                 case MID_ALLOW_OVERLAP:
                     aPropertyName = UNO_NAME_ALLOW_OVERLAP;
                     break;
+                default:
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled member-id: "
+                                            << o3tl::narrowing<sal_uInt16>(nMemberID)
+                                            << " (which-id: " << nWID << ")");
+                    break;
             }
             break;
+        default:
+            SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: unhandled which-id: "
+                                    << nWID << " (member-id: "
+                                    << o3tl::narrowing<sal_uInt16>(nMemberID) << ")");
+            break;
     }
 
     if (aPropertyName.isEmpty())
@@ -859,15 +818,16 @@ void SwTextBoxHelper::syncProperty(SwFrameFormat* pShape, sal_uInt16 nWID, sal_u
                 if (aValue >>= nValue)
                 {
                     if (bAdjustX)
-                        nValue += TWIPS_TO_MM(aRect.getX());
+                        nValue += convertTwipToMm100(aRect.getX());
                     else if (bAdjustY)
-                        nValue += TWIPS_TO_MM(aRect.getY());
+                        nValue += convertTwipToMm100(aRect.getY());
                     aValue <<= nValue;
                 }
             }
             else if (bAdjustSize)
             {
-                awt::Size aSize(TWIPS_TO_MM(aRect.getWidth()), TWIPS_TO_MM(aRect.getHeight()));
+                awt::Size aSize(convertTwipToMm100(aRect.getWidth()),
+                                convertTwipToMm100(aRect.getHeight()));
                 aValue <<= aSize;
             }
         }
@@ -949,16 +909,6 @@ void SwTextBoxHelper::syncFlyFrameAttr(SwFrameFormat& rShape, SfxItemSet const&
     SfxItemIter aIter(rSet);
     const SfxPoolItem* pItem = aIter.GetCurItem();
 
-    const RndStdIds aAnchId = rShape.GetAnchor().GetAnchorId();
-    if (aAnchId == RndStdIds::FLY_AT_PAGE && rShape.GetAnchor().GetPageNum() != 0)
-    {
-        aTextBoxSet.Put(SwFormatAnchor(RndStdIds::FLY_AT_PAGE, rShape.GetAnchor().GetPageNum()));
-    }
-    if ((aAnchId == RndStdIds::FLY_AT_PARA || aAnchId == RndStdIds::FLY_AT_CHAR)
-        && rShape.GetAnchor().GetContentAnchor())
-    {
-        aTextBoxSet.Put(rShape.GetAnchor());
-    }
     do
     {
         switch (pItem->Which())
@@ -971,7 +921,6 @@ void SwTextBoxHelper::syncFlyFrameAttr(SwFrameFormat& rShape, SfxItemSet const&
                 syncProperty(&rShape, RES_ANCHOR, MID_ANCHOR_ANCHORTYPE, uno::Any(aNewAnchorType));
                 if (bInlineAnchored)
                     return;
-
                 auto& rOrient = static_cast<const SwFormatVertOrient&>(*pItem);
                 SwFormatVertOrient aOrient(rOrient);
 
@@ -995,6 +944,10 @@ void SwTextBoxHelper::syncFlyFrameAttr(SwFrameFormat& rShape, SfxItemSet const&
             break;
             case RES_HORI_ORIENT:
             {
+                // The new position can be with anchor changing so sync it!
+                const text::TextContentAnchorType aNewAnchorType
+                    = mapAnchorType(rShape.GetAnchor().GetAnchorId());
+                syncProperty(&rShape, RES_ANCHOR, MID_ANCHOR_ANCHORTYPE, uno::Any(aNewAnchorType));
                 auto& rOrient = static_cast<const SwFormatHoriOrient&>(*pItem);
                 if (bInlineAnchored)
                     return;
@@ -1038,6 +991,24 @@ void SwTextBoxHelper::syncFlyFrameAttr(SwFrameFormat& rShape, SfxItemSet const&
                 }
             }
             break;
+            case RES_ANCHOR:
+            {
+                auto& rAnchor = static_cast<const SwFormatAnchor&>(*pItem);
+                if (rAnchor == rShape.GetAnchor())
+                // the anchor have to be synced
+                {
+                    const text::TextContentAnchorType aNewAnchorType
+                        = mapAnchorType(rShape.GetAnchor().GetAnchorId());
+                    syncProperty(&rShape, RES_ANCHOR, MID_ANCHOR_ANCHORTYPE,
+                                 uno::Any(aNewAnchorType));
+                }
+                else
+                {
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncFlyFrameAttr: The anchor of the "
+                                        "shape different from the textframe!");
+                }
+            }
+            break;
             default:
                 SAL_WARN("sw.core", "SwTextBoxHelper::syncFlyFrameAttr: unhandled which-id: "
                                         << pItem->Which());
@@ -1049,6 +1020,8 @@ void SwTextBoxHelper::syncFlyFrameAttr(SwFrameFormat& rShape, SfxItemSet const&
 
     if (aTextBoxSet.Count())
         pFormat->GetDoc()->SetFlyFrameAttr(*pFormat, aTextBoxSet);
+
+    DoTextBoxZOrderCorrection(&rShape);
 }
 
 void SwTextBoxHelper::updateTextBoxMargin(SdrObject* pObj)
@@ -1080,9 +1053,274 @@ void SwTextBoxHelper::updateTextBoxMargin(SdrObject* pObj)
     syncProperty(pParentFormat, UNO_NAME_TEXT_HORZADJUST,
                  xPropertySet->getPropertyValue(UNO_NAME_TEXT_HORZADJUST));
 
-    //FIXME: Sync autogrow: needs repositioning after sync
-    //syncProperty(pParentFormat, RES_FRM_SIZE, MID_FRMSIZE_IS_AUTO_HEIGHT,
-    //             xPropertySet->getPropertyValue(UNO_NAME_TEXT_AUTOGROWHEIGHT));
+    // tdf137803: Sync autogrow:
+    const bool bIsAutoGrow
+        = xPropertySet->getPropertyValue(UNO_NAME_TEXT_AUTOGROWHEIGHT).get<bool>();
+    const bool bIsAutoWrap = xPropertySet->getPropertyValue(UNO_NAME_TEXT_WORDWRAP).get<bool>();
+
+    syncProperty(pParentFormat, RES_FRM_SIZE, MID_FRMSIZE_IS_AUTO_HEIGHT, uno::Any(bIsAutoGrow));
+
+    syncProperty(pParentFormat, RES_FRM_SIZE, MID_FRMSIZE_WIDTH_TYPE,
+                 uno::Any(bIsAutoWrap ? text::SizeType::FIX : text::SizeType::MIN));
+}
+
+bool SwTextBoxHelper::setWrapThrough(SwFrameFormat* pShape)
+{
+    OUString sErrMsg;
+    if (isTextBoxShapeHasValidTextFrame(pShape))
+    {
+        if (auto pFormat = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT))
+        {
+            ::sw::UndoGuard const UndoGuard(pShape->GetDoc()->GetIDocumentUndoRedo());
+            if (auto xFrame = SwXTextFrame::CreateXTextFrame(*pFormat->GetDoc(), pFormat))
+                try
+                {
+                    uno::Reference<beans::XPropertySet> const xPropertySet(xFrame, uno::UNO_QUERY);
+                    xPropertySet->setPropertyValue(UNO_NAME_SURROUND,
+                                                   uno::makeAny(text::WrapTextMode_THROUGH));
+                    return true;
+                }
+                catch (uno::Exception& e)
+                {
+                    sErrMsg = "Exception caught: " + e.Message;
+                }
+            else
+                sErrMsg = "No XTextFrame!";
+        }
+        else
+            sErrMsg = "No Other TextBox Format!";
+    }
+    else
+        sErrMsg = "Not a Valid TextBox object!";
+
+    SAL_WARN("sw.core", "SwTextBoxHelper::setWrapThrough: " << sErrMsg);
+    return false;
+}
+
+bool SwTextBoxHelper::changeAnchor(SwFrameFormat* pShape)
+{
+    if (isTextBoxShapeHasValidTextFrame(pShape))
+    {
+        if (auto pFormat = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT))
+        {
+            const SwFormatAnchor& rOldAnch = pFormat->GetAnchor();
+            const SwFormatAnchor& rNewAnch = pShape->GetAnchor();
+
+            const auto pOldCnt = rOldAnch.GetContentAnchor();
+            const auto pNewCnt = rNewAnch.GetContentAnchor();
+
+            const uno::Any aShapeHorRelOrient
+                = uno::makeAny(pShape->GetHoriOrient().GetRelationOrient());
+
+            if (isAnchorTypeDifferent(pShape))
+            {
+                try
+                {
+                    ::sw::UndoGuard const UndoGuard(pShape->GetDoc()->GetIDocumentUndoRedo());
+                    uno::Reference<beans::XPropertySet> const xPropertySet(
+                        SwXTextFrame::CreateXTextFrame(*pFormat->GetDoc(), pFormat),
+                        uno::UNO_QUERY);
+                    if (pOldCnt && rNewAnch.GetAnchorId() == RndStdIds::FLY_AT_PAGE
+                        && rNewAnch.GetPageNum())
+                    {
+                        uno::Any aValue(text::TextContentAnchorType_AT_PAGE);
+                        xPropertySet->setPropertyValue(UNO_NAME_HORI_ORIENT_RELATION,
+                                                       aShapeHorRelOrient);
+                        xPropertySet->setPropertyValue(UNO_NAME_ANCHOR_TYPE, aValue);
+                        xPropertySet->setPropertyValue(UNO_NAME_ANCHOR_PAGE_NO,
+                                                       uno::Any(rNewAnch.GetPageNum()));
+                    }
+                    else if (rOldAnch.GetAnchorId() == RndStdIds::FLY_AT_PAGE && pNewCnt)
+                    {
+                        if (rNewAnch.GetAnchorId() == RndStdIds::FLY_AS_CHAR)
+                        {
+                            uno::Any aValue(text::TextContentAnchorType_AT_CHARACTER);
+                            xPropertySet->setPropertyValue(UNO_NAME_ANCHOR_TYPE, aValue);
+                            xPropertySet->setPropertyValue(UNO_NAME_HORI_ORIENT_RELATION,
+                                                           uno::Any(text::RelOrientation::CHAR));
+                            xPropertySet->setPropertyValue(
+                                UNO_NAME_VERT_ORIENT_RELATION,
+                                uno::Any(text::RelOrientation::PRINT_AREA));
+                            SwFormatAnchor aPos(pFormat->GetAnchor());
+                            aPos.SetAnchor(pNewCnt);
+                            pFormat->SetFormatAttr(aPos);
+                        }
+                        else
+                        {
+                            uno::Any aValue(mapAnchorType(rNewAnch.GetAnchorId()));
+                            xPropertySet->setPropertyValue(UNO_NAME_HORI_ORIENT_RELATION,
+                                                           aShapeHorRelOrient);
+                            xPropertySet->setPropertyValue(UNO_NAME_ANCHOR_TYPE, aValue);
+                            pFormat->SetFormatAttr(rNewAnch);
+                        }
+                    }
+                    else
+                    {
+                        if (rNewAnch.GetAnchorId() == RndStdIds::FLY_AS_CHAR)
+                        {
+                            uno::Any aValue(text::TextContentAnchorType_AT_CHARACTER);
+                            xPropertySet->setPropertyValue(UNO_NAME_ANCHOR_TYPE, aValue);
+                            xPropertySet->setPropertyValue(UNO_NAME_HORI_ORIENT_RELATION,
+                                                           uno::Any(text::RelOrientation::CHAR));
+                            xPropertySet->setPropertyValue(
+                                UNO_NAME_VERT_ORIENT_RELATION,
+                                uno::Any(text::RelOrientation::PRINT_AREA));
+                            SwFormatAnchor aPos(pFormat->GetAnchor());
+                            aPos.SetAnchor(pNewCnt);
+                            pFormat->SetFormatAttr(aPos);
+                        }
+                        else
+                        {
+                            xPropertySet->setPropertyValue(UNO_NAME_HORI_ORIENT_RELATION,
+                                                           aShapeHorRelOrient);
+                            pFormat->SetFormatAttr(pShape->GetAnchor());
+                        }
+                    }
+                }
+                catch (uno::Exception& e)
+                {
+                    SAL_WARN("sw.core", "SwTextBoxHelper::changeAnchor(): " << e.Message);
+                }
+            }
+
+            return doTextBoxPositioning(pShape) && DoTextBoxZOrderCorrection(pShape);
+        }
+    }
+    return false;
+}
+
+bool SwTextBoxHelper::doTextBoxPositioning(SwFrameFormat* pShape)
+{
+    if (isTextBoxShapeHasValidTextFrame(pShape))
+    {
+        if (auto pFormat = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT))
+        {
+            ::sw::UndoGuard const UndoGuard(pShape->GetDoc()->GetIDocumentUndoRedo());
+            if (pShape->GetAnchor().GetAnchorId() == RndStdIds::FLY_AS_CHAR)
+            {
+                tools::Rectangle aRect(getTextRectangle(pShape, false));
+
+                SwFormatHoriOrient aNewHOri(pFormat->GetHoriOrient());
+                aNewHOri.SetPos(aRect.getX());
+
+                SwFormatVertOrient aNewVOri(pFormat->GetVertOrient());
+                aNewVOri.SetPos(aRect.getY() + pShape->GetVertOrient().GetPos());
+
+                // tdf#140598: Do not apply wrong rectangle position.
+                if (aRect.TopLeft() != Point(0, 0))
+                {
+                    pFormat->SetFormatAttr(aNewHOri);
+                    pFormat->SetFormatAttr(aNewVOri);
+                }
+                else
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: Repositioning failed!");
+            }
+            else
+            {
+                tools::Rectangle aRect(getTextRectangle(pShape, false));
+
+                // tdf#140598: Do not apply wrong rectangle position.
+                if (aRect.TopLeft() != Point(0, 0))
+                {
+                    SwFormatHoriOrient aNewHOri(pShape->GetHoriOrient());
+                    aNewHOri.SetPos(aNewHOri.GetPos() + aRect.getX());
+                    SwFormatVertOrient aNewVOri(pShape->GetVertOrient());
+                    aNewVOri.SetPos(aNewVOri.GetPos() + aRect.getY());
+
+                    pFormat->SetFormatAttr(aNewHOri);
+                    pFormat->SetFormatAttr(aNewVOri);
+                }
+                else
+                    SAL_WARN("sw.core", "SwTextBoxHelper::syncProperty: Repositioning failed!");
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
+std::optional<bool> SwTextBoxHelper::isAnchorTypeDifferent(SwFrameFormat* pShape)
+{
+    std::optional<bool> bRet;
+    if (isTextBoxShapeHasValidTextFrame(pShape))
+    {
+        if (auto pFormat = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT))
+        {
+            if (pShape->GetAnchor().GetAnchorId() == RndStdIds::FLY_AS_CHAR)
+                bRet = (pFormat->GetAnchor().GetAnchorId() != RndStdIds::FLY_AT_CHAR
+                        && pFormat->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR);
+            else
+                bRet = pFormat->GetAnchor().GetAnchorId() != pShape->GetAnchor().GetAnchorId();
+        }
+    }
+    return bRet;
+}
+
+bool SwTextBoxHelper::isTextBoxShapeHasValidTextFrame(SwFrameFormat* pShape)
+{
+    if (pShape && pShape->Which() == RES_DRAWFRMFMT)
+        if (auto pFormat = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT))
+            if (pFormat && pFormat->Which() == RES_FLYFRMFMT)
+                return true;
+            else
+                SAL_WARN("sw.core", "SwTextBoxHelper::isTextBoxShapeHasValidTextFrame: "
+                                    "Shape does not have valid textframe!");
+        else
+            SAL_WARN("sw.core", "SwTextBoxHelper::isTextBoxShapeHasValidTextFrame: "
+                                "Shape does not have associated frame!");
+    else
+        SAL_WARN("sw.core", "SwTextBoxHelper::isTextBoxShapeHasValidTextFrame: Not valid shape!");
+    return false;
+}
+
+bool SwTextBoxHelper::DoTextBoxZOrderCorrection(SwFrameFormat* pShape)
+{
+    if (isTextBoxShapeHasValidTextFrame(pShape))
+    {
+        if (SdrObject* pShpObj = pShape->FindRealSdrObject())
+        {
+            if (SdrObject* pFrmObj
+                = getOtherTextBoxFormat(pShape, RES_DRAWFRMFMT)->FindRealSdrObject())
+            {
+                // Get the draw model from the doc
+                SwDrawModel* pDrawModel
+                    = pShape->GetDoc()->getIDocumentDrawModelAccess().GetDrawModel();
+                if (pDrawModel)
+                {
+                    // Not really sure this will work all page, but it seems it will.
+                    auto pPage = pDrawModel->GetPage(0);
+                    // Recalc all Zorders
+                    pPage->RecalcObjOrdNums();
+                    // If the shape is behind the frame, is good, but if there are some objects
+                    // between of them that is wrong so put the frame exactly one level higher
+                    // than the shape.
+                    if (pFrmObj->GetOrdNum() > pShpObj->GetOrdNum())
+                        pPage->SetObjectOrdNum(pFrmObj->GetOrdNum(), pShpObj->GetOrdNum() + 1);
+                    else
+                        // Else, if the frame is behind the shape, bring to the front of it.
+                        while (pFrmObj->GetOrdNum() <= pShpObj->GetOrdNum())
+                        {
+                            pPage->SetObjectOrdNum(pFrmObj->GetOrdNum(), pFrmObj->GetOrdNum() + 1);
+                            // If there is any problem with the indexes, do not run over the infinity
+                            if (pPage->GetObjCount() == pFrmObj->GetOrdNum())
+                                break;
+                        }
+                    pPage->RecalcObjOrdNums();
+                    return true; // Success
+                }
+                SAL_WARN("sw.core", "SwTextBoxHelper::DoTextBoxZOrderCorrection(): "
+                                    "No Valid Draw model for SdrObject for the shape!");
+            }
+            SAL_WARN("sw.core", "SwTextBoxHelper::DoTextBoxZOrderCorrection(): "
+                                "No Valid SdrObject for the frame!");
+        }
+        SAL_WARN("sw.core", "SwTextBoxHelper::DoTextBoxZOrderCorrection(): "
+                            "No Valid SdrObject for the shape!");
+    }
+    SAL_WARN("sw.core", "SwTextBoxHelper::DoTextBoxZOrderCorrection(): "
+                        "No Valid TextFrame!");
+
+    return false;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
