@@ -18,6 +18,7 @@
  */
 
 #include <hintids.hxx>
+#include <osl/diagnose.h>
 #include <sfx2/linkmgr.hxx>
 #include <svl/itemiter.hxx>
 #include <sal/log.hxx>
@@ -28,6 +29,7 @@
 #include <IDocumentLinksAdministration.hxx>
 #include <IDocumentLayoutAccess.hxx>
 #include <IDocumentFieldsAccess.hxx>
+#include <IDocumentRedlineAccess.hxx>
 #include <IDocumentState.hxx>
 #include <rootfrm.hxx>
 #include <pam.hxx>
@@ -52,7 +54,6 @@
 #include <strings.hrc>
 #include <viewsh.hxx>
 #include <txtfrm.hxx>
-#include <hints.hxx>
 #include <memory>
 #include "ndsect.hxx"
 #include <tools/datetimeutils.hxx>
@@ -1196,22 +1197,22 @@ void SwSectionNode::DelFrames(SwRootFrame const*const /*FIXME TODO*/, bool const
     // If the Area is within a Fly or TableBox, we can only hide it if
     // there is more Content which has Frames.
     // Or else the Fly/TableBox Frame does not have a Lower!
-    if (!bForce)
+    if (bForce)
+        return;
+
+    SwNodeIndex aIdx( *this );
+    if( !SwNodes::GoPrevSection( &aIdx, true, false ) ||
+        !CheckNodesRange( *this, aIdx, true ) ||
+        // #i21457#
+        !lcl_IsInSameTableBox( rNds, *this, true ))
     {
-        SwNodeIndex aIdx( *this );
-        if( !SwNodes::GoPrevSection( &aIdx, true, false ) ||
-            !CheckNodesRange( *this, aIdx, true ) ||
+        aIdx = *EndOfSectionNode();
+        if( !rNds.GoNextSection( &aIdx, true, false ) ||
+            !CheckNodesRange( *EndOfSectionNode(), aIdx, true ) ||
             // #i21457#
-            !lcl_IsInSameTableBox( rNds, *this, true ))
+            !lcl_IsInSameTableBox( rNds, *EndOfSectionNode(), false ))
         {
-            aIdx = *EndOfSectionNode();
-            if( !rNds.GoNextSection( &aIdx, true, false ) ||
-                !CheckNodesRange( *EndOfSectionNode(), aIdx, true ) ||
-                // #i21457#
-                !lcl_IsInSameTableBox( rNds, *EndOfSectionNode(), false ))
-            {
-                m_pSection->m_Data.SetHiddenFlag(false);
-            }
+            m_pSection->m_Data.SetHiddenFlag(false);
         }
     }
 }
