@@ -43,6 +43,7 @@
 #include <fmtftn.hxx>
 
 #include <docsh.hxx>
+#include <txtfrm.hxx>
 
 typedef std::vector<SwStartNode*> SwStartNodePointers;
 
@@ -227,8 +228,13 @@ void SwNodes::ChgNode( SwNodeIndex const & rDelPos, sal_uLong nSz,
                     }
                 }
                 else
+                {
                     // if movement into the UndoNodes-array, update numbering
-                    pTextNd->InvalidateNumRule();
+                    if (sw::HasNumberingWhichNeedsLayoutUpdate(*pTextNd))
+                    {
+                        pTextNd->InvalidateNumRule();
+                    }
+                }
 
                 pTextNd->RemoveFromList();
             }
@@ -1131,7 +1137,7 @@ void SwNodes::Delete(const SwNodeIndex &rIndex, sal_uLong nNodes)
                                 m_pOutlineNodes->Seek_Entry( pNd, &nIdxPos ))
                         {
                             // remove outline indices
-                            m_pOutlineNodes->erase(nIdxPos);
+                            m_pOutlineNodes->erase_at(nIdxPos);
                             bUpdateOutline = true;
                         }
                         pTextNode->InvalidateNumRule();
@@ -1197,7 +1203,10 @@ void SwNodes::Delete(const SwNodeIndex &rIndex, sal_uLong nNodes)
                     m_pOutlineNodes->erase( pTextNd );
                     bUpdateOutline = true;
                 }
-                pTextNd->InvalidateNumRule();
+                if (sw::HasNumberingWhichNeedsLayoutUpdate(*pTextNd))
+                {
+                    pTextNd->InvalidateNumRule();
+                }
             }
             else if( pCurrentNode->IsContentNode() )
                 static_cast<SwContentNode*>(pCurrentNode)->InvalidateNumRule();
@@ -1359,7 +1368,7 @@ void SwNodes::DelNodes( const SwNodeIndex & rStart, sal_uLong nCnt )
                 SwOutlineNodes::size_type nIdxPos;
                 if( m_pOutlineNodes->Seek_Entry( pNd, &nIdxPos ))
                 {
-                    m_pOutlineNodes->erase(nIdxPos);
+                    m_pOutlineNodes->erase_at(nIdxPos);
                     bUpdateNum = 1;
                 }
             }
@@ -2324,10 +2333,10 @@ bool SwNodes::IsDocNodes() const
 
 void SwNodes::dumpAsXml(xmlTextWriterPtr pWriter) const
 {
-    xmlTextWriterStartElement(pWriter, BAD_CAST("SwNodes"));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("SwNodes"));
     for (sal_uLong i = 0; i < Count(); ++i)
         (*this)[i]->dumpAsXml(pWriter);
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
