@@ -139,7 +139,7 @@ SdrInventor SwFlyDrawObj::GetObjInventor() const
     return SdrInventor::Swg;
 }
 
-sal_uInt16 SwFlyDrawObj::GetObjIdentifier() const
+SdrObjKind SwFlyDrawObj::GetObjIdentifier() const
 {
     return SwFlyDrawObjIdentifier;
 }
@@ -191,19 +191,19 @@ namespace drawinglayer::primitive2d
 {
         void SwVirtFlyDrawObjPrimitive::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
-            if(!getOuterRange().isEmpty())
-            {
-                // currently this SW object has no primitive representation. As long as this is the case,
-                // create invisible geometry to allow correct HitTest and BoundRect calculations for the
-                // object. Use a filled primitive to get 'inside' as default object hit. The special cases from
-                // the old SwVirtFlyDrawObj::CheckHit implementation are handled now in SwDrawView::PickObj;
-                // this removed the 'hack' to get a view from inside model data or to react on null-tolerance
-                // as it was done in the old implementation
-                rContainer.push_back(
-                    createHiddenGeometryPrimitives2D(
-                        true,
-                        getOuterRange()));
-            }
+            if(getOuterRange().isEmpty())
+                return;
+
+            // currently this SW object has no primitive representation. As long as this is the case,
+            // create invisible geometry to allow correct HitTest and BoundRect calculations for the
+            // object. Use a filled primitive to get 'inside' as default object hit. The special cases from
+            // the old SwVirtFlyDrawObj::CheckHit implementation are handled now in SwDrawView::PickObj;
+            // this removed the 'hack' to get a view from inside model data or to react on null-tolerance
+            // as it was done in the old implementation
+            rContainer.push_back(
+                createHiddenGeometryPrimitives2D(
+                    true,
+                    getOuterRange()));
         }
 
         bool SwVirtFlyDrawObjPrimitive::operator==(const BasePrimitive2D& rPrimitive) const
@@ -378,34 +378,34 @@ bool SwVirtFlyDrawObj::HasLimitedRotation() const
     return ContainsSwGrfNode();
 }
 
-void SwVirtFlyDrawObj::Rotate(const Point& rRef, long nAngle, double sn, double cs)
+void SwVirtFlyDrawObj::Rotate(const Point& rRef, Degree100 nAngle100, double sn, double cs)
 {
     if(ContainsSwGrfNode())
     {
         // RotGrfFlyFrame: Here is where the positively completed rotate interaction is executed.
         // Rotation is in 1/100th degree and may be signed (!)
-        nAngle /= 10;
+        Degree10 nAngle10 = toDegree10(nAngle100);
 
-        while(nAngle < 0)
+        while(nAngle10 < 0_deg10)
         {
-            nAngle += 3600;
+            nAngle10 += 3600_deg10;
         }
 
-        SwWrtShell *pShForAngle = nAngle ? dynamic_cast<SwWrtShell*>(GetFlyFrame()->getRootFrame()->GetCurrShell()) : nullptr;
+        SwWrtShell *pShForAngle = nAngle10 ? dynamic_cast<SwWrtShell*>(GetFlyFrame()->getRootFrame()->GetCurrShell()) : nullptr;
         if (pShForAngle)
         {
             // RotGrfFlyFrame: Add transformation to placeholder object
             Size aSize;
-            const sal_uInt16 nOldRot(SwVirtFlyDrawObj::getPossibleRotationFromFraphicFrame(aSize));
+            const Degree10 nOldRot(SwVirtFlyDrawObj::getPossibleRotationFromFraphicFrame(aSize));
             SwFlyFrameAttrMgr aMgr(false, pShForAngle, Frmmgr_Type::NONE, nullptr);
 
-            aMgr.SetRotation(nOldRot, (nOldRot + static_cast<sal_uInt16>(nAngle)) % 3600, aSize);
+            aMgr.SetRotation(nOldRot, (nOldRot + nAngle10) % 3600_deg10, aSize);
         }
     }
     else
     {
         // call parent
-        SdrVirtObj::Rotate(rRef, nAngle, sn, cs);
+        SdrVirtObj::Rotate(rRef, nAngle100, sn, cs);
     }
 }
 
@@ -424,8 +424,8 @@ SwVirtFlyDrawObj::SwVirtFlyDrawObj(
     m_pFlyFrame(pFly)
 {
     const SvxProtectItem &rP = m_pFlyFrame->GetFormat()->GetProtect();
-    bMovProt = rP.IsPosProtected();
-    bSizProt = rP.IsSizeProtected();
+    m_bMovProt = rP.IsPosProtected();
+    m_bSizProt = rP.IsSizeProtected();
 }
 
 SwVirtFlyDrawObj::~SwVirtFlyDrawObj()
@@ -453,24 +453,24 @@ namespace
                 : mbMapModeRestored( false )
                 , mpOutDev( pViewShell->GetOut() )
             {
-                if ( pViewShell->getPrePostMapMode() != mpOutDev->GetMapMode() )
+                if ( pViewShell->getPrePostMapMode() == mpOutDev->GetMapMode() )
+                    return;
+
+                mpOutDev->Push(PushFlags::MAPMODE);
+
+                GDIMetaFile* pMetaFile = mpOutDev->GetConnectMetaFile();
+                if ( pMetaFile &&
+                     pMetaFile->IsRecord() && !pMetaFile->IsPause() )
                 {
-                    mpOutDev->Push(PushFlags::MAPMODE);
-
-                    GDIMetaFile* pMetaFile = mpOutDev->GetConnectMetaFile();
-                    if ( pMetaFile &&
-                         pMetaFile->IsRecord() && !pMetaFile->IsPause() )
-                    {
-                        OSL_FAIL( "MapMode restoration during meta file creation is somehow suspect - using <SetRelativeMapMode(..)>, but not sure, if correct." );
-                        mpOutDev->SetRelativeMapMode( pViewShell->getPrePostMapMode() );
-                    }
-                    else
-                    {
-                        mpOutDev->SetMapMode( pViewShell->getPrePostMapMode() );
-                    }
-
-                    mbMapModeRestored = true;
+                    OSL_FAIL( "MapMode restoration during meta file creation is somehow suspect - using <SetRelativeMapMode(..)>, but not sure, if correct." );
+                    mpOutDev->SetRelativeMapMode( pViewShell->getPrePostMapMode() );
                 }
+                else
+                {
+                    mpOutDev->SetMapMode( pViewShell->getPrePostMapMode() );
+                }
+
+                mbMapModeRestored = true;
             };
 
             ~RestoreMapMode()
@@ -498,36 +498,36 @@ void SwVirtFlyDrawObj::wrap_DoPaintObject(
     // but no paints. IsPaintInProgress() depends on SW repaint, so, as long
     // as SW paints self and calls DrawLayer() for Heaven and Hell, this will
     // be correct
-    if ( pShell && pShell->IsDrawingLayerPaintInProgress() )
+    if ( !(pShell && pShell->IsDrawingLayerPaintInProgress()) )
+        return;
+
+    bool bDrawObject(true);
+
+    if ( !SwFlyFrame::IsPaint( const_cast<SwVirtFlyDrawObj*>(this), pShell ) )
     {
-        bool bDrawObject(true);
-
-        if ( !SwFlyFrame::IsPaint( const_cast<SwVirtFlyDrawObj*>(this), pShell ) )
-        {
-            bDrawObject = false;
-        }
-
-        if ( bDrawObject )
-        {
-            // if there's no viewport set, all fly-frames will be painted,
-            // which is slow, wastes memory, and can cause other trouble.
-            (void) rViewInformation; // suppress "unused parameter" warning
-            assert(comphelper::LibreOfficeKit::isActive() || !rViewInformation.getViewport().isEmpty());
-            if ( !m_pFlyFrame->IsFlyInContentFrame() )
-            {
-                // it is also necessary to restore the VCL MapMode from ViewInformation since e.g.
-                // the VCL PixelRenderer resets it at the used OutputDevice. Unfortunately, this
-                // excludes shears and rotates which are not expressible in MapMode.
-                // OD #i102707#
-                // new helper class to restore MapMode - restoration, only if
-                // needed and consideration of paint for meta file creation .
-                RestoreMapMode aRestoreMapModeIfNeeded( pShell );
-
-                // paint the FlyFrame (use standard VCL-Paint)
-                m_pFlyFrame->PaintSwFrame( *pShell->GetOut(), GetFlyFrame()->getFrameArea() );
-            }
-        }
+        bDrawObject = false;
     }
+
+    if ( !bDrawObject )
+        return;
+
+    // if there's no viewport set, all fly-frames will be painted,
+    // which is slow, wastes memory, and can cause other trouble.
+    (void) rViewInformation; // suppress "unused parameter" warning
+    assert(comphelper::LibreOfficeKit::isActive() || !rViewInformation.getViewport().isEmpty());
+    if ( m_pFlyFrame->IsFlyInContentFrame() )
+        return;
+
+    // it is also necessary to restore the VCL MapMode from ViewInformation since e.g.
+    // the VCL PixelRenderer resets it at the used OutputDevice. Unfortunately, this
+    // excludes shears and rotates which are not expressible in MapMode.
+    // OD #i102707#
+    // new helper class to restore MapMode - restoration, only if
+    // needed and consideration of paint for meta file creation .
+    RestoreMapMode aRestoreMapModeIfNeeded( pShell );
+
+    // paint the FlyFrame (use standard VCL-Paint)
+    m_pFlyFrame->PaintSwFrame( *pShell->GetOut(), m_pFlyFrame->GetPageFrame()->getFrameArea());
 }
 
 void SwVirtFlyDrawObj::TakeObjInfo( SdrObjTransformInfoRec& rInfo ) const
@@ -549,15 +549,15 @@ void SwVirtFlyDrawObj::TakeObjInfo( SdrObjTransformInfoRec& rInfo ) const
 void SwVirtFlyDrawObj::SetRect() const
 {
     if ( GetFlyFrame()->getFrameArea().HasArea() )
-        const_cast<SwVirtFlyDrawObj*>(this)->aOutRect = GetFlyFrame()->getFrameArea().SVRect();
+        const_cast<SwVirtFlyDrawObj*>(this)->m_aOutRect = GetFlyFrame()->getFrameArea().SVRect();
     else
-        const_cast<SwVirtFlyDrawObj*>(this)->aOutRect = tools::Rectangle();
+        const_cast<SwVirtFlyDrawObj*>(this)->m_aOutRect = tools::Rectangle();
 }
 
 const tools::Rectangle& SwVirtFlyDrawObj::GetCurrentBoundRect() const
 {
     SetRect();
-    return aOutRect;
+    return m_aOutRect;
 }
 
 const tools::Rectangle& SwVirtFlyDrawObj::GetLastBoundRect() const
@@ -578,7 +578,7 @@ void SwVirtFlyDrawObj::RecalcSnapRect()
 const tools::Rectangle& SwVirtFlyDrawObj::GetSnapRect()  const
 {
     SetRect();
-    return aOutRect;
+    return m_aOutRect;
 }
 
 void SwVirtFlyDrawObj::SetSnapRect(const tools::Rectangle& )
@@ -587,8 +587,8 @@ void SwVirtFlyDrawObj::SetSnapRect(const tools::Rectangle& )
     SetRect();
     SetChanged();
     BroadcastObjectChange();
-    if (pUserCall!=nullptr)
-        pUserCall->Changed(*this, SdrUserCallType::Resize, aTmp);
+    if (m_pUserCall!=nullptr)
+        m_pUserCall->Changed(*this, SdrUserCallType::Resize, aTmp);
 }
 
 void SwVirtFlyDrawObj::NbcSetSnapRect(const tools::Rectangle& )
@@ -599,7 +599,7 @@ void SwVirtFlyDrawObj::NbcSetSnapRect(const tools::Rectangle& )
 const tools::Rectangle& SwVirtFlyDrawObj::GetLogicRect() const
 {
     SetRect();
-    return aOutRect;
+    return m_aOutRect;
 }
 
 void SwVirtFlyDrawObj::SetLogicRect(const tools::Rectangle& )
@@ -608,8 +608,8 @@ void SwVirtFlyDrawObj::SetLogicRect(const tools::Rectangle& )
     SetRect();
     SetChanged();
     BroadcastObjectChange();
-    if (pUserCall!=nullptr)
-        pUserCall->Changed(*this, SdrUserCallType::Resize, aTmp);
+    if (m_pUserCall!=nullptr)
+        m_pUserCall->Changed(*this, SdrUserCallType::Resize, aTmp);
 }
 
 void SwVirtFlyDrawObj::NbcSetLogicRect(const tools::Rectangle& )
@@ -638,13 +638,13 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
         // working properly. Restore FrameArea and use aOutRect from old FrameArea.
         TransformableSwFrame* pTransformableSwFrame(static_cast<SwFlyFreeFrame*>(GetFlyFrame())->getTransformableSwFrame());
         pTransformableSwFrame->restoreFrameAreas();
-        aOutRect = GetFlyFrame()->getFrameArea().SVRect();
+        m_aOutRect = GetFlyFrame()->getFrameArea().SVRect();
     }
 
-    aOutRect.Move( rSiz );
+    m_aOutRect.Move( rSiz );
     const Point aOldPos( GetFlyFrame()->getFrameArea().Pos() );
-    const Point aNewPos( aOutRect.TopLeft() );
-    const SwRect aFlyRect( aOutRect );
+    const Point aNewPos( m_aOutRect.TopLeft() );
+    const SwRect aFlyRect( m_aOutRect );
 
     //If the Fly has an automatic align (right or top),
     //so preserve the automatic.
@@ -665,7 +665,7 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
         const SwFrameFormat *pTmpFormat = GetFormat();
         const SwFormatVertOrient &rVert = pTmpFormat->GetVertOrient();
         const SwFormatHoriOrient &rHori = pTmpFormat->GetHoriOrient();
-        long lXDiff = aNewPos.X() - aOldPos.X();
+        tools::Long lXDiff = aNewPos.X() - aOldPos.X();
         if( rHori.IsPosToggle() && text::HoriOrientation::NONE == eHori &&
             !GetFlyFrame()->FindPageFrame()->OnRightPage() )
             lXDiff = -lXDiff;
@@ -674,7 +674,7 @@ void SwVirtFlyDrawObj::NbcMove(const Size& rSiz)
             text::HoriOrientation::NONE == eHori )
             lXDiff = -lXDiff;
 
-        long lYDiff = aNewPos.Y() - aOldPos.Y();
+        tools::Long lYDiff = aNewPos.Y() - aOldPos.Y();
         if( GetFlyFrame()->GetAnchorFrame()->IsVertical() )
         {
             //lXDiff -= rVert.GetPos();
@@ -833,7 +833,7 @@ void SwVirtFlyDrawObj::NbcCrop(const basegfx::B2DPoint& rRef, double fxFact, dou
         // working properly. Restore FrameArea and use aOutRect from old FrameArea.
         TransformableSwFrame* pTransformableSwFrame(static_cast<SwFlyFreeFrame*>(GetFlyFrame())->getTransformableSwFrame());
         pTransformableSwFrame->restoreFrameAreas();
-        aOutRect = GetFlyFrame()->getFrameArea().SVRect();
+        m_aOutRect = GetFlyFrame()->getFrameArea().SVRect();
     }
 
     // Compute old and new rect. This will give us the deformation to apply to
@@ -842,8 +842,8 @@ void SwVirtFlyDrawObj::NbcCrop(const basegfx::B2DPoint& rRef, double fxFact, dou
     const tools::Rectangle aOldRect(
         GetFlyFrame()->getFrameArea().TopLeft() + GetFlyFrame()->getFramePrintArea().TopLeft(),
         GetFlyFrame()->getFramePrintArea().SSize());
-    const long nOldWidth(aOldRect.GetWidth());
-    const long nOldHeight(aOldRect.GetHeight());
+    const tools::Long nOldWidth(aOldRect.GetWidth());
+    const tools::Long nOldHeight(aOldRect.GetHeight());
 
     if (!nOldWidth || !nOldHeight)
     {
@@ -904,8 +904,8 @@ void SwVirtFlyDrawObj::NbcCrop(const basegfx::B2DPoint& rRef, double fxFact, dou
     // Set new frame size
     SwFrameFormat *pFormat = GetFormat();
     SwFormatFrameSize aSz( pFormat->GetFrameSize() );
-    const long aNewWidth(aNewRect.GetWidth() + (aOutRect.GetWidth() - aOldRect.GetWidth()));
-    const long aNewHeight(aNewRect.GetHeight() + (aOutRect.GetHeight() - aOldRect.GetHeight()));
+    const tools::Long aNewWidth(aNewRect.GetWidth() + (m_aOutRect.GetWidth() - aOldRect.GetWidth()));
+    const tools::Long aNewHeight(aNewRect.GetHeight() + (m_aOutRect.GetHeight() - aOldRect.GetHeight()));
     aSz.SetWidth(aNewWidth);
     aSz.SetHeight(aNewHeight);
     pFormat->GetDoc()->SetAttr( aSz, *pFormat );
@@ -1002,7 +1002,7 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef, const Fraction& xFact, const
         const basegfx::B2DVector aAbsScale(basegfx::absolute(aScale));
 
         // create new modified, but untransformed OutRect
-        aOutRect = tools::Rectangle(
+        m_aOutRect = tools::Rectangle(
             basegfx::fround(aCenter.getX() - (0.5 * aAbsScale.getX())),
             basegfx::fround(aCenter.getY() - (0.5 * aAbsScale.getY())),
             basegfx::fround(aCenter.getX() + (0.5 * aAbsScale.getX())),
@@ -1015,7 +1015,7 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef, const Fraction& xFact, const
     }
     else
     {
-        ResizeRect( aOutRect, rRef, xFact, yFact );
+        ResizeRect( m_aOutRect, rRef, xFact, yFact );
     }
 
     // Position may also change, remember old one. This is now already
@@ -1023,7 +1023,7 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef, const Fraction& xFact, const
     Point aOldPos(bUseRightEdge ? GetFlyFrame()->getFrameArea().TopRight() : GetFlyFrame()->getFrameArea().Pos());
 
     // get target size in old coordinate system
-    Size aSz( aOutRect.Right() - aOutRect.Left() + 1, aOutRect.Bottom()- aOutRect.Top()  + 1 );
+    Size aSz( m_aOutRect.Right() - m_aOutRect.Left() + 1, m_aOutRect.Bottom()- m_aOutRect.Top()  + 1 );
 
     // compare with restored FrameArea
     if( aSz != GetFlyFrame()->getFrameArea().SSize() )
@@ -1033,7 +1033,7 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef, const Fraction& xFact, const
         {
             SwBorderAttrAccess aAccess( SwFrame::GetCache(), GetFlyFrame() );
             const SwBorderAttrs &rAttrs = *aAccess.Get();
-            long nMin = rAttrs.CalcLeftLine()+rAttrs.CalcRightLine();
+            tools::Long nMin = rAttrs.CalcLeftLine()+rAttrs.CalcRightLine();
             const SwFormatCol& rCol = rAttrs.GetAttrSet().GetCol();
             if ( rCol.GetColumns().size() > 1 )
             {
@@ -1053,7 +1053,7 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef, const Fraction& xFact, const
 
         if ( aFrameSz.GetWidthPercent() || aFrameSz.GetHeightPercent() )
         {
-            long nRelWidth, nRelHeight;
+            tools::Long nRelWidth, nRelHeight;
             const SwFrame *pRel = GetFlyFrame()->IsFlyLayFrame() ?
                                 GetFlyFrame()->GetAnchorFrame() :
                                 GetFlyFrame()->GetAnchorFrame()->GetUpper();
@@ -1091,34 +1091,34 @@ void SwVirtFlyDrawObj::NbcResize(const Point& rRef, const Fraction& xFact, const
     }
 
     //Position can also be changed, get new one
-    const Point aNewPos(bUseRightEdge ? aOutRect.Right() + 1 : aOutRect.Left(), aOutRect.Top());
+    const Point aNewPos(bUseRightEdge ? m_aOutRect.Right() + 1 : m_aOutRect.Left(), m_aOutRect.Top());
 
-    if ( aNewPos != aOldPos )
+    if ( aNewPos == aOldPos )
+        return;
+
+    // Former late change in aOutRect by ChgSize
+    // is now taken into account directly by calculating
+    // aNewPos *after* calling ChgSize (see old code).
+    // Still need to adapt aOutRect since the 'Move' is already applied
+    // here (see ResizeRect) and it's the same SdrObject
+    const Size aDeltaMove(
+            aNewPos.X() - aOldPos.X(),
+            aNewPos.Y() - aOldPos.Y());
+    m_aOutRect.Move(-aDeltaMove.Width(), -aDeltaMove.Height());
+
+    // Now, move as needed (no empty delta which was a hack anyways)
+    if(bIsTransformableSwFrame)
     {
-        // Former late change in aOutRect by ChgSize
-        // is now taken into account directly by calculating
-        // aNewPos *after* calling ChgSize (see old code).
-        // Still need to adapt aOutRect since the 'Move' is already applied
-        // here (see ResizeRect) and it's the same SdrObject
-        const Size aDeltaMove(
-                aNewPos.X() - aOldPos.X(),
-                aNewPos.Y() - aOldPos.Y());
-        aOutRect.Move(-aDeltaMove.Width(), -aDeltaMove.Height());
-
-        // Now, move as needed (no empty delta which was a hack anyways)
-        if(bIsTransformableSwFrame)
-        {
-            // need to save aOutRect to FrameArea, will be restored to aOutRect in
-            // SwVirtFlyDrawObj::NbcMove currently for TransformableSwFrames
-            SwFrameAreaDefinition::FrameAreaWriteAccess aFrm(*GetFlyFrame());
-            aFrm.setSwRect(aOutRect);
-        }
-
-        // keep old hack - not clear what happens here
-        bInResize = true;
-        NbcMove(aDeltaMove);
-        bInResize = false;
+        // need to save aOutRect to FrameArea, will be restored to aOutRect in
+        // SwVirtFlyDrawObj::NbcMove currently for TransformableSwFrames
+        SwFrameAreaDefinition::FrameAreaWriteAccess aFrm(*GetFlyFrame());
+        aFrm.setSwRect(SwRect(m_aOutRect));
     }
+
+    // keep old hack - not clear what happens here
+    bInResize = true;
+    NbcMove(aDeltaMove);
+    bInResize = false;
 }
 
 void SwVirtFlyDrawObj::Move(const Size& rSiz)
@@ -1144,9 +1144,9 @@ void SwVirtFlyDrawObj::Crop(const basegfx::B2DPoint& rRef, double fxFact, double
 }
 
 // RotGrfFlyFrame: Helper to access possible rotation of Graphic contained in FlyFrame
-sal_uInt16 SwVirtFlyDrawObj::getPossibleRotationFromFraphicFrame(Size& rSize) const
+Degree10 SwVirtFlyDrawObj::getPossibleRotationFromFraphicFrame(Size& rSize) const
 {
-    sal_uInt16 nRetval(0);
+    Degree10 nRetval;
     const SwNoTextFrame* pNoTx = dynamic_cast< const SwNoTextFrame* >(GetFlyFrame()->Lower());
 
     if(pNoTx)
@@ -1167,12 +1167,12 @@ sal_uInt16 SwVirtFlyDrawObj::getPossibleRotationFromFraphicFrame(Size& rSize) co
     return nRetval;
 }
 
-long SwVirtFlyDrawObj::GetRotateAngle() const
+Degree100 SwVirtFlyDrawObj::GetRotateAngle() const
 {
     if(ContainsSwGrfNode())
     {
         Size aSize;
-        return getPossibleRotationFromFraphicFrame(aSize);
+        return toDegree100(getPossibleRotationFromFraphicFrame(aSize));
     }
     else
     {
@@ -1199,44 +1199,44 @@ SdrObjectUniquePtr SwVirtFlyDrawObj::getFullDragClone() const
 void SwVirtFlyDrawObj::addCropHandles(SdrHdlList& rTarget) const
 {
     // RotGrfFlyFrame: Adapt to possible rotated Graphic contained in FlyFrame
-    if(GetFlyFrame()->getFrameArea().HasArea())
-    {
-        // Use InnerBound, OuterBound (same as GetFlyFrame()->getFrameArea().SVRect())
-        // may have a distance to InnerBound which needs to be taken into account.
-        // The Graphic is mapped to InnerBound, as is the rotated Graphic.
-        const basegfx::B2DRange aTargetRange(getInnerBound());
+    if(!GetFlyFrame()->getFrameArea().HasArea())
+        return;
 
-        if(!aTargetRange.isEmpty())
-        {
-            // RotGrfFlyFrame3: get inner bounds/transformation
-            const basegfx::B2DHomMatrix aTargetTransform(GetFlyFrame()->getFramePrintAreaTransformation());
+    // Use InnerBound, OuterBound (same as GetFlyFrame()->getFrameArea().SVRect())
+    // may have a distance to InnerBound which needs to be taken into account.
+    // The Graphic is mapped to InnerBound, as is the rotated Graphic.
+    const basegfx::B2DRange aTargetRange(getInnerBound());
 
-            // break up matrix
-            basegfx::B2DTuple aScale;
-            basegfx::B2DTuple aTranslate;
-            double fRotate(0.0);
-            double fShearX(0.0);
-            aTargetTransform.decompose(aScale, aTranslate, fRotate, fShearX);
-            basegfx::B2DPoint aPos;
+    if(aTargetRange.isEmpty())
+        return;
 
-            aPos = aTargetTransform * basegfx::B2DPoint(0.0, 0.0);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::UpperLeft, fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(0.5, 0.0);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Upper, fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(1.0, 0.0);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::UpperRight, fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(0.0, 0.5);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Left , fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(1.0, 0.5);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Right, fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(0.0, 1.0);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::LowerLeft, fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(0.5, 1.0);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Lower, fShearX, fRotate));
-            aPos = aTargetTransform * basegfx::B2DPoint(1.0, 1.0);
-            rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::LowerRight, fShearX, fRotate));
-        }
-    }
+    // RotGrfFlyFrame3: get inner bounds/transformation
+    const basegfx::B2DHomMatrix aTargetTransform(GetFlyFrame()->getFramePrintAreaTransformation());
+
+    // break up matrix
+    basegfx::B2DTuple aScale;
+    basegfx::B2DTuple aTranslate;
+    double fRotate(0.0);
+    double fShearX(0.0);
+    aTargetTransform.decompose(aScale, aTranslate, fRotate, fShearX);
+    basegfx::B2DPoint aPos;
+
+    aPos = aTargetTransform * basegfx::B2DPoint(0.0, 0.0);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::UpperLeft, fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(0.5, 0.0);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Upper, fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(1.0, 0.0);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::UpperRight, fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(0.0, 0.5);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Left , fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(1.0, 0.5);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Right, fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(0.0, 1.0);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::LowerLeft, fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(0.5, 1.0);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::Lower, fShearX, fRotate));
+    aPos = aTargetTransform * basegfx::B2DPoint(1.0, 1.0);
+    rTarget.AddHdl(std::make_unique<SdrCropHdl>(Point(basegfx::fround(aPos.getX()), basegfx::fround(aPos.getY())), SdrHdlKind::LowerRight, fShearX, fRotate));
 }
 
 // Macro
