@@ -25,6 +25,7 @@
 #include <svx/sdrundomanager.hxx>
 #include <tools/globname.hxx>
 #include <editeng/outliner.hxx>
+#include <osl/diagnose.h>
 #include <com/sun/star/embed/EmbedMisc.hpp>
 #include <com/sun/star/embed/XEmbeddedObject.hpp>
 
@@ -79,8 +80,7 @@ bool SwSdrHdl::IsFocusHdl() const
 
 static const SwFrame *lcl_FindAnchor( const SdrObject *pObj, bool bAll )
 {
-    const SwVirtFlyDrawObj *pVirt = dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) !=  nullptr ?
-                                            static_cast<const SwVirtFlyDrawObj*>(pObj) : nullptr;
+    const SwVirtFlyDrawObj *pVirt = dynamic_cast< const SwVirtFlyDrawObj *>( pObj );
     if ( pVirt )
     {
         if ( bAll || !pVirt->GetFlyFrame()->IsFlyInContentFrame() )
@@ -243,8 +243,10 @@ void SwDrawView::AddCustomHdl()
     }
 
     // add anchor handle:
-    maHdlList.AddHdl( std::make_unique<SwSdrHdl>( aPos, ( pAnch->IsVertical() && !pAnch->IsVertLR() ) ||
-                                     pAnch->IsRightToLeft() ) );
+    std::unique_ptr<SdrHdl> hdl = std::make_unique<SwSdrHdl>( aPos, ( pAnch->IsVertical() && !pAnch->IsVertLR() ) ||
+                                     pAnch->IsRightToLeft() );
+    hdl->SetObjHdlNum(maHdlList.GetHdlCount());
+    maHdlList.AddHdl(std::move(hdl));
 }
 
 SdrObject* SwDrawView::GetMaxToTopObj( SdrObject* pObj ) const
@@ -987,7 +989,7 @@ SdrUndoManager* SwDrawView::getSdrUndoManagerForEnhancedTextEdit() const
 {
     SwDoc* pDoc = Imp().GetShell()->GetDoc();
 
-    return pDoc ? dynamic_cast< SdrUndoManager* >(&(pDoc->GetUndoManager())) : nullptr;
+    return pDoc ? &(pDoc->GetUndoManager()) : nullptr;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
