@@ -46,7 +46,7 @@ size_t SwEditShell::GetFieldTypeCount(SwFieldIds nResId ) const
 
     if(nResId == SwFieldIds::Unknown)
     {
-        return static_cast<sal_uInt16>(pFieldTypes->size());
+        return o3tl::narrowing<sal_uInt16>(pFieldTypes->size());
     }
 
     // all types with the same ResId
@@ -291,11 +291,6 @@ SwDBData const & SwEditShell::GetDBData() const
     return GetDoc()->GetDBData();
 }
 
-const SwDBData& SwEditShell::GetDBDesc() const
-{
-    return GetDoc()->GetDBDesc();
-}
-
 void SwEditShell::ChgDBData(const SwDBData& rNewData)
 {
     GetDoc()->ChgDBData(rNewData);
@@ -385,6 +380,7 @@ void SwEditShell::ChangeAuthorityData(const SwAuthEntry* pNewData)
 
 bool SwEditShell::IsAnyDatabaseFieldInDoc()const
 {
+    // Similar to: SwDoc::GetDBDesc
     const SwFieldTypes * pFieldTypes = GetDoc()->getIDocumentFieldsAccess().GetFieldTypes();
     for(const auto & pFieldType : *pFieldTypes)
     {
