@@ -25,7 +25,6 @@
 #include <ndtxt.hxx>
 #include <swtable.hxx>
 #include <swddetbl.hxx>
-#include <fmtfld.hxx>
 #include <ddefld.hxx>
 #include <ndindex.hxx>
 #include <fldupde.hxx>
@@ -83,18 +82,20 @@ SwDDETable::~SwDDETable()
     }
 }
 
-void SwDDETable::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
+void SwDDETable::SwClientNotify(const SwModify& rModify, const SfxHint& rHint)
 {
-    if( pNew && RES_UPDATEDDETBL == pNew->Which() )
-        ChangeContent();
-    else
-        SwTable::Modify( pOld, pNew );
-}
-
-void SwDDETable::SwClientNotify( const SwModify& rModify, const SfxHint& rHint )
-{
-    SwClient::SwClientNotify(rModify, rHint);
-    if(auto pFieldHint = dynamic_cast<const SwFieldHint*>(&rHint))
+    if(auto pLegacy = dynamic_cast<const sw::LegacyModifyHint*>(&rHint))
+    {
+        switch(pLegacy->GetWhich())
+        {
+            case RES_UPDATEDDETBL:
+                ChangeContent();
+                break;
+            default:
+                SwTable::SwClientNotify(rModify, rHint);
+        }
+    }
+    else if(auto pFieldHint = dynamic_cast<const SwFieldHint*>(&rHint))
     {
         pFieldHint->m_pPaM->DeleteMark(); // TODO: this is really hackish
         // replace DDETable by real table
@@ -117,9 +118,6 @@ void SwDDETable::SwClientNotify( const SwModify& rModify, const SfxHint& rHint )
                 pInRangeHint->m_nSttNd < pTableNd->EndOfSectionIndex() &&
                 pInRangeHint->m_nEndNd > pTableNd->GetIndex() )
             pInRangeHint->m_rIsInRange = true;
-    } else if (const auto pGatherDdeTablesHint = dynamic_cast<const sw::GatherDdeTablesHint*>(&rHint))
-    {
-        pGatherDdeTablesHint->m_rvTables.push_back(this);
     }
     else if (auto pModifyChangedHint = dynamic_cast<const sw::ModifyChangedHint*>(&rHint))
     {
@@ -177,7 +175,7 @@ SwDDEFieldType* SwDDETable::GetDDEFieldType()
     return m_pDDEType;
 }
 
-bool SwDDETable::NoDDETable()
+void SwDDETable::NoDDETable()
 {
     // search table node
     OSL_ENSURE( GetFrameFormat(), "No FrameFormat" );
@@ -185,11 +183,11 @@ bool SwDDETable::NoDDETable()
 
     // Is this the correct NodesArray? (because of UNDO)
     if( m_aLines.empty() )
-        return false;
+        return;
     OSL_ENSURE( !GetTabSortBoxes().empty(), "Table without content?" );
     SwNode* pNd = const_cast<SwNode*>(static_cast<SwNode const *>(GetTabSortBoxes()[0]->GetSttNd()));
     if( !pNd->GetNodes().IsDocNodes() )
-        return false;
+        return;
 
     SwTableNode* pTableNd = pNd->FindTableNode();
     OSL_ENSURE( pTableNd, "Where is the table?");
@@ -208,8 +206,6 @@ bool SwDDETable::NoDDETable()
         m_pDDEType->DecRefCnt();
 
     pTableNd->SetNewTable( std::move(pNewTable) );       // replace table
-
-    return true;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
