@@ -18,6 +18,7 @@
  */
 
 #include <svx/svdobj.hxx>
+#include <osl/diagnose.h>
 #include <comphelper/lok.hxx>
 #include <init.hxx>
 #include <fesh.hxx>
@@ -1299,8 +1300,9 @@ bool SwFEShell::IsFrameVertical(const bool bEnvironment, bool& bRTL, bool& bVert
             return bVert;
         }
 
-        if ( dynamic_cast<const SwVirtFlyDrawObj*>( pObj) !=  nullptr && !bEnvironment )
-            pRef = static_cast<const SwVirtFlyDrawObj*>(pObj)->GetFlyFrame();
+        if ( !bEnvironment )
+            if ( auto pVirtFly = dynamic_cast<const SwVirtFlyDrawObj*>( pObj) )
+                pRef = pVirtFly->GetFlyFrame();
 
         bVert = pRef->IsVertical();
         bRTL = pRef->IsRightToLeft();
