@@ -20,6 +20,7 @@
 #include <comphelper/lok.hxx>
 #include <ndole.hxx>
 #include <sal/log.hxx>
+#include <osl/diagnose.h>
 #include <svl/itemiter.hxx>
 #include <fmtfsize.hxx>
 #include <fmthdft.hxx>
@@ -35,7 +36,6 @@
 #include <wrtsh.hxx>
 #include <view.hxx>
 #include <edtwin.hxx>
-#include <docary.hxx>
 #include <frameformats.hxx>
 
 #include <viewimp.hxx>
@@ -496,52 +496,6 @@ void SwPageFrame::PreparePage( bool bFootnote )
     }
 }
 
-void SwPageFrame::Modify( const SfxPoolItem* pOld, const SfxPoolItem * pNew )
-{
-    SwViewShell *pSh = getRootFrame()->GetCurrShell();
-    if ( pSh )
-        pSh->SetFirstVisPageInvalid();
-    sal_uInt8 nInvFlags = 0;
-
-    if( pNew && RES_ATTRSET_CHG == pNew->Which() )
-    {
-        SfxItemIter aNIter( *static_cast<const SwAttrSetChg*>(pNew)->GetChgSet() );
-        SfxItemIter aOIter( *static_cast<const SwAttrSetChg*>(pOld)->GetChgSet() );
-        const SfxPoolItem* pNItem = aNIter.GetCurItem();
-        const SfxPoolItem* pOItem = aOIter.GetCurItem();
-        SwAttrSetChg aOldSet( *static_cast<const SwAttrSetChg*>(pOld) );
-        SwAttrSetChg aNewSet( *static_cast<const SwAttrSetChg*>(pNew) );
-        do
-        {
-            UpdateAttr_(pOItem, pNItem, nInvFlags, &aOldSet, &aNewSet);
-            pNItem = aNIter.NextItem();
-            pOItem = aOIter.NextItem();
-        } while (pNItem);
-        if ( aOldSet.Count() || aNewSet.Count() )
-            SwLayoutFrame::Modify( &aOldSet, &aNewSet );
-    }
-    else
-        UpdateAttr_( pOld, pNew, nInvFlags );
-
-    if ( nInvFlags == 0 )
-        return;
-
-    InvalidatePage( this );
-    if ( nInvFlags & 0x01 )
-        InvalidatePrt_();
-    if ( nInvFlags & 0x02 )
-        SetCompletePaint();
-    if ( nInvFlags & 0x04 && GetNext() )
-        GetNext()->InvalidatePos();
-    if ( nInvFlags & 0x08 )
-        PrepareHeader();
-    if ( nInvFlags & 0x10 )
-        PrepareFooter();
-    if ( nInvFlags & 0x20 )
-        CheckGrid( nInvFlags & 0x40 );
-}
-
-
 void SwPageFrame::SwClientNotify(const SwModify& rModify, const SfxHint& rHint)
 {
     if(typeid(sw::PageFootnoteHint) == typeid(rHint))
@@ -555,12 +509,56 @@ void SwPageFrame::SwClientNotify(const SwModify& rModify, const SfxHint& rHint)
         // here, the page might be destroyed:
         static_cast<SwRootFrame*>(GetUpper())->RemoveFootnotes(nullptr, false, true);
     }
-    else
+    else if(auto pLegacy = dynamic_cast<const sw::LegacyModifyHint*>(&rHint))
+    {
+        if(auto pSh = getRootFrame()->GetCurrShell())
+            pSh->SetFirstVisPageInvalid();
+
+        SwPageFrameInvFlags eInvFlags = SwPageFrameInvFlags::NONE;
+        if(pLegacy->m_pNew && RES_ATTRSET_CHG == pLegacy->m_pNew->Which())
+        {
+            auto& rOldSetChg = *static_cast<const SwAttrSetChg*>(pLegacy->m_pOld);
+            auto& rNewSetChg = *static_cast<const SwAttrSetChg*>(pLegacy->m_pNew);
+            SfxItemIter aOIter(*rOldSetChg.GetChgSet());
+            SfxItemIter aNIter(*rNewSetChg.GetChgSet());
+            const SfxPoolItem* pOItem = aOIter.GetCurItem();
+            const SfxPoolItem* pNItem = aNIter.GetCurItem();
+            SwAttrSetChg aOldSet(rOldSetChg);
+            SwAttrSetChg aNewSet(rNewSetChg);
+            do
+            {
+                UpdateAttr_(pOItem, pNItem, eInvFlags, &aOldSet, &aNewSet);
+                pOItem = aOIter.NextItem();
+                pNItem = aNIter.NextItem();
+            } while(pNItem);
+            if(aOldSet.Count() || aNewSet.Count())
+                SwLayoutFrame::SwClientNotify(rModify, sw::LegacyModifyHint(&aOldSet, &aNewSet));
+        }
+        else
+            UpdateAttr_(pLegacy->m_pOld, pLegacy->m_pNew, eInvFlags);
+
+        if (eInvFlags == SwPageFrameInvFlags::NONE)
+            return;
+
+        InvalidatePage( this );
+        if(eInvFlags & SwPageFrameInvFlags::InvalidatePrt)
+            InvalidatePrt_();
+        if(eInvFlags & SwPageFrameInvFlags::SetCompletePaint)
+            SetCompletePaint();
+        if(eInvFlags & SwPageFrameInvFlags::InvalidateNextPos && GetNext() )
+            GetNext()->InvalidatePos();
+        if(eInvFlags & SwPageFrameInvFlags::PrepareHeader)
+            PrepareHeader();
+        if(eInvFlags & SwPageFrameInvFlags::PrepareFooter)
+            PrepareFooter();
+        if(eInvFlags & SwPageFrameInvFlags::CheckGrid)
+            CheckGrid(bool(eInvFlags & SwPageFrameInvFlags::InvalidateGrid));
+    } else
         SwFrame::SwClientNotify(rModify, rHint);
 }
 
 void SwPageFrame::UpdateAttr_( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
-                             sal_uInt8 &rInvFlags,
+                             SwPageFrameInvFlags &rInvFlags,
                              SwAttrSetChg *pOldSet, SwAttrSetChg *pNewSet )
 {
     bool bClear = true;
@@ -604,19 +602,19 @@ void SwPageFrame::UpdateAttr_( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
                 SwLayoutFrame *pB = FindBodyCont();
                 assert(pB && "Page without Body.");
                 pB->ChgColumns( rOldCol, rNewCol );
-                rInvFlags |= 0x20;
+                rInvFlags |= SwPageFrameInvFlags::CheckGrid;
             }
 
             // 2. header and footer:
             const SwFormatHeader &rOldH = pOldFormat->GetHeader();
             const SwFormatHeader &rNewH = pNewFormat->GetHeader();
             if( rOldH != rNewH )
-                rInvFlags |= 0x08;
+                rInvFlags |= SwPageFrameInvFlags::PrepareHeader;
 
             const SwFormatFooter &rOldF = pOldFormat->GetFooter();
             const SwFormatFooter &rNewF = pNewFormat->GetFooter();
             if( rOldF != rNewF )
-                rInvFlags |= 0x10;
+                rInvFlags |= SwPageFrameInvFlags::PrepareFooter;
             CheckDirChange();
 
             [[fallthrough]];
@@ -632,7 +630,7 @@ void SwPageFrame::UpdateAttr_( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
                 // Calculation of the page is not necessary, because its size is
                 // invalidated here and further invalidation is done in the
                 // calling method <SwPageFrame::Modify(..)> and probably by calling
-                // <SwLayoutFrame::Modify(..)> at the end.
+                // <SwLayoutFrame::SwClientNotify(..)> at the end.
                 // It can also causes inconsistences, because the lowers are
                 // adjusted, but not calculated, and a <SwPageFrame::MakeAll()> of
                 // a next page is called. This is performed on the switch to the
@@ -667,9 +665,9 @@ void SwPageFrame::UpdateAttr_( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
                     IsLeftShadowNeeded(), IsRightShadowNeeded(), bRightSidebar );
                 pSh->InvalidateWindows( aOldRectWithBorderAndShadow );
             }
-            rInvFlags |= 0x03;
+            rInvFlags |= SwPageFrameInvFlags::InvalidatePrt | SwPageFrameInvFlags::SetCompletePaint;
             if ( aOldPageFrameRect.Height() != getFrameArea().Height() )
-                rInvFlags |= 0x04;
+                rInvFlags |= SwPageFrameInvFlags::InvalidateNextPos;
         }
         break;
 
@@ -680,19 +678,19 @@ void SwPageFrame::UpdateAttr_( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
                 SwLayoutFrame *pB = FindBodyCont();
                 assert(pB); //page without body
                 pB->ChgColumns( *static_cast<const SwFormatCol*>(pOld), *static_cast<const SwFormatCol*>(pNew) );
-                rInvFlags |= 0x22;
+                rInvFlags |= SwPageFrameInvFlags::SetCompletePaint | SwPageFrameInvFlags::CheckGrid;
             }
         break;
 
         case RES_HEADER:
-            rInvFlags |= 0x08;
+            rInvFlags |= SwPageFrameInvFlags::PrepareHeader;
             break;
 
         case RES_FOOTER:
-            rInvFlags |= 0x10;
+            rInvFlags |= SwPageFrameInvFlags::PrepareFooter;
             break;
         case RES_TEXTGRID:
-            rInvFlags |= 0x60;
+            rInvFlags |= SwPageFrameInvFlags::CheckGrid | SwPageFrameInvFlags::InvalidateGrid;
             break;
         case RES_FRAMEDIR :
             CheckDirChange();
@@ -701,17 +699,20 @@ void SwPageFrame::UpdateAttr_( const SfxPoolItem *pOld, const SfxPoolItem *pNew,
         default:
             bClear = false;
     }
-    if ( bClear )
+    if ( !bClear )
+        return;
+
+    if ( pOldSet || pNewSet )
     {
-        if ( pOldSet || pNewSet )
-        {
-            if ( pOldSet )
-                pOldSet->ClearItem( nWhich );
-            if ( pNewSet )
-                pNewSet->ClearItem( nWhich );
-        }
-        else
-            SwLayoutFrame::Modify( pOld, pNew );
+        if ( pOldSet )
+            pOldSet->ClearItem( nWhich );
+        if ( pNewSet )
+            pNewSet->ClearItem( nWhich );
+    }
+    else
+    {
+        SwModify aMod;
+        SwLayoutFrame::SwClientNotify(aMod, sw::LegacyModifyHint(pOld, pNew));
     }
 }
 
@@ -1700,12 +1701,12 @@ void SwRootFrame::AssertPageFlys( SwPageFrame *pPage )
                         // It can move by itself. Just send a modify to its anchor attribute.
 #if OSL_DEBUG_LEVEL > 1
                         const size_t nCnt = pPage->GetSortedObjs()->size();
-                        rFormat.NotifyClients( nullptr, &rAnch );
+                        rFormat.CallSwClientNotify(sw::LegacyModifyHint(nullptr, &rAnch));
                         OSL_ENSURE( !pPage->GetSortedObjs() ||
                                 nCnt != pPage->GetSortedObjs()->size(),
                                 "Object couldn't be reattached!" );
 #else
-                        rFormat.NotifyClients( nullptr, &rAnch );
+                        rFormat.CallSwClientNotify(sw::LegacyModifyHint(nullptr, &rAnch));
 #endif
                         // Do not increment index, in this case
                         continue;
