@@ -24,9 +24,11 @@
 #include <editeng/boxitem.hxx>
 #include <editeng/shaditem.hxx>
 #include <editeng/frmdiritem.hxx>
+#include <osl/diagnose.h>
 #include <sal/log.hxx>
 #include <fmtclds.hxx>
 #include <fmtfsize.hxx>
+#include <fmthdft.hxx>
 #include <pagefrm.hxx>
 #include <pagedesc.hxx>
 #include <swtable.hxx>
@@ -39,7 +41,6 @@
 #include <IDocumentStylePoolAccess.hxx>
 #include <poolfmt.hxx>
 #include <calbck.hxx>
-#include <hints.hxx>
 
 SwPageDesc::SwPageDesc(const OUString& rName, SwFrameFormat *pFormat, SwDoc *const pDoc)
     : sw::BroadcastingModify()
@@ -48,6 +49,8 @@ SwPageDesc::SwPageDesc(const OUString& rName, SwFrameFormat *pFormat, SwDoc *con
     , m_Left( pDoc->GetAttrPool(), rName, pFormat )
     , m_FirstMaster( pDoc->GetAttrPool(), rName, pFormat )
     , m_FirstLeft( pDoc->GetAttrPool(), rName, pFormat )
+    , m_aStashedHeader()
+    , m_aStashedFooter()
     , m_aDepends(*this)
     , m_pTextFormatColl(nullptr)
     , m_pFollow( this )
@@ -81,6 +84,14 @@ SwPageDesc::SwPageDesc( const SwPageDesc &rCpy )
     , m_FootnoteInfo( rCpy.GetFootnoteInfo() )
     , m_pdList( nullptr )
 {
+    m_aStashedHeader.m_pStashedFirst = rCpy.m_aStashedHeader.m_pStashedFirst;
+    m_aStashedHeader.m_pStashedLeft = rCpy.m_aStashedHeader.m_pStashedLeft;
+    m_aStashedHeader.m_pStashedFirstLeft = rCpy.m_aStashedHeader.m_pStashedFirstLeft;
+
+    m_aStashedFooter.m_pStashedFirst = rCpy.m_aStashedFooter.m_pStashedFirst;
+    m_aStashedFooter.m_pStashedLeft = rCpy.m_aStashedFooter.m_pStashedLeft;
+    m_aStashedFooter.m_pStashedFirstLeft = rCpy.m_aStashedFooter.m_pStashedFirstLeft;
+
     if (rCpy.m_pTextFormatColl && rCpy.m_aDepends.IsListeningTo(rCpy.m_pTextFormatColl))
     {
         m_pTextFormatColl = rCpy.m_pTextFormatColl;
@@ -99,6 +110,15 @@ SwPageDesc & SwPageDesc::operator = (const SwPageDesc & rSrc)
     m_Left = rSrc.m_Left;
     m_FirstMaster = rSrc.m_FirstMaster;
     m_FirstLeft = rSrc.m_FirstLeft;
+
+    m_aStashedHeader.m_pStashedFirst = rSrc.m_aStashedHeader.m_pStashedFirst;
+    m_aStashedHeader.m_pStashedLeft = rSrc.m_aStashedHeader.m_pStashedLeft;
+    m_aStashedHeader.m_pStashedFirstLeft = rSrc.m_aStashedHeader.m_pStashedFirstLeft;
+
+    m_aStashedFooter.m_pStashedFirst = rSrc.m_aStashedFooter.m_pStashedFirst;
+    m_aStashedFooter.m_pStashedLeft = rSrc.m_aStashedFooter.m_pStashedLeft;
+    m_aStashedFooter.m_pStashedFirstLeft = rSrc.m_aStashedFooter.m_pStashedFirstLeft;
+
     m_aDepends.EndListeningAll();
     if (rSrc.m_pTextFormatColl && rSrc.m_aDepends.IsListeningTo(rSrc.m_pTextFormatColl))
     {
@@ -151,6 +171,7 @@ void SwPageDesc::Mirror()
     const SvxLRSpaceItem &rLR = m_Master.GetLRSpace();
     aLR.SetLeft(  rLR.GetRight() );
     aLR.SetRight( rLR.GetLeft() );
+    aLR.SetRightGutterMargin(rLR.GetGutterMargin());
 
     SfxItemSet aSet( *m_Master.GetAttrSet().GetPool(),
                      m_Master.GetAttrSet().GetRanges() );
@@ -269,7 +290,7 @@ void SwPageDesc::SwClientNotify(const SwModify& rModify, const SfxHint& rHint)
                 : pLegacyHint->m_pNew
                 ? pLegacyHint->m_pNew->Which()
                 : 0;
-        NotifyClients(pLegacyHint->m_pOld, pLegacyHint->m_pNew);
+        CallSwClientNotify(rHint);
         if((RES_ATTRSET_CHG == nWhich)
                 || (RES_FMT_CHG == nWhich)
                 || isCHRATR(nWhich)
@@ -385,6 +406,156 @@ void SwPageDesc::ChgFirstShare( bool bNew )
         m_eUse &= UseOnPage::NoFirstShare;
 }
 
+void SwPageDesc::StashFrameFormat(const SwFrameFormat& rFormat, bool bHeader, bool bLeft, bool bFirst)
+{
+    assert(rFormat.GetRegisteredIn());
+    std::shared_ptr<SwFrameFormat>* pFormat = nullptr;
+
+    if (bHeader)
+    {
+        if (bLeft && !bFirst)
+            pFormat = &m_aStashedHeader.m_pStashedLeft;
+        else if (!bLeft && bFirst)
+            pFormat = &m_aStashedHeader.m_pStashedFirst;
+        else if (bLeft && bFirst)
+            pFormat = &m_aStashedHeader.m_pStashedFirstLeft;
+    }
+    else
+    {
+        if (bLeft && !bFirst)
+            pFormat = &m_aStashedFooter.m_pStashedLeft;
+        else if (!bLeft && bFirst)
+            pFormat = &m_aStashedFooter.m_pStashedFirst;
+        else if (bLeft && bFirst)
+            pFormat = &m_aStashedFooter.m_pStashedFirstLeft;
+    }
+
+    if (pFormat)
+    {
+        *pFormat = std::make_shared<SwFrameFormat>(rFormat);
+    }
+    else
+    {
+        SAL_WARN(
+            "sw",
+            "SwPageDesc::StashFrameFormat: Stashing the right page header/footer is pointless.");
+    }
+}
+
+const SwFrameFormat* SwPageDesc::GetStashedFrameFormat(bool bHeader, bool bLeft, bool bFirst) const
+{
+    std::shared_ptr<SwFrameFormat>* pFormat = nullptr;
+
+    if (bLeft && !bFirst)
+    {
+        pFormat = bHeader ? &m_aStashedHeader.m_pStashedLeft : &m_aStashedFooter.m_pStashedLeft;
+    }
+    else if (!bLeft && bFirst)
+    {
+        pFormat = bHeader ? &m_aStashedHeader.m_pStashedFirst : &m_aStashedFooter.m_pStashedFirst;
+    }
+    else if (bLeft && bFirst)
+    {
+        pFormat = bHeader ? &m_aStashedHeader.m_pStashedFirstLeft : &m_aStashedFooter.m_pStashedFirstLeft;
+    }
+
+    if (pFormat)
+    {
+        return pFormat->get();
+    }
+    else
+    {
+        SAL_WARN("sw", "SwPageDesc::GetStashedFrameFormat: Right page format is never stashed.");
+        return nullptr;
+    }
+}
+
+bool SwPageDesc::HasStashedFormat(bool bHeader, bool bLeft, bool bFirst)
+{
+    if (bHeader)
+    {
+        if (bLeft && !bFirst)
+        {
+            return m_aStashedHeader.m_pStashedLeft != nullptr;
+        }
+        else if (!bLeft && bFirst)
+        {
+            return m_aStashedHeader.m_pStashedFirst != nullptr;
+        }
+        else if (bLeft && bFirst)
+        {
+            return m_aStashedHeader.m_pStashedFirstLeft != nullptr;
+        }
+        else
+        {
+            SAL_WARN("sw", "SwPageDesc::HasStashedFormat: Right page format is never stashed.");
+            return false;
+        }
+    }
+    else
+    {
+        if (bLeft && !bFirst)
+        {
+            return m_aStashedFooter.m_pStashedLeft != nullptr;
+        }
+        else if (!bLeft && bFirst)
+        {
+            return m_aStashedFooter.m_pStashedFirst != nullptr;
+        }
+        else if (bLeft && bFirst)
+        {
+            return m_aStashedFooter.m_pStashedFirstLeft != nullptr;
+        }
+        else
+        {
+            SAL_WARN("sw", "SwPageDesc::HasStashedFormat: Right page format is never stashed.");
+            return false;
+        }
+    }
+}
+
+void SwPageDesc::RemoveStashedFormat(bool bHeader, bool bLeft, bool bFirst)
+{
+    if (bHeader)
+    {
+        if (bLeft && !bFirst)
+        {
+            m_aStashedHeader.m_pStashedLeft.reset();
+        }
+        else if (!bLeft && bFirst)
+        {
+            m_aStashedHeader.m_pStashedFirst.reset();
+        }
+        else if (bLeft && bFirst)
+        {
+            m_aStashedHeader.m_pStashedFirstLeft.reset();
+        }
+        else
+        {
+            SAL_WARN("sw", "SwPageDesc::RemoveStashedFormat: Right page format is never stashed.");
+        }
+    }
+    else
+    {
+        if (bLeft && !bFirst)
+        {
+            m_aStashedFooter.m_pStashedLeft.reset();
+        }
+        else if (!bLeft && bFirst)
+        {
+            m_aStashedFooter.m_pStashedFirst.reset();
+        }
+        else if (bLeft && bFirst)
+        {
+            m_aStashedFooter.m_pStashedFirstLeft.reset();
+        }
+        else
+        {
+            SAL_WARN("sw", "SwPageDesc::RemoveStashedFormat: Right page format is never stashed.");
+        }
+    }
+}
+
 // Page styles
 static const char* STR_POOLPAGE[] =
 {
@@ -400,7 +571,7 @@ static const char* STR_POOLPAGE[] =
     STR_POOLPAGE_LANDSCAPE
 };
 
-SwPageDesc* SwPageDesc::GetByName(SwDoc& rDoc, const OUString& rName)
+SwPageDesc* SwPageDesc::GetByName(SwDoc& rDoc, std::u16string_view rName)
 {
     const size_t nDCount = rDoc.GetPageDescCnt();
 
@@ -427,32 +598,32 @@ SwPageDesc* SwPageDesc::GetByName(SwDoc& rDoc, const OUString& rName)
 
 void SwPageDesc::dumpAsXml(xmlTextWriterPtr pWriter) const
 {
-    xmlTextWriterStartElement(pWriter, BAD_CAST("SwPageDesc"));
-    xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("ptr"), "%p", this);
-    xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("m_StyleName"), "%s",
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("SwPageDesc"));
+    (void)xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("ptr"), "%p", this);
+    (void)xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("m_StyleName"), "%s",
                                       BAD_CAST(m_StyleName.toUtf8().getStr()));
-    xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("m_pFollow"), "%p", m_pFollow);
-    xmlTextWriterWriteFormatAttribute(
+    (void)xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("m_pFollow"), "%p", m_pFollow);
+    (void)xmlTextWriterWriteFormatAttribute(
         pWriter, BAD_CAST("m_eUse"), "0x%s",
         BAD_CAST(OString::number(static_cast<int>(m_eUse), 16).getStr()));
 
-    xmlTextWriterStartElement(pWriter, BAD_CAST("m_Master"));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("m_Master"));
     m_Master.dumpAsXml(pWriter);
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 
-    xmlTextWriterStartElement(pWriter, BAD_CAST("m_Left"));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("m_Left"));
     m_Left.dumpAsXml(pWriter);
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 
-    xmlTextWriterStartElement(pWriter, BAD_CAST("m_FirstMaster"));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("m_FirstMaster"));
     m_FirstMaster.dumpAsXml(pWriter);
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 
-    xmlTextWriterStartElement(pWriter, BAD_CAST("m_FirstLeft"));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("m_FirstLeft"));
     m_FirstLeft.dumpAsXml(pWriter);
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 }
 
 SwPageFootnoteInfo::SwPageFootnoteInfo()
@@ -619,14 +790,14 @@ void SwPageDescs::erase( size_type index_ )
 
 void SwPageDescs::dumpAsXml(xmlTextWriterPtr pWriter) const
 {
-    xmlTextWriterStartElement(pWriter, BAD_CAST("SwPageDescs"));
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("SwPageDescs"));
 
     for (const auto& pPageDesc : m_PosIndex)
     {
         pPageDesc->dumpAsXml(pWriter);
     }
 
-    xmlTextWriterEndElement(pWriter);
+    (void)xmlTextWriterEndElement(pWriter);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
