@@ -307,10 +307,10 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
         {
             if ( pFrame->IsRightToLeft() )
             {
-                if( pCMS->m_b2Lines && pCMS->m_p2Lines)
+                if( pCMS->m_b2Lines && pCMS->m_x2Lines)
                 {
-                    pFrame->SwitchLTRtoRTL( pCMS->m_p2Lines->aLine );
-                    pFrame->SwitchLTRtoRTL( pCMS->m_p2Lines->aPortion );
+                    pFrame->SwitchLTRtoRTL( pCMS->m_x2Lines->aLine );
+                    pFrame->SwitchLTRtoRTL( pCMS->m_x2Lines->aPortion );
                 }
             }
 
@@ -327,10 +327,10 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
                                                    pCMS->m_aRealHeight.Y() );
                     }
                 }
-                if( pCMS->m_b2Lines && pCMS->m_p2Lines)
+                if( pCMS->m_b2Lines && pCMS->m_x2Lines)
                 {
-                    pFrame->SwitchHorizontalToVertical( pCMS->m_p2Lines->aLine );
-                    pFrame->SwitchHorizontalToVertical( pCMS->m_p2Lines->aPortion );
+                    pFrame->SwitchHorizontalToVertical( pCMS->m_x2Lines->aLine );
+                    pFrame->SwitchHorizontalToVertical( pCMS->m_x2Lines->aPortion );
                 }
             }
 
@@ -590,7 +590,7 @@ bool SwTextFrame::GetModelPositionForViewPoint_(SwPosition* pPos, const Point& r
         // See comment in AdjustFrame()
         SwTwips nMaxY = getFrameArea().Top() + getFramePrintArea().Top() + getFramePrintArea().Height();
         aLine.TwipsToLine( rPoint.Y() );
-        while( aLine.Y() + aLine.GetLineHeight() > nMaxY )
+        while( aLine.Y() + o3tl::narrowing<SwTwips>(aLine.GetLineHeight()) > nMaxY )
         {
             if( !aLine.Prev() )
                 break;
@@ -744,11 +744,15 @@ namespace {
 
 class SwSetToRightMargin
 {
-    bool bRight;
+    bool m_bRight;
+
 public:
-    SwSetToRightMargin() : bRight( false ) { }
-    ~SwSetToRightMargin() { SwTextCursor::SetRightMargin( bRight ); }
-    void SetRight( const bool bNew ) { bRight = bNew; }
+    SwSetToRightMargin()
+        : m_bRight(false)
+    {
+    }
+    ~SwSetToRightMargin() { SwTextCursor::SetRightMargin(m_bRight); }
+    void SetRight(const bool bNew) { m_bRight = bNew; }
 };
 
 }
@@ -1414,7 +1418,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
         if( nDiff > 0 )
         {
             nDiff /= nDist;
-            rFill.Fill().nParaCnt = static_cast<sal_uInt16>(nDiff + 1);
+            rFill.Fill().nParaCnt = o3tl::narrowing<sal_uInt16>(nDiff + 1);
             rFill.nLineWidth = 0;
             rFill.bInner = false;
             rFill.bEmpty = true;
