@@ -45,7 +45,7 @@
 
 // Not reentrant !!!
 // is set in GetCharRect and is interpreted in UnitUp/Down.
-bool SwTextCursor::bRightMargin = false;
+bool SwTextCursor::s_bRightMargin = false;
 
 // After calculating the position of a character during GetCharRect
 // this function allows to find the coordinates of a position (defined
@@ -142,7 +142,7 @@ namespace {
                 nListLevel = MAXLEVEL - 1;
 
             const SwNumFormat& rNumFormat =
-                    rTextNode.GetNumRule()->Get( static_cast<sal_uInt16>(nListLevel) );
+                    rTextNode.GetNumRule()->Get( o3tl::narrowing<sal_uInt16>(nListLevel) );
             if ( rNumFormat.GetPositionAndSpaceMode() == SvxNumberFormat::LABEL_ALIGNMENT )
             {
                 bRet = true;
@@ -184,7 +184,7 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
     if ( m_pFrame->IsRightToLeft() )
     {
         // this calculation is identical this the calculation for L2R layout - see below
-        nLeft = m_pFrame->getFrameArea().Left() +
+        mnLeft = m_pFrame->getFrameArea().Left() +
                 m_pFrame->getFramePrintArea().Left() +
                 nLMWithNum -
                 pNode->GetLeftMarginWithNum() -
@@ -203,7 +203,7 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
              !pNode->getIDocumentSettingAccess()->get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) )
         {
             // this calculation is identical this the calculation for R2L layout - see above
-            nLeft = m_pFrame->getFrameArea().Left() +
+            mnLeft = m_pFrame->getFrameArea().Left() +
                     m_pFrame->getFramePrintArea().Left() +
                     nLMWithNum -
                     pNode->GetLeftMarginWithNum() -
@@ -215,28 +215,28 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
         }
         else
         {
-            nLeft = m_pFrame->getFrameArea().Left() +
+            mnLeft = m_pFrame->getFrameArea().Left() +
                     std::max( tools::Long( rSpace.GetTextLeft() + nLMWithNum ),
                          m_pFrame->getFramePrintArea().Left() );
         }
     }
 
-    nRight = m_pFrame->getFrameArea().Left() + m_pFrame->getFramePrintArea().Left() + m_pFrame->getFramePrintArea().Width();
+    mnRight = m_pFrame->getFrameArea().Left() + m_pFrame->getFramePrintArea().Left() + m_pFrame->getFramePrintArea().Width();
 
-    if( nLeft >= nRight &&
+    if( mnLeft >= mnRight &&
          // #i53066# Omit adjustment of nLeft for numbered
          // paras inside cells inside new documents:
         ( pNode->getIDocumentSettingAccess()->get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) ||
           !m_pFrame->IsInTab() ||
           ( !nLMWithNum && (!bLabelAlignmentActive || bListLevelIndentsApplicable) ) ) )
     {
-        nLeft = m_pFrame->getFramePrintArea().Left() + m_pFrame->getFrameArea().Left();
-        if( nLeft >= nRight )   // e.g. with large paragraph indentations in slim table columns
-            nRight = nLeft + 1; // einen goennen wir uns immer
+        mnLeft = m_pFrame->getFramePrintArea().Left() + m_pFrame->getFrameArea().Left();
+        if( mnLeft >= mnRight )   // e.g. with large paragraph indentations in slim table columns
+            mnRight = mnLeft + 1; // einen goennen wir uns immer
     }
 
     if( m_pFrame->IsFollow() && m_pFrame->GetOffset() )
-        nFirst = nLeft;
+        mnFirst = mnLeft;
     else
     {
         short nFLOfst = 0;
@@ -306,20 +306,20 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
              !pNode->getIDocumentSettingAccess()->get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) )
         {
             if ( nFirstLineOfs < 0 && m_pFrame->IsInTab() &&
-                 nLeft == m_pFrame->getFramePrintArea().Left() + m_pFrame->getFrameArea().Left() &&
+                 mnLeft == m_pFrame->getFramePrintArea().Left() + m_pFrame->getFrameArea().Left() &&
                  !m_pFrame->IsRightToLeft() &&
                  !bListLevelIndentsApplicableAndLabelAlignmentActive )
             {
                 // tdf#130218 always show hanging indent in narrow table cells
                 // to avoid hiding the text content of the first line
-                nLeft -= nFirstLineOfs;
+                mnLeft -= nFirstLineOfs;
             }
 
-            nFirst = nLeft + nFirstLineOfs;
+            mnFirst = mnLeft + nFirstLineOfs;
         }
         else
         {
-              nFirst = m_pFrame->getFrameArea().Left() +
+              mnFirst = m_pFrame->getFrameArea().Left() +
                      std::max( rSpace.GetTextLeft() + nLMWithNum+ nFirstLineOfs,
                           m_pFrame->getFramePrintArea().Left() );
         }
@@ -328,21 +328,21 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
         //       value for the new list label position and space mode LABEL_ALIGNMENT
         //       and label alignment CENTER and RIGHT in L2R layout respectively
         //       label alignment LEFT and CENTER in R2L layout
-        nFirst += m_pFrame->GetAdditionalFirstLineOffset();
+        mnFirst += m_pFrame->GetAdditionalFirstLineOffset();
 
-        if( nFirst >= nRight )
-            nFirst = nRight - 1;
+        if( mnFirst >= mnRight )
+            mnFirst = mnRight - 1;
     }
     const SvxAdjustItem& rAdjust = m_pFrame->GetTextNodeForParaProps()->GetSwAttrSet().GetAdjust();
-    nAdjust = rAdjust.GetAdjust();
+    mnAdjust = rAdjust.GetAdjust();
 
     // left is left and right is right
     if ( m_pFrame->IsRightToLeft() )
     {
-        if ( SvxAdjust::Left == nAdjust )
-            nAdjust = SvxAdjust::Right;
-        else if ( SvxAdjust::Right == nAdjust )
-            nAdjust = SvxAdjust::Left;
+        if ( SvxAdjust::Left == mnAdjust )
+            mnAdjust = SvxAdjust::Right;
+        else if ( SvxAdjust::Right == mnAdjust )
+            mnAdjust = SvxAdjust::Left;
     }
 
     m_bOneBlock = rAdjust.GetOneWord() == SvxAdjust::Block;
@@ -357,17 +357,17 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
 
 void SwTextMargin::DropInit()
 {
-    nDropLeft = nDropLines = nDropHeight = nDropDescent = 0;
+    mnDropLeft = mnDropLines = mnDropHeight = mnDropDescent = 0;
     const SwParaPortion *pPara = GetInfo().GetParaPortion();
     if( pPara )
     {
         const SwDropPortion *pPorDrop = pPara->FindDropPortion();
         if ( pPorDrop )
         {
-            nDropLeft = pPorDrop->GetDropLeft();
-            nDropLines = pPorDrop->GetLines();
-            nDropHeight = pPorDrop->GetDropHeight();
-            nDropDescent = pPorDrop->GetDropDescent();
+            mnDropLeft = pPorDrop->GetDropLeft();
+            mnDropLines = pPorDrop->GetLines();
+            mnDropHeight = pPorDrop->GetDropHeight();
+            mnDropDescent = pPorDrop->GetDropDescent();
         }
     }
 }
@@ -401,7 +401,7 @@ void SwTextCursor::GetEndCharRect(SwRect* pOrig, const TextFrameIndex nOfst,
                                   SwCursorMoveState* pCMS, const tools::Long nMax )
 {
     // 1170: Ambiguity of document positions
-    bRightMargin = true;
+    s_bRightMargin = true;
     CharCursorToLine(nOfst);
 
     // Somehow twisted: nOfst names the position behind the last
@@ -411,7 +411,7 @@ void SwTextCursor::GetEndCharRect(SwRect* pOrig, const TextFrameIndex nOfst,
     {
         // 8810: Master line RightMargin, after that LeftMargin
         GetCharRect( pOrig, nOfst, pCMS, nMax );
-        bRightMargin = nOfst >= GetEnd() && nOfst < TextFrameIndex(GetInfo().GetText().getLength());
+        s_bRightMargin = nOfst >= GetEnd() && nOfst < TextFrameIndex(GetInfo().GetText().getLength());
         return;
     }
 
@@ -428,7 +428,7 @@ void SwTextCursor::GetEndCharRect(SwRect* pOrig, const TextFrameIndex nOfst,
     tools::Long nLast = 0;
     SwLinePortion *pPor = m_pCurr->GetFirstPortion();
 
-    sal_uInt16 nTmpHeight, nTmpAscent;
+    sal_uInt32 nTmpHeight, nTmpAscent;
     CalcAscentAndHeight( nTmpAscent, nTmpHeight );
     sal_uInt16 nPorHeight = nTmpHeight;
     sal_uInt16 nPorAscent = nTmpAscent;
@@ -479,7 +479,7 @@ void SwTextCursor::GetCharRect_( SwRect* pOrig, TextFrameIndex const nOfst,
     SwTextSizeInfo aInf( GetInfo(), &aText, m_nStart );
     if( GetPropFont() )
         aInf.GetFont()->SetProportion( GetPropFont() );
-    sal_uInt16 nTmpAscent, nTmpHeight;  // Line height
+    sal_uInt32 nTmpAscent, nTmpHeight;  // Line height
     CalcAscentAndHeight( nTmpAscent, nTmpHeight );
     const Size  aCharSize( 1, nTmpHeight );
     const Point aCharPos;
@@ -505,8 +505,8 @@ void SwTextCursor::GetCharRect_( SwRect* pOrig, TextFrameIndex const nOfst,
     }
     else
     {
-        sal_uInt16 nPorHeight = nTmpHeight;
-        sal_uInt16 nPorAscent = nTmpAscent;
+        sal_uInt32 nPorHeight = nTmpHeight;
+        sal_uInt32 nPorAscent = nTmpAscent;
         SwTwips nX = 0;
         SwTwips nTmpFirst = 0;
         SwLinePortion *pPor = m_pCurr->GetFirstPortion();
@@ -676,26 +676,26 @@ void SwTextCursor::GetCharRect_( SwRect* pOrig, TextFrameIndex const nOfst,
 
                         if( pCMS && pCMS->m_b2Lines )
                         {
-                            const bool bRecursion (pCMS->m_p2Lines);
+                            const bool bRecursion (pCMS->m_x2Lines);
                             if ( !bRecursion )
                             {
-                                pCMS->m_p2Lines.reset(new Sw2LinesPos);
-                                pCMS->m_p2Lines->aLine = SwRect(aCharPos, aCharSize);
+                                pCMS->m_x2Lines = Sw2LinesPos();
+                                pCMS->m_x2Lines->aLine = SwRect(aCharPos, aCharSize);
                             }
 
                             if( static_cast<SwMultiPortion*>(pPor)->HasRotation() )
                             {
                                 if( static_cast<SwMultiPortion*>(pPor)->IsRevers() )
-                                    pCMS->m_p2Lines->nMultiType = MultiPortionType::ROT_270;
+                                    pCMS->m_x2Lines->nMultiType = MultiPortionType::ROT_270;
                                 else
-                                    pCMS->m_p2Lines->nMultiType = MultiPortionType::ROT_90;
+                                    pCMS->m_x2Lines->nMultiType = MultiPortionType::ROT_90;
                             }
                             else if( static_cast<SwMultiPortion*>(pPor)->IsDouble() )
-                                pCMS->m_p2Lines->nMultiType = MultiPortionType::TWOLINE;
+                                pCMS->m_x2Lines->nMultiType = MultiPortionType::TWOLINE;
                             else if( static_cast<SwMultiPortion*>(pPor)->IsBidi() )
-                                pCMS->m_p2Lines->nMultiType = MultiPortionType::BIDI;
+                                pCMS->m_x2Lines->nMultiType = MultiPortionType::BIDI;
                             else
-                                pCMS->m_p2Lines->nMultiType = MultiPortionType::RUBY;
+                                pCMS->m_x2Lines->nMultiType = MultiPortionType::RUBY;
 
                             SwTwips nTmpWidth = pPor->Width();
                             if( nSpaceAdd )
@@ -705,9 +705,9 @@ void SwTextCursor::GetCharRect_( SwRect* pOrig, TextFrameIndex const nOfst,
                                           Size( nTmpWidth, pPor->Height() ) );
 
                             if ( ! bRecursion )
-                                pCMS->m_p2Lines->aPortion = aRect;
+                                pCMS->m_x2Lines->aPortion = aRect;
                             else
-                                pCMS->m_p2Lines->aPortion2 = aRect;
+                                pCMS->m_x2Lines->aPortion2 = aRect;
                         }
 
                         // In a multi-portion we use GetCharRect()-function
@@ -1051,7 +1051,7 @@ void SwTextCursor::GetCharRect_( SwRect* pOrig, TextFrameIndex const nOfst,
                     nPorHeight = nPorAscent;
                     pOrig->Height( nPorHeight +
                         static_cast<SwDropPortion*>(pPor)->GetDropDescent() );
-                    if( nTmpHeight < pOrig->Height() )
+                    if( o3tl::narrowing<SwTwips>(nTmpHeight) < pOrig->Height() )
                     {
                         nTmpAscent = nPorAscent;
                         nTmpHeight = sal_uInt16( pOrig->Height() );
@@ -1215,15 +1215,17 @@ void SwTextCursor::GetCharRect( SwRect* pOrig, TextFrameIndex const nOfst,
     pOrig->Pos().AdjustX(aCharPos.X() );
     pOrig->Pos().AdjustY(aCharPos.Y() );
 
-    if( pCMS && pCMS->m_b2Lines && pCMS->m_p2Lines )
+    if( pCMS && pCMS->m_b2Lines && pCMS->m_x2Lines )
     {
-        pCMS->m_p2Lines->aLine.Pos().AdjustX(aCharPos.X() );
-        pCMS->m_p2Lines->aLine.Pos().AdjustY(aCharPos.Y() );
-        pCMS->m_p2Lines->aPortion.Pos().AdjustX(aCharPos.X() );
-        pCMS->m_p2Lines->aPortion.Pos().AdjustY(aCharPos.Y() );
+        pCMS->m_x2Lines->aLine.Pos().AdjustX(aCharPos.X() );
+        pCMS->m_x2Lines->aLine.Pos().AdjustY(aCharPos.Y() );
+        pCMS->m_x2Lines->aPortion.Pos().AdjustX(aCharPos.X() );
+        pCMS->m_x2Lines->aPortion.Pos().AdjustY(aCharPos.Y() );
     }
 
-    const bool bTabOverMargin = GetTextFrame()->GetDoc().getIDocumentSettingAccess().get(DocumentSettingId::TAB_OVER_MARGIN);
+    const IDocumentSettingAccess& rIDSA = GetTextFrame()->GetDoc().getIDocumentSettingAccess();
+    const bool bTabOverMargin = rIDSA.get(DocumentSettingId::TAB_OVER_MARGIN)
+        || rIDSA.get(DocumentSettingId::TAB_OVER_SPACING);
     // Make sure the cursor respects the right margin, unless in compat mode, where the tab size has priority over the margin size.
     if( pOrig->Left() > nTmpRight && !bTabOverMargin)
         pOrig->Pos().setX( nTmpRight );
@@ -1264,13 +1266,19 @@ void SwTextCursor::GetCharRect( SwRect* pOrig, TextFrameIndex const nOfst,
  * Determines if SwTextCursor::GetModelPositionForViewPoint() should consider the next portion when calculating the
  * doc model position from a Point.
  */
-static bool ConsiderNextPortionForCursorOffset(const SwLinePortion* pPor, sal_uInt16 nWidth30, sal_uInt16 nX)
+static bool ConsiderNextPortionForCursorOffset(const SwLinePortion* pPor, sal_uInt32 nWidth30, sal_uInt16 nX)
 {
     if (!pPor->GetNextPortion() || pPor->IsBreakPortion())
     {
         return false;
     }
 
+    // tdf#138592: consider all following zero-width text portions of current text portion,
+    // like combining characters.
+    if (nWidth30 == nX && pPor->IsTextPortion() && pPor->GetNextPortion()->IsTextPortion()
+        && pPor->GetNextPortion()->Width() == 0)
+        return true;
+
     // If we're past the target position, stop the iteration in general.
     // Exception: don't stop the iteration between as-char fly portions and their comments.
     if (nWidth30 >= nX && (!pPor->IsFlyCntPortion() || !pPor->GetNextPortion()->IsPostItsPortion()))
@@ -1315,7 +1323,7 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
     // Until here everything in document coordinates.
     x -= nLeftMargin;
 
-    sal_uInt16 nX = sal_uInt16( x );
+    sal_uInt32 nX = sal_uInt16( x );
 
     // If there are attribute changes in the line, search for the paragraph,
     // in which nX is situated.
@@ -1334,7 +1342,7 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
     // nWidth is the width of the line, or the width of
     // the paragraph with the font change, in which nX is situated.
 
-    sal_uInt16 nWidth = pPor->Width();
+    sal_uInt32 nWidth = pPor->Width();
     if ( m_pCurr->IsSpaceAdd() || pKanaComp )
     {
         if ( pPor->InSpaceGrp() && nSpaceAdd )
@@ -1364,9 +1372,9 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
         }
     }
 
-    sal_uInt16 nWidth30;
+    sal_uInt32 nWidth30;
     if ( pPor->IsPostItsPortion() )
-        nWidth30 = 30 + pPor->GetViewWidth( GetInfo() ) / 2;
+        nWidth30 = 0;
     else
         nWidth30 = ! nWidth && pPor->GetLen() && pPor->InToxRefOrFieldGrp() ?
                      30 :
@@ -1410,7 +1418,7 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
         }
 
         if ( pPor->IsPostItsPortion() )
-            nWidth30 = 30 +  pPor->GetViewWidth( GetInfo() ) / 2;
+            nWidth30 = 0;
         else
             nWidth30 = ! nWidth && pPor->GetLen() && pPor->InToxRefOrFieldGrp() ?
                          30 :
@@ -1552,9 +1560,9 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
             if ( pPor->IsPostItsPortion() || pPor->IsBreakPortion() ||
                  pPor->InToxRefGrp() )
             {
-                if (pPor->IsPostItsPortion())
+                SwPostItsPortion* pPostItsPortion = pPor->IsPostItsPortion() ? dynamic_cast<SwPostItsPortion*>(pPor) : nullptr;
+                if (pPostItsPortion)
                 {
-                    SwPostItsPortion* pPostItsPortion = dynamic_cast<SwPostItsPortion*>(pPor);
                     if (!pPostItsPortion->IsScript()) // tdf#141079
                     {
                         // Offset would be nCurrStart + nLength below, do the same for post-it portions.
@@ -1619,7 +1627,7 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
                     nTmpY = pPor->Height() - nTmpY;
                 if( nTmpY < 0 )
                     nTmpY = 0;
-                nX = static_cast<sal_uInt16>(nTmpY);
+                nX = o3tl::narrowing<sal_uInt16>(nTmpY);
             }
 
             if( static_cast<SwMultiPortion*>(pPor)->HasBrackets() )
@@ -1683,12 +1691,12 @@ TextFrameIndex SwTextCursor::GetModelPositionForViewPoint( SwPosition *pPos, con
                         }
                         pCurrPart = pCurrPart->GetFollow();
                     }
-                    nX = std::max(0, nX - nSumBorderWidth);
+                    nX = std::max(o3tl::narrowing<sal_uInt32>(0), nX - nSumBorderWidth);
                 }
                 // Shift the offset with the left border width
                 else if( GetInfo().GetFont()->GetLeftBorder() && !pPor->GetJoinBorderWithPrev() )
                 {
-                    nX = std::max(0, nX - GetInfo().GetFont()->GetLeftBorderSpace());
+                    nX = std::max(o3tl::narrowing<sal_uInt32>(0), nX - GetInfo().GetFont()->GetLeftBorderSpace());
                 }
 
                 aDrawInf.SetOffset( nX );
