@@ -38,6 +38,8 @@
 #include "inftxt.hxx"
 
 #include <sortedobjs.hxx>
+#include <officecfg/Office/Common.hxx>
+#include <PostItMgr.hxx>
 
 /**
  * class SwFlyPortion => we expect a frame-locale SwRect!
@@ -56,7 +58,7 @@ bool SwFlyPortion::Format( SwTextFormatInfo &rInf )
         rInf.GetLastTab()->FormatEOL( rInf );
 
     rInf.GetLast()->FormatEOL( rInf );
-    PrtWidth( static_cast<sal_uInt16>(GetFix() - rInf.X() + PrtWidth()) );
+    PrtWidth( o3tl::narrowing<sal_uInt16>(GetFix() - rInf.X() + PrtWidth()) );
     if( !Width() )
     {
         OSL_ENSURE( Width(), "+SwFlyPortion::Format: a fly is a fly is a fly" );
@@ -80,7 +82,7 @@ bool SwFlyPortion::Format( SwTextFormatInfo &rInf )
         SetLen(TextFrameIndex(1));
     }
 
-    const sal_uInt16 nNewWidth = static_cast<sal_uInt16>(rInf.X() + PrtWidth());
+    const sal_uInt16 nNewWidth = o3tl::narrowing<sal_uInt16>(rInf.X() + PrtWidth());
     if( rInf.Width() <= nNewWidth )
     {
         Truncate();
@@ -222,6 +224,26 @@ void sw::FlyContentPortion::Paint(const SwTextPaintInfo& rInf) const
     {
         SwLayoutModeModifier aLayoutModeModifier(*rInf.GetOut());
         m_pFly->PaintSwFrame(const_cast<vcl::RenderContext&>(*rInf.GetOut()), aRect);
+
+        // track changes: cross out the image, if it is deleted
+        const SwFrame *pFrame = m_pFly->Lower();
+        if ( GetAuthor() != std::string::npos && IsDeleted() && pFrame )
+        {
+            SwRect aPaintRect( pFrame->GetPaintArea() );
+
+            const AntialiasingFlags nFormerAntialiasing( rInf.GetOut()->GetAntialiasing() );
+            const bool bIsAntiAliasing = officecfg::Office::Common::Drawinglayer::AntiAliasing::get();
+            if ( bIsAntiAliasing )
+                const_cast<vcl::RenderContext&>(*rInf.GetOut()).SetAntialiasing(AntialiasingFlags::Enable);
+            tools::Long startX = aPaintRect.Left(  ), endX = aPaintRect.Right();
+            tools::Long startY = aPaintRect.Top(  ),  endY = aPaintRect.Bottom();
+            const_cast<vcl::RenderContext&>(*rInf.GetOut()).SetLineColor(
+                SwPostItMgr::GetColorAnchor(GetAuthor()) );
+            const_cast<vcl::RenderContext&>(*rInf.GetOut()).DrawLine(Point(startX, startY), Point(endX, endY));
+            const_cast<vcl::RenderContext&>(*rInf.GetOut()).DrawLine(Point(startX, endY), Point(endX, startY));
+            if ( bIsAntiAliasing )
+                const_cast<vcl::RenderContext&>(*rInf.GetOut()).SetAntialiasing(nFormerAntialiasing);
+        }
     }
     const_cast<SwTextPaintInfo&>(rInf).GetRefDev()->SetLayoutMode(rInf.GetOut()->GetLayoutMode());
 
@@ -249,9 +271,11 @@ void sw::DrawFlyCntPortion::Paint(const SwTextPaintInfo&) const
  */
 SwFlyCntPortion::SwFlyCntPortion()
     : m_bMax(false)
+    , m_bDeleted(false)
+    , m_nAuthor(std::string::npos)
     , m_eAlign(sw::LineAlign::NONE)
 {
-    nLineLength = TextFrameIndex(1);
+    mnLineLength = TextFrameIndex(1);
     SetWhichPor(PortionType::FlyCnt);
 }
 
@@ -363,6 +387,7 @@ void SwFlyCntPortion::SetBase( const SwTextFrame& rFrame, const Point &rBase,
             if (!aPos->nNode.GetNode().FindFooterStartNode())
             {
                 aVert.SetVertOrient(css::text::VertOrientation::NONE);
+                aVert.SetRelationOrient(css::text::RelOrientation::FRAME);
                 sal_Int32 const nTop = aTextRectangle.getY() - rFrame.getFrameArea().Top()
                                        - rFrame.getFramePrintArea().Top();
                 aVert.SetPos(nTop);
@@ -399,20 +424,20 @@ void SwFlyCntPortion::SetBase( const SwTextFrame& rFrame, const Point &rBase,
         SwTwips nRelPos = aObjPositioning.GetRelPosY();
         if ( nRelPos < 0 )
         {
-            nAscent = static_cast<sal_uInt16>(-nRelPos);
-            if( nAscent > Height() )
-                Height( nAscent );
+            mnAscent = -nRelPos;
+            if( mnAscent > Height() )
+                Height( mnAscent );
         }
         else
         {
-            nAscent = 0;
-            Height( Height() + static_cast<sal_uInt16>(nRelPos) );
+            mnAscent = 0;
+            Height( Height() + o3tl::narrowing<sal_uInt16>(nRelPos) );
         }
     }
     else
     {
         Height( 1 );
-        nAscent = 0;
+        mnAscent = 0;
     }
 }
 
