@@ -183,11 +183,11 @@ SwRotatedPortion::SwRotatedPortion( const SwMultiCreator& rCreate,
 }
 
 SwBidiPortion::SwBidiPortion(TextFrameIndex const nEnd, sal_uInt8 nLv)
-    : SwMultiPortion( nEnd ), nLevel( nLv )
+    : SwMultiPortion( nEnd ), m_nLevel( nLv )
 {
     SetBidi();
 
-    if ( nLevel % 2 )
+    if ( m_nLevel % 2 )
         SetDirection( DIR_RIGHT2LEFT );
     else
         SetDirection( DIR_LEFT2RIGHT );
@@ -238,9 +238,9 @@ TextFrameIndex SwBidiPortion::GetSpaceCnt(const SwTextSizeInfo &rInf) const
 SwDoubleLinePortion::SwDoubleLinePortion(
         SwDoubleLinePortion& rDouble, TextFrameIndex const nEnd)
     : SwMultiPortion(nEnd)
-    , nLineDiff(0)
-    , nBlank1(0)
-    , nBlank2(0)
+    , m_nLineDiff(0)
+    , m_nBlank1(0)
+    , m_nBlank2(0)
 {
     SetDirection( rDouble.GetDirection() );
     SetDouble();
@@ -264,24 +264,24 @@ SwDoubleLinePortion::SwDoubleLinePortion(
 SwDoubleLinePortion::SwDoubleLinePortion(
         const SwMultiCreator& rCreate, TextFrameIndex const nEnd)
     : SwMultiPortion(nEnd)
-    , pBracket(new SwBracket)
-    , nLineDiff(0)
-    , nBlank1(0)
-    , nBlank2(0)
+    , m_pBracket(new SwBracket)
+    , m_nLineDiff(0)
+    , m_nBlank1(0)
+    , m_nBlank2(0)
 {
-    pBracket->nAscent = 0;
-    pBracket->nHeight = 0;
-    pBracket->nPreWidth = 0;
-    pBracket->nPostWidth = 0;
+    m_pBracket->nAscent = 0;
+    m_pBracket->nHeight = 0;
+    m_pBracket->nPreWidth = 0;
+    m_pBracket->nPostWidth = 0;
 
     SetDouble();
     const SvxTwoLinesItem* pTwo = static_cast<const SvxTwoLinesItem*>(rCreate.pItem);
     if( pTwo )
-        pBracket->nStart = TextFrameIndex(0);
+        m_pBracket->nStart = TextFrameIndex(0);
     else
     {
         const SwTextAttr& rAttr = *rCreate.pAttr;
-        pBracket->nStart = rCreate.nStartOfAttr;
+        m_pBracket->nStart = rCreate.nStartOfAttr;
 
         const SfxPoolItem * const pItem =
             CharFormat::GetItem( rAttr, RES_CHRATR_TWO_LINES );
@@ -292,32 +292,32 @@ SwDoubleLinePortion::SwDoubleLinePortion(
     }
     if( pTwo )
     {
-        pBracket->cPre = pTwo->GetStartBracket();
-        pBracket->cPost = pTwo->GetEndBracket();
+        m_pBracket->cPre = pTwo->GetStartBracket();
+        m_pBracket->cPost = pTwo->GetEndBracket();
     }
     else
     {
-        pBracket->cPre = 0;
-        pBracket->cPost = 0;
+        m_pBracket->cPre = 0;
+        m_pBracket->cPost = 0;
     }
     SwFontScript nTmp = SW_SCRIPTS;
-    if( pBracket->cPre > 255 )
+    if( m_pBracket->cPre > 255 )
     {
-        OUString aText(pBracket->cPre);
+        OUString aText(m_pBracket->cPre);
         nTmp = SwScriptInfo::WhichFont(0, aText);
     }
-    pBracket->nPreScript = nTmp;
+    m_pBracket->nPreScript = nTmp;
     nTmp = SW_SCRIPTS;
-    if( pBracket->cPost > 255 )
+    if( m_pBracket->cPost > 255 )
     {
-        OUString aText(pBracket->cPost);
+        OUString aText(m_pBracket->cPost);
         nTmp = SwScriptInfo::WhichFont(0, aText);
     }
-    pBracket->nPostScript = nTmp;
+    m_pBracket->nPostScript = nTmp;
 
-    if( !pBracket->cPre && !pBracket->cPost )
+    if( !m_pBracket->cPre && !m_pBracket->cPost )
     {
-        pBracket.reset();
+        m_pBracket.reset();
     }
 
     // double line portions have the same direction as the frame directions
@@ -336,7 +336,7 @@ void SwDoubleLinePortion::PaintBracket( SwTextPaintInfo &rInf,
                                         tools::Long nSpaceAdd,
                                         bool bOpen ) const
 {
-    sal_Unicode cCh = bOpen ? pBracket->cPre : pBracket->cPost;
+    sal_Unicode cCh = bOpen ? m_pBracket->cPre : m_pBracket->cPost;
     if( !cCh )
         return;
     const sal_uInt16 nChWidth = bOpen ? PreWidth() : PostWidth();
@@ -347,16 +347,16 @@ void SwDoubleLinePortion::PaintBracket( SwTextPaintInfo &rInf,
             ( nSpaceAdd > 0 ? CalcSpacing( nSpaceAdd, rInf ) : 0 ) );
 
     SwBlankPortion aBlank( cCh, true );
-    aBlank.SetAscent( pBracket->nAscent );
+    aBlank.SetAscent( m_pBracket->nAscent );
     aBlank.Width( nChWidth );
-    aBlank.Height( pBracket->nHeight );
+    aBlank.Height( m_pBracket->nHeight );
     {
-        std::unique_ptr<SwFont> pTmpFnt( new SwFont( *rInf.GetFont() ) );
-        SwFontScript nAct = bOpen ? pBracket->nPreScript : pBracket->nPostScript;
+        SwFont aTmpFnt( *rInf.GetFont() );
+        SwFontScript nAct = bOpen ? m_pBracket->nPreScript : m_pBracket->nPostScript;
         if( SW_SCRIPTS > nAct )
-            pTmpFnt->SetActual( nAct );
-        pTmpFnt->SetProportion( 100 );
-        SwFontSave aSave( rInf, pTmpFnt.get() );
+            aTmpFnt.SetActual( nAct );
+        aTmpFnt.SetProportion( 100 );
+        SwFontSave aSave( rInf, &aTmpFnt );
         aBlank.Paint( rInf );
     }
     if( bOpen )
@@ -367,14 +367,14 @@ void SwDoubleLinePortion::PaintBracket( SwTextPaintInfo &rInf,
 // and fills it, if not both characters are 0x00.
 void SwDoubleLinePortion::SetBrackets( const SwDoubleLinePortion& rDouble )
 {
-    if( rDouble.pBracket )
+    if( rDouble.m_pBracket )
     {
-        pBracket.reset( new SwBracket );
-        pBracket->cPre = rDouble.pBracket->cPre;
-        pBracket->cPost = rDouble.pBracket->cPost;
-        pBracket->nPreScript = rDouble.pBracket->nPreScript;
-        pBracket->nPostScript = rDouble.pBracket->nPostScript;
-        pBracket->nStart = rDouble.pBracket->nStart;
+        m_pBracket.reset( new SwBracket );
+        m_pBracket->cPre = rDouble.m_pBracket->cPre;
+        m_pBracket->cPost = rDouble.m_pBracket->cPost;
+        m_pBracket->nPreScript = rDouble.m_pBracket->nPreScript;
+        m_pBracket->nPostScript = rDouble.m_pBracket->nPostScript;
+        m_pBracket->nStart = rDouble.m_pBracket->nStart;
     }
 }
 
@@ -384,63 +384,63 @@ void SwDoubleLinePortion::SetBrackets( const SwDoubleLinePortion& rDouble )
 void SwDoubleLinePortion::FormatBrackets( SwTextFormatInfo &rInf, SwTwips& nMaxWidth )
 {
     nMaxWidth -= rInf.X();
-    std::unique_ptr<SwFont> pTmpFnt( new SwFont( *rInf.GetFont() ) );
-    pTmpFnt->SetProportion( 100 );
-    pBracket->nAscent = 0;
-    pBracket->nHeight = 0;
-    if( pBracket->cPre )
+    SwFont aTmpFnt( *rInf.GetFont() );
+    aTmpFnt.SetProportion( 100 );
+    m_pBracket->nAscent = 0;
+    m_pBracket->nHeight = 0;
+    if( m_pBracket->cPre )
     {
-        OUString aStr( pBracket->cPre );
-        SwFontScript nActualScr = pTmpFnt->GetActual();
-        if( SW_SCRIPTS > pBracket->nPreScript )
-            pTmpFnt->SetActual( pBracket->nPreScript );
-        SwFontSave aSave( rInf, pTmpFnt.get() );
+        OUString aStr( m_pBracket->cPre );
+        SwFontScript nActualScr = aTmpFnt.GetActual();
+        if( SW_SCRIPTS > m_pBracket->nPreScript )
+            aTmpFnt.SetActual( m_pBracket->nPreScript );
+        SwFontSave aSave( rInf, &aTmpFnt );
         SwPosSize aSize = rInf.GetTextSize( aStr );
-        pBracket->nAscent = rInf.GetAscent();
-        pBracket->nHeight = aSize.Height();
-        pTmpFnt->SetActual( nActualScr );
-        if( nMaxWidth > aSize.Width() )
+        m_pBracket->nAscent = rInf.GetAscent();
+        m_pBracket->nHeight = aSize.Height();
+        aTmpFnt.SetActual( nActualScr );
+        if( nMaxWidth > o3tl::narrowing<SwTwips>(aSize.Width()) )
         {
-            pBracket->nPreWidth = aSize.Width();
+            m_pBracket->nPreWidth = aSize.Width();
             nMaxWidth -= aSize.Width();
             rInf.X( rInf.X() + aSize.Width() );
         }
         else
         {
-            pBracket->nPreWidth = 0;
+            m_pBracket->nPreWidth = 0;
             nMaxWidth = 0;
         }
     }
     else
-        pBracket->nPreWidth = 0;
-    if( pBracket->cPost )
+        m_pBracket->nPreWidth = 0;
+    if( m_pBracket->cPost )
     {
-        OUString aStr( pBracket->cPost );
-        if( SW_SCRIPTS > pBracket->nPostScript )
-            pTmpFnt->SetActual( pBracket->nPostScript );
-        SwFontSave aSave( rInf, pTmpFnt.get() );
+        OUString aStr( m_pBracket->cPost );
+        if( SW_SCRIPTS > m_pBracket->nPostScript )
+            aTmpFnt.SetActual( m_pBracket->nPostScript );
+        SwFontSave aSave( rInf, &aTmpFnt );
         SwPosSize aSize = rInf.GetTextSize( aStr );
         const sal_uInt16 nTmpAsc = rInf.GetAscent();
-        if( nTmpAsc > pBracket->nAscent )
+        if( nTmpAsc > m_pBracket->nAscent )
         {
-            pBracket->nHeight += nTmpAsc - pBracket->nAscent;
-            pBracket->nAscent = nTmpAsc;
+            m_pBracket->nHeight += nTmpAsc - m_pBracket->nAscent;
+            m_pBracket->nAscent = nTmpAsc;
         }
-        if( aSize.Height() > pBracket->nHeight )
-            pBracket->nHeight = aSize.Height();
-        if( nMaxWidth > aSize.Width() )
+        if( aSize.Height() > m_pBracket->nHeight )
+            m_pBracket->nHeight = aSize.Height();
+        if( nMaxWidth > o3tl::narrowing<SwTwips>(aSize.Width()) )
         {
-            pBracket->nPostWidth = aSize.Width();
+            m_pBracket->nPostWidth = aSize.Width();
             nMaxWidth -= aSize.Width();
         }
         else
         {
-            pBracket->nPostWidth = 0;
+            m_pBracket->nPostWidth = 0;
             nMaxWidth = 0;
         }
     }
     else
-        pBracket->nPostWidth = 0;
+        m_pBracket->nPostWidth = 0;
     nMaxWidth += rInf.X();
 }
 
@@ -454,24 +454,24 @@ void SwDoubleLinePortion::CalcBlanks( SwTextFormatInfo &rInf )
     TextFrameIndex nStart = rInf.GetIdx();
     SetTab1( false );
     SetTab2( false );
-    for (nBlank1 = TextFrameIndex(0); pPor; pPor = pPor->GetNextPortion())
+    for (m_nBlank1 = TextFrameIndex(0); pPor; pPor = pPor->GetNextPortion())
     {
         if( pPor->InTextGrp() )
-            nBlank1 = nBlank1 + static_cast<SwTextPortion*>(pPor)->GetSpaceCnt( rInf, nNull );
+            m_nBlank1 = m_nBlank1 + static_cast<SwTextPortion*>(pPor)->GetSpaceCnt( rInf, nNull );
         rInf.SetIdx( rInf.GetIdx() + pPor->GetLen() );
         if( pPor->InTabGrp() )
             SetTab1( true );
     }
-    nLineDiff = GetRoot().Width();
+    m_nLineDiff = GetRoot().Width();
     if( GetRoot().GetNext() )
     {
         pPor = GetRoot().GetNext()->GetFirstPortion();
-        nLineDiff -= GetRoot().GetNext()->Width();
+        m_nLineDiff -= GetRoot().GetNext()->Width();
     }
-    for (nBlank2 = TextFrameIndex(0); pPor; pPor = pPor->GetNextPortion())
+    for (m_nBlank2 = TextFrameIndex(0); pPor; pPor = pPor->GetNextPortion())
     {
         if( pPor->InTextGrp() )
-            nBlank2 = nBlank2 + static_cast<SwTextPortion*>(pPor)->GetSpaceCnt( rInf, nNull );
+            m_nBlank2 = m_nBlank2 + static_cast<SwTextPortion*>(pPor)->GetSpaceCnt( rInf, nNull );
         rInf.SetIdx( rInf.GetIdx() + pPor->GetLen() );
         if( pPor->InTabGrp() )
             SetTab2( true );
@@ -538,8 +538,8 @@ SwDoubleLinePortion::~SwDoubleLinePortion()
 // beside the main text, e.g. phonetic characters.
 SwRubyPortion::SwRubyPortion(const SwRubyPortion& rRuby, TextFrameIndex const nEnd)
     : SwMultiPortion( nEnd )
-    , nRubyOffset( rRuby.GetRubyOffset() )
-    , nAdjustment( rRuby.GetAdjustment() )
+    , m_nRubyOffset( rRuby.GetRubyOffset() )
+    , m_nAdjustment( rRuby.GetAdjustment() )
 {
     SetDirection( rRuby.GetDirection() );
     SetRubyPosition( rRuby.GetRubyPosition() );
@@ -558,8 +558,8 @@ SwRubyPortion::SwRubyPortion( const SwMultiCreator& rCreate, const SwFont& rFnt,
     OSL_ENSURE( SwMultiCreatorId::Ruby == rCreate.nId, "Ruby expected" );
     OSL_ENSURE( RES_TXTATR_CJK_RUBY == rCreate.pAttr->Which(), "Wrong attribute" );
     const SwFormatRuby& rRuby = rCreate.pAttr->GetRuby();
-    nAdjustment = rRuby.GetAdjustment();
-    nRubyOffset = nOffs;
+    m_nAdjustment = rRuby.GetAdjustment();
+    m_nRubyOffset = nOffs;
 
     const SwTextFrame *pFrame = rInf.GetTextFrame();
     RubyPosition ePos = static_cast<RubyPosition>( rRuby.GetPosition() );
@@ -608,10 +608,10 @@ SwRubyPortion::SwRubyPortion( const SwMultiCreator& rCreate, const SwFont& rFnt,
     if ( rCreate.nLevel % 2 )
     {
         // switch right and left ruby adjustment in rtl environment
-        if ( css::text::RubyAdjust_LEFT == nAdjustment )
-            nAdjustment = css::text::RubyAdjust_RIGHT;
-        else if ( css::text::RubyAdjust_RIGHT == nAdjustment )
-            nAdjustment = css::text::RubyAdjust_LEFT;
+        if ( css::text::RubyAdjust_LEFT == m_nAdjustment )
+            m_nAdjustment = css::text::RubyAdjust_RIGHT;
+        else if ( css::text::RubyAdjust_RIGHT == m_nAdjustment )
+            m_nAdjustment = css::text::RubyAdjust_LEFT;
 
         SetDirection( DIR_RIGHT2LEFT );
     }
@@ -652,11 +652,11 @@ void SwRubyPortion::Adjust_( SwTextFormatInfo &rInf )
     sal_uInt16 nLeft = 0;   // the space in front of the first letter
     sal_uInt16 nRight = 0;  // the space at the end of the last letter
     TextFrameIndex nSub(0);
-    switch ( nAdjustment )
+    switch ( m_nAdjustment )
     {
-        case css::text::RubyAdjust_CENTER: nRight = static_cast<sal_uInt16>(nLineDiff / 2);
+        case css::text::RubyAdjust_CENTER: nRight = o3tl::narrowing<sal_uInt16>(nLineDiff / 2);
             [[fallthrough]];
-        case css::text::RubyAdjust_RIGHT: nLeft  = static_cast<sal_uInt16>(nLineDiff - nRight); break;
+        case css::text::RubyAdjust_RIGHT: nLeft  = o3tl::narrowing<sal_uInt16>(nLineDiff - nRight); break;
         case css::text::RubyAdjust_BLOCK: nSub   = TextFrameIndex(1);
             [[fallthrough]];
         case css::text::RubyAdjust_INDENT_BLOCK:
@@ -683,8 +683,8 @@ void SwRubyPortion::Adjust_( SwTextFormatInfo &rInf )
             }
             if( nLineDiff > 1 )
             {
-                nRight = static_cast<sal_uInt16>(nLineDiff / 2);
-                nLeft  = static_cast<sal_uInt16>(nLineDiff - nRight);
+                nRight = o3tl::narrowing<sal_uInt16>(nLineDiff / 2);
+                nLeft  = o3tl::narrowing<sal_uInt16>(nLineDiff - nRight);
             }
             break;
         }
@@ -737,9 +737,9 @@ void SwRubyPortion::CalcRubyOffset()
     if( pField )
     {
         if( pField->HasFollow() )
-            nRubyOffset = pField->GetNextOffset();
+            m_nRubyOffset = pField->GetNextOffset();
         else
-            nRubyOffset = TextFrameIndex(COMPLETE_STRING);
+            m_nRubyOffset = TextFrameIndex(COMPLETE_STRING);
     }
 }
 
@@ -786,7 +786,7 @@ static bool lcl_CheckRotation(const SfxPoolItem *const pItem,
 {
     if ( pItem )
     {
-        rValue = static_cast<const SvxCharRotateItem*>(pItem)->GetValue() != Degree10(0);
+        rValue = static_cast<const SvxCharRotateItem*>(pItem)->GetValue() != 0_deg10;
         if( !rpRef )
             rpRef = static_cast<const SvxCharRotateItem*>(pItem);
         else if( static_cast<const SvxCharRotateItem*>(pItem)->GetValue() !=
@@ -904,7 +904,7 @@ namespace sw {
 // interrupts the first attribute.
 // E.g. a ruby portion interrupts a 2-line-attribute, a 2-line-attribute
 // with different brackets interrupts another 2-line-attribute.
-std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &rPos,
+std::optional<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &rPos,
                                                 SwMultiPortion const * pMulti ) const
 {
     SwScriptInfo& rSI = const_cast<SwParaPortion*>(GetParaPortion())->GetScriptInfo();
@@ -936,19 +936,19 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
     {
         rPos = bFieldBidi ? rPos + TextFrameIndex(1) : rSI.NextDirChg(rPos, &nCurrLevel);
         if (TextFrameIndex(COMPLETE_STRING) == rPos)
-            return nullptr;
-        std::unique_ptr<SwMultiCreator> pRet(new SwMultiCreator);
-        pRet->pItem = nullptr;
-        pRet->pAttr = nullptr;
-        pRet->nStartOfAttr = TextFrameIndex(-1);
-        pRet->nId = SwMultiCreatorId::Bidi;
-        pRet->nLevel = nCurrLevel + 1;
-        return pRet;
+            return {};
+        SwMultiCreator aRet;
+        aRet.pItem = nullptr;
+        aRet.pAttr = nullptr;
+        aRet.nStartOfAttr = TextFrameIndex(-1);
+        aRet.nId = SwMultiCreatorId::Bidi;
+        aRet.nLevel = nCurrLevel + 1;
+        return aRet;
     }
 
     // a bidi portion can only contain other bidi portions
     if ( pMulti )
-        return nullptr;
+        return {};
 
     // need the node that contains input rPos
     std::pair<SwTextNode const*, sal_Int32> startPos(m_pFrame->MapViewToModel(rPos));
@@ -1037,26 +1037,26 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
         }
     }
     if (!pRuby && !pActiveTwoLinesItem && !pActiveRotateItem)
-        return nullptr;
+        return {};
 
     if( pRuby )
     {   // The winner is ... a ruby attribute and so
         // the end of the multiportion is the end of the ruby attribute.
         rPos = m_pFrame->MapModelToView(startPos.first, *pRuby->End());
-        std::unique_ptr<SwMultiCreator> pRet(new SwMultiCreator);
-        pRet->pItem = nullptr;
-        pRet->pAttr = pRuby;
-        pRet->nStartOfAttr = m_pFrame->MapModelToView(startPos.first, pRet->pAttr->GetStart());
-        pRet->nId = SwMultiCreatorId::Ruby;
-        pRet->nLevel = GetTextFrame()->IsRightToLeft() ? 1 : 0;
-        return pRet;
+        SwMultiCreator aRet;
+        aRet.pItem = nullptr;
+        aRet.pAttr = pRuby;
+        aRet.nStartOfAttr = m_pFrame->MapModelToView(startPos.first, aRet.pAttr->GetStart());
+        aRet.nId = SwMultiCreatorId::Ruby;
+        aRet.nLevel = GetTextFrame()->IsRightToLeft() ? 1 : 0;
+        return aRet;
     }
     if (pActiveTwoLinesHint ||
         (pNodeTwoLinesItem && pNodeTwoLinesItem == pActiveTwoLinesItem &&
          rPos < TextFrameIndex(GetText().getLength())))
     {   // The winner is a 2-line-attribute,
         // the end of the multiportion depends on the following attributes...
-        std::unique_ptr<SwMultiCreator> pRet(new SwMultiCreator);
+        SwMultiCreator aRet;
 
         // We note the endpositions of the 2-line attributes in aEnd as stack
         std::deque<TextFrameIndex> aEnd;
@@ -1068,9 +1068,9 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
 
         if (pActiveTwoLinesHint)
         {
-            pRet->pItem = nullptr;
-            pRet->pAttr = pActiveTwoLinesHint;
-            pRet->nStartOfAttr = m_pFrame->MapModelToView(startPos.first, pRet->pAttr->GetStart());
+            aRet.pItem = nullptr;
+            aRet.pAttr = pActiveTwoLinesHint;
+            aRet.nStartOfAttr = m_pFrame->MapModelToView(startPos.first, aRet.pAttr->GetStart());
             if (pNodeTwoLinesItem)
             {
                 aEnd.push_front(m_pFrame->MapModelToView(startPos.first, startPos.first->Len()));
@@ -1081,18 +1081,18 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
             }
             else
             {
-                aEnd.push_front(m_pFrame->MapModelToView(startPos.first, *pRet->pAttr->End()));
+                aEnd.push_front(m_pFrame->MapModelToView(startPos.first, *aRet.pAttr->End()));
             }
         }
         else
         {
-            pRet->pItem = pNodeTwoLinesItem;
-            pRet->pAttr = nullptr;
-            pRet->nStartOfAttr = TextFrameIndex(-1);
+            aRet.pItem = pNodeTwoLinesItem;
+            aRet.pAttr = nullptr;
+            aRet.nStartOfAttr = TextFrameIndex(-1);
             aEnd.push_front(m_pFrame->MapModelToView(startPos.first, startPos.first->Len()));
         }
-        pRet->nId = SwMultiCreatorId::Double;
-        pRet->nLevel = GetTextFrame()->IsRightToLeft() ? 1 : 0;
+        aRet.nId = SwMultiCreatorId::Double;
+        aRet.nLevel = GetTextFrame()->IsRightToLeft() ? 1 : 0;
 
         // pActiveTwoLinesHint is the last 2-line-attribute, which contains
         // the actual position.
@@ -1171,7 +1171,7 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
             }
             // A ruby attribute stops the 2-line immediately
             if (pTmp && RES_TXTATR_CJK_RUBY == pTmp->Which())
-                return pRet;
+                return aRet;
             if (pTmp ? lcl_Has2Lines(*pTmp, pActiveTwoLinesItem, bTwo)
                      : lcl_Check2Lines(pNodeTwoLinesItem, pActiveTwoLinesItem, bTwo))
             {   // We have an interesting attribute...
@@ -1198,15 +1198,15 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
         }
         if( bOn && !aEnd.empty() )
             rPos = aEnd.back();
-        return pRet;
+        return aRet;
     }
     if (pActiveRotateHint ||
         (pNodeRotateItem && pNodeRotateItem == pActiveRotateItem &&
          rPos < TextFrameIndex(GetText().getLength())))
     {   // The winner is a rotate-attribute,
         // the end of the multiportion depends on the following attributes...
-        std::unique_ptr<SwMultiCreator> pRet(new SwMultiCreator);
-        pRet->nId = SwMultiCreatorId::Rotate;
+        SwMultiCreator aRet;
+        aRet.nId = SwMultiCreatorId::Rotate;
 
         // We note the endpositions of the 2-line attributes in aEnd as stack
         std::deque<TextFrameIndex> aEnd;
@@ -1299,9 +1299,9 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
         bOn = true;
         if (pActiveRotateHint)
         {
-            pRet->pItem = nullptr;
-            pRet->pAttr = pActiveRotateHint;
-            pRet->nStartOfAttr = m_pFrame->MapModelToView(startPos.first, pRet->pAttr->GetStart());
+            aRet.pItem = nullptr;
+            aRet.pAttr = pActiveRotateHint;
+            aRet.nStartOfAttr = m_pFrame->MapModelToView(startPos.first, aRet.pAttr->GetStart());
             if (pNodeRotateItem)
             {
                 aEnd.push_front(m_pFrame->MapModelToView(startPos.first, startPos.first->Len()));
@@ -1310,14 +1310,14 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
             }
             else
             {
-                aEnd.push_front(m_pFrame->MapModelToView(startPos.first, *pRet->pAttr->End()));
+                aEnd.push_front(m_pFrame->MapModelToView(startPos.first, *aRet.pAttr->End()));
             }
         }
         else
         {
-            pRet->pItem = pNodeRotateItem;
-            pRet->pAttr = nullptr;
-            pRet->nStartOfAttr = TextFrameIndex(-1);
+            aRet.pItem = pNodeRotateItem;
+            aRet.pAttr = nullptr;
+            aRet.nStartOfAttr = TextFrameIndex(-1);
             aEnd.push_front(m_pFrame->MapModelToView(startPos.first, startPos.first->Len()));
         }
         for (sw::MergedAttrIterMulti iter = iterAtStartOfNode; ; )
@@ -1394,9 +1394,9 @@ std::unique_ptr<SwMultiCreator> SwTextSizeInfo::GetMultiCreator(TextFrameIndex &
             rPos = aEnd.back();
         if( rPos > n2Start )
             rPos = n2Start;
-        return pRet;
+        return aRet;
     }
-    return nullptr;
+    return {};
 }
 
 namespace {
@@ -1409,86 +1409,85 @@ namespace {
 // The destructor restores the values of the last manipulation.
 class SwSpaceManipulator
 {
-    SwTextPaintInfo& rInfo;
-    SwMultiPortion& rMulti;
-    std::vector<tools::Long>* pOldSpaceAdd;
-    sal_uInt16 nOldSpIdx;
-    tools::Long nSpaceAdd;
-    bool bSpaceChg;
-    sal_uInt8 nOldDir;
+    SwTextPaintInfo& m_rInfo;
+    SwMultiPortion& m_rMulti;
+    std::vector<tools::Long>* m_pOldSpaceAdd;
+    sal_uInt16 m_nOldSpaceIndex;
+    tools::Long m_nSpaceAdd;
+    bool m_bSpaceChg;
+    sal_uInt8 m_nOldDir;
+
 public:
     SwSpaceManipulator( SwTextPaintInfo& rInf, SwMultiPortion& rMult );
     ~SwSpaceManipulator();
     void SecondLine();
-    tools::Long GetSpaceAdd() const { return nSpaceAdd; }
+    tools::Long GetSpaceAdd() const { return m_nSpaceAdd; }
 };
 
 }
 
-SwSpaceManipulator::SwSpaceManipulator( SwTextPaintInfo& rInf,
-                                        SwMultiPortion& rMult )
-    : rInfo(rInf)
-    , rMulti(rMult)
-    , nSpaceAdd(0)
+SwSpaceManipulator::SwSpaceManipulator(SwTextPaintInfo& rInf, SwMultiPortion& rMult)
+    : m_rInfo(rInf)
+    , m_rMulti(rMult)
+    , m_nSpaceAdd(0)
 {
-    pOldSpaceAdd = rInfo.GetpSpaceAdd();
-    nOldSpIdx = rInfo.GetSpaceIdx();
-    nOldDir = rInfo.GetDirection();
-    rInfo.SetDirection( rMulti.GetDirection() );
-    bSpaceChg = false;
+    m_pOldSpaceAdd = m_rInfo.GetpSpaceAdd();
+    m_nOldSpaceIndex = m_rInfo.GetSpaceIdx();
+    m_nOldDir = m_rInfo.GetDirection();
+    m_rInfo.SetDirection(m_rMulti.GetDirection());
+    m_bSpaceChg = false;
 
-    if( rMulti.IsDouble() )
+    if (m_rMulti.IsDouble())
     {
-        nSpaceAdd = ( pOldSpaceAdd && !rMulti.HasTabulator() ) ?
-                      rInfo.GetSpaceAdd() : 0;
-        if( rMulti.GetRoot().IsSpaceAdd() )
+        m_nSpaceAdd = (m_pOldSpaceAdd && !m_rMulti.HasTabulator()) ? m_rInfo.GetSpaceAdd() : 0;
+        if (m_rMulti.GetRoot().IsSpaceAdd())
         {
-            rInfo.SetpSpaceAdd( rMulti.GetRoot().GetpLLSpaceAdd() );
-            rInfo.ResetSpaceIdx();
-            bSpaceChg = rMulti.ChgSpaceAdd( &rMulti.GetRoot(), nSpaceAdd );
+            m_rInfo.SetpSpaceAdd(m_rMulti.GetRoot().GetpLLSpaceAdd());
+            m_rInfo.ResetSpaceIdx();
+            m_bSpaceChg = m_rMulti.ChgSpaceAdd(&m_rMulti.GetRoot(), m_nSpaceAdd);
         }
-        else if( rMulti.HasTabulator() )
-            rInfo.SetpSpaceAdd( nullptr );
+        else if (m_rMulti.HasTabulator())
+            m_rInfo.SetpSpaceAdd(nullptr);
     }
-    else if ( ! rMulti.IsBidi() )
+    else if (!m_rMulti.IsBidi())
     {
-        rInfo.SetpSpaceAdd( rMulti.GetRoot().GetpLLSpaceAdd() );
-        rInfo.ResetSpaceIdx();
+        m_rInfo.SetpSpaceAdd(m_rMulti.GetRoot().GetpLLSpaceAdd());
+        m_rInfo.ResetSpaceIdx();
     }
 }
 
 void SwSpaceManipulator::SecondLine()
 {
-    if( bSpaceChg )
+    if (m_bSpaceChg)
     {
-        rInfo.RemoveFirstSpaceAdd();
-        bSpaceChg = false;
+        m_rInfo.RemoveFirstSpaceAdd();
+        m_bSpaceChg = false;
     }
-    SwLineLayout *pLay = rMulti.GetRoot().GetNext();
+    SwLineLayout* pLay = m_rMulti.GetRoot().GetNext();
     if( pLay->IsSpaceAdd() )
     {
-        rInfo.SetpSpaceAdd( pLay->GetpLLSpaceAdd() );
-        rInfo.ResetSpaceIdx();
-        bSpaceChg = rMulti.ChgSpaceAdd( pLay, nSpaceAdd );
+        m_rInfo.SetpSpaceAdd(pLay->GetpLLSpaceAdd());
+        m_rInfo.ResetSpaceIdx();
+        m_bSpaceChg = m_rMulti.ChgSpaceAdd(pLay, m_nSpaceAdd);
     }
     else
     {
-        rInfo.SetpSpaceAdd( (!rMulti.IsDouble() || rMulti.HasTabulator() ) ?
-                                nullptr : pOldSpaceAdd );
-        rInfo.SetSpaceIdx( nOldSpIdx);
+        m_rInfo.SetpSpaceAdd((!m_rMulti.IsDouble() || m_rMulti.HasTabulator()) ? nullptr
+                                                                               : m_pOldSpaceAdd);
+        m_rInfo.SetSpaceIdx(m_nOldSpaceIndex);
     }
 }
 
 SwSpaceManipulator::~SwSpaceManipulator()
 {
-    if( bSpaceChg )
+    if (m_bSpaceChg)
     {
-        rInfo.RemoveFirstSpaceAdd();
-        bSpaceChg = false;
+        m_rInfo.RemoveFirstSpaceAdd();
+        m_bSpaceChg = false;
     }
-    rInfo.SetpSpaceAdd( pOldSpaceAdd );
-    rInfo.SetSpaceIdx( nOldSpIdx);
-    rInfo.SetDirection( nOldDir );
+    m_rInfo.SetpSpaceAdd(m_pOldSpaceAdd);
+    m_rInfo.SetSpaceIdx(m_nOldSpaceIndex);
+    m_rInfo.SetDirection(m_nOldDir);
 }
 
 // Manages the paint for a SwMultiPortion.
@@ -1680,7 +1679,7 @@ void SwTextPainter::PaintMultiPortion( const SwRect &rPaint,
         }
         else if ( rMulti.IsRuby() && rMulti.OnRight() && GetInfo().IsRuby() )
         {
-            SwTwips nLineDiff = std::max(( rMulti.GetRoot().Height() - pPor->Width() ) / 2, 0 );
+            SwTwips nLineDiff = std::max(( rMulti.GetRoot().Height() - pPor->Width() ) / 2, static_cast<sal_uInt32>(0) );
             GetInfo().Y( nOfst + nLineDiff );
             // Draw the ruby text on top of the preserved space.
             GetInfo().X( GetInfo().X() - pPor->Height() );
@@ -1731,7 +1730,7 @@ void SwTextPainter::PaintMultiPortion( const SwRect &rPaint,
         {
             // we do not allow any rotation inside a bidi portion
             SwFont* pTmpFont = GetInfo().GetFont();
-            pTmpFont->SetVertical( Degree10(0), GetInfo().GetTextFrame()->IsVertical() );
+            pTmpFont->SetVertical( 0_deg10, GetInfo().GetTextFrame()->IsVertical() );
         }
 
         if( pPor->IsMultiPortion() && static_cast<SwMultiPortion*>(pPor)->IsBidi() )
@@ -1900,15 +1899,16 @@ bool SwTextFormatter::BuildMultiPortion( SwTextFormatInfo &rInf,
 
     SeekAndChg( rInf );
     std::unique_ptr<SwFontSave> xFontSave;
+    std::unique_ptr<SwFont> xTmpFont;
     if( rMulti.IsDouble() )
     {
-        SwFont* pTmpFnt = new SwFont( *rInf.GetFont() );
+        xTmpFont.reset(new SwFont( *rInf.GetFont() ));
         if( rMulti.IsDouble() )
         {
             SetPropFont( 50 );
-            pTmpFnt->SetProportion( GetPropFont() );
+            xTmpFont->SetProportion( GetPropFont() );
         }
-        xFontSave.reset(new SwFontSave(rInf, pTmpFnt, this));
+        xFontSave.reset(new SwFontSave(rInf, xTmpFont.get(), this));
     }
 
     SwLayoutModeModifier aLayoutModeModifier( *GetInfo().GetOut() );
@@ -2169,7 +2169,7 @@ bool SwTextFormatter::BuildMultiPortion( SwTextFormatInfo &rInf,
             // Setting this to the portion width ( = rMulti.Width() )
             // can make GetTextBreak inside SwTextGuess::Guess return too small
             // values. Therefore we add some extra twips.
-            if( nActWidth > nTmpX + rMulti.Width() + 6 )
+            if( nActWidth > nTmpX + o3tl::narrowing<SwTwips>(rMulti.Width()) + 6 )
                 nActWidth = nTmpX + rMulti.Width() + 6;
             nMaxWidth = nActWidth;
             nActWidth = ( 3 * nMaxWidth + nMinWidth + 3 ) / 4;
@@ -2454,7 +2454,7 @@ SwLinePortion* SwTextFormatter::MakeRestPortion( const SwLineLayout* pLine,
         return pRest;
 
     nPosition = nMultiPos + pHelpMulti->GetLen();
-    std::unique_ptr<SwMultiCreator> pCreate = GetInfo().GetMultiCreator( nMultiPos, nullptr );
+    std::optional<SwMultiCreator> pCreate = GetInfo().GetMultiCreator( nMultiPos, nullptr );
 
     if ( !pCreate )
     {
@@ -2511,7 +2511,7 @@ SwLinePortion* SwTextFormatter::MakeRestPortion( const SwLineLayout* pLine,
 SwTextCursorSave::SwTextCursorSave( SwTextCursor* pCursor,
                                   SwMultiPortion* pMulti,
                                   SwTwips nY,
-                                  sal_uInt16& nX,
+                                  sal_uInt32& nX,
                                   TextFrameIndex const nCurrStart,
                                   tools::Long nSpaceAdd )
   : pTextCursor(pCursor),
@@ -2520,7 +2520,7 @@ SwTextCursorSave::SwTextCursorSave( SwTextCursor* pCursor,
 {
     pCursor->m_nStart = nCurrStart;
     pCursor->m_pCurr = &pMulti->GetRoot();
-    while( pCursor->Y() + pCursor->GetLineHeight() < nY &&
+    while( pCursor->Y() + o3tl::narrowing<SwTwips>(pCursor->GetLineHeight()) < nY &&
         pCursor->Next() )
         ; // nothing
     nWidth = pCursor->m_pCurr->Width();
@@ -2545,7 +2545,7 @@ SwTextCursorSave::SwTextCursorSave( SwTextCursor* pCursor,
         }
 
         if( nSpaceAdd > 0 && !pMulti->HasTabulator() )
-            pCursor->m_pCurr->Width( static_cast<sal_uInt16>(nWidth + nSpaceAdd * sal_Int32(nSpaceCnt) / SPACING_PRECISION_FACTOR) );
+            pCursor->m_pCurr->Width( o3tl::narrowing<sal_uInt16>(nWidth + nSpaceAdd * sal_Int32(nSpaceCnt) / SPACING_PRECISION_FACTOR) );
 
         // For a BidiPortion we have to calculate the offset from the
         // end of the portion
