@@ -96,8 +96,8 @@ SwDropSave::~SwDropSave()
 /// SwDropPortionPart DTor
 SwDropPortionPart::~SwDropPortionPart()
 {
-    pFollow.reset();
-    pFnt.reset();
+    m_pFollow.reset();
+    m_pFnt.reset();
 }
 
 /// SwDropPortion CTor, DTor
@@ -105,19 +105,19 @@ SwDropPortion::SwDropPortion( const sal_uInt16 nLineCnt,
                               const sal_uInt16 nDrpHeight,
                               const sal_uInt16 nDrpDescent,
                               const sal_uInt16 nDist )
-  : nLines( nLineCnt ),
-    nDropHeight(nDrpHeight),
-    nDropDescent(nDrpDescent),
-    nDistance(nDist),
-    nFix(0),
-    nY(0)
+  : m_nLines( nLineCnt ),
+    m_nDropHeight(nDrpHeight),
+    m_nDropDescent(nDrpDescent),
+    m_nDistance(nDist),
+    m_nFix(0),
+    m_nY(0)
 {
     SetWhichPor( PortionType::Drop );
 }
 
 SwDropPortion::~SwDropPortion()
 {
-    pPart.reset();
+    m_pPart.reset();
 }
 
 /// nWishLen = 0 indicates that we want a whole word
@@ -299,7 +299,7 @@ bool SwTextNode::GetDropSize(int& rFontHeight, int& rDropHeight, int& rDropDesce
 /// Manipulate the width, otherwise the chars are being stretched
 void SwDropPortion::PaintText( const SwTextPaintInfo &rInf ) const
 {
-    OSL_ENSURE( nDropHeight && pPart && nLines != 1, "Drop Portion painted twice" );
+    OSL_ENSURE( m_nDropHeight && m_pPart && m_nLines != 1, "Drop Portion painted twice" );
 
     const SwDropPortionPart* pCurrPart = GetPart();
     const TextFrameIndex nOldLen = GetLen();
@@ -307,8 +307,8 @@ void SwDropPortion::PaintText( const SwTextPaintInfo &rInf ) const
     const sal_uInt16 nOldAscent = GetAscent();
 
     const SwTwips nBasePosY  = rInf.Y();
-    const_cast<SwTextPaintInfo&>(rInf).Y( nBasePosY + nY );
-    const_cast<SwDropPortion*>(this)->SetAscent( nOldAscent + nY );
+    const_cast<SwTextPaintInfo&>(rInf).Y( nBasePosY + m_nY );
+    const_cast<SwDropPortion*>(this)->SetAscent( nOldAscent + m_nY );
     SwDropSave aSave( rInf );
     // for text inside drop portions we let vcl handle the text directions
     SwLayoutModeModifier aLayoutModeModifier( *rInf.GetOut() );
@@ -348,7 +348,7 @@ void SwDropPortion::PaintText( const SwTextPaintInfo &rInf ) const
 void SwDropPortion::PaintDrop( const SwTextPaintInfo &rInf ) const
 {
     // normal output is being done during the normal painting
-    if( ! nDropHeight || ! pPart || nLines == 1 )
+    if( ! m_nDropHeight || ! m_pPart || m_nLines == 1 )
         return;
 
     // set the lying values
@@ -363,11 +363,11 @@ void SwDropPortion::PaintDrop( const SwTextPaintInfo &rInf ) const
     // make good for retouching
 
     // Set baseline
-    const_cast<SwTextPaintInfo&>(rInf).Y( aOutPos.Y() + nDropHeight );
+    const_cast<SwTextPaintInfo&>(rInf).Y( aOutPos.Y() + m_nDropHeight );
 
     // for background
-    const_cast<SwDropPortion*>(this)->Height( nDropHeight + nDropDescent );
-    const_cast<SwDropPortion*>(this)->SetAscent( nDropHeight );
+    const_cast<SwDropPortion*>(this)->Height( m_nDropHeight + m_nDropDescent );
+    const_cast<SwDropPortion*>(this)->SetAscent( m_nDropHeight );
 
     // Always adapt Clipregion to us, never set it off using the existing ClipRect
     // as that could be set for the line
@@ -393,7 +393,7 @@ void SwDropPortion::PaintDrop( const SwTextPaintInfo &rInf ) const
 void SwDropPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
     // normal output is being done here
-    if( !(! nDropHeight || ! pPart || 1 == nLines) )
+    if( !(! m_nDropHeight || ! m_pPart || 1 == m_nLines) )
         return;
 
     if ( rInf.OnWin() &&
@@ -405,7 +405,7 @@ void SwDropPortion::Paint( const SwTextPaintInfo &rInf ) const
     if ( rInf.GetFont()->GetOrientation( rInf.GetTextFrame()->IsVertical() ) )
     {
         pTmpFont.reset(new SwFont( *rInf.GetFont() ));
-        pTmpFont->SetVertical( Degree10(0), rInf.GetTextFrame()->IsVertical() );
+        pTmpFont->SetVertical( 0_deg10, rInf.GetTextFrame()->IsVertical() );
     }
 
     SwFontSave aFontSave( rInf, pTmpFont.get() );
@@ -484,8 +484,8 @@ void SwTextFormatter::CalcDropHeight( const sal_uInt16 nLines )
 {
     const SwLinePortion *const pOldCurr = GetCurr();
     sal_uInt16 nDropHght = 0;
-    sal_uInt16 nAscent = 0;
-    sal_uInt16 nHeight = 0;
+    sal_uInt32 nAscent = 0;
+    sal_uInt32 nHeight = 0;
     sal_uInt16 nDropLns = 0;
     const bool bRegisterOld = IsRegisterOn();
     m_bRegisterOn = false;
@@ -545,8 +545,8 @@ void SwTextFormatter::CalcDropHeight( const sal_uInt16 nLines )
 void SwTextFormatter::GuessDropHeight( const sal_uInt16 nLines )
 {
     OSL_ENSURE( nLines, "GuessDropHeight: Give me more Lines!" );
-    sal_uInt16 nAscent = 0;
-    sal_uInt16 nHeight = 0;
+    sal_uInt32 nAscent = 0;
+    sal_uInt32 nHeight = 0;
     SetDropLines( nLines );
     if ( GetDropLines() > 1 )
     {
@@ -620,7 +620,7 @@ SwDropPortion *SwTextFormatter::NewDropPortion( SwTextFormatInfo &rInf )
         }
 
         // we do not allow a vertical font for the drop portion
-        pTmpFnt->SetVertical( Degree10(0), rInf.GetTextFrame()->IsVertical() );
+        pTmpFnt->SetVertical( 0_deg10, rInf.GetTextFrame()->IsVertical() );
 
         // find next attribute change / script change
         const TextFrameIndex nTmpIdx = nNextChg;
@@ -678,7 +678,7 @@ void SwTextPainter::PaintDropPortion()
     Point aLineOrigin( GetTopLeft() );
 
     aLineOrigin.AdjustX(nX );
-    sal_uInt16 nTmpAscent, nTmpHeight;
+    sal_uInt32 nTmpAscent, nTmpHeight;
     CalcAscentAndHeight( nTmpAscent, nTmpHeight );
     aLineOrigin.AdjustY(nTmpAscent );
     GetInfo().SetIdx( GetStart() );
@@ -696,12 +696,12 @@ void SwTextPainter::PaintDropPortion()
 
 class SwDropCapCache
 {
-    const void* aFontCacheId[ DROP_CACHE_SIZE ] = {};
-    OUString aText[ DROP_CACHE_SIZE ];
-    sal_uInt16 aFactor[ DROP_CACHE_SIZE ];
-    sal_uInt16 aWishedHeight[ DROP_CACHE_SIZE ] = {};
-    short aDescent[ DROP_CACHE_SIZE ];
-    sal_uInt16 nIndex = 0;
+    const void* m_aFontCacheId[ DROP_CACHE_SIZE ] = {};
+    OUString m_aText[ DROP_CACHE_SIZE ];
+    sal_uInt16 m_aFactor[ DROP_CACHE_SIZE ];
+    sal_uInt16 m_aWishedHeight[ DROP_CACHE_SIZE ] = {};
+    short m_aDescent[ DROP_CACHE_SIZE ];
+    sal_uInt16 m_nIndex = 0;
 public:
     SwDropCapCache() = default;
     void CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf );
@@ -736,8 +736,8 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
         nTmpIdx = 0;
 
         while( nTmpIdx < DROP_CACHE_SIZE &&
-            ( aText[ nTmpIdx ] != aStr || aFontCacheId[ nTmpIdx ] != nFntCacheId ||
-            aWishedHeight[ nTmpIdx ] != pDrop->GetDropHeight() ) )
+            ( m_aText[ nTmpIdx ] != aStr || m_aFontCacheId[ nTmpIdx ] != nFntCacheId ||
+            m_aWishedHeight[ nTmpIdx ] != pDrop->GetDropHeight() ) )
             ++nTmpIdx;
     }
 
@@ -747,9 +747,9 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
     //    consists of more than one part
     if( nTmpIdx >= DROP_CACHE_SIZE || ! bUseCache )
     {
-        ++nIndex;
-        nIndex %= DROP_CACHE_SIZE;
-        nTmpIdx = nIndex;
+        ++m_nIndex;
+        m_nIndex %= DROP_CACHE_SIZE;
+        nTmpIdx = m_nIndex;
 
         tools::Long nWishedHeight = pDrop->GetDropHeight();
         tools::Long nAscent = 0;
@@ -771,11 +771,11 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
         if ( bUseCache )
         {
             // save keys for cache
-            aFontCacheId[ nTmpIdx ] = nFntCacheId;
-            aText[ nTmpIdx ] = aStr;
-            aWishedHeight[ nTmpIdx ] = sal_uInt16(nWishedHeight);
+            m_aFontCacheId[ nTmpIdx ] = nFntCacheId;
+            m_aText[ nTmpIdx ] = aStr;
+            m_aWishedHeight[ nTmpIdx ] = sal_uInt16(nWishedHeight);
             // save initial scaling factor
-            aFactor[ nTmpIdx ] = static_cast<sal_uInt16>(nFactor);
+            m_aFactor[ nTmpIdx ] = o3tl::narrowing<sal_uInt16>(nFactor);
         }
 
         bool bGrow = (pDrop->GetLen() != TextFrameIndex(0));
@@ -793,7 +793,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
         OutputDevice* pOut = rInf.GetOut();
         OutputDevice* pWin;
         if( rInf.GetVsh() && rInf.GetVsh()->GetWin() )
-            pWin = rInf.GetVsh()->GetWin();
+            pWin = rInf.GetVsh()->GetWin()->GetOutDev();
         else
             pWin = Application::GetDefaultDevice();
 
@@ -925,7 +925,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
                 else
                 {
                     if ( bUseCache )
-                        aFactor[ nTmpIdx ] = static_cast<sal_uInt16>(nFactor);
+                        m_aFactor[ nTmpIdx ] = o3tl::narrowing<sal_uInt16>(nFactor);
                     nMin = nFactor;
                 }
 
@@ -949,7 +949,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
         }
 
         if ( bUseCache )
-            aDescent[ nTmpIdx ] = -short( nDescent );
+            m_aDescent[ nTmpIdx ] = -short( nDescent );
     }
 
     pCurrPart = pDrop->GetPart();
@@ -957,8 +957,8 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
     // did made any new calculations or did we use the cache?
     if ( -1 == nFactor )
     {
-        nFactor = aFactor[ nTmpIdx ];
-        nDescent = aDescent[ nTmpIdx ];
+        nFactor = m_aFactor[ nTmpIdx ];
+        nDescent = m_aDescent[ nTmpIdx ];
     }
     else
         nDescent = -nDescent;
@@ -982,12 +982,12 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
 bool SwDropPortion::Format( SwTextFormatInfo &rInf )
 {
     bool bFull = false;
-    nFix = static_cast<sal_uInt16>(rInf.X());
+    m_nFix = o3tl::narrowing<sal_uInt16>(rInf.X());
 
     SwLayoutModeModifier aLayoutModeModifier( *rInf.GetOut() );
     aLayoutModeModifier.SetAuto();
 
-    if( nDropHeight && pPart && nLines!=1 )
+    if( m_nDropHeight && m_pPart && m_nLines!=1 )
     {
         if( !pDropCapCache )
             pDropCapCache = new SwDropCapCache;
@@ -998,7 +998,7 @@ bool SwDropPortion::Format( SwTextFormatInfo &rInf )
         const tools::Long nOldX = rInf.X();
         {
             SwDropSave aSave( rInf );
-            SwDropPortionPart* pCurrPart = pPart.get();
+            SwDropPortionPart* pCurrPart = m_pPart.get();
 
             while ( pCurrPart )
             {
@@ -1020,7 +1020,7 @@ bool SwDropPortion::Format( SwTextFormatInfo &rInf )
                         Width();
 
                 // set values
-                pCurrPart->SetWidth( static_cast<sal_uInt16>(nTmpWidth) );
+                pCurrPart->SetWidth( o3tl::narrowing<sal_uInt16>(nTmpWidth) );
 
                 // Move
                 rInf.SetIdx( rInf.GetIdx() + pCurrPart->GetLen() );
@@ -1029,7 +1029,7 @@ bool SwDropPortion::Format( SwTextFormatInfo &rInf )
             }
             SetJoinBorderWithNext(false);
             SetJoinBorderWithPrev(false);
-            Width( static_cast<sal_uInt16>(rInf.X() - nOldX) );
+            Width( o3tl::narrowing<sal_uInt16>(rInf.X() - nOldX) );
         }
 
         // reset my length
@@ -1037,7 +1037,7 @@ bool SwDropPortion::Format( SwTextFormatInfo &rInf )
 
         // Quit when Flys are overlapping
         if( ! bFull )
-            bFull = lcl_IsDropFlyInter( rInf, Width(), nDropHeight );
+            bFull = lcl_IsDropFlyInter( rInf, Width(), m_nDropHeight );
 
         if( bFull )
         {
@@ -1046,8 +1046,8 @@ bool SwDropPortion::Format( SwTextFormatInfo &rInf )
                 Height( rInf.GetTextHeight() );
 
             // And now for another round
-            nDropHeight = nLines = 0;
-            pPart.reset();
+            m_nDropHeight = m_nLines = 0;
+            m_pPart.reset();
 
             // Meanwhile use normal formatting
             bFull = SwTextPortion::Format( rInf );
@@ -1062,16 +1062,16 @@ bool SwDropPortion::Format( SwTextFormatInfo &rInf )
         bFull = SwTextPortion::Format( rInf );
 
     if( bFull )
-        nDistance = 0;
+        m_nDistance = 0;
     else
     {
         const sal_uInt16 nWant = Width() + GetDistance();
-        const sal_uInt16 nRest = static_cast<sal_uInt16>(rInf.Width() - rInf.X());
+        const sal_uInt16 nRest = o3tl::narrowing<sal_uInt16>(rInf.Width() - rInf.X());
         if( ( nWant > nRest ) ||
-            lcl_IsDropFlyInter( rInf, Width() + GetDistance(), nDropHeight ) )
-            nDistance = 0;
+            lcl_IsDropFlyInter( rInf, Width() + GetDistance(), m_nDropHeight ) )
+            m_nDistance = 0;
 
-        Width( Width() + nDistance );
+        Width( Width() + m_nDistance );
     }
     return bFull;
 }
