@@ -28,6 +28,7 @@
 #include <i18nutil/transliteration.hxx>
 #include <SwSmartTagMgr.hxx>
 #include <o3tl/safeint.hxx>
+#include <osl/diagnose.h>
 #include <officecfg/Office/Writer.hxx>
 #include <unotools/transliterationwrapper.hxx>
 #include <unotools/charclass.hxx>
@@ -98,9 +99,9 @@ namespace
 
 struct SwParaIdleData_Impl
 {
-    SwWrongList* pWrong;                // for spell checking
-    SwGrammarMarkUp* pGrammarCheck;     // for grammar checking /  proof reading
-    SwWrongList* pSmartTags;
+    std::unique_ptr<SwWrongList> pWrong;                // for spell checking
+    std::unique_ptr<SwGrammarMarkUp> pGrammarCheck;     // for grammar checking /  proof reading
+    std::unique_ptr<SwWrongList> pSmartTags;
     sal_uLong nNumberOfWords;
     sal_uLong nNumberOfAsianWords;
     sal_uLong nNumberOfChars;
@@ -112,9 +113,6 @@ struct SwParaIdleData_Impl
     bool bAutoComplDirty;               ///< auto complete list dirty
 
     SwParaIdleData_Impl() :
-        pWrong              ( nullptr ),
-        pGrammarCheck       ( nullptr ),
-        pSmartTags          ( nullptr ),
         nNumberOfWords      ( 0 ),
         nNumberOfAsianWords ( 0 ),
         nNumberOfChars      ( 0 ),
@@ -633,9 +631,9 @@ void SwTextNode::RstTextAttr(
         nMax,
         0);
 
-    NotifyClients( nullptr, &aHint );
+    CallSwClientNotify(sw::LegacyModifyHint(nullptr, &aHint));
     SwFormatChg aNew( GetFormatColl() );
-    NotifyClients( nullptr, &aNew );
+    CallSwClientNotify(sw::LegacyModifyHint(nullptr, &aNew));
 }
 
 static sal_Int32 clipIndexBounds(const OUString &rStr, sal_Int32 nPos)
@@ -1070,15 +1068,10 @@ void SwTextNode::SetLanguageAndFont( const SwPaM &rPaM,
     LanguageType nLang, sal_uInt16 nLangWhichId,
     const vcl::Font *pFont,  sal_uInt16 nFontWhichId )
 {
-    sal_uInt16 aRanges[] = {
-            nLangWhichId, nLangWhichId,
-            nFontWhichId, nFontWhichId,
-            0, 0, 0 };
-    if (!pFont)
-        aRanges[2] = aRanges[3] = 0;    // clear entries with font WhichId
-
     SwEditShell *pEditShell = GetDoc().GetEditShell();
-    SfxItemSet aSet( pEditShell->GetAttrPool(), aRanges );
+    SfxItemSet aSet(pEditShell->GetAttrPool(), { { nLangWhichId, nLangWhichId } });
+    if (pFont)
+        aSet.MergeRange(nFontWhichId, nFontWhichId); // Keep it sorted
     aSet.Put( SvxLanguageItem( nLang, nLangWhichId ) );
 
     OSL_ENSURE( pFont, "target font missing?" );
@@ -1342,7 +1335,7 @@ SwRect SwTextFrame::AutoSpell_(SwTextNode & rNode, sal_Int32 nActPos)
                     {
                         if( !pNode->GetWrong() )
                         {
-                            pNode->SetWrong( new SwWrongList( WRONGLIST_SPELL ) );
+                            pNode->SetWrong( std::make_unique<SwWrongList>( WRONGLIST_SPELL ) );
                             pNode->GetWrong()->SetInvalid( 0, nEnd );
                         }
                         SwWrongList::FreshState const eState(pNode->GetWrong()->Fresh(
@@ -1402,7 +1395,7 @@ SwRect SwTextFrame::AutoSpell_(SwTextNode & rNode, sal_Int32 nActPos)
                     : SwTextNode::WrongState::TODO)
                 : SwTextNode::WrongState::DONE);
         if( !pNode->GetWrong()->Count() && ! pNode->IsWrongDirty() )
-            pNode->SetWrong( nullptr );
+            pNode->ClearWrong();
     }
     else
         pNode->SetWrongDirty(SwTextNode::WrongState::DONE);
@@ -1523,7 +1516,7 @@ SwRect SwTextFrame::SmartTagScan(SwTextNode & rNode)
         pNode->SetSmartTagDirty( COMPLETE_STRING != pSmartTagList->GetBeginInv() );
 
         if( !pSmartTagList->Count() && !pNode->IsSmartTagDirty() )
-            pNode->SetSmartTags( nullptr );
+            pNode->ClearSmartTags();
 
         // Calculate repaint area:
         if ( nBegin < nEnd && ( 0 != nNumberOfRemovedEntries ||
@@ -1683,7 +1676,7 @@ namespace
 void SwTextNode::TransliterateText(
     utl::TransliterationWrapper& rTrans,
     sal_Int32 nStt, sal_Int32 nEnd,
-    SwUndoTransliterate* pUndo )
+    SwUndoTransliterate* pUndo, bool bUseRedlining )
 {
     if (nStt >= nEnd)
         return;
@@ -1907,7 +1900,7 @@ void SwTextNode::TransliterateText(
     // now apply the changes from end to start to leave the offsets of the
     // yet unchanged text parts remain the same.
     size_t nSum(0);
-    bool bIsRedlineOn(GetDoc().getIDocumentRedlineAccess().IsRedlineOn());
+
     for (size_t i = 0; i < aChanges.size(); ++i)
     {   // check this here since AddChanges cannot be moved below
         // call to ReplaceTextOnly
@@ -1921,7 +1914,7 @@ void SwTextNode::TransliterateText(
             return;
         }
 
-        if ( bIsRedlineOn )
+        if ( bUseRedlining )
         {
             // create SwPaM with mark & point spanning the attributed text
             //SwPaM aCurPaM( *this, *this, nBegin, nBegin + nLen ); <-- wrong c-tor, does sth different
@@ -1982,10 +1975,10 @@ void SwTextNode::ReplaceTextOnly( sal_Int32 nPos, sal_Int32 nLen,
 
     // notify the layout!
     SwDelText aDelHint( nPos, nTLen );
-    NotifyClients( nullptr, &aDelHint );
+    CallSwClientNotify(sw::LegacyModifyHint(nullptr, &aDelHint));
 
     SwInsText aHint( nPos, nTLen );
-    NotifyClients( nullptr, &aHint );
+    CallSwClientNotify(sw::LegacyModifyHint(nullptr, &aHint));
 }
 
 // the return values allows us to see if we did the heavy-
@@ -2165,52 +2158,62 @@ void SwTextNode::InitSwParaStatistics( bool bNew )
     }
     else if ( m_pParaIdleData_Impl )
     {
-        delete m_pParaIdleData_Impl->pWrong;
-        delete m_pParaIdleData_Impl->pGrammarCheck;
-        delete m_pParaIdleData_Impl->pSmartTags;
+        m_pParaIdleData_Impl->pWrong.reset();
+        m_pParaIdleData_Impl->pGrammarCheck.reset();
+        m_pParaIdleData_Impl->pSmartTags.reset();
         delete m_pParaIdleData_Impl;
         m_pParaIdleData_Impl = nullptr;
     }
 }
 
-void SwTextNode::SetWrong( SwWrongList* pNew, bool bDelete )
+void SwTextNode::SetWrong( std::unique_ptr<SwWrongList> pNew )
 {
     if ( m_pParaIdleData_Impl )
-    {
-        if ( bDelete )
-        {
-            delete m_pParaIdleData_Impl->pWrong;
-        }
-        m_pParaIdleData_Impl->pWrong = pNew;
-    }
+        m_pParaIdleData_Impl->pWrong = std::move(pNew);
+}
+
+void SwTextNode::ClearWrong()
+{
+    if ( m_pParaIdleData_Impl )
+        m_pParaIdleData_Impl->pWrong.reset();
+}
+
+std::unique_ptr<SwWrongList> SwTextNode::ReleaseWrong()
+{
+    return m_pParaIdleData_Impl ? std::move(m_pParaIdleData_Impl->pWrong) : nullptr;
 }
 
 SwWrongList* SwTextNode::GetWrong()
 {
-    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pWrong : nullptr;
+    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pWrong.get() : nullptr;
 }
 
 // #i71360#
 const SwWrongList* SwTextNode::GetWrong() const
 {
-    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pWrong : nullptr;
+    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pWrong.get() : nullptr;
 }
 
-void SwTextNode::SetGrammarCheck( SwGrammarMarkUp* pNew, bool bDelete )
+void SwTextNode::SetGrammarCheck( std::unique_ptr<SwGrammarMarkUp> pNew )
 {
     if ( m_pParaIdleData_Impl )
-    {
-        if ( bDelete )
-        {
-            delete m_pParaIdleData_Impl->pGrammarCheck;
-        }
-        m_pParaIdleData_Impl->pGrammarCheck = pNew;
-    }
+        m_pParaIdleData_Impl->pGrammarCheck = std::move(pNew);
+}
+
+void SwTextNode::ClearGrammarCheck()
+{
+    if ( m_pParaIdleData_Impl )
+        m_pParaIdleData_Impl->pGrammarCheck.reset();
+}
+
+std::unique_ptr<SwGrammarMarkUp> SwTextNode::ReleaseGrammarCheck()
+{
+    return m_pParaIdleData_Impl ? std::move(m_pParaIdleData_Impl->pGrammarCheck) : nullptr;
 }
 
 SwGrammarMarkUp* SwTextNode::GetGrammarCheck()
 {
-    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pGrammarCheck : nullptr;
+    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pGrammarCheck.get() : nullptr;
 }
 
 SwWrongList const* SwTextNode::GetGrammarCheck() const
@@ -2218,24 +2221,29 @@ SwWrongList const* SwTextNode::GetGrammarCheck() const
     return static_cast<SwWrongList const*>(const_cast<SwTextNode*>(this)->GetGrammarCheck());
 }
 
-void SwTextNode::SetSmartTags( SwWrongList* pNew, bool bDelete )
+void SwTextNode::SetSmartTags( std::unique_ptr<SwWrongList> pNew )
 {
     OSL_ENSURE( !pNew || SwSmartTagMgr::Get().IsSmartTagsEnabled(),
             "Weird - we have a smart tag list without any recognizers?" );
 
     if ( m_pParaIdleData_Impl )
-    {
-        if ( bDelete )
-        {
-            delete m_pParaIdleData_Impl->pSmartTags;
-        }
-        m_pParaIdleData_Impl->pSmartTags = pNew;
-    }
+        m_pParaIdleData_Impl->pSmartTags = std::move(pNew);
+}
+
+void SwTextNode::ClearSmartTags()
+{
+    if ( m_pParaIdleData_Impl )
+        m_pParaIdleData_Impl->pSmartTags.reset();
+}
+
+std::unique_ptr<SwWrongList> SwTextNode::ReleaseSmartTags()
+{
+    return m_pParaIdleData_Impl ? std::move(m_pParaIdleData_Impl->pSmartTags) : nullptr;
 }
 
 SwWrongList* SwTextNode::GetSmartTags()
 {
-    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pSmartTags : nullptr;
+    return m_pParaIdleData_Impl ? m_pParaIdleData_Impl->pSmartTags.get() : nullptr;
 }
 
 SwWrongList const* SwTextNode::GetSmartTags() const
