@@ -59,6 +59,7 @@
 #include <unocrsrhelper.hxx>
 #include <docary.hxx>
 #include <doc.hxx>
+#include <IDocumentRedlineAccess.hxx>
 #include <IDocumentUndoRedo.hxx>
 #include <redline.hxx>
 #include <swundo.hxx>
@@ -72,7 +73,7 @@
 
 using namespace ::com::sun::star;
 
-const char cInvalidObject[] = "this object is invalid";
+constexpr OUStringLiteral cInvalidObject = u"this object is invalid";
 
 class SwXText::Impl
 {
@@ -1119,7 +1120,7 @@ SwXText::getPropertyValue(
         throw  uno::RuntimeException();
     }
 
-    SfxItemPropertySimpleEntry const*const pEntry =
+    SfxItemPropertyMapEntry const*const pEntry =
         m_pImpl->m_rPropSet.getPropertyMap().getByName(rPropertyName);
     if (!pEntry)
     {
@@ -1195,12 +1196,12 @@ SwXText::removeVetoableChangeListener(
 
 namespace
 {
-    class theSwXTextUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSwXTextUnoTunnelId > {};
 }
 
 const uno::Sequence< sal_Int8 > & SwXText::getUnoTunnelId()
 {
-    return theSwXTextUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theSwXTextUnoTunnelId;
+    return theSwXTextUnoTunnelId.getSeq();
 }
 
 sal_Int64 SAL_CALL
@@ -1537,8 +1538,8 @@ SwXText::convertToTextFrame(
         throw  uno::RuntimeException();
     }
     uno::Reference< text::XTextContent > xRet;
-    std::unique_ptr<SwUnoInternalPaM> pTempStartPam(new SwUnoInternalPaM(*GetDoc()));
-    std::unique_ptr< SwUnoInternalPaM > pEndPam(new SwUnoInternalPaM(*GetDoc()));
+    std::optional<SwUnoInternalPaM> pTempStartPam(*GetDoc());
+    std::optional<SwUnoInternalPaM> pEndPam(*GetDoc());
     if (!::sw::XTextRangeToSwPaM(*pTempStartPam, xStart) ||
         !::sw::XTextRangeToSwPaM(*pEndPam, xEnd))
     {
@@ -2078,7 +2079,7 @@ lcl_ApplyCellProperties(
             }
             catch (const uno::Exception&)
             {
-                TOOLS_WARN_EXCEPTION( "sw.uno", "Exception when getting PropertyState: " << rName );
+                TOOLS_WARN_EXCEPTION( "sw.uno", "Exception when setting cell property " << rName );
             }
         }
     }
@@ -2368,7 +2369,7 @@ SwXBodyText::queryInterface(const uno::Type& rType)
         :   ret;
 }
 
-SwXTextCursor * SwXBodyText::CreateTextCursor(const bool bIgnoreTables)
+rtl::Reference<SwXTextCursor> SwXBodyText::CreateTextCursor(const bool bIgnoreTables)
 {
     if(!IsValid())
     {
@@ -2401,8 +2402,8 @@ SwXBodyText::createTextCursor()
 {
     SolarMutexGuard aGuard;
 
-    const uno::Reference< text::XTextCursor > xRef(
-            static_cast<text::XWordCursor*>(CreateTextCursor()) );
+    const uno::Reference< text::XTextCursor > xRef =
+            static_cast<text::XWordCursor*>(CreateTextCursor().get());
     if (!xRef.is())
     {
         uno::RuntimeException aRuntime;
@@ -2538,8 +2539,7 @@ uno::Reference<text::XText> SwXHeadFootText::CreateXHeadFootText(
     uno::Reference<text::XText> xText(rHeadFootFormat.GetXObject(), uno::UNO_QUERY);
     if(!xText.is())
     {
-        const auto pXHFT(new SwXHeadFootText(rHeadFootFormat, bIsHeader));
-        xText.set(pXHFT);
+        xText = new SwXHeadFootText(rHeadFootFormat, bIsHeader);
         rHeadFootFormat.SetXObject(xText);
     }
     return xText;
@@ -2623,7 +2623,7 @@ SwXHeadFootText::createTextCursor()
     const SwFormatContent& rFlyContent = rHeadFootFormat.GetContent();
     const SwNode& rNode = rFlyContent.GetContentIdx()->GetNode();
     SwPosition aPos(rNode);
-    SwXTextCursor *const pXCursor = new SwXTextCursor(*GetDoc(), this,
+    rtl::Reference<SwXTextCursor> pXCursor = new SwXTextCursor(*GetDoc(), this,
             (m_pImpl->m_bIsHeader) ? CursorType::Header : CursorType::Footer, aPos);
     auto& rUnoCursor(pXCursor->GetCursor());
     rUnoCursor.Move(fnMoveForward, GoInNode);
@@ -2653,7 +2653,7 @@ SwXHeadFootText::createTextCursor()
         aExcept.Message = "no text available";
         throw aExcept;
     }
-    return static_cast<text::XWordCursor*>(pXCursor);
+    return static_cast<text::XWordCursor*>(pXCursor.get());
 }
 
 uno::Reference<text::XTextCursor> SAL_CALL SwXHeadFootText::createTextCursorByRange(
