@@ -118,7 +118,7 @@ void SwHTMLWrtTable::Pixelize( sal_uInt16& rValue )
         if( !aSz.Width() )
             aSz.setWidth( 1 );
         aSz = Application::GetDefaultDevice()->PixelToLogic( aSz, MapMode(MapUnit::MapTwip) );
-        rValue = static_cast<sal_uInt16>(aSz.Width());
+        rValue = o3tl::narrowing<sal_uInt16>(aSz.Width());
     }
 }
 
@@ -309,13 +309,13 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
     // output ROW- and COLSPAN
     if( nRowSpan>1 )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_rowspan).
-            append("=\"").append(static_cast<sal_Int32>(nRowSpan)).append("\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_rowspan
+                "=\"" + OString::number(nRowSpan) + "\"");
     }
     if( nColSpan > 1 )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_colspan).
-            append("=\"").append(static_cast<sal_Int32>(nColSpan)).append("\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_colspan
+                "=\"" + OString::number(nColSpan) + "\"");
     }
 
     tools::Long nWidth = 0;
@@ -367,8 +367,7 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
     // output WIDTH: from layout or calculated
     if( bOutWidth )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_width).
-            append("=\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_width "=\"");
         if( nPercentWidth != SAL_MAX_UINT32 )
         {
             sOut.append(static_cast<sal_Int32>(nPercentWidth)).append('%');
@@ -380,10 +379,16 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
         sOut.append("\"");
     }
 
+    if (rWrt.mbReqIF)
+    {
+        // ReqIF implies strict XHTML: no height for <td>.
+        nHeight = 0;
+    }
+
     if( nHeight )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_height)
-            .append("=\"").append(static_cast<sal_Int32>(aPixelSz.Height())).append("\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_height
+                "=\"" + OString::number(aPixelSz.Height()) + "\"");
     }
 
     const SfxItemSet& rItemSet = pBox->GetFrameFormat()->GetAttrSet();
@@ -397,8 +402,8 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
         sal_Int16 eVertOri = pCell->GetVertOri();
         if( text::VertOrientation::TOP==eVertOri || text::VertOrientation::BOTTOM==eVertOri )
         {
-            sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_valign)
-                .append("=\"").append(text::VertOrientation::TOP==eVertOri ?
+            sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_valign
+                    "=\"").append(text::VertOrientation::TOP==eVertOri ?
                     OOO_STRING_SVTOOLS_HTML_VA_top :
                     OOO_STRING_SVTOOLS_HTML_VA_bottom)
                 .append("\"");
@@ -424,14 +429,11 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
             // Avoid non-CSS version in the ReqIF case.
             rWrt.OutBackground( pBrushItem, false );
 
-        if (!rWrt.m_bCfgOutStyles)
-            pBrushItem = nullptr;
+        if( rWrt.m_bCfgOutStyles )
+            OutCSS1_TableBGStyleOpt( rWrt, *pBrushItem );
     }
 
-    // tdf#132739 with rWrt.m_bCfgOutStyles of true bundle the brush item css
-    // properties into the same "style" tag as the borders so there is only one
-    // style tag
-    rWrt.OutCSS1_TableCellBordersAndBG(*pBox->GetFrameFormat(), pBrushItem);
+    rWrt.OutCSS1_TableCellBorderHack(*pBox->GetFrameFormat());
 
     sal_uInt32 nNumFormat = 0;
     double nValue = 0.0;
@@ -497,7 +499,7 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
     if( rWrt.m_bLFPossible )
         rWrt.OutNewLine();
     aTag = bHead ? OOO_STRING_SVTOOLS_HTML_tableheader : OOO_STRING_SVTOOLS_HTML_tabledata;
-    HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), rWrt.GetNamespace() + aTag, false);
+    HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), OString(rWrt.GetNamespace() + aTag), false);
     rWrt.m_bLFPossible = true;
 }
 
@@ -527,7 +529,7 @@ void SwHTMLWrtTable::OutTableCells( SwHTMLWriter& rWrt,
     }
 
     rWrt.OutNewLine();  // <TR> in new line
-    rWrt.Strm().WriteChar( '<' ).WriteOString( rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow );
+    rWrt.Strm().WriteChar( '<' ).WriteOString( OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow) );
     if( pBrushItem )
     {
         rWrt.OutBackground( pBrushItem, false );
@@ -541,8 +543,8 @@ void SwHTMLWrtTable::OutTableCells( SwHTMLWriter& rWrt,
     if( text::VertOrientation::TOP==eRowVertOri || text::VertOrientation::BOTTOM==eRowVertOri )
     {
         OStringBuffer sOut;
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_valign)
-            .append("=\"").append(text::VertOrientation::TOP==eRowVertOri ? OOO_STRING_SVTOOLS_HTML_VA_top : OOO_STRING_SVTOOLS_HTML_VA_bottom)
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_valign
+                "=\"").append(text::VertOrientation::TOP==eRowVertOri ? OOO_STRING_SVTOOLS_HTML_VA_top : OOO_STRING_SVTOOLS_HTML_VA_bottom)
             .append("\"");
         rWrt.Strm().WriteOString( sOut.makeStringAndClear() );
     }
@@ -559,7 +561,7 @@ void SwHTMLWrtTable::OutTableCells( SwHTMLWriter& rWrt,
     rWrt.DecIndentLevel(); // indent content of <TR>...</TR>
 
     rWrt.OutNewLine();  // </TR> in new line
-    HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow, false );
+    HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow), false );
 }
 
 void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
@@ -625,25 +627,24 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
     // output ALIGN=
     if( text::HoriOrientation::RIGHT == eAlign )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_align).
-            append("=\"").append(OOO_STRING_SVTOOLS_HTML_AL_right).append("\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_align
+                "=\"" OOO_STRING_SVTOOLS_HTML_AL_right "\"");
     }
     else if( text::HoriOrientation::CENTER == eAlign )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_align).
-            append("=\"").append(OOO_STRING_SVTOOLS_HTML_AL_center).append("\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_align
+                "=\"" OOO_STRING_SVTOOLS_HTML_AL_center "\"");
     }
     else if( text::HoriOrientation::LEFT == eAlign )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_align).
-            append("=\"").append(OOO_STRING_SVTOOLS_HTML_AL_left).append("\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_align
+                "=\"" OOO_STRING_SVTOOLS_HTML_AL_left "\"");
     }
 
     // output WIDTH: from layout or calculated
     if( m_nTabWidth )
     {
-        sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_width).
-            append("=\"");
+        sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_width "=\"");
         if( HasRelWidths() )
             sOut.append(static_cast<sal_Int32>(m_nTabWidth)).append('%');
         else if( Application::GetDefaultDevice() )
@@ -675,24 +676,24 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
 
         if( aPixelSpc.Width() )
         {
-            sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_hspace).
-                append("=\"").append(static_cast<sal_Int32>(aPixelSpc.Width())).append("\"");
+            sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_hspace
+                    "=\"" + OString::number(aPixelSpc.Width()) + "\"");
         }
 
         if( aPixelSpc.Height() )
         {
-            sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_vspace).
-                append("=\"").append(static_cast<sal_Int32>(aPixelSpc.Height())).append("\"");
+            sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_vspace
+                    "=\"" + OString::number(aPixelSpc.Height()) + "\"");
         }
     }
 
     // output CELLPADDING: from layout or calculated
-    sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_cellpadding).
-        append("=\"").append(static_cast<sal_Int32>(SwHTMLWriter::ToPixel(m_nCellPadding,false))).append("\"");
+    sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_cellpadding
+            "=\"" + OString::number(SwHTMLWriter::ToPixel(m_nCellPadding,false)) + "\"");
 
     // output CELLSPACING: from layout or calculated
-    sOut.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_cellspacing).
-        append("=\"").append(static_cast<sal_Int32>(SwHTMLWriter::ToPixel(m_nCellSpacing,false))).append("\"");
+    sOut.append(" " OOO_STRING_SVTOOLS_HTML_O_cellspacing
+            "=\"" + OString::number(SwHTMLWriter::ToPixel(m_nCellSpacing,false)) + "\"");
 
     rWrt.Strm().WriteOString( sOut.makeStringAndClear() );
 
@@ -715,12 +716,12 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
     {
         rWrt.OutNewLine(); // <CAPTION> in new line
         OStringBuffer sOutStr(OOO_STRING_SVTOOLS_HTML_caption);
-        sOutStr.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_align).append("=\"")
+        sOutStr.append(" " OOO_STRING_SVTOOLS_HTML_O_align "=\"")
                .append(bTopCaption ? OOO_STRING_SVTOOLS_HTML_VA_top : OOO_STRING_SVTOOLS_HTML_VA_bottom)
                .append("\"");
-        HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + sOutStr.getStr() );
+        HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + sOutStr) );
         HTMLOutFuncs::Out_String( rWrt.Strm(), *pCaption, rWrt.m_eDestEnc, &rWrt.m_aNonConvertableCharacters );
-        HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_caption, false );
+        HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_caption), false );
     }
 
     const SwWriteTableCols::size_type nCols = m_aCols.size();
@@ -733,7 +734,7 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
         if( bColGroups )
         {
             rWrt.OutNewLine(); // <COLGRP> in new line
-            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup );
+            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup) );
 
             rWrt.IncIndentLevel(); // indent content of <COLGRP>
         }
@@ -761,7 +762,7 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             }
 
             if( bRel )
-                html.attribute(OOO_STRING_SVTOOLS_HTML_O_width, OString::number(nWidth) + "*");
+                html.attribute(OOO_STRING_SVTOOLS_HTML_O_width, OString(OString::number(nWidth) + "*"));
             else
                 html.attribute(OOO_STRING_SVTOOLS_HTML_O_width, OString::number(SwHTMLWriter::ToPixel(nWidth,false)));
             html.end();
@@ -770,10 +771,10 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             {
                 rWrt.DecIndentLevel(); // indent content of <COLGRP>
                 rWrt.OutNewLine(); // </COLGRP> in new line
-                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup,
+                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup),
                                             false );
                 rWrt.OutNewLine(); // <COLGRP> in new line
-                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup );
+                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup) );
                 rWrt.IncIndentLevel(); // indent content of <COLGRP>
             }
         }
@@ -782,7 +783,7 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             rWrt.DecIndentLevel(); // indent content of <COLGRP>
 
             rWrt.OutNewLine(); // </COLGRP> in new line
-            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup,
+            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_colgroup),
                                         false );
         }
     }
@@ -807,7 +808,7 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
     {
         rWrt.OutNewLine(); // <THEAD>/<TDATA> in new line
         OString aTag = bTHead ? OOO_STRING_SVTOOLS_HTML_thead : OOO_STRING_SVTOOLS_HTML_tbody;
-        HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), rWrt.GetNamespace() + aTag);
+        HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), OString(rWrt.GetNamespace() + aTag));
 
         rWrt.IncIndentLevel(); // indent content of <THEAD>/<TDATA>
     }
@@ -823,8 +824,8 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             for( auto nCnt = (pRow2->nBottomBorder / DEF_LINE_WIDTH_1) - 1; nCnt; --nCnt )
             {
                 rWrt.OutNewLine();
-                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow );
-                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow,
+                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow ));
+                HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_tablerow),
                                             false );
             }
         }
@@ -835,14 +836,14 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             rWrt.DecIndentLevel(); // indent content of <THEAD>/<TDATA>
             rWrt.OutNewLine(); // </THEAD>/</TDATA> in new line
             OString aTag = bTHead ? OOO_STRING_SVTOOLS_HTML_thead : OOO_STRING_SVTOOLS_HTML_tbody;
-            HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), rWrt.GetNamespace() + aTag, false);
+            HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), OString(rWrt.GetNamespace() + aTag), false);
             rWrt.OutNewLine(); // <THEAD>/<TDATA> in new line
 
             if( bTHead && nRow==m_nHeadEndRow )
                 bTHead = false;
 
             aTag = bTHead ? OOO_STRING_SVTOOLS_HTML_thead : OOO_STRING_SVTOOLS_HTML_tbody;
-            HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), rWrt.GetNamespace() + aTag);
+            HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), OString(rWrt.GetNamespace() + aTag));
             rWrt.IncIndentLevel(); // indent content of <THEAD>/<TDATA>
         }
     }
@@ -853,13 +854,13 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
 
         rWrt.OutNewLine(); // </THEAD>/</TDATA> in new line
         OString aTag = bTHead ? OOO_STRING_SVTOOLS_HTML_thead : OOO_STRING_SVTOOLS_HTML_tbody;
-        HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), rWrt.GetNamespace() + aTag, false);
+        HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), OString(rWrt.GetNamespace() + aTag), false);
     }
 
     rWrt.DecIndentLevel(); // indent content of <TABLE>
 
     rWrt.OutNewLine(); // </TABLE> in new line
-    HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_table, false );
+    HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_table), false );
 
     rWrt.m_nDirection = nOldDirection;
 }
@@ -914,7 +915,7 @@ Writer& OutHTML_SwTableNode( Writer& rWrt, SwTableNode & rNode,
     const SwFormatFrameSize& rFrameSize = pFormat->GetFrameSize();
     tools::Long nWidth = rFrameSize.GetSize().Width();
     sal_uInt8 nPercentWidth = rFrameSize.GetWidthPercent();
-    sal_uInt16 nBaseWidth = static_cast<sal_uInt16>(nWidth);
+    sal_uInt16 nBaseWidth = o3tl::narrowing<sal_uInt16>(nWidth);
 
     sal_Int16 eTabHoriOri = pFormat->GetHoriOrient().GetHoriOrient();
 
@@ -1009,7 +1010,7 @@ Writer& OutHTML_SwTableNode( Writer& rWrt, SwTableNode & rNode,
     {
         if( rHTMLWrt.m_bLFPossible )
             rHTMLWrt.OutNewLine();
-        HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rHTMLWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_dd );
+        HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rHTMLWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_dd) );
     }
 
     // eFlyHoriOri and eTabHoriOri now only contain the values of
@@ -1066,13 +1067,13 @@ Writer& OutHTML_SwTableNode( Writer& rWrt, SwTableNode & rNode,
         if( rHTMLWrt.m_bLFPossible )
             rHTMLWrt.OutNewLine();  // <CENTER> in new line
         if( text::HoriOrientation::CENTER==eDivHoriOri )
-            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rHTMLWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_center );
+            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rHTMLWrt.GetNamespace() + OOO_STRING_SVTOOLS_HTML_center) );
         else
         {
-            OString sOut = OOO_STRING_SVTOOLS_HTML_division
+            OStringLiteral sOut = OOO_STRING_SVTOOLS_HTML_division
                 " " OOO_STRING_SVTOOLS_HTML_O_align "=\""
                 OOO_STRING_SVTOOLS_HTML_AL_right "\"";
-            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), rHTMLWrt.GetNamespace() + sOut.getStr() );
+            HTMLOutFuncs::Out_AsciiTag( rWrt.Strm(), OString(rHTMLWrt.GetNamespace() + sOut) );
         }
         rHTMLWrt.IncIndentLevel();  // indent content of <CENTER>
         rHTMLWrt.m_bLFPossible = true;
@@ -1119,7 +1120,7 @@ Writer& OutHTML_SwTableNode( Writer& rWrt, SwTableNode & rNode,
         OString aTag = text::HoriOrientation::CENTER == eDivHoriOri
                            ? OOO_STRING_SVTOOLS_HTML_center
                            : OOO_STRING_SVTOOLS_HTML_division;
-        HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), rHTMLWrt.GetNamespace() + aTag, false);
+        HTMLOutFuncs::Out_AsciiTag(rWrt.Strm(), OString(rHTMLWrt.GetNamespace() + aTag), false);
         rHTMLWrt.m_bLFPossible = true;
     }
 
