@@ -10,6 +10,7 @@
 #include "docxsdrexport.hxx"
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/drawing/PointSequenceSequence.hpp>
+#include <com/sun/star/drawing/EnhancedCustomShapeParameterPair.hpp>
 #include <editeng/lrspitem.hxx>
 #include <editeng/ulspitem.hxx>
 #include <editeng/shaditem.hxx>
@@ -23,6 +24,7 @@
 #include <fmtcntnt.hxx>
 #include <fmtornt.hxx>
 #include <fmtfsize.hxx>
+#include <fmtfollowtextflow.hxx>
 #include <frmatr.hxx>
 #include <fmtwrapinfluenceonobjpos.hxx>
 #include "docxattributeoutput.hxx"
@@ -32,13 +34,14 @@
 #include <comphelper/sequenceashashmap.hxx>
 #include <sal/log.hxx>
 #include <frmfmt.hxx>
-#include <fmtpdsc.hxx>
 #include <IDocumentDrawModelAccess.hxx>
-#include <comphelper/propertysequence.hxx>
+
+#include <tools/diagnose_ex.h>
 #include <svx/xlnwtit.hxx>
 
 using namespace com::sun::star;
 using namespace oox;
+using namespace sax_fastparser;
 
 namespace
 {
@@ -80,14 +83,14 @@ OUString lclGetAnchorIdFromGrabBag(const SdrObject* pObj)
     return aResult;
 }
 
-void lclMovePositionWithRotation(awt::Point& aPos, const Size& rSize, sal_Int64 nRotation)
+void lclMovePositionWithRotation(awt::Point& aPos, const Size& rSize, Degree100 nRotation100)
 {
     // code from ImplEESdrWriter::ImplFlipBoundingBox (filter/source/msfilter/eschesdo.cxx)
     // TODO: refactor
 
-    if (nRotation == 0)
+    if (nRotation100 == 0_deg100)
         return;
-
+    sal_Int64 nRotation = nRotation100.get();
     if (nRotation < 0)
         nRotation = (36000 + nRotation) % 36000;
     if (nRotation % 18000 == 0)
@@ -144,13 +147,13 @@ private:
     bool m_bParagraphSdtOpen;
     bool m_bParagraphHasDrawing; ///Flag for checking drawing in a paragraph.
     rtl::Reference<sax_fastparser::FastAttributeList> m_pFlyFillAttrList;
-    sax_fastparser::FastAttributeList* m_pFlyWrapAttrList;
-    sax_fastparser::FastAttributeList* m_pBodyPrAttrList;
+    rtl::Reference<sax_fastparser::FastAttributeList> m_pFlyWrapAttrList;
+    rtl::Reference<sax_fastparser::FastAttributeList> m_pBodyPrAttrList;
     rtl::Reference<sax_fastparser::FastAttributeList> m_pDashLineStyleAttr;
     bool m_bDMLAndVMLDrawingOpen;
     /// List of TextBoxes in this document: they are exported as part of their shape, never alone.
     /// Preserved rotation for TextFrames.
-    sal_Int32 m_nDMLandVMLTextFrameRotation;
+    Degree100 m_nDMLandVMLTextFrameRotation;
 
 public:
     bool m_bFlyFrameGraphic = false;
@@ -166,10 +169,7 @@ public:
         , m_bDrawingOpen(false)
         , m_bParagraphSdtOpen(false)
         , m_bParagraphHasDrawing(false)
-        , m_pFlyWrapAttrList(nullptr)
-        , m_pBodyPrAttrList(nullptr)
         , m_bDMLAndVMLDrawingOpen(false)
-        , m_nDMLandVMLTextFrameRotation(0)
     {
     }
 
@@ -247,19 +247,23 @@ public:
         return m_pFlyFillAttrList;
     }
 
-    void setFlyWrapAttrList(sax_fastparser::FastAttributeList* pFlyWrapAttrList)
+    void
+    setFlyWrapAttrList(rtl::Reference<sax_fastparser::FastAttributeList> const& pFlyWrapAttrList)
     {
         m_pFlyWrapAttrList = pFlyWrapAttrList;
     }
 
-    sax_fastparser::FastAttributeList* getFlyWrapAttrList() const { return m_pFlyWrapAttrList; }
+    sax_fastparser::FastAttributeList* getFlyWrapAttrList() const
+    {
+        return m_pFlyWrapAttrList.get();
+    }
 
     void setBodyPrAttrList(sax_fastparser::FastAttributeList* pBodyPrAttrList)
     {
         m_pBodyPrAttrList = pBodyPrAttrList;
     }
 
-    sax_fastparser::FastAttributeList* getBodyPrAttrList() const { return m_pBodyPrAttrList; }
+    sax_fastparser::FastAttributeList* getBodyPrAttrList() const { return m_pBodyPrAttrList.get(); }
 
     rtl::Reference<sax_fastparser::FastAttributeList>& getDashLineStyleAttr()
     {
@@ -272,12 +276,12 @@ public:
 
     DocxExport& getExport() const { return m_rExport; }
 
-    void setDMLandVMLTextFrameRotation(sal_Int32 nDMLandVMLTextFrameRotation)
+    void setDMLandVMLTextFrameRotation(Degree100 nDMLandVMLTextFrameRotation)
     {
         m_nDMLandVMLTextFrameRotation = nDMLandVMLTextFrameRotation;
     }
 
-    sal_Int32& getDMLandVMLTextFrameRotation() { return m_nDMLandVMLTextFrameRotation; }
+    Degree100& getDMLandVMLTextFrameRotation() { return m_nDMLandVMLTextFrameRotation; }
 };
 
 DocxSdrExport::DocxSdrExport(DocxExport& rExport, const sax_fastparser::FSHelperPtr& pSerializer,
@@ -342,7 +346,8 @@ rtl::Reference<sax_fastparser::FastAttributeList>& DocxSdrExport::getDashLineSty
     return m_pImpl->getDashLineStyleAttr();
 }
 
-void DocxSdrExport::setFlyWrapAttrList(sax_fastparser::FastAttributeList* pAttrList)
+void DocxSdrExport::setFlyWrapAttrList(
+    rtl::Reference<sax_fastparser::FastAttributeList> const& pAttrList)
 {
     m_pImpl->setFlyWrapAttrList(pAttrList);
 }
@@ -423,13 +428,13 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
 
     if (isAnchor)
     {
-        sax_fastparser::FastAttributeList* attrList
+        rtl::Reference<sax_fastparser::FastAttributeList> attrList
             = sax_fastparser::FastSerializerHelper::createAttrList();
         bool bOpaque = pFrameFormat->GetOpaque().GetValue();
         awt::Point aPos(pFrameFormat->GetHoriOrient().GetPos(),
                         pFrameFormat->GetVertOrient().GetPos());
         const SdrObject* pObj = pFrameFormat->FindRealSdrObject();
-        tools::Long nRotation = 0;
+        Degree100 nRotation(0);
         if (pObj != nullptr)
         {
             // SdrObjects know their layer, consider that instead of the frame format.
@@ -507,8 +512,7 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
                 attrList->addNS(XML_wp14, XML_anchorId,
                                 OUStringToOString(sAnchorId, RTL_TEXTENCODING_UTF8));
         }
-        sax_fastparser::XFastAttributeListRef xAttrList(attrList);
-        m_pImpl->getSerializer()->startElementNS(XML_wp, XML_anchor, xAttrList);
+        m_pImpl->getSerializer()->startElementNS(XML_wp, XML_anchor, attrList);
         m_pImpl->getSerializer()->singleElementNS(XML_wp, XML_simplePos, XML_x, "0", XML_y,
                                                   "0"); // required, unused
         const char* relativeFromH;
@@ -664,7 +668,7 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
             && (!alignV || strcmp(alignV, "top") == 0))
         {
             alignV = nullptr;
-            nPosYEMU = 635;
+            nPosYEMU = TwipsToEMU(1);
         }
 
         if (alignV != nullptr)
@@ -691,7 +695,7 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
     }
     else
     {
-        sax_fastparser::FastAttributeList* aAttrList
+        rtl::Reference<sax_fastparser::FastAttributeList> aAttrList
             = sax_fastparser::FastSerializerHelper::createAttrList();
         aAttrList->add(XML_distT, OString::number(TwipsToEMU(aULSpaceItem.GetUpper())).getStr());
         aAttrList->add(XML_distB, OString::number(TwipsToEMU(aULSpaceItem.GetLower())).getStr());
@@ -806,6 +810,85 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
                 m_pImpl->getSerializer()->endElementNS(XML_wp, nWrapToken);
             }
         }
+        else if (SdrObject* pSdrObj = const_cast<SdrObject*>(pFrameFormat->FindRealSdrObject()))
+        {
+            // In this case we likely had an odt document to be exported to docx.
+            // There is no grab-bag or something else so for a workaround,
+            // let's export the geometry of the shape...
+            // First get the UNO-shape
+            uno::Reference<drawing::XShape> xShape(pSdrObj->getUnoShape(), uno::UNO_QUERY);
+
+            if (xShape && xShape->getShapeType() == u"com.sun.star.drawing.CustomShape")
+            {
+                try
+                {
+                    // Get the properties of the Xshape
+                    uno::Reference<beans::XPropertySet> XProps(xShape, uno::UNO_QUERY);
+                    // Get the "CustomShapeGeometry" property and from its Any() make a hashMap
+                    comphelper::SequenceAsHashMap aCustomShapeGeometry(
+                        XProps->getPropertyValue("CustomShapeGeometry"));
+                    // Get the "Path" property and from its Any() make a hashMap
+                    comphelper::SequenceAsHashMap aPath(aCustomShapeGeometry.getValue("Path"));
+                    // From the Any() of the "Coordinates" property get the points
+                    uno::Sequence<css::drawing::EnhancedCustomShapeParameterPair> aCoords
+                        = aPath.getValue("Coordinates")
+                              .get<uno::Sequence<css::drawing::EnhancedCustomShapeParameterPair>>();
+
+                    // Check if only one side wrap allowed
+                    OUString sWrapType;
+                    switch (pFrameFormat->GetSurround().GetSurround())
+                    {
+                        case text::WrapTextMode_DYNAMIC:
+                            sWrapType = OUString("largest");
+                            break;
+                        case text::WrapTextMode_LEFT:
+                            sWrapType = OUString("left");
+                            break;
+                        case text::WrapTextMode_RIGHT:
+                            sWrapType = OUString("right");
+                            break;
+                        case text::WrapTextMode_PARALLEL:
+                        default:
+                            sWrapType = OUString("bothSides");
+                            break;
+                    }
+
+                    // And export:
+                    nWrapToken = XML_wrapTight;
+                    m_pImpl->getSerializer()->startElementNS(XML_wp, nWrapToken, XML_wrapText,
+                                                             sWrapType);
+
+                    m_pImpl->getSerializer()->startElementNS(XML_wp, XML_wrapPolygon, XML_edited,
+                                                             "0");
+
+                    try
+                    {
+                        // There are the coordinates
+                        for (sal_Int32 i = 0; i < aCoords.getLength(); i++)
+                            m_pImpl->getSerializer()->singleElementNS(
+                                XML_wp, (i == 0 ? XML_start : XML_lineTo), XML_x,
+                                OString::number(aCoords[i].First.Value.get<double>()), XML_y,
+                                OString::number(aCoords[i].Second.Value.get<double>()));
+                    }
+                    catch (const uno::Exception& e)
+                    {
+                        // e.g. on exporting first attachment of tdf#94591 to docx
+                        TOOLS_WARN_EXCEPTION(
+                            "sw.ww8",
+                            "DocxSdrExport::startDMLAnchorInline: bad coordinate: " << e.Message);
+                    }
+
+                    m_pImpl->getSerializer()->endElementNS(XML_wp, XML_wrapPolygon);
+
+                    m_pImpl->getSerializer()->endElementNS(XML_wp, nWrapToken);
+                }
+                catch (uno::Exception& e)
+                {
+                    TOOLS_WARN_EXCEPTION(
+                        "sw.ww8", "DocxSdrExport::startDMLAnchorInline: exception: " << e.Message);
+                }
+            }
+        }
     }
 
     // No? Then just approximate based on what we have.
@@ -855,15 +938,15 @@ void DocxSdrExport::writeVMLDrawing(const SdrObject* sdrObj, const SwFrameFormat
     m_pImpl->getDrawingML()->SetFS(m_pImpl->getSerializer());
     // See WinwordAnchoring::SetAnchoring(), these are not part of the SdrObject, have to be passed around manually.
 
+    SwFormatFollowTextFlow const& rFlow(rFrameFormat.GetFollowTextFlow());
     const SwFormatHoriOrient& rHoriOri = rFrameFormat.GetHoriOrient();
     const SwFormatVertOrient& rVertOri = rFrameFormat.GetVertOrient();
     SwFormatSurround const& rSurround(rFrameFormat.GetSurround());
 
-    std::unique_ptr<sax_fastparser::FastAttributeList> pAttrList(
-        docx::SurroundToVMLWrap(rSurround));
+    rtl::Reference<sax_fastparser::FastAttributeList> pAttrList(docx::SurroundToVMLWrap(rSurround));
     m_pImpl->getExport().VMLExporter().AddSdrObject(
-        *sdrObj, rHoriOri.GetHoriOrient(), rVertOri.GetVertOrient(), rHoriOri.GetRelationOrient(),
-        rVertOri.GetRelationOrient(), std::move(pAttrList), true);
+        *sdrObj, rFlow.GetValue(), rHoriOri.GetHoriOrient(), rVertOri.GetVertOrient(),
+        rHoriOri.GetRelationOrient(), rVertOri.GetRelationOrient(), pAttrList.get(), true);
     m_pImpl->getSerializer()->endElementNS(XML_w, XML_pict);
 }
 
@@ -893,11 +976,10 @@ void DocxSdrExport::writeDMLDrawing(const SdrObject* pSdrObject, const SwFrameFo
     Size aSize(pSdrObject->GetLogicRect().GetWidth(), pSdrObject->GetLogicRect().GetHeight());
     startDMLAnchorInline(pFrameFormat, aSize);
 
-    sax_fastparser::FastAttributeList* pDocPrAttrList
+    rtl::Reference<sax_fastparser::FastAttributeList> pDocPrAttrList
         = sax_fastparser::FastSerializerHelper::createAttrList();
     pDocPrAttrList->add(XML_id, OString::number(nAnchorId).getStr());
-    pDocPrAttrList->add(XML_name,
-                        OUStringToOString(pSdrObject->GetName(), RTL_TEXTENCODING_UTF8).getStr());
+    pDocPrAttrList->add(XML_name, OUStringToOString(pSdrObject->GetName(), RTL_TEXTENCODING_UTF8));
     if (!pSdrObject->GetTitle().isEmpty())
         pDocPrAttrList->add(XML_title,
                             OUStringToOString(pSdrObject->GetTitle(), RTL_TEXTENCODING_UTF8));
@@ -908,8 +990,7 @@ void DocxSdrExport::writeDMLDrawing(const SdrObject* pSdrObject, const SwFrameFo
         && pFrameFormat->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR)
 
         pDocPrAttrList->add(XML_hidden, OString::number(1).getStr());
-    sax_fastparser::XFastAttributeListRef xDocPrAttrListRef(pDocPrAttrList);
-    pFS->singleElementNS(XML_wp, XML_docPr, xDocPrAttrListRef);
+    pFS->singleElementNS(XML_wp, XML_docPr, pDocPrAttrList);
 
     uno::Reference<lang::XServiceInfo> xServiceInfo(xShape, uno::UNO_QUERY_THROW);
     const char* pNamespace = "http://schemas.microsoft.com/office/word/2010/wordprocessingShape";
@@ -1093,12 +1174,12 @@ void DocxSdrExport::writeDMLAndVMLDrawing(const SdrObject* sdrObj,
 }
 
 // Converts ARGB transparency (0..255) to drawingml alpha (opposite, and 0..100000)
-static OString lcl_ConvertTransparency(const Color& rColor)
+static OString lcl_TransparencyToDrawingMlAlpha(const Color& rColor)
 {
-    if (rColor.GetTransparency() > 0)
+    if (rColor.IsTransparent())
     {
-        sal_Int32 nTransparencyPercent = 100 - float(rColor.GetTransparency()) / 2.55;
-        return OString::number(nTransparencyPercent * oox::drawingml::PER_PERCENT);
+        sal_Int32 nAlphaPercent = float(rColor.GetAlpha()) / 2.55;
+        return OString::number(nAlphaPercent * oox::drawingml::PER_PERCENT);
     }
 
     return OString();
@@ -1117,7 +1198,7 @@ void DocxSdrExport::writeDMLEffectLst(const SwFrameFormat& rFrameFormat)
         = sqrt(static_cast<double>(aShadowItem.GetWidth()) * aShadowItem.GetWidth() * 2.0);
     OString aShadowDist(OString::number(TwipsToEMU(nShadowDist)));
     OString aShadowColor = msfilter::util::ConvertColor(aShadowItem.GetColor());
-    OString aShadowAlpha = lcl_ConvertTransparency(aShadowItem.GetColor());
+    OString aShadowAlpha = lcl_TransparencyToDrawingMlAlpha(aShadowItem.GetColor());
     sal_uInt32 nShadowDir = 0;
     switch (aShadowItem.GetLocation())
     {
@@ -1180,7 +1261,7 @@ void DocxSdrExport::writeOnlyTextOfFrame(ww8::Frame const* pParentFrame)
     //Save data here and restore when out of scope
     ExportDataSaveRestore aDataGuard(m_pImpl->getExport(), nStt, nEnd, pParentFrame);
 
-    m_pImpl->setBodyPrAttrList(sax_fastparser::FastSerializerHelper::createAttrList());
+    m_pImpl->setBodyPrAttrList(sax_fastparser::FastSerializerHelper::createAttrList().get());
     ::comphelper::FlagRestorationGuard const g(m_pImpl->m_bFlyFrameGraphic, true);
     comphelper::ValueRestorationGuard vg(m_pImpl->getExport().m_nTextTyp, TXT_TXTBOX);
     m_pImpl->getExport().WriteText();
@@ -1258,7 +1339,7 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
     if (xPropertySet.is())
         xPropSetInfo = xPropertySet->getPropertySetInfo();
 
-    m_pImpl->setBodyPrAttrList(sax_fastparser::FastSerializerHelper::createAttrList());
+    m_pImpl->setBodyPrAttrList(sax_fastparser::FastSerializerHelper::createAttrList().get());
     {
         drawing::TextVerticalAdjust eAdjust = drawing::TextVerticalAdjust_TOP;
         if (xPropSetInfo.is() && xPropSetInfo->hasPropertyByName("TextVerticalAdjust"))
@@ -1271,13 +1352,12 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
     {
         startDMLAnchorInline(&rFrameFormat, aSize);
 
-        sax_fastparser::FastAttributeList* pDocPrAttrList
+        rtl::Reference<sax_fastparser::FastAttributeList> pDocPrAttrList
             = sax_fastparser::FastSerializerHelper::createAttrList();
         pDocPrAttrList->add(XML_id, OString::number(nAnchorId).getStr());
-        pDocPrAttrList->add(
-            XML_name, OUStringToOString(rFrameFormat.GetName(), RTL_TEXTENCODING_UTF8).getStr());
-        sax_fastparser::XFastAttributeListRef xDocPrAttrListRef(pDocPrAttrList);
-        pFS->singleElementNS(XML_wp, XML_docPr, xDocPrAttrListRef);
+        pDocPrAttrList->add(XML_name,
+                            OUStringToOString(rFrameFormat.GetName(), RTL_TEXTENCODING_UTF8));
+        pFS->singleElementNS(XML_wp, XML_docPr, pDocPrAttrList);
 
         pFS->startElementNS(XML_a, XML_graphic, FSNS(XML_xmlns, XML_a),
                             m_pImpl->getExport().GetFilter().getNamespaceURL(OOX_NS(dml)));
@@ -1287,7 +1367,7 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
         pFS->singleElementNS(XML_wps, XML_cNvSpPr, XML_txBox, "1");
 
         uno::Any aRotation;
-        m_pImpl->setDMLandVMLTextFrameRotation(0);
+        m_pImpl->setDMLandVMLTextFrameRotation(0_deg100);
         if (xPropSetInfo.is() && xPropSetInfo->hasPropertyByName("FrameInteropGrabBag"))
         {
             uno::Sequence<beans::PropertyValue> propList;
@@ -1299,7 +1379,9 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
             if (pProp != propList.end())
                 aRotation = pProp->Value;
         }
-        aRotation >>= m_pImpl->getDMLandVMLTextFrameRotation();
+        sal_Int32 nTmp;
+        if (aRotation >>= nTmp)
+            m_pImpl->getDMLandVMLTextFrameRotation() = Degree100(nTmp);
         OString sRotation(OString::number(
             oox::drawingml::ExportRotateClockwisify(m_pImpl->getDMLandVMLTextFrameRotation())));
         // Shape properties
@@ -1466,7 +1548,7 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
             m_pImpl->getBodyPrAttrList()->add(XML_bIns, OString::number(0));
     }
 
-    sax_fastparser::XFastAttributeListRef xBodyPrAttrList(m_pImpl->getBodyPrAttrList());
+    rtl::Reference<FastAttributeList> xBodyPrAttrList(m_pImpl->getBodyPrAttrList());
     m_pImpl->setBodyPrAttrList(nullptr);
     if (!bTextBoxOnly)
     {
@@ -1539,12 +1621,8 @@ void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bText
     m_pImpl->getTextFrameStyle() = "position:absolute";
     if (!bTextBoxOnly)
     {
-        OString sRotation(OString::number(m_pImpl->getDMLandVMLTextFrameRotation() / -100));
-        m_pImpl->getExport()
-            .SdrExporter()
-            .getTextFrameStyle()
-            .append(";rotation:")
-            .append(sRotation);
+        OString sRotation(OString::number(m_pImpl->getDMLandVMLTextFrameRotation().get() / -100));
+        m_pImpl->getExport().SdrExporter().getTextFrameStyle().append(";rotation:" + sRotation);
     }
     m_pImpl->getExport().OutputFormat(pParentFrame->GetFrameFormat(), false, false, true);
     m_pImpl->getFlyAttrList()->add(XML_style, m_pImpl->getTextFrameStyle().makeStringAndClear());
@@ -1557,9 +1635,9 @@ void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bText
             m_pImpl->getFlyAttrList()->addNS(XML_w14, XML_anchorId,
                                              OUStringToOString(sAnchorId, RTL_TEXTENCODING_UTF8));
     }
-    sax_fastparser::XFastAttributeListRef xFlyAttrList(m_pImpl->getFlyAttrList().get());
+    rtl::Reference<FastAttributeList> xFlyAttrList(m_pImpl->getFlyAttrList());
     m_pImpl->getFlyAttrList().clear();
-    sax_fastparser::XFastAttributeListRef xTextboxAttrList(m_pImpl->getTextboxAttrList().get());
+    rtl::Reference<FastAttributeList> xTextboxAttrList(m_pImpl->getTextboxAttrList());
     m_pImpl->getTextboxAttrList().clear();
     m_pImpl->setTextFrameSyntax(false);
     m_pImpl->setFlyFrameSize(nullptr);
@@ -1572,15 +1650,13 @@ void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bText
         m_pImpl->textFrameShadow(rFrameFormat);
         if (m_pImpl->getFlyFillAttrList().is())
         {
-            sax_fastparser::XFastAttributeListRef xFlyFillAttrList(
-                m_pImpl->getFlyFillAttrList().get());
+            rtl::Reference<FastAttributeList> xFlyFillAttrList(m_pImpl->getFlyFillAttrList());
             m_pImpl->getFlyFillAttrList().clear();
             pFS->singleElementNS(XML_v, XML_fill, xFlyFillAttrList);
         }
         if (m_pImpl->getDashLineStyleAttr().is())
         {
-            sax_fastparser::XFastAttributeListRef xDashLineStyleAttr(
-                m_pImpl->getDashLineStyleAttr().get());
+            rtl::Reference<FastAttributeList> xDashLineStyleAttr(m_pImpl->getDashLineStyleAttr());
             m_pImpl->getDashLineStyleAttr().clear();
             pFS->singleElementNS(XML_v, XML_stroke, xDashLineStyleAttr);
         }
@@ -1604,7 +1680,7 @@ void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bText
 
         if (m_pImpl->getFlyWrapAttrList())
         {
-            sax_fastparser::XFastAttributeListRef xFlyWrapAttrList(m_pImpl->getFlyWrapAttrList());
+            rtl::Reference<FastAttributeList> xFlyWrapAttrList(m_pImpl->getFlyWrapAttrList());
             m_pImpl->setFlyWrapAttrList(nullptr);
             pFS->singleElementNS(XML_w10, XML_wrap, xFlyWrapAttrList);
         }
