@@ -231,9 +231,9 @@ RedlineInfo::~RedlineInfo()
     delete pNextRedline;
 }
 
-const char g_sShowChanges[] = "ShowChanges";
-const char g_sRecordChanges[] = "RecordChanges";
-const char g_sRedlineProtectionKey[] = "RedlineProtectionKey";
+constexpr OUStringLiteral g_sShowChanges = u"ShowChanges";
+constexpr OUStringLiteral g_sRecordChanges = u"RecordChanges";
+constexpr OUStringLiteral g_sRedlineProtectionKey = u"RedlineProtectionKey";
 
 XMLRedlineImportHelper::XMLRedlineImportHelper(
     SvXMLImport & rImport,
@@ -374,7 +374,7 @@ XMLRedlineImportHelper::~XMLRedlineImportHelper()
 }
 
 void XMLRedlineImportHelper::Add(
-    const OUString& rType,
+    std::u16string_view rType,
     const OUString& rId,
     const OUString& rAuthor,
     const OUString& rComment,
@@ -476,11 +476,11 @@ Reference<XTextCursor> XMLRedlineImportHelper::CreateRedlineTextSection(
 
         // create (UNO-) cursor
         SwPosition aPos(*pRedlineNode);
-        SwXTextCursor *const pXCursor =
-            new SwXTextCursor(*pDoc, pXText.get(), CursorType::Redline, aPos);
+        rtl::Reference<SwXTextCursor> pXCursor =
+            new SwXTextCursor(*pDoc, pXText, CursorType::Redline, aPos);
         pXCursor->GetCursor().Move(fnMoveForward, GoInNode);
         // cast to avoid ambiguity
-        xReturn = static_cast<text::XWordCursor*>(pXCursor);
+        xReturn = static_cast<text::XWordCursor*>(pXCursor.get());
     }
     // else: unknown redline -> Ignore
 
@@ -628,7 +628,7 @@ void XMLRedlineImportHelper::InsertIntoDocument(RedlineInfo* pRedlineInfo)
              && (pTempNode = pDoc->GetNodes()[pRedlineInfo->pContentIndex->GetIndex() + 1]->GetTextNode()) != nullptr
              && pTempNode->GetText().isEmpty()
              && !pTempNode->GetpSwpHints()
-             && !pTempNode->GetAnchoredFlys()))
+             && pTempNode->GetAnchoredFlys().empty()))
     {
         // ignore redline (e.g. file loaded in insert mode):
         // delete 'deleted' redlines and forget about the whole thing
