@@ -50,6 +50,7 @@
 #include "xmltexte.hxx"
 #include "xmlexp.hxx"
 #include "xmlexpit.hxx"
+#include "zorder.hxx"
 #include <comphelper/processfactory.hxx>
 #include <docary.hxx>
 #include <frameformats.hxx>
@@ -104,7 +105,7 @@ ErrCode SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
         Reference<XPropertySet> rInfoSet = getExportInfo();
         if( rInfoSet.is() )
         {
-            const OUString sAutoTextMode("AutoTextMode");
+            static const OUStringLiteral sAutoTextMode(u"AutoTextMode");
             if( rInfoSet->getPropertySetInfo()->hasPropertyByName(
                         sAutoTextMode ) )
             {
@@ -232,7 +233,7 @@ ErrCode SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     if (!GetGraphicStorageHandler().is())
     {
         xGraphicStorageHandler = SvXMLGraphicHelper::Create(SvXMLGraphicHelperMode::Write, GetImageFilterName());
-        SetGraphicStorageHandler(xGraphicStorageHandler.get());
+        SetGraphicStorageHandler(xGraphicStorageHandler);
     }
 
     rtl::Reference<SvXMLEmbeddedObjectHelper> xEmbeddedResolver;
@@ -244,7 +245,7 @@ ErrCode SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
             xEmbeddedResolver = SvXMLEmbeddedObjectHelper::Create(
                                             *pPersist,
                                             SvXMLEmbeddedObjectHelperMode::Write );
-            SetEmbeddedResolver( Reference<XEmbeddedObjectResolver>( xEmbeddedResolver.get() ) );
+            SetEmbeddedResolver( xEmbeddedResolver );
         }
     }
 
@@ -269,6 +270,11 @@ ErrCode SwXMLExport::exportDoc( enum XMLTokenEnum eClass )
     m_bSavedShowChanges = pLayout == nullptr || !pLayout->IsHideRedlines();
     if( bSaveRedline )
     {
+        // tdf#133487 call this once in flat-ODF case
+        uno::Reference<drawing::XDrawPageSupplier> const xDPS(GetModel(), uno::UNO_QUERY);
+        assert(xDPS.is());
+        xmloff::FixZOrder(xDPS->getDrawPage(), sw::GetZOrderLayer(m_pDoc->getIDocumentDrawModelAccess()));
+
         // now save and switch redline mode
         nRedlineFlags = pDoc->getIDocumentRedlineAccess().GetRedlineFlags();
         pDoc->getIDocumentRedlineAccess().SetRedlineFlags(
@@ -361,7 +367,7 @@ void SwXMLExport::GetViewSettings(Sequence<PropertyValue>& aProps)
     Reference<XPropertySet> xInfoSet( getExportInfo() );
     if ( xInfoSet.is() )
     {
-        const OUString sShowChanges( "ShowChanges" );
+        static const OUStringLiteral sShowChanges( u"ShowChanges" );
         if( xInfoSet->getPropertySetInfo()->hasPropertyByName( sShowChanges ) )
         {
             bShowRedlineChanges = *o3tl::doAccess<bool>(xInfoSet->
@@ -469,14 +475,10 @@ void SwXMLExport::ExportContent_()
     GetTextParagraphExport()->exportText( xText, m_bShowProgress );
 }
 
-namespace
+const Sequence< sal_Int8 > & SwXMLExport::getUnoTunnelId() noexcept
 {
-    class theSwXMLExportUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSwXMLExportUnoTunnelId > {};
-}
-
-const Sequence< sal_Int8 > & SwXMLExport::getUnoTunnelId() throw()
-{
-    return theSwXMLExportUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theSwXMLExportUnoTunnelId;
+    return theSwXMLExportUnoTunnelId.getSeq();
 }
 
 sal_Int64 SAL_CALL SwXMLExport::getSomething( const Sequence< sal_Int8 >& rId )
