@@ -27,6 +27,7 @@
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
 #include <o3tl/any.hxx>
+#include <osl/diagnose.h>
 #include <rtl/ustrbuf.hxx>
 #include <sal/log.hxx>
 #include <comphelper/classids.hxx>
@@ -179,11 +180,10 @@ SwXMLTextImportHelper::~SwXMLTextImportHelper()
 
 SvXMLImportContext *SwXMLTextImportHelper::CreateTableChildContext(
                 SvXMLImport& rImport,
-                sal_uInt16 nPrefix, const OUString& rLocalName,
-                const uno::Reference< XAttributeList > & xAttrList )
+                sal_Int32 /*nElement*/,
+                const uno::Reference< XFastAttributeList > & xAttrList )
 {
-    return new SwXMLTableContext(
-                static_cast<SwXMLImport&>(rImport), nPrefix, rLocalName, xAttrList );
+    return new SwXMLTableContext( static_cast<SwXMLImport&>(rImport), xAttrList );
 }
 
 bool SwXMLTextImportHelper::IsInHeaderFooter() const
