@@ -42,8 +42,6 @@ SwCondCollPage::SwCondCollPage(weld::Container* pPage, weld::DialogController* p
     , m_rSh(::GetActiveView()->GetWrtShell())
     , m_pCmds(SwCondCollItem::GetCmds())
     , m_pFormat(nullptr)
-    , m_bNewTemplate(false)
-    , m_xConditionCB(m_xBuilder->weld_check_button("condstyle"))
     , m_xTbLinks(m_xBuilder->weld_tree_view("links"))
     , m_xStyleLB(m_xBuilder->weld_tree_view("styles"))
     , m_xFilterLB(m_xBuilder->weld_combo_box("filter"))
@@ -66,7 +64,6 @@ SwCondCollPage::SwCondCollPage(weld::Container* pPage, weld::DialogController* p
     SetExchangeSupport();
 
     // Install handlers
-    m_xConditionCB->connect_toggled(LINK(this, SwCondCollPage, OnOffHdl));
     m_xTbLinks->connect_row_activated(LINK(this, SwCondCollPage, AssignRemoveTreeListBoxHdl));
     m_xStyleLB->connect_row_activated(LINK(this, SwCondCollPage, AssignRemoveTreeListBoxHdl));
     m_xRemovePB->connect_clicked(LINK(this, SwCondCollPage, AssignRemoveClickHdl));
@@ -75,7 +72,7 @@ SwCondCollPage::SwCondCollPage(weld::Container* pPage, weld::DialogController* p
     m_xStyleLB->connect_changed(LINK(this, SwCondCollPage, SelectTreeListBoxHdl));
     m_xFilterLB->connect_changed(LINK(this, SwCondCollPage, SelectListBoxHdl));
 
-    std::unique_ptr<SfxStyleFamilies> xFamilies(SW_MOD()->CreateStyleFamilies());
+    std::optional<SfxStyleFamilies> xFamilies(SW_MOD()->CreateStyleFamilies());
     size_t nCount = xFamilies->size();
     for (size_t j = 0; j < nCount; ++j)
     {
@@ -124,12 +121,6 @@ bool SwCondCollPage::FillItemSet(SfxItemSet *rSet)
 
 void SwCondCollPage::Reset(const SfxItemSet *)
 {
-    if (m_bNewTemplate)
-        m_xConditionCB->set_sensitive(true);
-    if (RES_CONDTXTFMTCOLL == m_pFormat->Which())
-        m_xConditionCB->set_active(true);
-    OnOffHdl(*m_xConditionCB);
-
     m_xTbLinks->clear();
 
     SfxStyleSheetBasePool* pPool = m_rSh.GetView().GetDocShell()->GetStyleSheetPool();
@@ -164,18 +155,6 @@ void SwCondCollPage::Reset(const SfxItemSet *)
     }
 }
 
-IMPL_LINK(SwCondCollPage, OnOffHdl, weld::ToggleButton&, rBox, void)
-{
-    const bool bEnable = rBox.get_active();
-    m_xTbLinks->set_sensitive(bEnable);
-    m_xStyleLB->set_sensitive(bEnable);
-    m_xFilterLB->set_sensitive(bEnable);
-    m_xRemovePB->set_sensitive(bEnable);
-    m_xAssignPB->set_sensitive(bEnable);
-    if (bEnable)
-        SelectHdl(nullptr);
-}
-
 IMPL_LINK(SwCondCollPage, AssignRemoveClickHdl, weld::Button&, rBtn, void)
 {
     AssignRemove(&rBtn);
@@ -245,17 +224,16 @@ void SwCondCollPage::SelectHdl(const weld::Widget* pBox)
             : OUString();
         const OUString sStyle = m_xStyleLB->get_selected_text();
 
-        m_xAssignPB->set_sensitive(sStyle != sTbEntry && m_xConditionCB->get_active());
+        m_xAssignPB->set_sensitive(sStyle != sTbEntry);
 
         if (pBox != m_xStyleLB.get())
-            m_xRemovePB->set_sensitive(m_xConditionCB->get_active() && !sTbEntry.isEmpty());
+            m_xRemovePB->set_sensitive(!sTbEntry.isEmpty());
     }
 }
 
-void SwCondCollPage::SetCollection(SwFormat* pFormat, bool bNew)
+void SwCondCollPage::SetCollection(SwFormat* pFormat)
 {
     m_pFormat = pFormat;
-    m_bNewTemplate = bNew;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
