@@ -44,7 +44,6 @@
 #include <mmaddressblockpage.hrc>
 #include <helpids.h>
 
-using namespace svt;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::sdb;
@@ -68,8 +67,8 @@ SwMailMergeAddressBlockPage::SwMailMergeAddressBlockPage(weld::Container* pPage,
     , m_xPrevSetIB(m_xBuilder->weld_button("prev"))
     , m_xNextSetIB(m_xBuilder->weld_button("next"))
     , m_xDifferentlist(m_xBuilder->weld_button("differentlist"))
-    , m_xSettings(new SwAddressPreview(m_xBuilder->weld_scrolled_window("settingspreviewwin")))
-    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("addresspreviewwin")))
+    , m_xSettings(new SwAddressPreview(m_xBuilder->weld_scrolled_window("settingspreviewwin", true)))
+    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("addresspreviewwin", true)))
     , m_xSettingsWIN(new weld::CustomWeld(*m_xBuilder, "settingspreview", *m_xSettings))
     , m_xPreviewWIN(new weld::CustomWeld(*m_xBuilder, "addresspreview", *m_xPreview))
 {
@@ -129,22 +128,22 @@ void SwMailMergeAddressBlockPage::Activate()
     m_xStep3->set_visible(bIsLetter);
     m_xStep4->set_visible(bIsLetter);
 
-    if (bIsLetter)
-    {
-        m_xHideEmptyParagraphsCB->set_active( rConfigItem.IsHideEmptyParagraphs() );
-        m_xDocumentIndexFI->set_label(m_sDocument.replaceFirst("%1", "1"));
+    if (!bIsLetter)
+        return;
 
-        m_xSettings->Clear();
-        const uno::Sequence< OUString> aBlocks =
-                    m_pWizard->GetConfigItem().GetAddressBlocks();
-        for(const auto& rAddress : aBlocks)
-            m_xSettings->AddAddress(rAddress);
-        m_xSettings->SelectAddress(static_cast<sal_uInt16>(rConfigItem.GetCurrentAddressBlockIndex()));
-        m_xAddressCB->set_active(rConfigItem.IsAddressBlock());
-        AddressBlockHdl_Impl(*m_xAddressCB);
-        m_xSettings->SetLayout(1, 2);
-        InsertDataHdl(nullptr);
-    }
+    m_xHideEmptyParagraphsCB->set_active( rConfigItem.IsHideEmptyParagraphs() );
+    m_xDocumentIndexFI->set_label(m_sDocument.replaceFirst("%1", "1"));
+
+    m_xSettings->Clear();
+    const uno::Sequence< OUString> aBlocks =
+                m_pWizard->GetConfigItem().GetAddressBlocks();
+    for(const auto& rAddress : aBlocks)
+        m_xSettings->AddAddress(rAddress);
+    m_xSettings->SelectAddress(o3tl::narrowing<sal_uInt16>(rConfigItem.GetCurrentAddressBlockIndex()));
+    m_xAddressCB->set_active(rConfigItem.IsAddressBlock());
+    AddressBlockHdl_Impl(*m_xAddressCB);
+    m_xSettings->SetLayout(1, 2);
+    InsertDataHdl(nullptr);
 }
 
 bool SwMailMergeAddressBlockPage::commitPage( ::vcl::WizardTypes::CommitPageReason _eReason )
@@ -231,7 +230,7 @@ void SwMailMergeAddressBlockPage::EnableAddressBlock(bool bAll, bool bSelective)
     m_xStep4->set_sensitive(bSelective);
 }
 
-IMPL_LINK(SwMailMergeAddressBlockPage, AddressBlockHdl_Impl, weld::ToggleButton&, rBox, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, AddressBlockHdl_Impl, weld::Toggleable&, rBox, void)
 {
     EnableAddressBlock(rBox.get_sensitive(), rBox.get_active());
     SwMailMergeConfigItem& rConfigItem = m_pWizard->GetConfigItem();
@@ -252,7 +251,7 @@ IMPL_LINK_NOARG(SwMailMergeAddressBlockPage, AddressBlockSelectHdl_Impl, LinkPar
     GetWizard()->enableButtons(WizardButtonFlags::NEXT, GetWizard()->isStateEnabled(MM_GREETINGSPAGE));
 }
 
-IMPL_LINK(SwMailMergeAddressBlockPage, HideParagraphsHdl_Impl, weld::ToggleButton&, rBox, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, HideParagraphsHdl_Impl, weld::Toggleable&, rBox, void)
 {
     SwMailMergeConfigItem& rConfigItem = m_pWizard->GetConfigItem();
     rConfigItem.SetHideEmptyParagraphs(rBox.get_active());
@@ -315,7 +314,7 @@ IMPL_LINK(SwMailMergeAddressBlockPage, InsertDataHdl_Impl, weld::Button&, rButto
 SwSelectAddressBlockDialog::SwSelectAddressBlockDialog(weld::Window* pParent, SwMailMergeConfigItem& rConfig)
     : SfxDialogController(pParent, "modules/swriter/ui/selectblockdialog.ui", "SelectBlockDialog")
     , m_rConfig(rConfig)
-    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("previewwin")))
+    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("previewwin", true)))
     , m_xNewPB(m_xBuilder->weld_button("new"))
     , m_xCustomizePB(m_xBuilder->weld_button("edit"))
     , m_xDeletePB(m_xBuilder->weld_button("delete"))
@@ -334,7 +333,7 @@ SwSelectAddressBlockDialog::SwSelectAddressBlockDialog(weld::Window* pParent, Sw
 
     m_xDeletePB->connect_clicked(LINK(this, SwSelectAddressBlockDialog, DeleteHdl_Impl));
 
-    Link<weld::ToggleButton&,void> aLk = LINK(this, SwSelectAddressBlockDialog, IncludeHdl_Impl);
+    Link<weld::Toggleable&,void> aLk = LINK(this, SwSelectAddressBlockDialog, IncludeHdl_Impl);
     m_xNeverRB->connect_toggled(aLk);
     m_xAlwaysRB->connect_toggled(aLk);
     m_xDependentRB->connect_toggled(aLk);
@@ -416,27 +415,27 @@ IMPL_LINK(SwSelectAddressBlockDialog, NewCustomizeHdl_Impl, weld::Button&, rButt
     {
         xDlg->SetAddress(m_aAddressBlocks[m_xPreview->GetSelectedAddress()]);
     }
-    if (RET_OK == xDlg->run())
+    if (RET_OK != xDlg->run())
+        return;
+
+    const OUString sNew = xDlg->GetAddress();
+    if(bCustomize)
     {
-        const OUString sNew = xDlg->GetAddress();
-        if(bCustomize)
-        {
-            m_xPreview->ReplaceSelectedAddress(sNew);
-            m_aAddressBlocks[m_xPreview->GetSelectedAddress()] = sNew;
-        }
-        else
-        {
-            m_xPreview->AddAddress(sNew);
-            m_aAddressBlocks.realloc(m_aAddressBlocks.getLength() + 1);
-            const sal_Int32 nSelect = m_aAddressBlocks.getLength() - 1;
-            m_aAddressBlocks[nSelect] = sNew;
-            m_xPreview->SelectAddress(static_cast<sal_uInt16>(nSelect));
-        }
-        m_xDeletePB->set_sensitive(m_aAddressBlocks.getLength() > 1);
+        m_xPreview->ReplaceSelectedAddress(sNew);
+        m_aAddressBlocks[m_xPreview->GetSelectedAddress()] = sNew;
     }
+    else
+    {
+        m_xPreview->AddAddress(sNew);
+        m_aAddressBlocks.realloc(m_aAddressBlocks.getLength() + 1);
+        const sal_Int32 nSelect = m_aAddressBlocks.getLength() - 1;
+        m_aAddressBlocks[nSelect] = sNew;
+        m_xPreview->SelectAddress(o3tl::narrowing<sal_uInt16>(nSelect));
+    }
+    m_xDeletePB->set_sensitive(m_aAddressBlocks.getLength() > 1);
 }
 
-IMPL_LINK_NOARG(SwSelectAddressBlockDialog, IncludeHdl_Impl, weld::ToggleButton&,  void)
+IMPL_LINK_NOARG(SwSelectAddressBlockDialog, IncludeHdl_Impl, weld::Toggleable&,  void)
 {
     m_xCountryED->set_sensitive(m_xDependentRB->get_active());
 }
@@ -471,7 +470,7 @@ SwCustomizeAddressBlockDialog::SwCustomizeAddressBlockDialog(
     , m_xFieldFT(m_xBuilder->weld_label("customft"))
     , m_xFieldCB(m_xBuilder->weld_combo_box("custom"))
     , m_xOK(m_xBuilder->weld_button("ok"))
-    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("previewwin")))
+    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("previewwin", true)))
     , m_xPreviewWIN(new weld::CustomWeld(*m_xBuilder, "addrpreview", *m_xPreview))
     , m_xDragED(new AddressMultiLineEdit(this))
     , m_xDragWIN(new weld::CustomWeld(*m_xBuilder, "addressdest", *m_xDragED))
@@ -609,7 +608,7 @@ sal_Int32 SwCustomizeAddressBlockDialog::GetSelectedItem_Impl() const
         for (int i = 0, nEntryCount = m_xAddressElementsLB->n_children(); i < nEntryCount; ++i)
         {
             const OUString sEntry = m_xAddressElementsLB->get_text(i);
-            if( sEntry == sSelected.copy( 1, sSelected.getLength() - 2 ) )
+            if( sEntry == sSelected.subView( 1, sSelected.getLength() - 2 ) )
             {
                 nRet = m_xAddressElementsLB->get_id(i).toInt32();
                 break;
@@ -632,7 +631,7 @@ bool SwCustomizeAddressBlockDialog::HasItem(sal_Int32 nUserData)
         }
     }
     //search for this entry in the content
-    return m_xDragED->GetText().indexOf("<" + sEntry + ">") >= 0;
+    return m_xDragED->GetText().indexOf(OUString("<" + sEntry + ">")) >= 0;
 }
 
 IMPL_LINK_NOARG(SwCustomizeAddressBlockDialog, SelectionChangedIdleHdl, Timer*, void)
@@ -971,7 +970,7 @@ SwAssignFieldsDialog::SwAssignFieldsDialog(
     , m_sNone(SwResId(SW_STR_NONE))
     , m_rPreviewString(rPreview)
     , m_rConfigItem(rConfigItem)
-    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("previewwin")))
+    , m_xPreview(new SwAddressPreview(m_xBuilder->weld_scrolled_window("previewwin", true)))
     , m_xMatchingFI(m_xBuilder->weld_label("MATCHING_LABEL"))
     , m_xAddressTitle(m_xBuilder->weld_label("addresselem"))
     , m_xMatchTitle(m_xBuilder->weld_label("matchelem"))
@@ -1171,8 +1170,8 @@ void AddressMultiLineEdit::InsertNewEntry( const OUString& rStr )
     m_xEditEngine->GetCharAttribs(nPara, aAttribList);
 
     sal_Int32 nIndex = aSelection.nEndPara;
-    const EECharAttrib* pAttrib;
-    if(nullptr != (pAttrib = FindCharAttrib(aSelection.nStartPos, aAttribList)))
+    const EECharAttrib* pAttrib = FindCharAttrib(aSelection.nStartPos, aAttribList);
+    if(nullptr != pAttrib)
         nIndex = pAttrib->nEnd;
     InsertNewEntryAtPosition( rStr, nPara, nIndex );
 
@@ -1229,8 +1228,8 @@ void AddressMultiLineEdit::MoveCurrentItem(MoveItemFlags nMove)
 
     const EECharAttrib* pBeginAttrib = FindCharAttrib(aSelection.nStartPos, aAttribList);
     if(!pBeginAttrib ||
-       !(pBeginAttrib->nStart <= aSelection.nStartPos &&
-         pBeginAttrib->nEnd >= aSelection.nEndPos))
+         pBeginAttrib->nStart > aSelection.nStartPos ||
+         pBeginAttrib->nEnd < aSelection.nEndPos)
         return;
 
     //current item has been found
@@ -1546,10 +1545,9 @@ css::uno::Reference<css::datatransfer::dnd::XDropTarget> AddressMultiLineEdit::G
     if (!m_xDropTarget.is())
     {
         auto xRealDropTarget = GetDrawingArea()->get_drop_target();
-        DropTargetListener* pProxy = new DropTargetListener(xRealDropTarget, m_pParentDialog);
-        uno::Reference<css::datatransfer::dnd::XDropTargetListener> xListener(pProxy);
-        xRealDropTarget->addDropTargetListener(xListener);
-        m_xDropTarget = uno::Reference<css::datatransfer::dnd::XDropTarget>(pProxy);
+        rtl::Reference<DropTargetListener> pProxy = new DropTargetListener(xRealDropTarget, m_pParentDialog);
+        xRealDropTarget->addDropTargetListener(pProxy);
+        m_xDropTarget = pProxy;
     }
     return m_xDropTarget;
 }
