@@ -257,7 +257,7 @@ SwMMResultSaveDialog::SwMMResultSaveDialog(weld::Window* pParent)
     , m_xToNF(m_xBuilder->weld_spin_button("to"))
     , m_xOKButton(m_xBuilder->weld_button("ok"))
 {
-    Link<weld::ToggleButton&,void> aLink = LINK(this, SwMMResultSaveDialog, DocumentSelectionHdl_Impl);
+    Link<weld::Toggleable&,void> aLink = LINK(this, SwMMResultSaveDialog, DocumentSelectionHdl_Impl);
     m_xSaveAsOneRB->connect_toggled(aLink);
     m_xSaveIndividualRB->connect_toggled(aLink);
     m_xFromRB->connect_toggled(aLink);
@@ -295,7 +295,7 @@ SwMMResultPrintDialog::SwMMResultPrintDialog(weld::Window* pParent)
     m_xPrinterLB->connect_changed(LINK(this, SwMMResultPrintDialog, PrinterChangeHdl_Impl));
     m_xPrinterSettingsPB->connect_clicked(LINK(this, SwMMResultPrintDialog, PrinterSetupHdl_Impl));
 
-    Link<weld::ToggleButton&,void> aLink = LINK(this, SwMMResultPrintDialog, DocumentSelectionHdl_Impl);
+    Link<weld::Toggleable&,void> aLink = LINK(this, SwMMResultPrintDialog, DocumentSelectionHdl_Impl);
     m_xPrintAllRB->connect_toggled(aLink);
     m_xFromRB->connect_toggled(aLink);
     // m_pPrintAllRB is the default, so disable m_xFromNF and m_xToNF initially.
@@ -338,7 +338,7 @@ SwMMResultEmailDialog::SwMMResultEmailDialog(weld::Window* pParent)
     m_xSendAsLB->connect_changed(LINK(this, SwMMResultEmailDialog, SendTypeHdl_Impl));
     m_xPasswordCB->connect_toggled( LINK( this, SwMMResultEmailDialog, CheckHdl ));
 
-    Link<weld::ToggleButton&,void> aLink = LINK(this, SwMMResultEmailDialog, DocumentSelectionHdl_Impl);
+    Link<weld::Toggleable&,void> aLink = LINK(this, SwMMResultEmailDialog, DocumentSelectionHdl_Impl);
     m_xSendAllRB->connect_toggled(aLink);
     m_xFromRB->connect_toggled(aLink);
     // m_xSendAllRB is the default, so disable m_xFromNF and m_xToNF initially.
@@ -455,7 +455,7 @@ void SwMMResultEmailDialog::FillInEmailSettings()
     m_xToNF->set_value(nCount);
 }
 
-IMPL_LINK_NOARG(SwMMResultSaveDialog, DocumentSelectionHdl_Impl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(SwMMResultSaveDialog, DocumentSelectionHdl_Impl, weld::Toggleable&, void)
 {
     bool bEnableFromTo = m_xFromRB->get_active();
     m_xFromNF->set_sensitive(bEnableFromTo);
@@ -463,7 +463,7 @@ IMPL_LINK_NOARG(SwMMResultSaveDialog, DocumentSelectionHdl_Impl, weld::ToggleBut
     m_xToNF->set_sensitive(bEnableFromTo);
 }
 
-IMPL_LINK_NOARG(SwMMResultEmailDialog, CheckHdl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(SwMMResultEmailDialog, CheckHdl, weld::Toggleable&, void)
 {
     bool bEnable = m_xPasswordCB->get_active();
 
@@ -471,7 +471,7 @@ IMPL_LINK_NOARG(SwMMResultEmailDialog, CheckHdl, weld::ToggleButton&, void)
     m_xPasswordLB->set_sensitive(bEnable);
 }
 
-IMPL_LINK_NOARG(SwMMResultPrintDialog, DocumentSelectionHdl_Impl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(SwMMResultPrintDialog, DocumentSelectionHdl_Impl, weld::Toggleable&, void)
 {
     bool bEnableFromTo = m_xFromRB->get_active();
     m_xFromNF->set_sensitive(bEnableFromTo);
@@ -479,7 +479,7 @@ IMPL_LINK_NOARG(SwMMResultPrintDialog, DocumentSelectionHdl_Impl, weld::ToggleBu
     m_xToNF->set_sensitive(bEnableFromTo);
 }
 
-IMPL_LINK_NOARG(SwMMResultEmailDialog, DocumentSelectionHdl_Impl, weld::ToggleButton&, void)
+IMPL_LINK_NOARG(SwMMResultEmailDialog, DocumentSelectionHdl_Impl, weld::Toggleable&, void)
 {
     bool bEnableFromTo = m_xFromRB->get_active();
     m_xFromNF->set_sensitive(bEnableFromTo);
@@ -551,6 +551,15 @@ IMPL_LINK_NOARG(SwMMResultSaveDialog, SaveOutputHdl_Impl, weld::Button&, void)
     SwView* pView = ::GetActiveView();
     std::shared_ptr<SwMailMergeConfigItem> xConfigItem = pView->GetMailMergeConfigItem();
     assert(xConfigItem);
+
+    sal_uInt32 nBegin = static_cast<sal_Int32>(m_xFromNF->get_value() - 1);
+    sal_uInt32 nEnd = static_cast<sal_Int32>(m_xToNF->get_value());
+    sal_uInt32 nMax = static_cast<sal_Int32>(m_xToNF->get_max());
+    if (nEnd > nMax)
+        nEnd = nMax;
+
+    xConfigItem->SetBeginEnd(nBegin, nEnd);
+
     if (!xConfigItem->GetTargetView())
         SwDBManager::PerformMailMerge(pView);
 
@@ -594,18 +603,6 @@ IMPL_LINK_NOARG(SwMMResultSaveDialog, SaveOutputHdl_Impl, weld::Button&, void)
     }
     else
     {
-        const sal_uInt32 nDocumentCount = xConfigItem->GetMergedDocumentCount();
-        sal_uInt32 nBegin = 0;
-        sal_uInt32 nEnd = nDocumentCount;
-
-        if (!m_xSaveIndividualRB->get_active())
-        {
-            nBegin  = static_cast< sal_Int32 >(m_xFromNF->get_value() - 1);
-            nEnd    = static_cast< sal_Int32 >(m_xToNF->get_value());
-            if(nEnd > nDocumentCount)
-                nEnd = nDocumentCount;
-        }
-
         OUString sTargetTempURL = URIHelper::SmartRel2Abs(
             INetURLObject(), utl::TempFile::CreateTempName(),
             URIHelper::GetMaybeFileHdl());
@@ -649,7 +646,7 @@ IMPL_LINK_NOARG(SwMMResultSaveDialog, SaveOutputHdl_Impl, weld::Button&, void)
             xSaveMonitor.reset();
         });
 
-        for(sal_uInt32 nDoc = nBegin; nDoc < nEnd && !m_bCancelSaving; ++nDoc)
+        for(sal_uInt32 nDoc = 0; nDoc < nEnd - nBegin && !m_bCancelSaving; ++nDoc)
         {
             INetURLObject aURL(sPath);
             OUString sExtension = aURL.getExtension();
@@ -658,7 +655,7 @@ IMPL_LINK_NOARG(SwMMResultSaveDialog, SaveOutputHdl_Impl, weld::Button&, void)
                 sExtension = pSfxFlt->GetWildcard().getGlob().getToken(1, '.');
                 sPath += "." + sExtension;
             }
-            OUString sStat = SwResId(STR_STATSTR_LETTER) + " " + OUString::number( nDoc );
+            OUString sStat = SwResId(STR_STATSTR_LETTER) + " " + OUString::number(nDoc + 1);
             xSaveMonitor->m_xPrintInfo->set_label(sStat);
 
             //now extract a document from the target document
@@ -775,24 +772,21 @@ IMPL_LINK_NOARG(SwMMResultPrintDialog, PrintHdl_Impl, weld::Button&, void)
     SwView* pView = ::GetActiveView();
     std::shared_ptr<SwMailMergeConfigItem> xConfigItem = pView->GetMailMergeConfigItem();
     assert(xConfigItem);
+
+    sal_uInt32 nBegin = static_cast<sal_Int32>(m_xFromNF->get_value() - 1);
+    sal_uInt32 nEnd = static_cast<sal_Int32>(m_xToNF->get_value());
+    sal_uInt32 nMax = static_cast<sal_Int32>(m_xToNF->get_max());
+    if (nEnd > nMax)
+        nEnd = nMax;
+
+    xConfigItem->SetBeginEnd(nBegin, nEnd);
+
     if(!xConfigItem->GetTargetView())
         SwDBManager::PerformMailMerge(pView);
 
     SwView* pTargetView = xConfigItem->GetTargetView();
     assert(pTargetView);
 
-    const sal_uInt32 nDocumentCount = xConfigItem->GetMergedDocumentCount();
-    sal_uInt32 nBegin = 0;
-    sal_uInt32 nEnd = nDocumentCount;
-
-    if (!m_xPrintAllRB->get_active())
-    {
-        nBegin  = m_xFromNF->get_value() - 1;
-        nEnd    = m_xToNF->get_value();
-        if(nEnd > nDocumentCount)
-            nEnd = nDocumentCount;
-    }
-
     // If we skip autoinserted blanks, then the page numbers used in the print range string
     // refer to the non-blank pages as they appear in the document (see tdf#89708).
     const bool bIgnoreEmptyPages =
@@ -889,6 +883,15 @@ IMPL_LINK_NOARG(SwMMResultEmailDialog, SendDocumentsHdl_Impl, weld::Button&, voi
     SwView* pView = ::GetActiveView();
     std::shared_ptr<SwMailMergeConfigItem> xConfigItem = pView->GetMailMergeConfigItem();
     assert(xConfigItem);
+
+    sal_uInt32 nBegin = static_cast<sal_Int32>(m_xFromNF->get_value() - 1);
+    sal_uInt32 nEnd = static_cast<sal_Int32>(m_xToNF->get_value());
+    sal_uInt32 nMax = static_cast<sal_Int32>(m_xToNF->get_max());
+    if (nEnd > nMax)
+        nEnd = nMax;
+
+    xConfigItem->SetBeginEnd(nBegin, nEnd);
+
     if (!xConfigItem->GetTargetView())
         SwDBManager::PerformMailMerge(pView);
 
@@ -920,16 +923,6 @@ IMPL_LINK_NOARG(SwMMResultEmailDialog, SendDocumentsHdl_Impl, weld::Button&, voi
         lcl_UpdateEmailSettingsFromGlobalConfig(*xConfigItem);
     }
     //add the documents
-    const sal_uInt32 nDocumentCount = xConfigItem->GetMergedDocumentCount();
-    sal_uInt32 nBegin = 0;
-    sal_uInt32 nEnd = nDocumentCount;
-    if (!m_xSendAllRB->get_active())
-    {
-        nBegin  = static_cast< sal_Int32 >(m_xFromNF->get_value() - 1);
-        nEnd    = static_cast< sal_Int32 >(m_xToNF->get_value());
-        if(nEnd > nDocumentCount)
-            nEnd = nDocumentCount;
-    }
     bool bAsBody = false;
     rtl_TextEncoding eEncoding = ::osl_getThreadTextEncoding();
     SfxFilterContainer* pFilterContainer = SwDocShell::Factory().GetFilterContainer();
