@@ -22,6 +22,7 @@
 #include <com/sun/star/frame/XModel.hpp>
 
 #include <tools/urlobj.hxx>
+#include <rtl/ref.hxx>
 
 #include "vbadocument.hxx"
 #include "vbadocuments.hxx"
@@ -37,7 +38,7 @@ getDocument( uno::Reference< uno::XComponentContext > const & xContext, const un
     if( !xDoc.is() )
         return uno::Any();
 
-    SwVbaDocument *pWb = new SwVbaDocument(  uno::Reference< XHelperInterface >( aApplication, uno::UNO_QUERY_THROW ), xContext, xDoc );
+    rtl::Reference<SwVbaDocument> pWb = new SwVbaDocument(  uno::Reference< XHelperInterface >( aApplication, uno::UNO_QUERY_THROW ), xContext, xDoc );
     return uno::Any( uno::Reference< word::XDocument > (pWb) );
 }
 
@@ -71,8 +72,8 @@ SwVbaDocuments::getElementType()
 uno::Reference< container::XEnumeration >
 SwVbaDocuments::createEnumeration()
 {
-    // #FIXME its possible the DocumentEnumImpl here doesn't reflect
-    // the state of this object ( although it should ) would be
+    // #FIXME it's possible the DocumentEnumImpl here doesn't reflect
+    // the state of this object (although it should) would be
     // safer to create an enumeration based on this objects state
     // rather than one effectively based of the desktop component
     uno::Reference< container::XEnumerationAccess > xEnumerationAccess( m_xIndexAccess, uno::UNO_QUERY_THROW );
