@@ -27,6 +27,7 @@
 #include <svl/whiter.hxx>
 #include <svx/swframevalidation.hxx>
 #include <svx/anchorid.hxx>
+#include <osl/diagnose.h>
 #include <drawdoc.hxx>
 #include <uitool.hxx>
 #include <fmtornt.hxx>
@@ -235,8 +236,6 @@ void SwDrawBaseShell::Execute(SfxRequest const &rReq)
                         pDlg->StartExecuteAsync([bCaption, bChanged, pDlg, pFrameFormat, pSdrView,
                                                  pSh, &rMarkList, this](
                                                     sal_Int32 nResult){
-                            pSdrView->GetModel()->SetChanged(false);
-
                             if (nResult == RET_OK)
                             {
                                 SwFormatVertOrient aVOrientFinal(pFrameFormat->GetFormatAttr(RES_VERT_ORIENT));
