@@ -25,9 +25,9 @@
 #include <svx/xflgrit.hxx>
 #include <svx/xflhtit.hxx>
 #include <svx/xbtmpit.hxx>
+#include <svx/itemwin.hxx>
 #include <svx/SvxNumOptionsTabPageHelper.hxx>
 #include "PageStylesPanel.hxx"
-#include <sfx2/sidebar/Panel.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/objsh.hxx>
@@ -68,7 +68,6 @@ static sal_uInt16 PageUsageToPos_Impl( SvxPageUsage nUsage )
     return 3;
 }
 
-
 static SvxPageUsage PosToPageUsage_Impl( sal_uInt16 nPos )
 {
     if ( nPos >= SAL_N_ELEMENTS(aArr) )
@@ -76,27 +75,21 @@ static SvxPageUsage PosToPageUsage_Impl( sal_uInt16 nPos )
     return aArr[nPos];
 }
 
-VclPtr<vcl::Window> PageStylesPanel::Create(
-    vcl::Window* pParent,
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rxFrame,
-    SfxBindings* pBindings)
+std::unique_ptr<PanelLayout> PageStylesPanel::Create(weld::Widget* pParent, SfxBindings* pBindings)
 {
     if( pParent == nullptr )
         throw ::com::sun::star::lang::IllegalArgumentException("no parent window given to PageStylesPanel::Create", nullptr, 0);
-    if( !rxFrame.is() )
-        throw ::com::sun::star::lang::IllegalArgumentException("no XFrame given to PageStylesPanel::Create", nullptr, 0);
     if( pBindings == nullptr )
         throw ::com::sun::star::lang::IllegalArgumentException("no SfxBindings given to PageStylesPanel::Create", nullptr, 0);
 
-    return VclPtr<PageStylesPanel>::Create(pParent, rxFrame, pBindings);
+    return std::make_unique<PageStylesPanel>(pParent, pBindings);
 }
 
 PageStylesPanel::PageStylesPanel(
-    vcl::Window* pParent,
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rxFrame,
+    weld::Widget* pParent,
     SfxBindings* pBindings
     ) :
-    PanelLayout(pParent, "PageStylesPanel", "modules/swriter/ui/pagestylespanel.ui", rxFrame),
+    PanelLayout(pParent, "PageStylesPanel", "modules/swriter/ui/pagestylespanel.ui"),
     mpBindings( pBindings ),
     mpPageColumnItem( new SfxInt16Item(SID_ATTR_PAGE_COLUMN) ),
     mpPageItem( new SvxPageItem(SID_ATTR_PAGE) ),
@@ -107,9 +100,9 @@ PageStylesPanel::PageStylesPanel(
     maBgGradientControl( SID_ATTR_PAGE_GRADIENT, *pBindings, *this ),
     maBgBitmapControl( SID_ATTR_PAGE_BITMAP, *pBindings, *this ),
     maBgFillStyleControl(SID_ATTR_PAGE_FILLSTYLE, *pBindings, *this),
-    mxBgColorLB(new ColorListBox(m_xBuilder->weld_menu_button("lbcolor"), GetFrameWeld())),
+    mxBgColorLB(new ColorListBox(m_xBuilder->weld_menu_button("lbcolor"), [this]{ return GetFrameWeld(); })),
     mxBgHatchingLB(m_xBuilder->weld_combo_box("lbhatching")),
-    mxBgGradientLB(new ColorListBox(m_xBuilder->weld_menu_button("lbgradient"), GetFrameWeld())),
+    mxBgGradientLB(new ColorListBox(m_xBuilder->weld_menu_button("lbgradient"), [this]{ return GetFrameWeld(); })),
     mxBgBitmapLB(m_xBuilder->weld_combo_box("lbbitmap")),
     mxLayoutSelectLB(m_xBuilder->weld_combo_box("layoutbox")),
     mxColumnCount(m_xBuilder->weld_combo_box("columnbox")),
@@ -122,11 +115,6 @@ PageStylesPanel::PageStylesPanel(
 }
 
 PageStylesPanel::~PageStylesPanel()
-{
-    disposeOnce();
-}
-
-void PageStylesPanel::dispose()
 {
     mxColumnCount.reset();
     mxNumberSelectLB.reset();
@@ -145,7 +133,6 @@ void PageStylesPanel::dispose()
     maBgHatchingControl.dispose();
     maPageColumnControl.dispose();
     maPageNumFormatControl.dispose();
-    PanelLayout::dispose();
 }
 
 void PageStylesPanel::Initialize()
@@ -250,11 +237,6 @@ void PageStylesPanel::Update()
         default:
             break;
     }
-
-    // Need to do a relayouting, otherwise the panel size is not updated after show / hide controls
-    sfx2::sidebar::Panel* pPanel = dynamic_cast<sfx2::sidebar::Panel*>(GetParent());
-    if (pPanel)
-        pPanel->TriggerDeckLayouting();
 }
 
 Color const & PageStylesPanel::GetColorSetOrDefault()
@@ -330,7 +312,7 @@ void PageStylesPanel::NotifyItemUpdate(
     const SfxItemState eState,
     const SfxPoolItem* pState)
 {
-    if(IsDisposed())
+    if (!mxColumnCount) //disposed
         return;
 
     switch(nSid)
