@@ -26,6 +26,7 @@
 #include <sfx2/dispatch.hxx>
 #include <svx/dataaccessdescriptor.hxx>
 #include <comphelper/servicehelper.hxx>
+#include <osl/diagnose.h>
 #include <unodispatch.hxx>
 #include <view.hxx>
 #include <cmdid.h>
@@ -149,14 +150,10 @@ void SwXDispatchProviderInterceptor::disposing( const lang::EventObject& )
     m_xIntercepted = nullptr;
 }
 
-namespace
-{
-    class theSwXDispatchProviderInterceptorUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSwXDispatchProviderInterceptorUnoTunnelId > {};
-}
-
 const uno::Sequence< sal_Int8 > & SwXDispatchProviderInterceptor::getUnoTunnelId()
 {
-    return theSwXDispatchProviderInterceptorUnoTunnelId::get().getSeq();
+    static const UnoTunnelIdInit theSwXDispatchProviderInterceptorUnoTunnelId;
+    return theSwXDispatchProviderInterceptorUnoTunnelId.getSeq();
 }
 
 sal_Int64 SwXDispatchProviderInterceptor::getSomething(
@@ -242,7 +239,7 @@ void SwXDispatch::dispatch(const util::URL& aURL,
         frame::FeatureStateEvent aEvent;
         aEvent.Source = *static_cast<cppu::OWeakObject*>(this);
 
-        const SwDBData& rData = m_pView->GetWrtShell().GetDBDesc();
+        const SwDBData& rData = m_pView->GetWrtShell().GetDBData();
         svx::ODataAccessDescriptor aDescriptor;
         aDescriptor.setDataSource(rData.sDataSource);
         aDescriptor[svx::DataAccessDescriptorProperty::Command]       <<= rData.sCommand;
@@ -288,7 +285,7 @@ void SwXDispatch::addStatusListener(
     // one of the URLs requires a special state...
     if (aURL.Complete == cURLDocumentDataSource)
     {
-        const SwDBData& rData = m_pView->GetWrtShell().GetDBDesc();
+        const SwDBData& rData = m_pView->GetWrtShell().GetDBData();
 
         svx::ODataAccessDescriptor aDescriptor;
         aDescriptor.setDataSource(rData.sDataSource);
