@@ -27,11 +27,10 @@
 #include <sfx2/docfilt.hxx>
 #include <vcl/commandevent.hxx>
 #include <vcl/event.hxx>
-#include <vcl/help.hxx>
 #include <sot/filelist.hxx>
 #include <svl/eitem.hxx>
 #include <vcl/graphicfilter.hxx>
-#include <vcl/settings.hxx>
+#include <osl/diagnose.h>
 
 #include <sfx2/docinsert.hxx>
 #include <sfx2/filedlghelper.hxx>
@@ -127,11 +126,11 @@ static const char* GLOBAL_CONTEXT_ARY[] =
 SwGlobalTree::SwGlobalTree(std::unique_ptr<weld::TreeView> xTreeView, SwNavigationPI* pDialog)
     : m_xTreeView(std::move(xTreeView))
     , m_aDropTargetHelper(*this)
-    , m_xDialog(pDialog)
+    , m_pDialog(pDialog)
     , m_pActiveShell(nullptr)
 {
-    Size aSize(m_xDialog->LogicToPixel(Size(110, 112), MapMode(MapUnit::MapAppFont)));;
-    m_xTreeView->set_size_request(aSize.Width(), aSize.Height());
+    m_xTreeView->set_size_request(m_xTreeView->get_approximate_digit_width() * 30,
+                                  m_xTreeView->get_text_height() * 14);
 
     m_aUpdateTimer.SetTimeout(GLOBAL_UPDATE_TIMEOUT);
     m_aUpdateTimer.SetInvokeHandler(LINK(this, SwGlobalTree, Timeout));
@@ -155,7 +154,6 @@ SwGlobalTree::~SwGlobalTree()
     m_pSwGlblDocContents.reset();
     m_pDocInserter.reset();
     m_aUpdateTimer.Stop();
-    m_xDialog.clear();
 }
 
 SwGlobalTreeDropTarget::SwGlobalTreeDropTarget(SwGlobalTree& rTreeView)
@@ -186,7 +184,7 @@ sal_Int8 SwGlobalTreeDropTarget::ExecuteDrop( const ExecuteDropEvent& rEvt )
         if( aData.HasFormat( SotClipboardFormatId::FILE_LIST ))
         {
             nRet = rEvt.mnAction;
-            std::unique_ptr<SwGlblDocContents> pTempContents(new SwGlblDocContents);
+            SwGlblDocContents aTempContents;
             int nAbsContPos = xDropEntry ?
                                 rWidget.get_iter_index_in_parent(*xDropEntry):
                                     - 1;
@@ -203,14 +201,14 @@ sal_Int8 SwGlobalTreeDropTarget::ExecuteDrop( const ExecuteDropEvent& rEvt )
                 // to not work on an old content.
                 if(n)
                 {
-                    m_rTreeView.GetActiveWrtShell()->GetGlobalDocContent(*pTempContents);
+                    m_rTreeView.GetActiveWrtShell()->GetGlobalDocContent(aTempContents);
                     // If the file was successfully inserted,
                     // then the next content must also be fetched.
-                    if(nEntryCount < pTempContents->size())
+                    if(nEntryCount < aTempContents.size())
                     {
                         nEntryCount++;
                         nAbsContPos++;
-                        pCnt = (*pTempContents)[ nAbsContPos ].get();
+                        pCnt = aTempContents[ nAbsContPos ].get();
                     }
                 }
             }
@@ -294,7 +292,7 @@ IMPL_LINK(SwGlobalTree, CommandHdl, const CommandEvent&, rCEvt, bool)
     return bPop;
 }
 
-void SwGlobalTree::TbxMenuHdl(const OString& rCommand, weld::Menu& rMenu)
+void SwGlobalTree::TbxMenuHdl(std::string_view rCommand, weld::Menu& rMenu)
 {
     const MenuEnableFlags nEnableFlags = GetEnableFlags();
     if (rCommand == "insert")
@@ -515,7 +513,8 @@ void SwGlobalTree::InsertRegion( const SwGlblDocContent* pCont, const OUString*
     Sequence< OUString > aFileNames;
     if ( !pFileName )
     {
-        m_pDocInserter.reset(new ::sfx2::DocumentInserter(GetParentWindow()->GetFrameWeld(), "swriter", sfx2::DocumentInserter::Mode::InsertMulti));
+        SwNavigationPI* pNavi = GetParentWindow();
+        m_pDocInserter.reset(new ::sfx2::DocumentInserter(pNavi->GetFrameWeld(), "swriter", sfx2::DocumentInserter::Mode::InsertMulti));
         m_pDocInserter->StartExecuteModal( LINK( this, SwGlobalTree, DialogClosedHdl ) );
     }
     else if ( !pFileName->isEmpty() )
@@ -562,7 +561,7 @@ void SwGlobalTree::EditContent(const SwGlblDocContent* pCont )
     }
 }
 
-void SwGlobalTree::ExecuteContextMenuAction(const OString& rSelectedPopupEntry)
+void SwGlobalTree::ExecuteContextMenuAction(std::string_view rSelectedPopupEntry)
 {
     bool bUpdateHard = false;
 
@@ -667,7 +666,7 @@ void SwGlobalTree::ExecuteContextMenuAction(const OString& rSelectedPopupEntry)
 
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
             ScopedVclPtr<AbstractMultiTOXTabDialog> pDlg(pFact->CreateMultiTOXTabDialog(
-                                                    m_xDialog->GetFrameWeld(), aSet,
+                                                    m_xTreeView.get(), aSet,
                                                     *m_pActiveShell,
                                                     nullptr,
                                                     true));
@@ -810,7 +809,7 @@ void SwGlobalTree::HideTree()
     m_xTreeView->hide();
 }
 
-void SwGlobalTree::ExecCommand(const OString &rCmd)
+void SwGlobalTree::ExecCommand(std::string_view rCmd)
 {
     int nEntry = m_xTreeView->get_selected_index();
     if (nEntry == -1)
@@ -868,20 +867,20 @@ bool SwGlobalTree::Update(bool bHard)
         else
         {
             bool bCopy = false;
-            std::unique_ptr<SwGlblDocContents> pTempContents(new SwGlblDocContents);
-            m_pActiveShell->GetGlobalDocContent(*pTempContents);
+            SwGlblDocContents aTempContents;
+            m_pActiveShell->GetGlobalDocContent(aTempContents);
             size_t nChildren = m_xTreeView->n_children();
-            if (pTempContents->size() != m_pSwGlblDocContents->size() ||
-                    pTempContents->size() != nChildren)
+            if (aTempContents.size() != m_pSwGlblDocContents->size() ||
+                    aTempContents.size() != nChildren)
             {
                 bRet = true;
                 bCopy = true;
             }
             else
             {
-                for(size_t i = 0; i < pTempContents->size() && !bCopy; i++)
+                for(size_t i = 0; i < aTempContents.size() && !bCopy; i++)
                 {
-                    SwGlblDocContent* pLeft = (*pTempContents)[i].get();
+                    SwGlblDocContent* pLeft = aTempContents[i].get();
                     SwGlblDocContent* pRight = (*m_pSwGlblDocContents)[i].get();
                     GlobalDocContentType eType = pLeft->GetType();
                     OUString sTemp = m_xTreeView->get_text(i);
@@ -903,7 +902,7 @@ bool SwGlobalTree::Update(bool bHard)
             }
             if (bCopy || bHard)
             {
-                *m_pSwGlblDocContents = std::move( *pTempContents );
+                *m_pSwGlblDocContents = std::move( aTempContents );
                 bRet = true;
             }
         }
@@ -965,7 +964,7 @@ IMPL_LINK_NOARG( SwGlobalTree, DoubleClickHdl, weld::TreeView&, bool)
 
 SwNavigationPI* SwGlobalTree::GetParentWindow()
 {
-    return m_xDialog;
+    return m_pDialog;
 }
 
 IMPL_STATIC_LINK_NOARG(SwGlobalTree, ShowFrameHdl, void*, void)
@@ -1077,7 +1076,9 @@ IMPL_LINK( SwGlobalTree, DialogClosedHdl, sfx2::FileDialogHelper*, _pFileDlg, vo
     sal_Int32 nPos = 0;
     for (const std::unique_ptr<SfxMedium>& pMed : aMedList)
     {
-        OUString sFileName = pMed->GetURLObject().GetMainURL( INetURLObject::DecodeMechanism::NONE )
+        // tdf#127978 - don't URL encode filename for navigator's tooltip
+        OUString sFileName
+            = pMed->GetURLObject().GetMainURL(INetURLObject::DecodeMechanism::Unambiguous)
             + OUStringChar(sfx2::cTokenSeparator)
             + pMed->GetFilter()->GetFilterName()
             + OUStringChar(sfx2::cTokenSeparator);
