@@ -23,6 +23,7 @@
 // This method positions the cursor to the position rPos.
 
 void SwNavigationMgr::GotoSwPosition(const SwPosition &rPos) {
+
     // EnterStdMode() prevents the cursor to 'block' the current
     // shell when it should move from the image back to the normal shell
     m_rMyShell.EnterStdMode();
@@ -168,6 +169,11 @@ void SwNavigationMgr::goForward() {
 // rPos is usually the current position of the cursor in the document
 
 bool SwNavigationMgr::addEntry(const SwPosition& rPos) {
+
+    // For additions other than to the end, check here if the cursor position has changed
+    if (m_nCurrent < m_entries.size() && (rPos == *m_entries[m_nCurrent]->GetPoint()))
+        return false;
+
     // Flags that will be used for refreshing the buttons
     bool bBackWasDisabled = !backEnabled();
     bool bForwardWasEnabled = forwardEnabled();
@@ -216,31 +222,6 @@ bool SwNavigationMgr::addEntry(const SwPosition& rPos) {
     if (bForwardWasEnabled)
         m_rMyShell.GetView().GetViewFrame()->GetBindings().Invalidate(FN_NAVIGATION_FORWARD);
 
-    // show the Navigation toolbar
-    css::uno::Reference< css::frame::XFrame > xFrame =
-        m_rMyShell.GetView().GetViewFrame()->GetFrame().GetFrameInterface();
-    if (xFrame.is())
-    {
-        css::uno::Reference< css::beans::XPropertySet > xPropSet(xFrame, css::uno::UNO_QUERY);
-        if (xPropSet.is())
-        {
-            css::uno::Reference< css::frame::XLayoutManager > xLayoutManager;
-            css::uno::Any aValue = xPropSet->getPropertyValue("LayoutManager");
-
-            aValue >>= xLayoutManager;
-            if (xLayoutManager.is())
-            {
-                const OUString sResourceURL( "private:resource/toolbar/navigationobjectbar" );
-                css::uno::Reference< css::ui::XUIElement > xUIElement = xLayoutManager->getElement(sResourceURL);
-                if (!xUIElement.is())
-                {
-                    xLayoutManager->createElement( sResourceURL );
-                    xLayoutManager->showElement( sResourceURL );
-                }
-            }
-        }
-    }
-
     return bRet;
 }
 
