@@ -31,7 +31,7 @@
 #include <vcl/toolkit/dialog.hxx>
 #include <vcl/vclevent.hxx>
 #include <vcl/window.hxx>
-#include <vcl/edit.hxx>
+#include <vcl/toolkit/edit.hxx>
 #include <vcl/settings.hxx>
 #include <tools/debug.hxx>
 #include <unotools/accessiblestatesethelper.hxx>
@@ -343,37 +343,37 @@ void VCLXAccessibleComponent::disposing()
     m_xVCLXWindow.clear();
 }
 
-VclPtr<vcl::Window> VCLXAccessibleComponent::GetWindow() const
+vcl::Window* VCLXAccessibleComponent::GetWindow() const
 {
     return GetVCLXWindow() ? GetVCLXWindow()->GetWindow()
-                           : VclPtr<vcl::Window>();
+                           : nullptr;
 }
 
 void VCLXAccessibleComponent::FillAccessibleRelationSet( utl::AccessibleRelationSetHelper& rRelationSet )
 {
     VclPtr<vcl::Window> pWindow = GetWindow();
-    if ( pWindow )
+    if ( !pWindow )
+        return;
+
+    vcl::Window *pLabeledBy = pWindow->GetAccessibleRelationLabeledBy();
+    if ( pLabeledBy && pLabeledBy != pWindow )
     {
-        vcl::Window *pLabeledBy = pWindow->GetAccessibleRelationLabeledBy();
-        if ( pLabeledBy && pLabeledBy != pWindow )
-        {
-            uno::Sequence< uno::Reference< uno::XInterface > > aSequence { pLabeledBy->GetAccessible() };
-            rRelationSet.AddRelation( accessibility::AccessibleRelation( accessibility::AccessibleRelationType::LABELED_BY, aSequence ) );
-        }
+        uno::Sequence< uno::Reference< uno::XInterface > > aSequence { pLabeledBy->GetAccessible() };
+        rRelationSet.AddRelation( accessibility::AccessibleRelation( accessibility::AccessibleRelationType::LABELED_BY, aSequence ) );
+    }
 
-        vcl::Window* pLabelFor = pWindow->GetAccessibleRelationLabelFor();
-        if ( pLabelFor && pLabelFor != pWindow )
-        {
-            uno::Sequence< uno::Reference< uno::XInterface > > aSequence { pLabelFor->GetAccessible() };
-            rRelationSet.AddRelation( accessibility::AccessibleRelation( accessibility::AccessibleRelationType::LABEL_FOR, aSequence ) );
-        }
+    vcl::Window* pLabelFor = pWindow->GetAccessibleRelationLabelFor();
+    if ( pLabelFor && pLabelFor != pWindow )
+    {
+        uno::Sequence< uno::Reference< uno::XInterface > > aSequence { pLabelFor->GetAccessible() };
+        rRelationSet.AddRelation( accessibility::AccessibleRelation( accessibility::AccessibleRelationType::LABEL_FOR, aSequence ) );
+    }
 
-        vcl::Window* pMemberOf = pWindow->GetAccessibleRelationMemberOf();
-        if ( pMemberOf && pMemberOf != pWindow )
-        {
-            uno::Sequence< uno::Reference< uno::XInterface > > aSequence { pMemberOf->GetAccessible() };
-            rRelationSet.AddRelation( accessibility::AccessibleRelation( accessibility::AccessibleRelationType::MEMBER_OF, aSequence ) );
-        }
+    vcl::Window* pMemberOf = pWindow->GetAccessibleRelationMemberOf();
+    if ( pMemberOf && pMemberOf != pWindow )
+    {
+        uno::Sequence< uno::Reference< uno::XInterface > > aSequence { pMemberOf->GetAccessible() };
+        rRelationSet.AddRelation( accessibility::AccessibleRelation( accessibility::AccessibleRelationType::MEMBER_OF, aSequence ) );
     }
 }
 
@@ -631,20 +631,18 @@ uno::Reference< accessibility::XAccessibleRelationSet > VCLXAccessibleComponent:
 {
     OExternalLockGuard aGuard( this );
 
-    utl::AccessibleRelationSetHelper* pRelationSetHelper = new utl::AccessibleRelationSetHelper;
-    uno::Reference< accessibility::XAccessibleRelationSet > xSet = pRelationSetHelper;
+    rtl::Reference<utl::AccessibleRelationSetHelper> pRelationSetHelper = new utl::AccessibleRelationSetHelper;
     FillAccessibleRelationSet( *pRelationSetHelper );
-    return xSet;
+    return pRelationSetHelper;
 }
 
 uno::Reference< accessibility::XAccessibleStateSet > VCLXAccessibleComponent::getAccessibleStateSet(  )
 {
     OExternalLockGuard aGuard( this );
 
-    utl::AccessibleStateSetHelper* pStateSetHelper = new utl::AccessibleStateSetHelper;
-    uno::Reference< accessibility::XAccessibleStateSet > xSet = pStateSetHelper;
+    rtl::Reference<utl::AccessibleStateSetHelper> pStateSetHelper = new utl::AccessibleStateSetHelper;
     FillAccessibleStateSet( *pStateSetHelper );
-    return xSet;
+    return pStateSetHelper;
 }
 
 lang::Locale VCLXAccessibleComponent::getLocale()
@@ -790,7 +788,7 @@ uno::Reference< awt::XFont > SAL_CALL VCLXAccessibleComponent::getFont(  )
                 aFont = pWindow->GetControlFont();
             else
                 aFont = pWindow->GetFont();
-            VCLXFont* pVCLXFont = new VCLXFont;
+            rtl::Reference<VCLXFont> pVCLXFont = new VCLXFont;
             pVCLXFont->Init( *xDev, aFont );
             xFont = pVCLXFont;
         }
