@@ -43,6 +43,7 @@
 #include <toolkit/awt/vclxwindows.hxx>
 #include <toolkit/controls/unocontrols.hxx>
 
+#include <awt/vclxwindows.hxx>
 #include <helper/unopropertyarrayhelper.hxx>
 #include "controlmodelcontainerbase_internal.hxx"
 
@@ -211,7 +212,7 @@ UnoControlDialogModel::UnoControlDialogModel( const UnoControlDialogModel& rMode
 rtl::Reference<UnoControlModel> UnoControlDialogModel::Clone() const
 {
     // clone the container itself
-    UnoControlDialogModel* pClone = new UnoControlDialogModel( *this );
+    rtl::Reference<UnoControlDialogModel> pClone = new UnoControlDialogModel( *this );
 
     Clone_Impl(*pClone);
 
@@ -870,7 +871,7 @@ UnoMultiPageModel::~UnoMultiPageModel()
 rtl::Reference<UnoControlModel> UnoMultiPageModel::Clone() const
 {
     // clone the container itself
-    UnoMultiPageModel* pClone = new UnoMultiPageModel( *this );
+    rtl::Reference<UnoMultiPageModel> pClone = new UnoMultiPageModel( *this );
     Clone_Impl( *pClone );
     return pClone;
 }
@@ -976,7 +977,7 @@ UnoPageModel::~UnoPageModel()
 rtl::Reference<UnoControlModel> UnoPageModel::Clone() const
 {
     // clone the container itself
-    UnoPageModel* pClone = new UnoPageModel( *this );
+    rtl::Reference<UnoPageModel> pClone = new UnoPageModel( *this );
     Clone_Impl( *pClone );
     return pClone;
 }
@@ -1122,7 +1123,7 @@ UnoFrameModel::~UnoFrameModel()
 rtl::Reference<UnoControlModel> UnoFrameModel::Clone() const
 {
     // clone the container itself
-    UnoFrameModel* pClone = new UnoFrameModel( *this );
+    rtl::Reference<UnoFrameModel> pClone = new UnoFrameModel( *this );
     Clone_Impl( *pClone );
     return pClone;
 }
