@@ -39,7 +39,6 @@ void BigIntTest::testConstructionFromLongLong()
     // small positive number
     {
         BigInt bi(static_cast<sal_Int64>(42));
-        CPPUNIT_ASSERT(bi.IsSet());
         CPPUNIT_ASSERT(!bi.IsZero());
         CPPUNIT_ASSERT(!bi.IsNeg());
         CPPUNIT_ASSERT(bi.IsLong());
@@ -49,7 +48,6 @@ void BigIntTest::testConstructionFromLongLong()
     // small negative number
     {
         BigInt bi(static_cast<sal_Int64>(-42));
-        CPPUNIT_ASSERT(bi.IsSet());
         CPPUNIT_ASSERT(!bi.IsZero());
         CPPUNIT_ASSERT(bi.IsNeg());
         CPPUNIT_ASSERT(bi.IsLong());
@@ -57,41 +55,35 @@ void BigIntTest::testConstructionFromLongLong()
     }
 
 #if SAL_TYPES_SIZEOFLONG < SAL_TYPES_SIZEOFLONGLONG
-    // positive number just fitting to long
+    // positive number just fitting to sal_Int32
     {
-        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<long>::max()));
-        CPPUNIT_ASSERT(bi.IsSet());
+        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<sal_Int32>::max()));
         CPPUNIT_ASSERT(!bi.IsZero());
         CPPUNIT_ASSERT(!bi.IsNeg());
         CPPUNIT_ASSERT(bi.IsLong());
-        CPPUNIT_ASSERT_EQUAL(std::numeric_limits<long>::max(), static_cast<long>(bi));
+        CPPUNIT_ASSERT_EQUAL(std::numeric_limits<sal_Int32>::max(), static_cast<sal_Int32>(bi));
     }
 
-    // negative number just fitting to long
+    // negative number just fitting to sal_Int32
     {
-        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<long>::min()));
-        CPPUNIT_ASSERT(bi.IsSet());
+        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<sal_Int32>::min()));
         CPPUNIT_ASSERT(!bi.IsZero());
         CPPUNIT_ASSERT(bi.IsNeg());
         CPPUNIT_ASSERT(bi.IsLong());
-        CPPUNIT_ASSERT_EQUAL(std::numeric_limits<long>::min(), static_cast<long>(bi));
+        CPPUNIT_ASSERT_EQUAL(std::numeric_limits<sal_Int32>::min(), static_cast<sal_Int32>(bi));
     }
 
-    // positive number not fitting to long
+    // positive number not fitting to sal_Int32
     {
-        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<long>::max())
-                  + static_cast<sal_Int64>(1));
-        CPPUNIT_ASSERT(bi.IsSet());
+        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<sal_Int32>::max()) + 1);
         CPPUNIT_ASSERT(!bi.IsZero());
         CPPUNIT_ASSERT(!bi.IsNeg());
         CPPUNIT_ASSERT(!bi.IsLong());
     }
 
-    // negative number not fitting to long
+    // negative number not fitting to sal_Int32
     {
-        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<long>::min())
-                  - static_cast<sal_Int64>(1));
-        CPPUNIT_ASSERT(bi.IsSet());
+        BigInt bi(static_cast<sal_Int64>(std::numeric_limits<sal_Int32>::min()) - 1);
         CPPUNIT_ASSERT(!bi.IsZero());
         CPPUNIT_ASSERT(bi.IsNeg());
         CPPUNIT_ASSERT(!bi.IsLong());
