@@ -306,7 +306,7 @@ void tools::Time::GetClock( double fTimeInDays,
     if (fAbsTimeInDays >= 1.0)
     {
         const int nDig = static_cast<int>(ceil( log10( fAbsTimeInDays)));
-        nDec = std::max( std::min( 10 - nDig, 9), 2);
+        nDec = std::clamp( 10 - nDig, 2, 9 );
     }
     double fSeconds = rtl::math::round( fRawSeconds, nDec);
 
@@ -401,8 +401,6 @@ Time tools::Time::GetUTCOffset()
     sal_uInt64          nTicks = tools::Time::GetSystemTicks();
     time_t          nTime;
     tm              aTM;
-    sal_Int32           nLocalTime;
-    sal_Int32           nUTC;
     short           nTempTime;
 
     // determine value again if needed
@@ -413,17 +411,17 @@ Time tools::Time::GetUTCOffset()
     {
         nTime = time( nullptr );
         localtime_r( &nTime, &aTM );
-        nLocalTime = mktime( &aTM );
+        sal_Int32 nLocalTime = mktime( &aTM );
 #if defined(__sun)
         // Solaris gmtime_r() seems not to handle daylight saving time
         // flags correctly
         nUTC = nLocalTime + ( aTM.tm_isdst == 0 ? timezone : altzone );
 #elif defined( LINUX )
         // Linux mktime() seems not to handle tm_isdst correctly
-        nUTC = nLocalTime - aTM.tm_gmtoff;
+        sal_Int32 nUTC = nLocalTime - aTM.tm_gmtoff;
 #else
         gmtime_r( &nTime, &aTM );
-        nUTC = mktime( &aTM );
+        sal_Int32 nUTC = mktime( &aTM );
 #endif
         nCacheTicks = nTicks;
         nCacheSecOffset = (nLocalTime-nUTC) / 60;
