@@ -26,21 +26,23 @@
 
 #include <algorithm>
 #include <cmath>
+#include <numeric>
 
-#include <boost/version.hpp>
-#if BOOST_VERSION >= 106700
-#include <boost/integer/common_factor_rt.hpp>
-#else
-#include <boost/math/common_factor_rt.hpp>
-#endif
 #include <boost/rational.hpp>
 
+#ifdef _MSC_VER
+#include <intrin.h>
+#endif
+
 static boost::rational<sal_Int32> rational_FromDouble(double dVal);
 
 static void rational_ReduceInaccurate(boost::rational<sal_Int32>& rRational, unsigned nSignificantBits);
 
 static boost::rational<sal_Int32> toRational(sal_Int32 n, sal_Int32 d)
 {
+    // https://github.com/boostorg/boost/issues/335 when these are std::numeric_limits<sal_Int32>::min
+    if (n == d)
+        return 1;
     return boost::rational<sal_Int32>(n, d);
 }
 
@@ -60,6 +62,13 @@ Fraction::Fraction( sal_Int64 nNum, sal_Int64 nDen ) : mnNumerator(nNum), mnDeno
         SAL_WARN( "tools.fraction", "'Fraction(" << nNum << ",0)' invalid fraction created" );
         return;
     }
+    if ((nDen == -1 && nNum == std::numeric_limits<sal_Int32>::min()) ||
+        (nNum == -1 && nDen == std::numeric_limits<sal_Int32>::min()))
+    {
+        mbValid = false;
+        SAL_WARN("tools.fraction", "'Fraction(" << nNum << "," << nDen << ")' invalid fraction created");
+        return;
+    }
 }
 
 /**
@@ -104,10 +113,6 @@ Fraction::operator double() const
         return 0.0;
     }
 
-    // https://github.com/boostorg/boost/issues/335 when these are std::numeric_limits<sal_Int32>::min
-    if (mnNumerator == mnDenominator)
-        return 1.0;
-
     return boost::rational_cast<double>(toRational(mnNumerator, mnDenominator));
 }
 
@@ -162,13 +167,8 @@ namespace
         T den = r.denominator();
 
         // Avoid overflow and preserve normalization
-#if BOOST_VERSION >= 106700
-        T gcd1 = boost::integer::gcd(i.numerator(), den);
-        T gcd2 = boost::integer::gcd(num, i.denominator());
-#else
-        T gcd1 = boost::math::gcd(i.numerator(), den);
-        T gcd2 = boost::math::gcd(num, i.denominator());
-#endif
+        T gcd1 = std::gcd(i.numerator(), den);
+        T gcd2 = std::gcd(num, i.denominator());
 
         bool fail = false;
         fail |= o3tl::checked_multiply(i.numerator() / gcd1, num / gcd2, num);
@@ -366,42 +366,9 @@ bool operator > ( const Fraction& rVal1, const Fraction& rVal2 )
     return toRational(rVal1.mnNumerator, rVal1.mnDenominator) > toRational(rVal2.mnNumerator, rVal2.mnDenominator);
 }
 
-SvStream& ReadFraction( SvStream& rIStream, Fraction & rFract )
-{
-    sal_Int32 num(0), den(0);
-    rIStream.ReadInt32( num );
-    rIStream.ReadInt32( den );
-    if ( den <= 0 )
-    {
-        SAL_WARN( "tools.fraction", "'ReadFraction()' read an invalid fraction" );
-        rFract.mbValid = false;
-    }
-    else
-    {
-        rFract.mnNumerator = num;
-        rFract.mnDenominator = den;
-        rFract.mbValid = true;
-    }
-    return rIStream;
-}
-
-SvStream& WriteFraction( SvStream& rOStream, const Fraction& rFract )
-{
-    if ( !rFract.mbValid )
-    {
-        SAL_WARN( "tools.fraction", "'WriteFraction()' write an invalid fraction" );
-        rOStream.WriteInt32( 0 );
-        rOStream.WriteInt32( -1 );
-    } else {
-        rOStream.WriteInt32( rFract.mnNumerator );
-        rOStream.WriteInt32( rFract.mnDenominator );
-    }
-    return rOStream;
-}
-
 // If dVal > LONG_MAX or dVal < LONG_MIN, the rational throws a boost::bad_rational.
-// Otherwise, dVal and denominator are multiplied by 10, until one of them
-// is larger than (LONG_MAX / 10).
+// Otherwise, dVal and denominator are multiplied by 8, until one of them
+// is larger than (LONG_MAX / 8).
 //
 // NOTE: here we use 'sal_Int32' due that only values in sal_Int32 range are valid.
 static boost::rational<sal_Int32> rational_FromDouble(double dVal)
@@ -411,60 +378,29 @@ static boost::rational<sal_Int32> rational_FromDouble(double dVal)
          std::isnan(dVal) )
         throw boost::bad_rational();
 
-    const sal_Int32 nMAX = std::numeric_limits<sal_Int32>::max() / 10;
+    const sal_Int32 nMAX = std::numeric_limits<sal_Int32>::max() / 8;
     sal_Int32 nDen = 1;
     while ( std::abs( dVal ) < nMAX && nDen < nMAX ) {
-        dVal *= 10;
-        nDen *= 10;
+        dVal *= 8;
+        nDen *= 8;
     }
     return boost::rational<sal_Int32>( sal_Int32(dVal), nDen );
 }
 
-// Similar to clz_table that can be googled
-const char nbits_table[32] =
-{
-    32,  1, 23,  2, 29, 24, 14,  3,
-    30, 27, 25, 18, 20, 15, 10,  4,
-    31, 22, 28, 13, 26, 17, 19,  9,
-    21, 12, 16,  8, 11,  7,  6,  5
-};
-
+/**
+ * Find the number of bits required to represent this number, using the CLZ intrinsic
+ */
 static int impl_NumberOfBits( sal_uInt32 nNum )
 {
-    // http://en.wikipedia.org/wiki/De_Bruijn_sequence
-    // background paper: Using de Bruijn Sequences to Index a 1 in a
-    // Computer Word (1998) Charles E. Leiserson,
-    // Harald Prokop, Keith H. Randall
-    // (e.g. http://citeseer.ist.psu.edu/leiserson98using.html)
-    const sal_uInt32 nDeBruijn = 0x7DCD629;
-
-    if ( nNum == 0 )
+    if (nNum == 0)
         return 0;
-
-    // Get it to form like 0000001111111111b
-    nNum |= ( nNum >>  1 );
-    nNum |= ( nNum >>  2 );
-    nNum |= ( nNum >>  4 );
-    nNum |= ( nNum >>  8 );
-    nNum |= ( nNum >> 16 );
-
-    sal_uInt32 nNumber;
-    int nBonus;
-
-    nNumber = nNum;
-    nBonus = 0;
-
-    // De facto shift left of nDeBruijn using multiplication (nNumber
-    // is all ones from topmost bit, thus nDeBruijn + (nDeBruijn *
-    // nNumber) => nDeBruijn * (nNumber+1) clears all those bits to
-    // zero, sets the next bit to one, and thus effectively shift-left
-    // nDeBruijn by lg2(nNumber+1). This generates a distinct 5bit
-    // sequence in the msb for each distinct position of the last
-    // leading 0 bit - that's the property of a de Bruijn number.
-    nNumber = nDeBruijn + ( nDeBruijn * nNumber );
-
-    // 5-bit window indexes the result
-    return ( nbits_table[nNumber >> 27] ) + nBonus;
+#ifdef _MSC_VER
+    unsigned long r = 0;
+    _BitScanReverse(&r, nNum);
+    return r + 1;
+#else
+    return 32 - __builtin_clz(nNum);
+#endif
 }
 
 /** Inaccurate cancellation for a fraction.
@@ -491,8 +427,15 @@ static void rational_ReduceInaccurate(boost::rational<sal_Int32>& rRational, uns
         return;
 
     // http://www.boost.org/doc/libs/release/libs/rational/rational.html#Internal%20representation
-    const bool bNeg = ( rRational.numerator() < 0 );
-    sal_Int32 nMul = bNeg? -rRational.numerator(): rRational.numerator();
+    sal_Int32 nMul = rRational.numerator();
+    if (nMul == std::numeric_limits<sal_Int32>::min())
+    {
+        // ofz#32973 Integer-overflow
+        return;
+    }
+    const bool bNeg = nMul < 0;
+    if (bNeg)
+        nMul = -nMul;
     sal_Int32 nDiv = rRational.denominator();
 
     DBG_ASSERT(nSignificantBits<65, "More than 64 bit of significance is overkill!");
