@@ -546,7 +546,7 @@ css::uno::Reference< css::sdbc::XRow > Content::getPropertyValues(
         }
     }
 
-    return css::uno::Reference< css::sdbc::XRow >( xRow.get() );
+    return xRow;
 }
 
 static css::lang::IllegalAccessException
@@ -712,7 +712,7 @@ css::uno::Sequence< css::uno::Any > Content::setPropertyValues(
                 continue;
             }
 
-            if ( aNewTitle.getLength() <= 0 )
+            if ( aNewTitle.isEmpty() )
             {
                 aRet[ n ] <<= css::lang::IllegalArgumentException
                     ( "Empty title not allowed!",
@@ -1103,8 +1103,13 @@ void Content::transfer( const css::ucb::TransferInfo& aTransferInfo, const css::
         bSuccess = g_file_copy(pSource, pDest, DEFAULT_COPYDATA_FLAGS, nullptr, nullptr, nullptr, &pError);
     g_object_unref(pSource);
     g_object_unref(pDest);
-    if (!bSuccess)
+    if (!bSuccess) {
+        SAL_INFO(
+            "ucb.ucp.gio",
+            "transfer <" << aTransferInfo.SourceURL << "> to <" << sDest << "> (MoveData = "
+                << int(aTransferInfo.MoveData) << ") failed with \"" << pError->message << "\"");
         ucbhelper::cancelCommandExecution(mapGIOError(pError), xEnv);
+    }
 }
 
 css::uno::Sequence< css::ucb::ContentInfo > Content::queryCreatableContentsInfo(
@@ -1112,32 +1117,22 @@ css::uno::Sequence< css::ucb::ContentInfo > Content::queryCreatableContentsInfo(
 {
     if ( isFolder( xEnv ) )
     {
-        css::uno::Sequence< css::ucb::ContentInfo > seq(2);
 
         // Minimum set of props we really need
-        css::uno::Sequence< css::beans::Property > props( 1 );
-        props[0] = css::beans::Property(
-            "Title",
-            -1,
-            cppu::UnoType<OUString>::get(),
-            css::beans::PropertyAttribute::MAYBEVOID | css::beans::PropertyAttribute::BOUND );
+        css::uno::Sequence< css::beans::Property > props
+        {
+            { "Title", -1, cppu::UnoType<OUString>::get(), css::beans::PropertyAttribute::MAYBEVOID | css::beans::PropertyAttribute::BOUND }
+        };
 
-        // file
-        seq[0].Type       = GIO_FILE_TYPE;
-        seq[0].Attributes = ( css::ucb::ContentInfoAttribute::INSERT_WITH_INPUTSTREAM |
-                              css::ucb::ContentInfoAttribute::KIND_DOCUMENT );
-        seq[0].Properties = props;
-
-        // folder
-        seq[1].Type       = GIO_FOLDER_TYPE;
-        seq[1].Attributes = css::ucb::ContentInfoAttribute::KIND_FOLDER;
-        seq[1].Properties = props;
-
-        return seq;
+        return
+        {
+            { GIO_FILE_TYPE, ( css::ucb::ContentInfoAttribute::INSERT_WITH_INPUTSTREAM | css::ucb::ContentInfoAttribute::KIND_DOCUMENT ), props },
+            { GIO_FOLDER_TYPE, css::ucb::ContentInfoAttribute::KIND_FOLDER, props }
+        };
     }
     else
     {
-        return css::uno::Sequence< css::ucb::ContentInfo >();
+        return {};
     }
 }
 
@@ -1309,12 +1304,12 @@ css::uno::Sequence< css::ucb::CommandInfo > Content::getCommands( const css::uno
 
 XTYPEPROVIDER_COMMON_IMPL( Content );
 
-void SAL_CALL Content::acquire() throw()
+void SAL_CALL Content::acquire() noexcept
 {
     ContentImplHelper::acquire();
 }
 
-void SAL_CALL Content::release() throw()
+void SAL_CALL Content::release() noexcept
 {
     ContentImplHelper::release();
 }
