@@ -19,9 +19,9 @@
 
 #include <sal/log.hxx>
 #include <ucbhelper/contenthelper.hxx>
-#include <ucbhelper/getcomponentcontext.hxx>
 #include <ucbhelper/macros.hxx>
 #include <cppuhelper/queryinterface.hxx>
+#include <cppuhelper/weak.hxx>
 #include <com/sun/star/ucb/ContentCreationException.hpp>
 #include <com/sun/star/ucb/IllegalIdentifierException.hpp>
 #include "gio_provider.hxx"
@@ -37,7 +37,7 @@ ContentProvider::queryContent(
     osl::MutexGuard aGuard( m_aMutex );
 
     // Check, if a content with given id already exists...
-    css::uno::Reference< css::ucb::XContent > xContent = queryExistingContent( Identifier ).get();
+    css::uno::Reference< css::ucb::XContent > xContent = queryExistingContent( Identifier );
     if ( xContent.is() )
         return xContent;
 
@@ -68,13 +68,13 @@ ContentProvider::~ContentProvider()
 
 // XInterface
 void SAL_CALL ContentProvider::acquire()
-    throw()
+    noexcept
 {
     OWeakObject::acquire();
 }
 
 void SAL_CALL ContentProvider::release()
-    throw()
+    noexcept
 {
     OWeakObject::release();
 }
@@ -94,24 +94,21 @@ XTYPEPROVIDER_IMPL_3( ContentProvider,
                       css::lang::XServiceInfo,
                       css::ucb::XContentProvider );
 
-XSERVICEINFO_COMMOM_IMPL( ContentProvider,
-                          "com.sun.star.comp.GIOContentProvider" )
-/// @throws css::uno::Exception
-static css::uno::Reference< css::uno::XInterface >
-ContentProvider_CreateInstance( const css::uno::Reference< css::lang::XMultiServiceFactory> & rSMgr )
+css::uno::Sequence< OUString > SAL_CALL ContentProvider::getSupportedServiceNames()
 {
-    css::lang::XServiceInfo* pX = new ContentProvider( ucbhelper::getComponentContext(rSMgr) );
-    return css::uno::Reference< css::uno::XInterface >::query( pX );
+    return { "com.sun.star.ucb.GIOContentProvider" };
 }
 
-css::uno::Sequence< OUString >
-ContentProvider::getSupportedServiceNames_Static()
+OUString SAL_CALL ContentProvider::getImplementationName()
 {
-    css::uno::Sequence< OUString > aSNS { "com.sun.star.ucb.GIOContentProvider" };
-    return aSNS;
+    return "com.sun.star.comp.GIOContentProvider";
+}
+
+sal_Bool SAL_CALL ContentProvider::supportsService(const OUString& aServiceName)
+{
+    return cppu::supportsService(this, aServiceName);
 }
 
-ONE_INSTANCE_SERVICE_FACTORY_IMPL( ContentProvider );
 
 }
 
@@ -125,32 +122,18 @@ static bool isDisabled()
     return aDisable.indexOf("ucpgio1") >= 0;
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT void * ucpgio1_component_getFactory( const char *pImplName,
-    void *pServiceManager, void * )
+
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface*
+ucb_gio_ContentProvider_get_implementation(
+    css::uno::XComponentContext* context , css::uno::Sequence<css::uno::Any> const&)
 {
-    void * pRet = nullptr;
-
-    static bool bDisabled = isDisabled();
-    if (bDisabled)
+    if (isDisabled())
         return nullptr;
-
-    css::uno::Reference< css::lang::XMultiServiceFactory > xSMgr
-        (static_cast< css::lang::XMultiServiceFactory * >( pServiceManager ) );
-    css::uno::Reference< css::lang::XSingleServiceFactory > xFactory;
-
 #if !GLIB_CHECK_VERSION(2,36,0)
     g_type_init();
 #endif
-    if ( ::gio::ContentProvider::getImplementationName_Static().equalsAscii( pImplName ) )
-        xFactory = ::gio::ContentProvider::createServiceFactory( xSMgr );
-
-    if ( xFactory.is() )
-    {
-        xFactory->acquire();
-        pRet = xFactory.get();
-    }
-
-    return pRet;
+    return cppu::acquire(new gio::ContentProvider(context));
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
