@@ -252,7 +252,7 @@ bool HierarchyResultSetDataSupplier::getResult( sal_uInt32 nIndex )
     if ( !bFound )
         m_pImpl->m_bCountFinal = true;
 
-    rtl::Reference< ::ucbhelper::ResultSet > xResultSet = getResultSet().get();
+    rtl::Reference< ::ucbhelper::ResultSet > xResultSet = getResultSet();
     if ( xResultSet.is() )
     {
         // Callbacks follow!
@@ -289,7 +289,7 @@ sal_uInt32 HierarchyResultSetDataSupplier::totalCount()
 
     m_pImpl->m_bCountFinal = true;
 
-    rtl::Reference< ::ucbhelper::ResultSet > xResultSet = getResultSet().get();
+    rtl::Reference< ::ucbhelper::ResultSet > xResultSet = getResultSet();
     if ( xResultSet.is() )
     {
         // Callbacks follow!
