@@ -803,7 +803,7 @@ bool SvtLinguConfigItem::IsReadOnly( sal_Int32 nPropertyHandle ) const
 static SvtLinguConfigItem *pCfgItem = nullptr;
 static sal_Int32           nCfgItemRefCount = 0;
 
-const char aG_Dictionaries[] = "Dictionaries";
+constexpr OUStringLiteral aG_Dictionaries = u"Dictionaries";
 
 SvtLinguConfig::SvtLinguConfig()
 {
@@ -1013,10 +1013,10 @@ uno::Sequence< OUString > SvtLinguConfig::GetDisabledDictionaries() const
 }
 
 std::vector< SvtLinguConfigDictionaryEntry > SvtLinguConfig::GetActiveDictionariesByFormat(
-    const OUString &rFormatName ) const
+    std::u16string_view rFormatName ) const
 {
     std::vector< SvtLinguConfigDictionaryEntry > aRes;
-    if (rFormatName.isEmpty())
+    if (rFormatName.empty())
         return aRes;
 
     try
