@@ -20,10 +20,13 @@
 #include <com/sun/star/xml/crypto/XSecurityEnvironment.hpp>
 #include <com/sun/star/security/DocumentDigitalSignatures.hpp>
 #include <comphelper/processfactory.hxx>
+#include <vcl/svapp.hxx>
+#include <osl/file.hxx>
 #include <osl/file.h>
 #include <rtl/ustrbuf.hxx>
 #include <tools/debug.hxx>
 #include <unotools/securityoptions.hxx>
+#include <tools/urlobj.hxx>
 
 using namespace ::com::sun::star::security;
 
@@ -73,14 +76,23 @@ MacroWarning::MacroWarning(weld::Window* pParent, bool _bWithSignatures)
     InitControls();
 
     mxEnableBtn->connect_clicked(LINK(this, MacroWarning, EnableBtnHdl));
+    mxDisableBtn->connect_clicked(LINK(this, MacroWarning, DisableBtnHdl));
     mxDisableBtn->grab_focus(); // Default button, but focus is on view button
+    m_xDialog->SetInstallLOKNotifierHdl(LINK(this, MacroWarning, InstallLOKNotifierHdl));
+}
+
+IMPL_STATIC_LINK_NOARG(MacroWarning, InstallLOKNotifierHdl, void*, vcl::ILibreOfficeKitNotifier*)
+{
+    return GetpApp();
 }
 
 void MacroWarning::SetDocumentURL( const OUString& rDocURL )
 {
-    OUString aAbbreviatedPath;
-    osl_abbreviateSystemPath(rDocURL.pData, &aAbbreviatedPath.pData, 50, nullptr);
-    m_xDialog->set_primary_text(aAbbreviatedPath);
+    OUString aPath;
+
+    osl::FileBase::getFileURLFromSystemPath(rDocURL, aPath);
+    aPath = INetURLObject(aPath).GetLastName();
+    m_xDialog->set_primary_text(aPath);
 }
 
 IMPL_LINK_NOARG(MacroWarning, ViewSignsBtnHdl, weld::Button&, void)
@@ -120,7 +132,12 @@ IMPL_LINK_NOARG(MacroWarning, EnableBtnHdl, weld::Button&, void)
     m_xDialog->response(RET_OK);
 }
 
-IMPL_LINK_NOARG(MacroWarning, AlwaysTrustCheckHdl, weld::Button&, void)
+IMPL_LINK_NOARG(MacroWarning, DisableBtnHdl, weld::Button&, void)
+{
+    m_xDialog->response(RET_CANCEL);
+}
+
+IMPL_LINK_NOARG(MacroWarning, AlwaysTrustCheckHdl, weld::Toggleable&, void)
 {
     const bool bEnable = (mnActSecLevel < 2 || mxAlwaysTrustCB->get_active());
     mxEnableBtn->set_sensitive(bEnable);
@@ -137,7 +154,7 @@ void MacroWarning::InitControls()
 
         const SvtSecurityOptions aSecOption;
         if (!aSecOption.IsReadOnly(SvtSecurityOptions::EOption::MacroTrustedAuthors))
-            mxAlwaysTrustCB->connect_clicked(LINK(this, MacroWarning, AlwaysTrustCheckHdl));
+            mxAlwaysTrustCB->connect_toggled(LINK(this, MacroWarning, AlwaysTrustCheckHdl));
         else
             mxAlwaysTrustCB->set_visible(false);
 
@@ -158,21 +175,21 @@ void MacroWarning::SetStorage( const css::uno::Reference < css::embed::XStorage
     mxStore = rxStore;
     maODFVersion = aODFVersion;
     sal_Int32   nCnt = rInfos.getLength();
-    if( mxStore.is() && nCnt > 0 )
+    if( !(mxStore.is() && nCnt > 0) )
+        return;
+
+    mpInfos = &rInfos;
+    OUString aCN_Id("CN");
+    OUStringBuffer s = GetContentPart( rInfos[ 0 ].Signer->getSubjectName(), aCN_Id );
+
+    for( sal_Int32 i = 1 ; i < nCnt ; ++i )
     {
-        mpInfos = &rInfos;
-        OUString aCN_Id("CN");
-        OUStringBuffer s = GetContentPart( rInfos[ 0 ].Signer->getSubjectName(), aCN_Id );
-
-        for( sal_Int32 i = 1 ; i < nCnt ; ++i )
-        {
-            s.append("\n");
-            s.append(GetContentPart( rInfos[ i ].Signer->getSubjectName(), aCN_Id ));
-        }
-
-        mxSignsFI->set_label(s.makeStringAndClear());
-        mxViewSignsBtn->set_sensitive(true);
+        s.append("\n");
+        s.append(GetContentPart( rInfos[ i ].Signer->getSubjectName(), aCN_Id ));
     }
+
+    mxSignsFI->set_label(s.makeStringAndClear());
+    mxViewSignsBtn->set_sensitive(true);
 }
 
 void MacroWarning::SetCertificate( const css::uno::Reference< css::security::XCertificate >& _rxCert )
