@@ -21,15 +21,13 @@
 using namespace ::ooo::vba;
 using namespace ::com::sun::star;
 
-::sal_Int32
-VbaDialogsBase::getCount() throw (uno::RuntimeException, std::exception)
+::sal_Int32 VbaDialogsBase::getCount()
 {
     //#STUB
     return 0;
 }
 
-uno::Any
-VbaDialogsBase::Item( const uno::Any& /* &aItem */) throw (uno::RuntimeException, std::exception)
+uno::Any VbaDialogsBase::Item(const uno::Any& /* &aItem */)
 {
     //#STUB
     return uno::Any();
