@@ -124,13 +124,11 @@ namespace
 
 bool SvpSalGraphics::blendBitmap( const SalTwoRect&, const SalBitmap& /*rBitmap*/ )
 {
-    SAL_WARN("vcl.gdi", "unsupported SvpSalGraphics::blendBitmap case");
     return false;
 }
 
 bool SvpSalGraphics::blendAlphaBitmap( const SalTwoRect&, const SalBitmap&, const SalBitmap&, const SalBitmap& )
 {
-    SAL_WARN("vcl.gdi", "unsupported SvpSalGraphics::blendAlphaBitmap case");
     return false;
 }
 
@@ -754,7 +752,8 @@ bool SvpSalGraphics::drawTransformedBitmap(
     const basegfx::B2DPoint& rX,
     const basegfx::B2DPoint& rY,
     const SalBitmap& rSourceBitmap,
-    const SalBitmap* pAlphaBitmap)
+    const SalBitmap* pAlphaBitmap,
+    double fAlpha)
 {
     if (pAlphaBitmap && pAlphaBitmap->GetBitCount() != 8 && pAlphaBitmap->GetBitCount() != 1)
     {
@@ -762,6 +761,9 @@ bool SvpSalGraphics::drawTransformedBitmap(
         return false;
     }
 
+    if( fAlpha != 1.0 )
+        return false;
+
     // MM02 try to access buffered BitmapHelper
     std::shared_ptr<BitmapHelper> aSurface;
     tryToUseSourceBuffer(rSourceBitmap, aSurface);
@@ -831,6 +833,11 @@ bool SvpSalGraphics::drawTransformedBitmap(
     return true;
 }
 
+bool SvpSalGraphics::hasFastDrawTransformedBitmap() const
+{
+    return false;
+}
+
 void SvpSalGraphics::clipRegion(cairo_t* cr, const vcl::Region& rClipRegion)
 {
     RectangleVector aRectangles;
@@ -1947,7 +1954,7 @@ bool SvpSalGraphics::drawGradient(const tools::PolyPolygon& rPolyPolygon, const
     tools::Rectangle aBoundRect;
     Point aCenter;
 
-    aGradient.SetAngle(aGradient.GetAngle() + Degree10(2700));
+    aGradient.SetAngle(aGradient.GetAngle() + 2700_deg10);
     aGradient.GetBoundRect(aInputRect, aBoundRect, aCenter);
     Color aStartColor = aGradient.GetStartColor();
     Color aEndColor = aGradient.GetEndColor();
@@ -1956,7 +1963,7 @@ bool SvpSalGraphics::drawGradient(const tools::PolyPolygon& rPolyPolygon, const
     if (rGradient.GetStyle() == GradientStyle::Linear)
     {
         tools::Polygon aPoly(aBoundRect);
-        aPoly.Rotate(aCenter, aGradient.GetAngle() % Degree10(3600));
+        aPoly.Rotate(aCenter, aGradient.GetAngle() % 3600_deg10);
         pattern = cairo_pattern_create_linear(aPoly[0].X(), aPoly[0].Y(), aPoly[1].X(), aPoly[1].Y());
     }
     else
@@ -2009,7 +2016,7 @@ bool SvpSalGraphics::implDrawGradient(basegfx::B2DPolyPolygon const & rPolyPolyg
         double r = rStop.maColor.GetRed() / 255.0;
         double g = rStop.maColor.GetGreen() / 255.0;
         double b = rStop.maColor.GetBlue() / 255.0;
-        double a = (0xFF - rStop.maColor.GetTransparency()) / 255.0;
+        double a = rStop.maColor.GetAlpha() / 255.0;
         double offset = rStop.mfOffset;
 
         cairo_pattern_add_color_stop_rgba(pattern, offset, r, g, b, a);
@@ -2196,7 +2203,7 @@ void SvpSalGraphics::drawMask( const SalTwoRect& rTR,
     }
     sal_Int32 nStride;
     unsigned char *mask_data = aSurface.getBits(nStride);
-    vcl::bitmap::lookup_table unpremultiply_table = vcl::bitmap::get_unpremultiply_table();
+    vcl::bitmap::lookup_table const & unpremultiply_table = vcl::bitmap::get_unpremultiply_table();
     for (tools::Long y = rTR.mnSrcY ; y < rTR.mnSrcY + rTR.mnSrcHeight; ++y)
     {
         unsigned char *row = mask_data + (nStride*y);
@@ -2255,14 +2262,20 @@ std::shared_ptr<SalBitmap> SvpSalGraphics::getBitmap( tools::Long nX, tools::Lon
 {
     std::shared_ptr<SvpSalBitmap> pBitmap = std::make_shared<SvpSalBitmap>();
     BitmapPalette aPal;
+    vcl::PixelFormat ePixelFormat = vcl::PixelFormat::INVALID;
     if (GetBitCount() == 1)
     {
+        ePixelFormat = vcl::PixelFormat::N1_BPP;
         aPal.SetEntryCount(2);
         aPal[0] = COL_BLACK;
         aPal[1] = COL_WHITE;
     }
+    else
+    {
+        ePixelFormat = vcl::PixelFormat::N32_BPP;
+    }
 
-    if (!pBitmap->Create(Size(nWidth, nHeight), GetBitCount(), aPal))
+    if (!pBitmap->Create(Size(nWidth, nHeight), ePixelFormat, aPal))
     {
         SAL_WARN("vcl.gdi", "SvpSalGraphics::getBitmap, cannot create bitmap");
         return nullptr;
@@ -2303,13 +2316,13 @@ Color SvpSalGraphics::getPixel( tools::Long nX, tools::Long nY )
     cairo_destroy(cr);
 
     cairo_surface_flush(target);
-    vcl::bitmap::lookup_table unpremultiply_table = vcl::bitmap::get_unpremultiply_table();
+    vcl::bitmap::lookup_table const & unpremultiply_table = vcl::bitmap::get_unpremultiply_table();
     unsigned char *data = cairo_image_surface_get_data(target);
     sal_uInt8 a = data[SVP_CAIRO_ALPHA];
     sal_uInt8 b = unpremultiply_table[a][data[SVP_CAIRO_BLUE]];
     sal_uInt8 g = unpremultiply_table[a][data[SVP_CAIRO_GREEN]];
     sal_uInt8 r = unpremultiply_table[a][data[SVP_CAIRO_RED]];
-    Color aColor(0xFF - a, r, g, b);
+    Color aColor(ColorAlpha, a, r, g, b);
     cairo_surface_destroy(target);
 
     return aColor;
@@ -2570,8 +2583,22 @@ void SvpSalGraphics::releaseCairoContext(cairo_t* cr, bool bXorModeAllowed, cons
         sal_Int32 nUnscaledExtentsRight = nExtentsRight * m_fScale;
         sal_Int32 nUnscaledExtentsTop = nExtentsTop * m_fScale;
         sal_Int32 nUnscaledExtentsBottom = nExtentsBottom * m_fScale;
-        vcl::bitmap::lookup_table unpremultiply_table = vcl::bitmap::get_unpremultiply_table();
-        vcl::bitmap::lookup_table premultiply_table = vcl::bitmap::get_premultiply_table();
+
+        // not sure why this happens
+        int target_surface_width = cairo_image_surface_get_width(target_surface);
+        if (nUnscaledExtentsLeft > target_surface_width)
+            nUnscaledExtentsLeft = target_surface_width;
+        if (nUnscaledExtentsRight > target_surface_width)
+            nUnscaledExtentsRight = target_surface_width;
+        int target_surface_height = cairo_image_surface_get_height(target_surface);
+        if (nUnscaledExtentsTop > target_surface_height)
+            nUnscaledExtentsTop = target_surface_height;
+        if (nUnscaledExtentsBottom > target_surface_height)
+            nUnscaledExtentsBottom = target_surface_height;
+
+        vcl::bitmap::lookup_table const & unpremultiply_table
+            = vcl::bitmap::get_unpremultiply_table();
+        vcl::bitmap::lookup_table const & premultiply_table = vcl::bitmap::get_premultiply_table();
         for (sal_Int32 y = nUnscaledExtentsTop; y < nUnscaledExtentsBottom; ++y)
         {
             unsigned char *true_row = target_surface_data + (nStride*y);
