@@ -241,12 +241,12 @@ void SvpSalInstance::DestroyObject( SalObject* pObject )
 
 #ifndef IOS
 
-std::unique_ptr<SalVirtualDevice> SvpSalInstance::CreateVirtualDevice(SalGraphics* pGraphics,
+std::unique_ptr<SalVirtualDevice> SvpSalInstance::CreateVirtualDevice(SalGraphics& rGraphics,
                                                        tools::Long &nDX, tools::Long &nDY,
-                                                       DeviceFormat eFormat,
+                                                       DeviceFormat /*eFormat*/,
                                                        const SystemGraphicsData* pGd)
 {
-    SvpSalGraphics *pSvpSalGraphics = dynamic_cast<SvpSalGraphics*>(pGraphics);
+    SvpSalGraphics *pSvpSalGraphics = dynamic_cast<SvpSalGraphics*>(&rGraphics);
     assert(pSvpSalGraphics);
 #ifndef ANDROID
     // tdf#127529 normally pPreExistingTarget is null and we are a true virtualdevice drawing to a backing buffer.
@@ -258,7 +258,7 @@ std::unique_ptr<SalVirtualDevice> SvpSalInstance::CreateVirtualDevice(SalGraphic
     (void)pGd;
     cairo_surface_t* pPreExistingTarget = nullptr;
 #endif
-    std::unique_ptr<SalVirtualDevice> pNew(new SvpSalVirtualDevice(eFormat, pSvpSalGraphics->getSurface(), pPreExistingTarget));
+    std::unique_ptr<SalVirtualDevice> pNew(new SvpSalVirtualDevice(pSvpSalGraphics->getSurface(), pPreExistingTarget));
     pNew->SetSize( nDX, nDY );
     return pNew;
 }
@@ -369,7 +369,11 @@ void SvpSalYieldMutex::doAcquire(sal_uInt32 const nLockCount)
                 m_bNoYieldLock = true;
                 bool const bEvents = pInst->DoYield(false, request == SvpRequest::MainThreadDispatchAllEvents);
                 m_bNoYieldLock = false;
-                write(m_FeedbackFDs[1], &bEvents, sizeof(bool));
+                if (write(m_FeedbackFDs[1], &bEvents, sizeof(bool)) != sizeof(bool))
+                {
+                    SAL_WARN("vcl.headless", "Could not write: " << strerror(errno));
+                    std::abort();
+                }
             }
         }
         while (true);
@@ -590,9 +594,11 @@ void SvpSalInstance::AddToRecentDocumentList(const OUString&, const OUString&, c
 std::shared_ptr<vcl::BackendCapabilities> SvpSalInstance::GetBackendCapabilities()
 {
     auto pBackendCapabilities = SalInstance::GetBackendCapabilities();
+#if 0 // LO code is not yet bitmap32-ready.
 #ifndef IOS
     // Note: This code is used for iOS, too. Let's not use 32-bit bitmaps with included alpha on iOS for now.
     pBackendCapabilities->mbSupportsBitmap32 = true;
+#endif
 #endif
     return pBackendCapabilities;
 }
