@@ -53,7 +53,6 @@
 
 class AquaSalFrame;
 class FontAttributes;
-class CoreTextStyle;
 class XorEmulation;
 
 // CoreText-specific physically available font face
@@ -131,175 +130,326 @@ private:
     std::unordered_map<sal_IntPtr, rtl::Reference<CoreTextFontFace>> maFontContainer;
 };
 
-class AquaSalGraphics : public SalGraphics
+namespace sal::aqua
 {
+float getWindowScaling();
+}
+
+struct AquaSharedAttributes
+{
+    /// path representing current clip region
+    CGMutablePathRef mxClipPath;
+
+    /// Drawing colors
+    /// pen color RGBA
+    RGBAColor maLineColor;
+
+    /// brush color RGBA
+    RGBAColor maFillColor;
+
+    // Graphics types
+#ifdef MACOSX
+    AquaSalFrame* mpFrame;
+    /// is this a window graphics
+    bool mbWindow;
+#else // IOS
+    // mirror AquaSalVirtualDevice::mbForeignContext for SvpSalGraphics objects related to such
+    bool mbForeignContext;
+#endif
+    /// is this a printer graphics
+    bool mbPrinter;
+    /// is this a virtual device graphics
+    bool mbVirDev;
+
     CGLayerHolder maLayer; // Quartz graphics layer
     CGContextHolder maContextHolder;  // Quartz drawing context
     CGContextHolder maBGContextHolder;  // Quartz drawing context for CGLayer
     CGContextHolder maCSContextHolder;  // Quartz drawing context considering the color space
+    int mnWidth;
+    int mnHeight;
+    int mnXorMode; // 0: off 1: on 2: invert only
+    int mnBitmapDepth;  // zero unless bitmap
+
+    std::unique_ptr<XorEmulation> mpXorEmulation;
+
+    AquaSharedAttributes()
+        : mxClipPath(nullptr)
+        , maLineColor(COL_WHITE)
+        , maFillColor(COL_BLACK)
+#ifdef MACOSX
+        , mpFrame(nullptr)
+        , mbWindow(false)
+#else
+        , mbForeignContext(false)
+#endif
+        , mbPrinter(false)
+        , mbVirDev(false)
+        , mnWidth(0)
+        , mnHeight(0)
+        , mnXorMode(0)
+        , mnBitmapDepth(0)
+    {}
+
+    void unsetClipPath()
+    {
+        if (mxClipPath)
+        {
+            CGPathRelease(mxClipPath);
+            mxClipPath = nullptr;
+        }
+    }
+
+    void unsetState()
+    {
+        unsetClipPath();
+    }
+
+    bool checkContext();
+    void setState();
+
+    bool isPenVisible() const
+    {
+        return maLineColor.IsVisible();
+    }
+    bool isBrushVisible() const
+    {
+        return maFillColor.IsVisible();
+    }
+
+    void refreshRect(float lX, float lY, float lWidth, float lHeight)
+    {
+#ifdef MACOSX
+        if (!mbWindow) // view only on Window graphics
+            return;
+
+        if (mpFrame)
+        {
+            // update a little more around the designated rectangle
+            // this helps with antialiased rendering
+            // Rounding down x and width can accumulate a rounding error of up to 2
+            // The decrementing of x, the rounding error and the antialiasing border
+            // require that the width and the height need to be increased by four
+            const tools::Rectangle aVclRect(
+                    Point(tools::Long(lX - 1), tools::Long(lY - 1)),
+                    Size(tools::Long(lWidth + 4), tools::Long(lHeight + 4)));
+
+            mpFrame->maInvalidRect.Union(aVclRect);
+        }
+#else
+        (void) lX;
+        (void) lY;
+        (void) lWidth;
+        (void) lHeight;
+        return;
+#endif
+    }
+
+    // apply the XOR mask to the target context if active and dirty
+    void applyXorContext()
+    {
+        if (!mpXorEmulation)
+            return;
+        if (mpXorEmulation->UpdateTarget())
+        {
+            refreshRect(0, 0, mnWidth, mnHeight); // TODO: refresh minimal changerect
+        }
+    }
+
+    // differences between VCL, Quartz and kHiThemeOrientation coordinate systems
+    // make some graphics seem to be vertically-mirrored from a VCL perspective
+    bool isFlipped() const
+    {
+    #ifdef MACOSX
+        return mbWindow;
+    #else
+        return false;
+    #endif
+    }
+};
+
+class AquaGraphicsBackend final : public SalGraphicsImpl
+{
+private:
+    AquaSharedAttributes& mrShared;
+
+    void drawPixelImpl( tools::Long nX, tools::Long nY, const RGBAColor& rColor); // helper to draw single pixels
+
+#ifdef MACOSX
+    void refreshRect(const NSRect& rRect)
+    {
+        mrShared.refreshRect(rRect.origin.x, rRect.origin.y, rRect.size.width, rRect.size.height);
+    }
+#else
+    void refreshRect(const CGRect& /*rRect*/)
+    {}
+#endif
+
+    void pattern50Fill();
+
+#ifdef MACOSX
+    void copyScaledArea(tools::Long nDestX, tools::Long nDestY, tools::Long nSrcX, tools::Long nSrcY,
+                        tools::Long nSrcWidth, tools::Long nSrcHeight, AquaSharedAttributes* pSrcShared);
+#endif
+
+public:
+    AquaGraphicsBackend(AquaSharedAttributes & rShared);
+    ~AquaGraphicsBackend() override;
+
+    void Init() override;
+
+    void freeResources() override;
+
+    OUString getRenderBackendName() const override
+    {
+        return "aqua";
+    }
+
+    bool setClipRegion(vcl::Region const& rRegion) override;
+    void ResetClipRegion() override;
+
+    sal_uInt16 GetBitCount() const override;
+
+    tools::Long GetGraphicsWidth() const override;
+
+    void SetLineColor() override;
+    void SetLineColor(Color nColor) override;
+    void SetFillColor() override;
+    void SetFillColor(Color nColor) override;
+    void SetXORMode(bool bSet, bool bInvertOnly) override;
+    void SetROPLineColor(SalROPColor nROPColor) override;
+    void SetROPFillColor(SalROPColor nROPColor) override;
+
+    void drawPixel(tools::Long nX, tools::Long nY) override;
+    void drawPixel(tools::Long nX, tools::Long nY, Color nColor) override;
+
+    void drawLine(tools::Long nX1, tools::Long nY1, tools::Long nX2, tools::Long nY2) override;
+    void drawRect(tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight) override;
+    void drawPolyLine(sal_uInt32 nPoints, const Point* pPointArray) override;
+    void drawPolygon(sal_uInt32 nPoints, const Point* pPointArray) override;
+    void drawPolyPolygon(sal_uInt32 nPoly, const sal_uInt32* pPoints,
+                         const Point** pPointArray) override;
+
+    bool drawPolyPolygon(const basegfx::B2DHomMatrix& rObjectToDevice,
+                         const basegfx::B2DPolyPolygon&, double fTransparency) override;
+
+    bool drawPolyLine(const basegfx::B2DHomMatrix& rObjectToDevice, const basegfx::B2DPolygon&,
+                      double fTransparency, double fLineWidth, const std::vector<double>* pStroke,
+                      basegfx::B2DLineJoin, css::drawing::LineCap, double fMiterMinimumAngle,
+                      bool bPixelSnapHairline) override;
+
+    bool drawPolyLineBezier(sal_uInt32 nPoints, const Point* pPointArray,
+                            const PolyFlags* pFlagArray) override;
+
+    bool drawPolygonBezier(sal_uInt32 nPoints, const Point* pPointArray,
+                           const PolyFlags* pFlagArray) override;
+
+    bool drawPolyPolygonBezier(sal_uInt32 nPoly, const sal_uInt32* pPoints,
+                               const Point* const* pPointArray,
+                               const PolyFlags* const* pFlagArray) override;
+
+    void copyArea(tools::Long nDestX, tools::Long nDestY, tools::Long nSrcX, tools::Long nSrcY,
+                  tools::Long nSrcWidth, tools::Long nSrcHeight, bool bWindowInvalidate) override;
+
+    void copyBits(const SalTwoRect& rPosAry, SalGraphics* pSrcGraphics) override;
+
+    void drawBitmap(const SalTwoRect& rPosAry, const SalBitmap& rSalBitmap) override;
+
+    void drawBitmap(const SalTwoRect& rPosAry, const SalBitmap& rSalBitmap,
+                    const SalBitmap& rMaskBitmap) override;
+
+    void drawMask(const SalTwoRect& rPosAry, const SalBitmap& rSalBitmap,
+                  Color nMaskColor) override;
+
+    std::shared_ptr<SalBitmap> getBitmap(tools::Long nX, tools::Long nY, tools::Long nWidth,
+                                         tools::Long nHeight) override;
+
+    Color getPixel(tools::Long nX, tools::Long nY) override;
+
+    void invert(tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight,
+                SalInvert nFlags) override;
+
+    void invert(sal_uInt32 nPoints, const Point* pPtAry, SalInvert nFlags) override;
+
+    bool drawEPS(tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight,
+                 void* pPtr, sal_uInt32 nSize) override;
+
+    bool blendBitmap(const SalTwoRect&, const SalBitmap& rBitmap) override;
+
+    bool blendAlphaBitmap(const SalTwoRect&, const SalBitmap& rSrcBitmap,
+                          const SalBitmap& rMaskBitmap, const SalBitmap& rAlphaBitmap) override;
+
+    bool drawAlphaBitmap(const SalTwoRect&, const SalBitmap& rSourceBitmap,
+                         const SalBitmap& rAlphaBitmap) override;
+
+    bool drawTransformedBitmap(const basegfx::B2DPoint& rNull, const basegfx::B2DPoint& rX,
+                               const basegfx::B2DPoint& rY, const SalBitmap& rSourceBitmap,
+                               const SalBitmap* pAlphaBitmap, double fAlpha) override;
+
+    bool hasFastDrawTransformedBitmap() const override;
+
+    bool drawAlphaRect(tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight,
+                       sal_uInt8 nTransparency) override;
+
+    bool drawGradient(const tools::PolyPolygon& rPolygon, const Gradient& rGradient) override;
+    bool implDrawGradient(basegfx::B2DPolyPolygon const& rPolyPolygon,
+                          SalGradient const& rGradient) override;
+
+    bool supportsOperation(OutDevSupportType eType) const override;
+};
+
+class AquaSalGraphics : public SalGraphicsAutoDelegateToImpl
+{
+    AquaSharedAttributes maShared;
+    std::unique_ptr<AquaGraphicsBackend> mpBackend;
 
-    XorEmulation*                           mpXorEmulation;
-    int                                     mnXorMode; // 0: off 1: on 2: invert only
-    int                                     mnWidth;
-    int                                     mnHeight;
-    int                                     mnBitmapDepth;  // zero unless bitmap
     /// device resolution of this graphics
     sal_Int32                               mnRealDPIX;
     sal_Int32                               mnRealDPIY;
 
-    /// path representing current clip region
-    CGMutablePathRef                        mxClipPath;
-
-    /// Drawing colors
-    /// pen color RGBA
-    RGBAColor                               maLineColor;
-    /// brush color RGBA
-    RGBAColor                               maFillColor;
-
     // Device Font settings
     rtl::Reference<CoreTextStyle>           mpTextStyle[MAX_FALLBACK];
     RGBAColor                               maTextColor;
     /// allows text to be rendered without antialiasing
     bool                                    mbNonAntialiasedText;
 
-#ifdef MACOSX
-    AquaSalFrame*                           mpFrame;
-#endif
-
-    // Graphics types
-
-    /// is this a printer graphics
-    bool                                    mbPrinter;
-    /// is this a virtual device graphics
-    bool                                    mbVirDev;
-#ifdef MACOSX
-    /// is this a window graphics
-    bool                                    mbWindow;
-
-#else // IOS
-
-    // mirror AquaSalVirtualDevice::mbForeignContext for SvpSalGraphics objects related to such
-    bool mbForeignContext;
-
-#endif
-
 public:
                             AquaSalGraphics();
     virtual                 ~AquaSalGraphics() override;
 
-    bool                    IsPenVisible() const    { return maLineColor.IsVisible(); }
-    bool                    IsBrushVisible() const  { return maFillColor.IsVisible(); }
-
     void                    SetVirDevGraphics(CGLayerHolder const &rLayer, CGContextRef, int nBitDepth = 0);
 #ifdef MACOSX
     void                    initResolution( NSWindow* );
     void                    copyResolution( AquaSalGraphics& );
     void                    updateResolution();
 
-    static float            GetWindowScaling();
     void                    SetWindowGraphics( AquaSalFrame* pFrame );
-    bool                    IsWindowGraphics()      const   { return mbWindow; }
+    bool                    IsWindowGraphics() const { return maShared.mbWindow; }
     void                    SetPrinterGraphics(CGContextRef, sal_Int32 nRealDPIX, sal_Int32 nRealDPIY);
-    AquaSalFrame*           getGraphicsFrame() const { return mpFrame; }
-    void                    setGraphicsFrame( AquaSalFrame* pFrame ) { mpFrame = pFrame; }
+    AquaSalFrame*           getGraphicsFrame() const { return maShared.mpFrame; }
+    void                    setGraphicsFrame( AquaSalFrame* pFrame ) { maShared.mpFrame = pFrame; }
 #endif
 
-    void                    ImplDrawPixel( tools::Long nX, tools::Long nY, const RGBAColor& ); // helper to draw single pixels
-
-    bool                    CheckContext();
-    CGContextRef            GetContext();
 #ifdef MACOSX
     void                    UpdateWindow( NSRect& ); // delivered in NSView coordinates
-    void                    RefreshRect( const NSRect& );
+    void                    RefreshRect(const NSRect& rRect)
+    {
+        maShared.refreshRect(rRect.origin.x, rRect.origin.y, rRect.size.width, rRect.size.height);
+    }
 #else
     void                    RefreshRect( const CGRect& ) {}
 #endif
-    void                    RefreshRect(float lX, float lY, float lWidth, float lHeight);
 
-    void                    SetState();
     void                    UnsetState();
     // InvalidateContext does an UnsetState and sets mrContext to 0
     void                    InvalidateContext();
 
+    AquaGraphicsBackend* getAquaGraphicsBackend() const
+    {
+        return mpBackend.get();
+    }
+
     virtual SalGraphicsImpl* GetImpl() const override;
 
-    virtual bool            setClipRegion( const vcl::Region& ) override;
-
-    // draw --> LineColor and FillColor and RasterOp and ClipRegion
-    virtual void            drawPixel( tools::Long nX, tools::Long nY ) override;
-    virtual void            drawPixel( tools::Long nX, tools::Long nY, Color nColor ) override;
-    virtual void            drawLine(
-        tools::Long nX1, tools::Long nY1, tools::Long nX2, tools::Long nY2 ) override;
-    virtual void            drawRect(
-        tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight ) override;
-    virtual void            drawPolyLine( sal_uInt32 nPoints, const Point* pPtAry ) override;
-    virtual void            drawPolygon( sal_uInt32 nPoints, const Point* pPtAry ) override;
-    virtual void            drawPolyPolygon( sal_uInt32 nPoly, const sal_uInt32* pPoints, const Point** pPtAry ) override;
-    virtual bool            drawPolyPolygon(
-                                const basegfx::B2DHomMatrix& rObjectToDevice,
-                                const basegfx::B2DPolyPolygon&,
-                                double fTransparency) override;
-    virtual bool            drawPolyLineBezier( sal_uInt32 nPoints, const Point* pPtAry, const PolyFlags* pFlgAry ) override;
-    virtual bool            drawPolygonBezier( sal_uInt32 nPoints, const Point* pPtAry, const PolyFlags* pFlgAry ) override;
-    virtual bool            drawPolyPolygonBezier( sal_uInt32 nPoly, const sal_uInt32* pPoints, const Point* const* pPtAry, const PolyFlags* const* pFlgAry ) override;
-    virtual bool            drawPolyLine(
-                                const basegfx::B2DHomMatrix& rObjectToDevice,
-                                const basegfx::B2DPolygon&,
-                                double fTransparency,
-                                double rLineWidth,
-                                const std::vector< double >* pStroke, // MM01
-                                basegfx::B2DLineJoin,
-                                css::drawing::LineCap eLineCap,
-                                double fMiterMinimumAngle,
-                                bool bPixelSnapHairline) override;
-    virtual bool            drawGradient( const tools::PolyPolygon&, const Gradient& ) override { return false; };
-
-    // CopyArea --> No RasterOp, but ClipRegion
-    virtual void            copyArea( tools::Long nDestX, tools::Long nDestY, tools::Long nSrcX, tools::Long nSrcY, tools::Long nSrcWidth,
-                                      tools::Long nSrcHeight, bool bWindowInvalidate ) override;
-
-    // CopyBits and DrawBitmap --> RasterOp and ClipRegion
-    // CopyBits() --> pSrcGraphics == NULL, then CopyBits on same Graphics
-    virtual void            copyBits( const SalTwoRect& rPosAry, SalGraphics* pSrcGraphics ) override;
-    virtual void            drawBitmap( const SalTwoRect& rPosAry, const SalBitmap& rSalBitmap ) override;
-    virtual void            drawBitmap( const SalTwoRect& rPosAry,
-                                        const SalBitmap& rSalBitmap,
-                                        const SalBitmap& rTransparentBitmap ) override;
-    virtual void            drawMask( const SalTwoRect& rPosAry,
-                                      const SalBitmap& rSalBitmap,
-                                      Color nMaskColor ) override;
-
-    virtual std::shared_ptr<SalBitmap> getBitmap( tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight ) override;
-    virtual Color           getPixel( tools::Long nX, tools::Long nY ) override;
-
-    // invert --> ClipRegion (only Windows or VirDevs)
-    virtual void            invert( tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight, SalInvert nFlags) override;
-    virtual void            invert( sal_uInt32 nPoints, const Point* pPtAry, SalInvert nFlags ) override;
-
-    virtual bool            drawEPS( tools::Long nX, tools::Long nY, tools::Long nWidth, tools::Long nHeight, void* pPtr, sal_uInt32 nSize ) override;
-
-    virtual bool            blendBitmap( const SalTwoRect&,
-                                         const SalBitmap& rBitmap ) override;
-
-    virtual bool            blendAlphaBitmap( const SalTwoRect&,
-                                              const SalBitmap& rSrcBitmap,
-                                              const SalBitmap& rMaskBitmap,
-                                              const SalBitmap& rAlphaBitmap ) override;
-
-    virtual bool            drawAlphaBitmap( const SalTwoRect&,
-                                             const SalBitmap& rSourceBitmap,
-                                             const SalBitmap& rAlphaBitmap ) override;
-
-    bool                    drawTransformedBitmap(
-                                            const basegfx::B2DPoint& rNull,
-                                            const basegfx::B2DPoint& rX,
-                                            const basegfx::B2DPoint& rY,
-                                            const SalBitmap& rSourceBitmap,
-                                            const SalBitmap* pAlphaBitmap) override;
-
-    virtual bool            drawAlphaRect( tools::Long nX, tools::Long nY, tools::Long nWidth,
-                                           tools::Long nHeight, sal_uInt8 nTransparency ) override;
-
 #ifdef MACOSX
 
 protected:
@@ -316,37 +466,11 @@ protected:
     virtual bool            getNativeControlRegion( ControlType nType, ControlPart nPart, const tools::Rectangle& rControlRegion, ControlState nState,
                                                     const ImplControlValue& aValue, const OUString& aCaption,
                                                     tools::Rectangle &rNativeBoundingRegion, tools::Rectangle &rNativeContentRegion ) override;
-
-    void                    copyScaledArea( tools::Long nDestX, tools::Long nDestY, tools::Long nSrcX, tools::Long nSrcY,
-                                                tools::Long nSrcWidth, tools::Long nSrcHeight, SalGraphics* pSrcGraphics );
 #endif
 
 public:
     // get device resolution
     virtual void            GetResolution( sal_Int32& rDPIX, sal_Int32& rDPIY ) override;
-    // get the depth of the device
-    virtual sal_uInt16      GetBitCount() const override;
-    // get the width of the device
-    virtual tools::Long     GetGraphicsWidth() const override;
-
-    // set the clip region to empty
-    virtual void            ResetClipRegion() override;
-
-    // set the line color to transparent (= don't draw lines)
-    virtual void            SetLineColor() override;
-    // set the line color to a specific color
-    virtual void            SetLineColor( Color nColor ) override;
-    // set the fill color to transparent (= don't fill)
-    virtual void            SetFillColor() override;
-    // set the fill color to a specific color, shapes will be
-    // filled accordingly
-    virtual void            SetFillColor( Color nColor ) override;
-    // enable/disable XOR drawing
-    virtual void            SetXORMode( bool bSet, bool bInvertOnly ) override;
-    // set line color for raster operations
-    virtual void            SetROPLineColor( SalROPColor nROPColor ) override;
-    // set fill color for raster operations
-    virtual void            SetROPFillColor( SalROPColor nROPColor ) override;
     // set the text color to a specific color
     virtual void            SetTextColor( Color nColor ) override;
     // set the font
@@ -399,19 +523,11 @@ public:
     virtual std::unique_ptr<GenericSalLayout>
                             GetTextLayout(int nFallbackLevel) override;
     virtual void            DrawTextLayout( const GenericSalLayout& ) override;
-    virtual bool            supportsOperation( OutDevSupportType ) const override;
-    virtual OUString getRenderBackendName() const override { return "aqua"; }
 
     virtual SystemGraphicsData
                             GetGraphicsData() const override;
 
 private:
-    // differences between VCL, Quartz and kHiThemeOrientation coordinate systems
-    // make some graphics seem to be vertically-mirrored from a VCL perspective
-    bool                    IsFlipped() const;
-
-    void                    ApplyXorContext();
-    void                    Pattern50Fill();
     UInt32                  getState( ControlState nState );
     UInt32                  getTrackState( ControlState nState );
     static bool             GetRawFontData( const PhysicalFontFace* pFontData,
@@ -419,16 +535,6 @@ private:
                                 bool* pJustCFF );
 };
 
-// --- some trivial inlines
-
-#ifdef MACOSX
-
-inline void AquaSalGraphics::RefreshRect( const NSRect& rRect )
-{
-    RefreshRect( rRect.origin.x, rRect.origin.y, rRect.size.width, rRect.size.height );
-}
-
-#endif
 
 #endif // INCLUDED_VCL_INC_QUARTZ_SALGDI_H
 
