@@ -28,8 +28,10 @@
 #include <vcl/inputctx.hxx>
 #include <vcl/window.hxx>
 #include <vcl/settings.hxx>
+#include <o3tl/deleter.hxx>
 #include <o3tl/typed_flags_set.hxx>
 #include <cppuhelper/weakref.hxx>
+#include "windowdev.hxx"
 
 #include <optional>
 #include <list>
@@ -61,10 +63,6 @@ namespace com::sun::star {
         class XAccessibleEditableText;
     }
 
-    namespace rendering {
-        class XCanvas;
-    }
-
     namespace awt {
         class XWindowPeer;
         class XWindow;
@@ -171,7 +169,6 @@ struct ImplFrameData
     css::uno::Reference< css::datatransfer::dnd::XDropTarget > mxDropTarget;
     css::uno::Reference< css::datatransfer::dnd::XDropTargetListener > mxDropTargetListener;
     css::uno::Reference< css::datatransfer::clipboard::XClipboard > mxClipboard;
-    css::uno::Reference< css::datatransfer::clipboard::XClipboard > mxSelection;
 
     bool                mbInternalDragGestureRecognizer;
     VclPtr<VirtualDevice> mpBuffer; ///< Buffer for the double-buffering
@@ -218,10 +215,11 @@ private:
     WindowImpl(const WindowImpl&) = delete;
     WindowImpl& operator=(const WindowImpl&) = delete;
 public:
-    WindowImpl( WindowType );
+    WindowImpl( vcl::Window& rWindow, WindowType );
     ~WindowImpl();
 
-    ImplWinData*        mpWinData;
+    VclPtr<vcl::WindowOutputDevice> mxOutDev;
+    std::unique_ptr<ImplWinData> mpWinData;
     ImplFrameData*      mpFrameData;
     SalFrame*           mpFrame;
     SalObject*          mpSysObj;
@@ -250,9 +248,6 @@ public:
     Link<vcl::Window&, bool> maMnemonicActivateHdl;
     Link<tools::JsonWriter&, void> maDumpAsPropertyTreeHdl;
 
-    // The canvas interface for this VCL window. Is persistent after the first GetCanvas() call
-    css::uno::WeakReference< css::rendering::XCanvas >    mxCanvas;
-
     vcl::Cursor*        mpCursor;
     PointerStyle        maPointer;
     Fraction            maZoom;
@@ -411,12 +406,13 @@ class VCL_DLLPUBLIC PaintBufferGuard
     tools::Rectangle m_aPaintRect;
 public:
     PaintBufferGuard(ImplFrameData* pFrameData, vcl::Window* pWindow);
-    ~PaintBufferGuard();
+    ~PaintBufferGuard() COVERITY_NOEXCEPT_FALSE;
     /// If this is called, then the dtor will also copy rRectangle to the window from the buffer, before restoring the state.
     void SetPaintRect(const tools::Rectangle& rRectangle);
     /// Returns either the frame's buffer or the window, in case of no buffering.
     vcl::RenderContext* GetRenderContext();
 };
+typedef std::unique_ptr<PaintBufferGuard, o3tl::default_delete<PaintBufferGuard>> PaintBufferGuardPtr;
 }
 
 // helper methods
