@@ -186,19 +186,6 @@ void AquaSalInstance::AfterAppInit()
 #endif
 }
 
-void SalAbort( const OUString& rErrorText, bool bDumpCore )
-{
-    if( rErrorText.isEmpty() )
-        fprintf( stderr, "Application Error " );
-    else
-        fprintf( stderr, "%s ",
-            OUStringToOString( rErrorText, osl_getThreadTextEncoding() ).getStr() );
-    if( bDumpCore )
-        abort();
-    else
-        _exit(1);
-}
-
 SalYieldMutex::SalYieldMutex()
     : m_aCodeBlock( nullptr )
 {
@@ -317,7 +304,7 @@ VCLPLUG_OSX_PUBLIC SalInstance* create_SalInstance()
 
     // Dark mode is disabled as long as it is not implemented completely. For development purposes, it may be controlled by
     // environment variables: VCL_MACOS_FORCE_DARK_MODE enable dark mode independent of system settings,
-    // VCL_MACOS_USE_SYSTEM_APPEARANCE to use system settings (light mode oder dark mode as configured within system preferences).
+    // VCL_MACOS_USE_SYSTEM_APPEARANCE to use system settings (light mode or the dark mode as configured within system preferences).
 
     // TODO: After implementation of dark mode, this code has to be removed.
 
@@ -914,7 +901,7 @@ CGImageRef CreateCGImage( const Image& rImage )
     BitmapEx aBmpEx( rImage.GetBitmapEx() );
     Bitmap aBmp( aBmpEx.GetBitmap() );
 
-    if( ! aBmp || ! aBmp.ImplGetSalBitmap() )
+    if( aBmp.IsEmpty() || ! aBmp.ImplGetSalBitmap() )
         return nullptr;
 
     // simple case, no transparency
@@ -924,9 +911,9 @@ CGImageRef CreateCGImage( const Image& rImage )
         return nullptr;
 
     CGImageRef xImage = nullptr;
-    if( ! (aBmpEx.IsAlpha() || aBmpEx.IsTransparent() ) )
+    if( !aBmpEx.IsAlpha() )
         xImage = pSalBmp->CreateCroppedImage( 0, 0, pSalBmp->mnWidth, pSalBmp->mnHeight );
-    else if( aBmpEx.IsAlpha() )
+    else
     {
         AlphaMask aAlphaMask( aBmpEx.GetAlpha() );
         Bitmap aMask( aAlphaMask.GetBitmap() );
@@ -936,21 +923,6 @@ CGImageRef CreateCGImage( const Image& rImage )
         else
             xImage = pSalBmp->CreateCroppedImage( 0, 0, pSalBmp->mnWidth, pSalBmp->mnHeight );
     }
-    else if( aBmpEx.GetTransparentType() == TransparentType::Bitmap )
-    {
-        Bitmap aMask( aBmpEx.GetMask() );
-        QuartzSalBitmap* pMaskBmp = static_cast<QuartzSalBitmap*>(aMask.ImplGetSalBitmap().get());
-        if( pMaskBmp )
-            xImage = pSalBmp->CreateWithMask( *pMaskBmp, 0, 0, pSalBmp->mnWidth, pSalBmp->mnHeight );
-        else
-            xImage = pSalBmp->CreateCroppedImage( 0, 0, pSalBmp->mnWidth, pSalBmp->mnHeight );
-    }
-    else if( aBmpEx.GetTransparentType() == TransparentType::Color )
-    {
-        Color aTransColor( aBmpEx.GetTransparentColor() );
-        Color nTransColor( aTransColor.GetRed(), aTransColor.GetGreen(), aTransColor.GetBlue() );
-        xImage = pSalBmp->CreateColorMask( 0, 0, pSalBmp->mnWidth, pSalBmp->mnHeight, nTransColor );
-    }
 
     return xImage;
 }
