@@ -13,7 +13,7 @@
 
 #include <vcl/bitmapex.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
-#include <bitmapwriteaccess.hxx>
+#include <bitmap/BitmapWriteAccess.hxx>
 #include <svdata.hxx>
 #include <salinst.hxx>
 
@@ -34,20 +34,21 @@ class BitmapExTest : public CppUnit::TestFixture
 
 void BitmapExTest::testGetPixelColor24_8()
 {
-    Bitmap aBitmap(Size(3, 3), 24);
+    Bitmap aBitmap(Size(3, 3), vcl::PixelFormat::N24_BPP);
     {
         BitmapScopedWriteAccess pWriteAccess(aBitmap);
-        pWriteAccess->Erase(Color(0x00, 0x00, 0xFF, 0x00));
+        pWriteAccess->Erase(Color(ColorTransparency, 0x00, 0x00, 0xFF, 0x00));
     }
     AlphaMask aMask(Size(3, 3));
     {
         AlphaScopedWriteAccess pWriteAccess(aMask);
-        pWriteAccess->Erase(Color(0x00, 0xAA, 0xAA, 0xAA));
+        pWriteAccess->Erase(Color(ColorTransparency, 0x00, 0xAA, 0xAA, 0xAA));
     }
 
     BitmapEx aBitmapEx(aBitmap, aMask);
 
-    CPPUNIT_ASSERT_EQUAL(Color(0xAA, 0x00, 0xFF, 0x00), aBitmapEx.GetPixelColor(0, 0));
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0xAA, 0x00, 0xFF, 0x00),
+                         aBitmapEx.GetPixelColor(0, 0));
 }
 
 void BitmapExTest::testGetPixelColor32()
@@ -58,20 +59,21 @@ void BitmapExTest::testGetPixelColor32()
     if (!pBackendCapabilities->mbSupportsBitmap32)
         return;
 
-    Bitmap aBitmap(Size(3, 3), 32);
+    Bitmap aBitmap(Size(3, 3), vcl::PixelFormat::N32_BPP);
     {
         BitmapScopedWriteAccess pWriteAccess(aBitmap);
-        pWriteAccess->Erase(Color(0xAA, 0x00, 0xFF, 0x00));
+        pWriteAccess->Erase(Color(ColorTransparency, 0xAA, 0x00, 0xFF, 0x00));
     }
 
     BitmapEx aBitmapEx(aBitmap);
 
-    CPPUNIT_ASSERT_EQUAL(Color(0xAA, 0x00, 0xFF, 0x00), aBitmapEx.GetPixelColor(0, 0));
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0xAA, 0x00, 0xFF, 0x00),
+                         aBitmapEx.GetPixelColor(0, 0));
 }
 
 void BitmapExTest::testTransformBitmapEx()
 {
-    Bitmap aBitmap(Size(16, 16), 24);
+    Bitmap aBitmap(Size(16, 16), vcl::PixelFormat::N24_BPP);
     {
         BitmapScopedWriteAccess pWriteAccess(aBitmap);
         pWriteAccess->Erase(COL_WHITE);
