@@ -7,10 +7,14 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#include <sal/config.h>
+
+#include <string_view>
+
 #include <test/bootstrapfixture.hxx>
 
 #include <vcl/virdev.hxx>
-#include <vcl/bitmapaccess.hxx>
+#include <vcl/BitmapReadAccess.hxx>
 #include <vcl/svapp.hxx>
 
 #include <tools/stream.hxx>
@@ -25,7 +29,7 @@ constexpr OUStringLiteral gaDataUrl = u"/vcl/qa/cppunit/bitmaprender/data/";
 
 class BitmapRenderTest : public test::BootstrapFixture
 {
-    OUString getFullUrl(const OUString& sFileName)
+    OUString getFullUrl(std::u16string_view sFileName)
     {
         return m_directories.getURLFromSrc(gaDataUrl) + sFileName;
     }
@@ -45,7 +49,6 @@ public:
     CPPUNIT_TEST_SUITE(BitmapRenderTest);
     CPPUNIT_TEST(testTdf104141);
     CPPUNIT_TEST(testTdf113918);
-
     CPPUNIT_TEST(testDrawAlphaBitmapEx);
     CPPUNIT_TEST(testAlphaVirtualDevice);
     CPPUNIT_TEST(testTdf116888);
@@ -63,7 +66,7 @@ void BitmapRenderTest::testTdf104141()
     // Load animated GIF and draw it on green background
     GraphicFilter& rFilter = GraphicFilter::GetGraphicFilter();
     Graphic aGraphic;
-    const OUString aURL(getFullUrl("tdf104141.gif"));
+    const OUString aURL(getFullUrl(u"tdf104141.gif"));
     SvFileStream aFileStream(aURL, StreamMode::READ);
     ErrCode bResult = rFilter.ImportGraphic(aGraphic, aURL, aFileStream);
     CPPUNIT_ASSERT_EQUAL(ERRCODE_NONE, bResult);
@@ -73,8 +76,8 @@ void BitmapRenderTest::testTdf104141()
     // Check drawing results: ensure that it contains transparent
     // (greenish) pixels
     const Color aColor = pVDev->GetPixel(Point(21, 21));
-    CPPUNIT_ASSERT(aColor.GetGreen() > 10 * aColor.GetRed()
-                   && aColor.GetGreen() > 10 * aColor.GetBlue());
+    CPPUNIT_ASSERT(aColor.GetGreen() > 10 * aColor.GetRed());
+    CPPUNIT_ASSERT(aColor.GetGreen() > 10 * aColor.GetBlue());
 }
 
 void BitmapRenderTest::testTdf113918()
@@ -86,7 +89,7 @@ void BitmapRenderTest::testTdf113918()
 
     GraphicFilter& rFilter = GraphicFilter::GetGraphicFilter();
     Graphic aGraphic;
-    const OUString aURL(getFullUrl("tdf113918.png"));
+    const OUString aURL(getFullUrl(u"tdf113918.png"));
     SvFileStream aFileStream(aURL, StreamMode::READ);
     ErrCode bResult = rFilter.ImportGraphic(aGraphic, aURL, aFileStream);
     CPPUNIT_ASSERT_EQUAL(ERRCODE_NONE, bResult);
@@ -98,7 +101,8 @@ void BitmapRenderTest::testTdf113918()
 
     // Ensure that image is drawn with gray text color from palette
     const Color aColor = pVDev->GetPixel(Point(1298, 1368));
-    CPPUNIT_ASSERT(aColor.GetGreen() == aColor.GetRed() && aColor.GetGreen() == aColor.GetBlue());
+    CPPUNIT_ASSERT_EQUAL(aColor.GetGreen(), aColor.GetRed());
+    CPPUNIT_ASSERT_EQUAL(aColor.GetGreen(), aColor.GetBlue());
     CPPUNIT_ASSERT(aColor.GetGreen() > 100);
 }
 
@@ -133,7 +137,7 @@ void BitmapRenderTest::testDrawAlphaBitmapEx()
     CPPUNIT_ASSERT_EQUAL(COL_WHITE, pVDev->GetPixel(Point(1, 1)));
     CPPUNIT_ASSERT_EQUAL(COL_WHITE, pVDev->GetPixel(Point(2, 2)));
 
-    SvFileStream aFileStream(getFullUrl("ImageRGBA.png"), StreamMode::READ);
+    SvFileStream aFileStream(getFullUrl(u"ImageRGBA.png"), StreamMode::READ);
 
     vcl::PngImageReader aPngReader(aFileStream);
     BitmapEx aBitmapEx;
@@ -143,30 +147,33 @@ void BitmapRenderTest::testDrawAlphaBitmapEx()
     auto pBackendCapabilities = ImplGetSVData()->mpDefInst->GetBackendCapabilities();
     if (pBackendCapabilities->mbSupportsBitmap32)
     {
-        CPPUNIT_ASSERT_EQUAL(sal_uInt16(32), aBitmapEx.GetBitmap().GetBitCount());
+        CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N32_BPP, aBitmapEx.GetBitmap().getPixelFormat());
     }
     else
     {
-        CPPUNIT_ASSERT_EQUAL(sal_uInt16(24), aBitmapEx.GetBitmap().GetBitCount());
+        CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N24_BPP, aBitmapEx.GetBitmap().getPixelFormat());
         CPPUNIT_ASSERT_EQUAL(true, aBitmapEx.IsAlpha());
-        CPPUNIT_ASSERT_EQUAL(sal_uInt16(8), aBitmapEx.GetAlpha().GetBitCount());
+        CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N8_BPP, aBitmapEx.GetAlpha().getPixelFormat());
     }
 
     // Check the bitmap has pixels we expect
-    CPPUNIT_ASSERT_EQUAL(Color(0xFF, 0x00, 0x00, 0x00), aBitmapEx.GetPixelColor(0, 0));
-    CPPUNIT_ASSERT_EQUAL(Color(0x00, 0xFF, 0xFF, 0x00), aBitmapEx.GetPixelColor(1, 1));
-    CPPUNIT_ASSERT_EQUAL(Color(0x7F, 0x00, 0xFF, 0x00), aBitmapEx.GetPixelColor(2, 2));
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0xFF, 0x00, 0x00, 0x00),
+                         aBitmapEx.GetPixelColor(0, 0));
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0x00, 0xFF, 0xFF, 0x00),
+                         aBitmapEx.GetPixelColor(1, 1));
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0x7F, 0x00, 0xFF, 0x00),
+                         aBitmapEx.GetPixelColor(2, 2));
 
     pVDev->DrawBitmapEx(Point(), aBitmapEx);
 
-    CPPUNIT_ASSERT_EQUAL(Color(0x00, 0xFF, 0xFF, 0xFF), pVDev->GetPixel(Point(0, 0)));
-    CPPUNIT_ASSERT_EQUAL(Color(0x00, 0xFF, 0xFF, 0x00), pVDev->GetPixel(Point(1, 1)));
+    CPPUNIT_ASSERT_EQUAL(Color(0xFF, 0xFF, 0xFF), pVDev->GetPixel(Point(0, 0)));
+    CPPUNIT_ASSERT_EQUAL(Color(0xFF, 0xFF, 0x00), pVDev->GetPixel(Point(1, 1)));
 
 #if defined(_WIN32) || defined(MACOSX) || defined(IOS)
     // sometimes on Windows we get rounding error in blending so let's ignore this on Windows for now.
-    CPPUNIT_ASSERT_LESS(2, deltaColor(Color(0x00, 0x7F, 0xFF, 0x7F), pVDev->GetPixel(Point(2, 2))));
+    CPPUNIT_ASSERT_LESS(2, deltaColor(Color(0x7F, 0xFF, 0x7F), pVDev->GetPixel(Point(2, 2))));
 #else
-    CPPUNIT_ASSERT_EQUAL(Color(0x00, 0x7F, 0xFF, 0x7F), pVDev->GetPixel(Point(2, 2)));
+    CPPUNIT_ASSERT_EQUAL(Color(0x7F, 0xFF, 0x7F), pVDev->GetPixel(Point(2, 2)));
 #endif
 #endif
 }
@@ -215,14 +222,14 @@ void BitmapRenderTest::testAlphaVirtualDevice()
 #endif
 
     // Draw an semi-transparent pixel
-    pAlphaVirtualDevice->DrawPixel(Point(0, 0), Color(0x44, 0x22, 0xff, 0x55));
+    pAlphaVirtualDevice->DrawPixel(Point(0, 0), Color(ColorTransparency, 0x44, 0x22, 0xff, 0x55));
 
     aColor = pAlphaVirtualDevice->GetPixel(Point(0, 0));
     // Read back the semi-transparent pixel
 #if defined _WIN32
-    CPPUNIT_ASSERT_LESS(6, deltaColor(Color(0x4422FF55), aColor));
+    CPPUNIT_ASSERT_LESS(6, deltaColor(Color(ColorTransparency, 0x4422FF55), aColor));
 #else
-    CPPUNIT_ASSERT_EQUAL(Color(0x4422FF55), aColor);
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0x4422FF55), aColor);
 #endif
 
     // Read back the BitmapEx and check the semi-transparent pixel
@@ -232,9 +239,9 @@ void BitmapRenderTest::testAlphaVirtualDevice()
 
     aColor = aBitmap.GetPixelColor(0, 0);
 #if defined _WIN32
-    CPPUNIT_ASSERT_LESS(6, deltaColor(Color(0x4422FF55), aColor));
+    CPPUNIT_ASSERT_LESS(6, deltaColor(Color(ColorTransparency, 0x4422FF55), aColor));
 #else
-    CPPUNIT_ASSERT_EQUAL(Color(0x4422FF55), aColor);
+    CPPUNIT_ASSERT_EQUAL(Color(ColorTransparency, 0x4422FF55), aColor);
 #endif
 #endif
 }
@@ -247,7 +254,7 @@ void BitmapRenderTest::testTdf116888()
     // didn't properly release mpUserBuffer after ReadTexture() failure.
     GraphicFilter& rFilter = GraphicFilter::GetGraphicFilter();
     Graphic aGraphic;
-    const OUString aURL(getFullUrl("tdf116888.gif"));
+    const OUString aURL(getFullUrl(u"tdf116888.gif"));
     SvFileStream aFileStream(aURL, StreamMode::READ);
     ErrCode bResult = rFilter.ImportGraphic(aGraphic, aURL, aFileStream);
     CPPUNIT_ASSERT_EQUAL(ERRCODE_NONE, bResult);
