@@ -46,33 +46,28 @@ public:
     void testArabic();
     void testKashida();
     void testTdf95650(); // Windows-only issue
+    void testCaching();
 
     CPPUNIT_TEST_SUITE(VclComplexTextTest);
     CPPUNIT_TEST(testArabic);
     CPPUNIT_TEST(testKashida);
     CPPUNIT_TEST(testTdf95650);
+    CPPUNIT_TEST(testCaching);
     CPPUNIT_TEST_SUITE_END();
 };
 
 void VclComplexTextTest::testArabic()
 {
 #if HAVE_MORE_FONTS
-    const unsigned char pOneTwoThreeUTF8[] = {
-        0xd9, 0x88, 0xd8, 0xa7, 0xd8, 0xad, 0xd9, 0x90,
-        0xd8, 0xaf, 0xd9, 0x92, 0x20, 0xd8, 0xa5, 0xd8,
-        0xab, 0xd9, 0x8d, 0xd9, 0x86, 0xd9, 0x8a, 0xd9,
-        0x86, 0x20, 0xd8, 0xab, 0xd9, 0x84, 0xd8, 0xa7,
-        0xd8, 0xab, 0xd8, 0xa9, 0xd9, 0x8c, 0x00
-    };
-    OUString aOneTwoThree( reinterpret_cast<char const *>(pOneTwoThreeUTF8),
-                           SAL_N_ELEMENTS( pOneTwoThreeUTF8 ) - 1,
-                           RTL_TEXTENCODING_UTF8 );
+    OUString aOneTwoThree(
+        u"\u0648\u0627\u062d\u0650\u062f\u0652 \u0625\u062b\u064d\u0646\u064a\u0646"
+        " \u062b\u0644\u0627\u062b\u0629\u064c" );
     ScopedVclPtrInstance<WorkWindow> pWin(static_cast<vcl::Window *>(nullptr));
     CPPUNIT_ASSERT( pWin );
 
     vcl::Font aFont("DejaVu Sans", "Book", Size(0, 12));
 
-    OutputDevice *pOutDev = pWin.get();
+    OutputDevice *pOutDev = pWin->GetOutDev();
     pOutDev->SetFont( aFont );
 
     // absolute character widths AKA text array.
@@ -128,20 +123,18 @@ void VclComplexTextTest::testKashida()
     // Cache the glyph list of some Arabic text.
     ScopedVclPtrInstance<VirtualDevice> pOutputDevice;
     auto aText
-        = OUString::fromUtf8(u8"ﻊﻨﺻﺭ ﺎﻠﻓﻮﺴﻓﻭﺭ ﻊﻨﺻﺭ ﻒﻟﺰﻳ ﺺﻠﺑ. ﺖﺘﻛﻮﻧ ﺎﻟﺩﻭﺭﺓ ﺎﻟﺭﺎﺒﻋﺓ ﻢﻧ ١٥ ﻊﻨﺻﺭﺍ.");
+        = OUString(u"ﻊﻨﺻﺭ ﺎﻠﻓﻮﺴﻓﻭﺭ ﻊﻨﺻﺭ ﻒﻟﺰﻳ ﺺﻠﺑ. ﺖﺘﻛﻮﻧ ﺎﻟﺩﻭﺭﺓ ﺎﻟﺭﺎﺒﻋﺓ ﻢﻧ ١٥ ﻊﻨﺻﺭﺍ.");
     std::unique_ptr<SalLayout> pLayout = pOutputDevice->ImplLayout(
         aText, 0, aText.getLength(), Point(0, 0), 0, nullptr, SalLayoutFlags::GlyphItemsOnly);
-    const SalLayoutGlyphs* pGlyphs = pLayout->GetGlyphs();
-    if (!pGlyphs)
-        // Failed in some non-interesting ways.
-        return;
-    SalLayoutGlyphs aGlyphs = *pGlyphs;
+    SalLayoutGlyphs aGlyphs = pLayout->GetGlyphs();
+    CPPUNIT_ASSERT(aGlyphs.IsValid());
+    CPPUNIT_ASSERT(aGlyphs.Impl(0) != nullptr);
 
     // Now lay it out using the cached glyph list.
     ImplLayoutArgs aLayoutArgs(aText, 0, aText.getLength(), SalLayoutFlags::NONE,
                                pOutputDevice->GetFont().GetLanguageTag(), nullptr);
     pLayout = pOutputDevice->GetGraphics()->GetTextLayout(0);
-    CPPUNIT_ASSERT(pLayout->LayoutText(aLayoutArgs, &aGlyphs));
+    CPPUNIT_ASSERT(pLayout->LayoutText(aLayoutArgs, aGlyphs.Impl(0)));
 
     // Without the accompanying fix in place, this test would have failed with 'assertion failed'.
     // The kashida justification flag was lost when going via the glyph cache.
@@ -151,24 +144,73 @@ void VclComplexTextTest::testKashida()
 
 void VclComplexTextTest::testTdf95650()
 {
-    const sal_Unicode pTxt[] = {
-        0x0131, 0x0302, 0x0504, 0x4E44, 0x3031, 0x3030, 0x3531, 0x2D30,
-        0x3037, 0x0706, 0x0908, 0x0B0A, 0x0D0C, 0x0F0E, 0x072E, 0x100A,
-        0x0D11, 0x1312, 0x0105, 0x020A, 0x0512, 0x1403, 0x030C, 0x1528,
-        0x2931, 0x632E, 0x7074, 0x0D20, 0x0E0A, 0x100A, 0xF00D, 0x0D20,
-        0x030A, 0x0C0B, 0x20E0, 0x0A0D
-    };
-    OUString aTxt(pTxt, SAL_N_ELEMENTS(pTxt) - 1);
+    static constexpr OUStringLiteral aTxt =
+        u"\u0131\u0302\u0504\u4E44\u3031\u3030\u3531\u2D30"
+        "\u3037\u0706\u0908\u0B0A\u0D0C\u0F0E\u072E\u100A"
+        "\u0D11\u1312\u0105\u020A\u0512\u1403\u030C\u1528"
+        "\u2931\u632E\u7074\u0D20\u0E0A\u100A\uF00D\u0D20"
+        "\u030A\u0C0B\u20E0\u0A0D";
     ScopedVclPtrInstance<WorkWindow> pWin(static_cast<vcl::Window *>(nullptr));
     CPPUNIT_ASSERT(pWin);
 
-    OutputDevice *pOutDev = pWin.get();
+    OutputDevice *pOutDev = pWin->GetOutDev();
     // Check that the following executes without failing assertion
     pOutDev->ImplLayout(aTxt, 9, 1, Point(), 0, nullptr, SalLayoutFlags::BiDiRtl);
 }
 
+static void testCachedGlyphs( const OUString& aText, const OUString& aFontName = OUString())
+{
+    const std::string message = OUString("Font: " + aFontName + ", text: '" + aText + "'").toUtf8().getStr();
+    ScopedVclPtrInstance<VirtualDevice> pOutputDevice;
+    if(!aFontName.isEmpty())
+    {
+        vcl::Font aFont( aFontName, Size(0, 12));
+        pOutputDevice->SetFont( aFont );
+    }
+    // Get the glyphs for the text.
+    std::unique_ptr<SalLayout> pLayout1 = pOutputDevice->ImplLayout(
+        aText, 0, aText.getLength(), Point(0, 0), 0, nullptr, SalLayoutFlags::GlyphItemsOnly);
+    SalLayoutGlyphs aGlyphs1 = pLayout1->GetGlyphs();
+    CPPUNIT_ASSERT_MESSAGE(message, aGlyphs1.IsValid());
+    CPPUNIT_ASSERT_MESSAGE(message, aGlyphs1.Impl(0) != nullptr);
+    // Reuse the cached glyphs to get glyphs again.
+    std::unique_ptr<SalLayout> pLayout2 = pOutputDevice->ImplLayout(
+        aText, 0, aText.getLength(), Point(0, 0), 0, nullptr, SalLayoutFlags::GlyphItemsOnly, nullptr, &aGlyphs1);
+    SalLayoutGlyphs aGlyphs2 = pLayout2->GetGlyphs();
+    CPPUNIT_ASSERT_MESSAGE(message, aGlyphs2.IsValid());
+    // And check it's the same.
+    for( int level = 0; level < MAX_FALLBACK; ++level )
+    {
+        const std::string messageLevel = OString(message.c_str()
+            + OString::Concat(", level: ") + OString::number(level)).getStr();
+        if( aGlyphs1.Impl(level) == nullptr)
+        {
+            CPPUNIT_ASSERT_MESSAGE(messageLevel, aGlyphs2.Impl(level) == nullptr);
+            continue;
+        }
+        const SalLayoutGlyphsImpl* g1 = aGlyphs1.Impl(level);
+        const SalLayoutGlyphsImpl* g2 = aGlyphs2.Impl(level);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(messageLevel, g1->GetFont().get(), g2->GetFont().get());
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(messageLevel, g1->size(), g2->size());
+        for( size_t i = 0; i < g1->size(); ++i )
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(messageLevel, (*g1)[i].glyphId(), (*g2)[i].glyphId());
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(messageLevel, (*g1)[i].IsRTLGlyph(), (*g2)[i].IsRTLGlyph());
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(messageLevel, (*g1)[i].IsVertical(), (*g2)[i].IsVertical());
+        }
+    }
+}
+
+// Check that caching using SalLayoutGlyphs gives same results as without caching.
+// This should preferably use fonts that come with LO.
+void VclComplexTextTest::testCaching()
+{
+    // Just something basic, no font fallback.
+    testCachedGlyphs( "test", "Dejavu Sans" );
+    // This font does not have latin characters, will need fallback.
+    testCachedGlyphs( "test", "KacstBook" );
+}
+
 CPPUNIT_TEST_SUITE_REGISTRATION(VclComplexTextTest);
 
-CPPUNIT_PLUGIN_IMPLEMENT();
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
