@@ -9,14 +9,19 @@
 
 #include <test/bootstrapfixture.hxx>
 
-#include <vcl/skia/SkiaHelper.hxx>
-#include <skia/salbmp.hxx>
-#include <bitmapwriteaccess.hxx>
-#include <vcl/virdev.hxx>
 #include <tools/stream.hxx>
-#include <vcl/graphicfilter.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 
+#include <vcl/graphicfilter.hxx>
+#include <vcl/virdev.hxx>
+#include <vcl/skia/SkiaHelper.hxx>
+
+#include <skia/salbmp.hxx>
+#include <skia/utils.hxx>
+#include <bitmap/BitmapWriteAccess.hxx>
+
+using namespace SkiaHelper;
+
 // This tests backends that use Skia (i.e. intentionally not the svp one, which is the default.)
 // Note that you still may need to actually set for Skia to be used (see vcl/README.vars).
 // If Skia is not enabled, all tests will be silently skipped.
@@ -35,8 +40,11 @@ public:
     void testInterpretAs8Bit();
     void testAlphaBlendWith();
     void testBitmapCopyOnWrite();
+    void testMatrixQuality();
+    void testDelayedScale();
     void testTdf137329();
     void testTdf140848();
+    void testTdf132367();
 
     CPPUNIT_TEST_SUITE(SkiaTest);
     CPPUNIT_TEST(testBitmapErase);
@@ -44,8 +52,11 @@ public:
     CPPUNIT_TEST(testInterpretAs8Bit);
     CPPUNIT_TEST(testAlphaBlendWith);
     CPPUNIT_TEST(testBitmapCopyOnWrite);
+    CPPUNIT_TEST(testMatrixQuality);
+    CPPUNIT_TEST(testDelayedScale);
     CPPUNIT_TEST(testTdf137329);
     CPPUNIT_TEST(testTdf140848);
+    CPPUNIT_TEST(testTdf132367);
     CPPUNIT_TEST_SUITE_END();
 
 private:
@@ -70,7 +81,7 @@ void SkiaTest::testBitmapErase()
 {
     if (!SkiaHelper::isVCLSkiaEnabled())
         return;
-    Bitmap bitmap(Size(10, 10), 24);
+    Bitmap bitmap(Size(10, 10), vcl::PixelFormat::N24_BPP);
     SkiaSalBitmap* skiaBitmap = dynamic_cast<SkiaSalBitmap*>(bitmap.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaBitmap);
     // Uninitialized bitmap.
@@ -103,7 +114,7 @@ void SkiaTest::testDrawShaders()
     device->SetOutputSizePixel(Size(20, 20));
     device->SetBackground(Wallpaper(COL_WHITE));
     device->Erase();
-    Bitmap bitmap(Size(10, 10), 24);
+    Bitmap bitmap(Size(10, 10), vcl::PixelFormat::N24_BPP);
     bitmap.Erase(COL_RED);
     SkiaSalBitmap* skiaBitmap = dynamic_cast<SkiaSalBitmap*>(bitmap.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaBitmap->PreferSkShader());
@@ -146,7 +157,7 @@ void SkiaTest::testDrawShaders()
     deviceLarge->SetOutputSizePixel(Size(200, 200));
     deviceLarge->SetBackground(Wallpaper(COL_WHITE));
     deviceLarge->Erase();
-    Bitmap bitmapLarge(Size(100, 100), 24);
+    Bitmap bitmapLarge(Size(100, 100), vcl::PixelFormat::N24_BPP);
     bitmapLarge.Erase(COL_RED);
     SkiaSalBitmap* skiaBitmapLarge
         = dynamic_cast<SkiaSalBitmap*>(bitmapLarge.ImplGetSalBitmap().get());
@@ -181,31 +192,31 @@ void SkiaTest::testInterpretAs8Bit()
 {
     if (!SkiaHelper::isVCLSkiaEnabled())
         return;
-    Bitmap bitmap(Size(10, 10), 24);
+    Bitmap bitmap(Size(10, 10), vcl::PixelFormat::N24_BPP);
     // Test with erase color.
     bitmap.Erase(Color(33, 33, 33));
     SkiaSalBitmap* skiaBitmap = dynamic_cast<SkiaSalBitmap*>(bitmap.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaBitmap->unittestHasEraseColor());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(24), bitmap.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N24_BPP, bitmap.getPixelFormat());
     bitmap.Convert(BmpConversion::N8BitNoConversion);
     skiaBitmap = dynamic_cast<SkiaSalBitmap*>(bitmap.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaBitmap->unittestHasEraseColor());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(8), bitmap.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N8_BPP, bitmap.getPixelFormat());
     CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt8>(33), BitmapReadAccess(bitmap).GetPixelIndex(0, 0));
 
     // Test with image.
-    bitmap = Bitmap(Size(10, 10), 24);
+    bitmap = Bitmap(Size(10, 10), vcl::PixelFormat::N24_BPP);
     bitmap.Erase(Color(34, 34, 34));
     BitmapReadAccess(bitmap).GetColor(0, 0); // Create pixel data, reset erase color.
     skiaBitmap = dynamic_cast<SkiaSalBitmap*>(bitmap.ImplGetSalBitmap().get());
     skiaBitmap->GetSkImage();
     CPPUNIT_ASSERT(!skiaBitmap->unittestHasEraseColor());
     CPPUNIT_ASSERT(skiaBitmap->unittestHasImage());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(24), bitmap.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N24_BPP, bitmap.getPixelFormat());
     bitmap.Convert(BmpConversion::N8BitNoConversion);
     skiaBitmap = dynamic_cast<SkiaSalBitmap*>(bitmap.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaBitmap->unittestHasImage());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(8), bitmap.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N8_BPP, bitmap.getPixelFormat());
     CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt8>(34), BitmapReadAccess(bitmap).GetPixelIndex(0, 0));
 }
 
@@ -214,7 +225,7 @@ void SkiaTest::testAlphaBlendWith()
     if (!SkiaHelper::isVCLSkiaEnabled())
         return;
     AlphaMask alpha(Size(10, 10));
-    Bitmap bitmap(Size(10, 10), 24);
+    Bitmap bitmap(Size(10, 10), vcl::PixelFormat::N24_BPP);
     // Test with erase colors set.
     alpha.Erase(64);
     SkiaSalBitmap* skiaAlpha = dynamic_cast<SkiaSalBitmap*>(alpha.ImplGetSalBitmap().get());
@@ -225,7 +236,7 @@ void SkiaTest::testAlphaBlendWith()
     alpha.BlendWith(bitmap);
     skiaAlpha = dynamic_cast<SkiaSalBitmap*>(alpha.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaAlpha->unittestHasEraseColor());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(8), alpha.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N8_BPP, alpha.getPixelFormat());
     CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt8>(112),
                          AlphaMask::ScopedReadAccess(alpha)->GetPixelIndex(0, 0));
 
@@ -245,7 +256,7 @@ void SkiaTest::testAlphaBlendWith()
     alpha.BlendWith(bitmap);
     skiaAlpha = dynamic_cast<SkiaSalBitmap*>(alpha.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaAlpha->unittestHasImage());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(8), alpha.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N8_BPP, alpha.getPixelFormat());
     CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt8>(112),
                          AlphaMask::ScopedReadAccess(alpha)->GetPixelIndex(0, 0));
 
@@ -262,7 +273,7 @@ void SkiaTest::testAlphaBlendWith()
     alpha.BlendWith(bitmap);
     skiaAlpha = dynamic_cast<SkiaSalBitmap*>(alpha.ImplGetSalBitmap().get());
     CPPUNIT_ASSERT(skiaAlpha->unittestHasImage());
-    CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt16>(8), alpha.GetBitCount());
+    CPPUNIT_ASSERT_EQUAL(vcl::PixelFormat::N8_BPP, alpha.getPixelFormat());
     CPPUNIT_ASSERT_EQUAL(static_cast<sal_uInt8>(112),
                          AlphaMask::ScopedReadAccess(alpha)->GetPixelIndex(0, 0));
 }
@@ -272,7 +283,7 @@ void SkiaTest::testBitmapCopyOnWrite()
     if (!SkiaHelper::isVCLSkiaEnabled())
         return;
     SkiaSalBitmap bitmap;
-    CPPUNIT_ASSERT(bitmap.Create(Size(10, 10), 24, BitmapPalette()));
+    CPPUNIT_ASSERT(bitmap.Create(Size(10, 10), vcl::PixelFormat::N24_BPP, BitmapPalette()));
     bitmap.GetSkImage();
     bitmap.GetAlphaSkImage();
     CPPUNIT_ASSERT(bitmap.unittestHasBuffer());
@@ -307,8 +318,68 @@ void SkiaTest::testBitmapCopyOnWrite()
     CPPUNIT_ASSERT(bitmap.unittestGetAlphaImage() != oldAlphaImage);
 }
 
+void SkiaTest::testMatrixQuality()
+{
+// This test fails on the tb68 tinderbox for a mysterious reason:
+// https://lists.freedesktop.org/archives/libreoffice/2021-March/086969.html
+#if !(defined(_WIN32) && !defined(_WIN64))
+    if (!SkiaHelper::isVCLSkiaEnabled())
+        return;
+    // Not changing the size (but possibly rotated/flipped) does not need high quality transformations.
+    CPPUNIT_ASSERT(!SkiaTests::matrixNeedsHighQuality(SkMatrix()));
+    CPPUNIT_ASSERT(!SkiaTests::matrixNeedsHighQuality(SkMatrix::RotateDeg(90)));
+    CPPUNIT_ASSERT(!SkiaTests::matrixNeedsHighQuality(SkMatrix::RotateDeg(180)));
+    CPPUNIT_ASSERT(!SkiaTests::matrixNeedsHighQuality(SkMatrix::RotateDeg(270)));
+    CPPUNIT_ASSERT(!SkiaTests::matrixNeedsHighQuality(SkMatrix::Scale(1, -1)));
+    CPPUNIT_ASSERT(SkiaTests::matrixNeedsHighQuality(SkMatrix::Scale(0, -1)));
+    CPPUNIT_ASSERT(SkiaTests::matrixNeedsHighQuality(SkMatrix::Scale(2, 1)));
+    CPPUNIT_ASSERT(SkiaTests::matrixNeedsHighQuality(SkMatrix::RotateDeg(89)));
+#endif
+}
+
+void SkiaTest::testDelayedScale()
+{
+    if (!SkiaHelper::isVCLSkiaEnabled())
+        return;
+    Bitmap bitmap1(Size(10, 10), vcl::PixelFormat::N24_BPP);
+    SkiaSalBitmap* skiaBitmap1 = dynamic_cast<SkiaSalBitmap*>(bitmap1.ImplGetSalBitmap().get());
+    CPPUNIT_ASSERT(skiaBitmap1);
+    // Do scaling based on mBuffer.
+    (void)BitmapReadAccess(bitmap1); // allocates mBuffer
+    CPPUNIT_ASSERT(skiaBitmap1->unittestHasBuffer());
+    CPPUNIT_ASSERT(!skiaBitmap1->unittestHasImage());
+    CPPUNIT_ASSERT(bitmap1.Scale(2, 2, BmpScaleFlag::Default));
+    skiaBitmap1 = dynamic_cast<SkiaSalBitmap*>(bitmap1.ImplGetSalBitmap().get());
+    CPPUNIT_ASSERT(skiaBitmap1);
+    CPPUNIT_ASSERT(skiaBitmap1->unittestHasBuffer());
+    CPPUNIT_ASSERT(!skiaBitmap1->unittestHasImage());
+    CPPUNIT_ASSERT_EQUAL(Size(20, 20), bitmap1.GetSizePixel());
+    CPPUNIT_ASSERT_EQUAL(Size(20, 20), imageSize(skiaBitmap1->GetSkImage()));
+    BitmapBuffer* buffer1 = skiaBitmap1->AcquireBuffer(BitmapAccessMode::Read);
+    CPPUNIT_ASSERT(buffer1);
+    CPPUNIT_ASSERT_EQUAL(tools::Long(20), buffer1->mnWidth);
+    CPPUNIT_ASSERT_EQUAL(tools::Long(20), buffer1->mnHeight);
+    skiaBitmap1->ReleaseBuffer(buffer1, BitmapAccessMode::Read);
+    // Do scaling based on mImage.
+    SkiaSalBitmap skiaBitmap2(skiaBitmap1->GetSkImage());
+    CPPUNIT_ASSERT(!skiaBitmap2.unittestHasBuffer());
+    CPPUNIT_ASSERT(skiaBitmap2.unittestHasImage());
+    CPPUNIT_ASSERT(skiaBitmap2.Scale(2, 3, BmpScaleFlag::Default));
+    CPPUNIT_ASSERT(!skiaBitmap2.unittestHasBuffer());
+    CPPUNIT_ASSERT(skiaBitmap2.unittestHasImage());
+    CPPUNIT_ASSERT_EQUAL(Size(40, 60), skiaBitmap2.GetSize());
+    CPPUNIT_ASSERT_EQUAL(Size(40, 60), imageSize(skiaBitmap2.GetSkImage()));
+    BitmapBuffer* buffer2 = skiaBitmap2.AcquireBuffer(BitmapAccessMode::Read);
+    CPPUNIT_ASSERT(buffer2);
+    CPPUNIT_ASSERT_EQUAL(tools::Long(40), buffer2->mnWidth);
+    CPPUNIT_ASSERT_EQUAL(tools::Long(60), buffer2->mnHeight);
+    skiaBitmap2.ReleaseBuffer(buffer2, BitmapAccessMode::Read);
+}
+
 void SkiaTest::testTdf137329()
 {
+    if (!SkiaHelper::isVCLSkiaEnabled())
+        return;
     // Draw a filled polygon in the entire device, with AA enabled.
     // All pixels in the device should be black, even those at edges (i.e. not affected by AA).
     ScopedVclPtr<VirtualDevice> device = VclPtr<VirtualDevice>::Create(DeviceFormat::DEFAULT);
@@ -356,6 +427,27 @@ void SkiaTest::testTdf140848()
     CPPUNIT_ASSERT_EQUAL(COL_WHITE, device->GetPixel(Point(1200, 100)));
 }
 
+void SkiaTest::testTdf132367()
+{
+    if (!SkiaHelper::isVCLSkiaEnabled())
+        return;
+    ScopedVclPtr<VirtualDevice> device = VclPtr<VirtualDevice>::Create(DeviceFormat::DEFAULT);
+    device->SetOutputSizePixel(Size(2, 2));
+    device->SetBackground(Wallpaper(COL_BLACK));
+    device->Erase();
+    device->DrawPixel(Point(1, 1), COL_WHITE);
+    // This will make the bitmap store data in SkImage.
+    Bitmap bitmap = device->GetBitmap(Point(0, 0), Size(2, 2));
+    // Scaling will only set up delayed scaling of the SkImage.
+    bitmap.Scale(Size(4, 4), BmpScaleFlag::NearestNeighbor);
+    // Now it will need to be converted to pixel buffer, check it's converted properly
+    // from the SkImage.
+    BitmapReadAccess access(bitmap);
+    CPPUNIT_ASSERT_EQUAL(tools::Long(4), access.Width());
+    CPPUNIT_ASSERT_EQUAL(tools::Long(4), access.Height());
+    CPPUNIT_ASSERT_EQUAL(BitmapColor(COL_WHITE), access.GetColor(3, 3));
+}
+
 } // namespace
 
 CPPUNIT_TEST_SUITE_REGISTRATION(SkiaTest);
