@@ -54,6 +54,11 @@
 #include <mutex>
 #include <condition_variable>
 
+#ifdef EMSCRIPTEN
+#include <QtCore/QtPlugin>
+Q_IMPORT_PLUGIN(QWasmIntegrationPlugin)
+#endif
+
 namespace
 {
 /// TODO: not much Qt5 specific here? could be generalised, esp. for OSX...
@@ -196,6 +201,17 @@ void Qt5Instance::RunInMainThread(std::function<void()> func)
     }
 }
 
+OUString Qt5Instance::constructToolkitID(std::u16string_view sTKname)
+{
+    OUString sID(sTKname + OUString::Concat(u" ("));
+    if (m_bUseCairo)
+        sID += "cairo+";
+    else
+        sID += "qfont+";
+    sID += toOUString(QGuiApplication::platformName()) + OUString::Concat(u")");
+    return sID;
+}
+
 Qt5Instance::Qt5Instance(std::unique_ptr<QApplication>& pQApp, bool bUseCairo)
     : SalGenericInstance(std::make_unique<Qt5YieldMutex>())
     , m_bUseCairo(bUseCairo)
@@ -206,10 +222,7 @@ Qt5Instance::Qt5Instance(std::unique_ptr<QApplication>& pQApp, bool bUseCairo)
     , m_bUpdateFonts(false)
 {
     ImplSVData* pSVData = ImplGetSVData();
-    if (bUseCairo)
-        pSVData->maAppData.mxToolkitName = OUString("qt5+cairo");
-    else
-        pSVData->maAppData.mxToolkitName = OUString("qt5");
+    pSVData->maAppData.mxToolkitName = constructToolkitID(u"qt5");
 
     // this one needs to be blocking, so that the handling in main thread
     // is processed before the thread emitting the signal continues
@@ -229,6 +242,9 @@ Qt5Instance::Qt5Instance(std::unique_ptr<QApplication>& pQApp, bool bUseCairo)
     connect(dispatcher, &QAbstractEventDispatcher::awake, this, [this]() { m_bSleeping = false; });
     connect(dispatcher, &QAbstractEventDispatcher::aboutToBlock, this,
             [this]() { m_bSleeping = true; });
+
+    connect(QGuiApplication::inputMethod(), &QInputMethod::localeChanged, this,
+            &Qt5Instance::localeChanged);
 }
 
 Qt5Instance::~Qt5Instance()
@@ -248,6 +264,19 @@ void Qt5Instance::AfterAppInit()
                                                                     : Qt::LeftToRight);
 }
 
+void Qt5Instance::localeChanged()
+{
+    SolarMutexGuard aGuard;
+    const vcl::Window* pFocusWindow = Application::GetFocusWindow();
+    SalFrame* const pFocusFrame = pFocusWindow ? pFocusWindow->ImplGetFrame() : nullptr;
+    if (!pFocusFrame)
+        return;
+
+    const LanguageTag aTag(
+        toOUString(QGuiApplication::inputMethod()->locale().name().replace("_", "-")));
+    static_cast<Qt5Frame*>(pFocusFrame)->setInputLanguage(aTag.getLanguageType());
+}
+
 void Qt5Instance::deleteObjectLater(QObject* pObject) { pObject->deleteLater(); }
 
 SalFrame* Qt5Instance::CreateChildFrame(SystemParentData* /*pParent*/, SalFrameStyleFlags nStyle)
@@ -286,24 +315,24 @@ void Qt5Instance::DestroyObject(SalObject* pObject)
 }
 
 std::unique_ptr<SalVirtualDevice>
-Qt5Instance::CreateVirtualDevice(SalGraphics* pGraphics, tools::Long& nDX, tools::Long& nDY,
-                                 DeviceFormat eFormat, const SystemGraphicsData* pGd)
+Qt5Instance::CreateVirtualDevice(SalGraphics& rGraphics, tools::Long& nDX, tools::Long& nDY,
+                                 DeviceFormat /*eFormat*/, const SystemGraphicsData* pGd)
 {
     if (m_bUseCairo)
     {
-        SvpSalGraphics* pSvpSalGraphics = dynamic_cast<Qt5SvpGraphics*>(pGraphics);
+        SvpSalGraphics* pSvpSalGraphics = dynamic_cast<Qt5SvpGraphics*>(&rGraphics);
         assert(pSvpSalGraphics);
         // tdf#127529 see SvpSalInstance::CreateVirtualDevice for the rare case of a non-null pPreExistingTarget
         cairo_surface_t* pPreExistingTarget
             = pGd ? static_cast<cairo_surface_t*>(pGd->pSurface) : nullptr;
         std::unique_ptr<SalVirtualDevice> pVD(
-            new Qt5SvpVirtualDevice(eFormat, pSvpSalGraphics->getSurface(), pPreExistingTarget));
+            new Qt5SvpVirtualDevice(pSvpSalGraphics->getSurface(), pPreExistingTarget));
         pVD->SetSize(nDX, nDY);
         return pVD;
     }
     else
     {
-        std::unique_ptr<SalVirtualDevice> pVD(new Qt5VirtualDevice(eFormat, 1));
+        std::unique_ptr<SalVirtualDevice> pVD(new Qt5VirtualDevice(/*scale*/ 1));
         pVD->SetSize(nDX, nDY);
         return pVD;
     }
@@ -403,7 +432,7 @@ OUString Qt5Instance::GetConnectionIdentifier() { return OUString(); }
 
 void Qt5Instance::AddToRecentDocumentList(const OUString&, const OUString&, const OUString&) {}
 
-OpenGLContext* Qt5Instance::CreateOpenGLContext() { return new Qt5OpenGLContext; }
+OpenGLContext* Qt5Instance::CreateOpenGLContext() { return nullptr; }
 
 bool Qt5Instance::IsMainThread() const
 {
@@ -421,14 +450,14 @@ void Qt5Instance::ProcessEvent(SalUserEvent aEvent)
     aEvent.m_pFrame->CallCallback(aEvent.m_nEvent, aEvent.m_pData);
 }
 
-Qt5FilePicker*
+rtl::Reference<Qt5FilePicker>
 Qt5Instance::createPicker(css::uno::Reference<css::uno::XComponentContext> const& context,
                           QFileDialog::FileMode eMode)
 {
     if (!IsMainThread())
     {
         SolarMutexGuard g;
-        Qt5FilePicker* pPicker;
+        rtl::Reference<Qt5FilePicker> pPicker;
         RunInMainThread([&, this]() { pPicker = createPicker(context, eMode); });
         assert(pPicker);
         return pPicker;
@@ -546,7 +575,7 @@ void* Qt5Instance::CreateGStreamerSink(const SystemChildWindow* pWindow)
 
     return pVideosink;
 #else
-    (void*)pWindow;
+    Q_UNUSED(pWindow);
     return nullptr;
 #endif
 }
