@@ -30,6 +30,7 @@
 #include <comphelper/processfactory.hxx>
 #include <comphelper/asyncnotification.hxx>
 #include <i18nlangtag/mslangid.hxx>
+#include <unotools/syslocale.hxx>
 #include <unotools/syslocaleoptions.hxx>
 #include <vcl/QueueInfo.hxx>
 #include <vcl/svapp.hxx>
@@ -50,6 +51,8 @@
 #include <vcl/print.hxx>
 #include <debugevent.hxx>
 #include <scrwnd.hxx>
+#include <windowdev.hxx>
+#include <saldatabasic.hxx>
 
 #ifdef _WIN32
 #include <svsys.h>
@@ -333,7 +336,7 @@ bool InitVCL()
         //force that in as $LANGUAGE. That way we can get gtk to render widgets RTL
         //if we have a RTL UI in an otherwise LTR locale and get gettext using externals (e.g. python)
         //to match their translations to our preferred UI language
-        OUString aLocaleString(SvtSysLocaleOptions().GetRealUILanguageTag().getGlibcLocaleString(".UTF-8"));
+        OUString aLocaleString(SvtSysLocaleOptions().GetRealUILanguageTag().getGlibcLocaleString(u".UTF-8"));
         if (!aLocaleString.isEmpty())
         {
             MsLangId::getSystemUILanguage(); //call this now to pin what the system UI really was
@@ -360,7 +363,7 @@ bool InitVCL()
     // Initialize global data
     pSVData->maGDIData.mxScreenFontList = std::make_shared<PhysicalFontCollection>();
     pSVData->maGDIData.mxScreenFontCache = std::make_shared<ImplFontCache>();
-    pSVData->maGDIData.mpGrfConverter = new GraphicConverter;
+    pSVData->maGDIData.mxGrfConverter.reset(new GraphicConverter);
 
     g_bIsLeanException = getenv("LO_LEAN_EXCEPTION") != nullptr;
     // Set exception handler
@@ -466,12 +469,7 @@ void DeInitVCL()
     pExceptionHandler = nullptr;
 
     // free global data
-    if (pSVData->maGDIData.mpGrfConverter)
-    {
-        delete pSVData->maGDIData.mpGrfConverter;
-        pSVData->maGDIData.mpGrfConverter = nullptr;
-    }
-
+    pSVData->maGDIData.mxGrfConverter.reset();
     pSVData->mpSettingsConfigItem.reset();
 
     // prevent unnecessary painting during Scheduler shutdown
@@ -493,7 +491,7 @@ void DeInitVCL()
             pSVData->m_xSystemClipboard, css::uno::UNO_QUERY))
     {
         SolarMutexReleaser r; // unblock pending "clipboard content changed" notifications
-        comp->dispose(); // will use CWinClipbImpl::s_aMutex
+        comp->dispose(); // will use s_aClipboardSingletonMutex for CWinClipboard
     }
     pSVData->m_xSystemClipboard.clear();
 #endif
@@ -598,6 +596,12 @@ void DeInitVCL()
         pSVData->mpDefInst = nullptr;
     }
 
+    // This only works on Linux. On Mac and Windows I get very
+    // weird segment violations.
+#if defined LINUX
+    delete pSVData->mpSalData;
+#endif
+
     if( pOwnSvApp )
     {
         delete pOwnSvApp;
