@@ -10,14 +10,13 @@
 
 #include <sal/config.h>
 
-#include <algorithm>
-
 #include <vcl/bitmap.hxx>
 #include <vcl/bitmapex.hxx>
-#include <vcl/bitmapaccess.hxx>
 #include <vcl/BitmapSepiaFilter.hxx>
 
-#include <bitmapwriteaccess.hxx>
+#include <bitmap/BitmapWriteAccess.hxx>
+
+#include <algorithm>
 
 BitmapEx BitmapSepiaFilter::execute(BitmapEx const& rBitmapEx) const
 {
@@ -41,7 +40,7 @@ BitmapEx BitmapSepiaFilter::execute(BitmapEx const& rBitmapEx) const
             rCol.SetBlue(cSepiaValue);
         }
 
-        Bitmap aNewBmp(aBitmap.GetSizePixel(), 8, &aSepiaPal);
+        Bitmap aNewBmp(aBitmap.GetSizePixel(), vcl::PixelFormat::N8_BPP, &aSepiaPal);
         BitmapScopedWriteAccess pWriteAcc(aNewBmp);
 
         if (pWriteAcc)
