@@ -36,10 +36,12 @@
 #include <svdata.hxx>
 
 #include <com/sun/star/i18n/XCharacterClassification.hpp>
+#include <com/sun/star/i18n/CalendarFieldIndex.hdl>
 
 #include <unotools/localedatawrapper.hxx>
 #include <unotools/calendarwrapper.hxx>
 #include <unotools/charclass.hxx>
+#include <svl/zforlist.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::comphelper;
@@ -744,7 +746,7 @@ static bool ImplPatternProcessKeyInput( IEditImplementation& rEdit, const KeyEve
             {
                 // possibly extend string until cursor position
                 if ( aStr.getLength() < nNewPos )
-                    aStr.append( std::u16string_view(rLiteralMask).substr(aStr.getLength(), nNewPos-aStr.getLength()) );
+                    aStr.append( rLiteralMask.subView(aStr.getLength(), nNewPos-aStr.getLength()) );
                 if ( nNewPos < aStr.getLength() )
                     aStr.insert( cChar, nNewPos );
                 else if ( nNewPos < rEditMask.getLength() )
@@ -1168,13 +1170,15 @@ void PatternBox::ReformatAll()
     SetUpdateMode( true );
 }
 
-static ExtDateFieldFormat ImplGetExtFormat( DateOrder eOld )
+static ExtDateFieldFormat ImplGetExtFormat( LongDateOrder eOld )
 {
     switch( eOld )
     {
-        case DateOrder::DMY:   return ExtDateFieldFormat::ShortDDMMYY;
-        case DateOrder::MDY:   return ExtDateFieldFormat::ShortMMDDYY;
-        default:               return ExtDateFieldFormat::ShortYYMMDD;
+        case LongDateOrder::YDM:
+        case LongDateOrder::DMY:    return ExtDateFieldFormat::ShortDDMMYY;
+        case LongDateOrder::MDY:    return ExtDateFieldFormat::ShortMMDDYY;
+        case LongDateOrder::YMD:
+        default:                    return ExtDateFieldFormat::ShortYYMMDD;
     }
 }
 
@@ -1200,20 +1204,83 @@ static bool ImplCutMonthName( OUString& rStr, std::u16string_view _rLookupMonthN
     return index >= 0;
 }
 
-static sal_uInt16 ImplCutMonthFromString( OUString& rStr, const CalendarWrapper& rCalendarWrapper )
+static sal_uInt16 ImplGetMonthFromCalendarItem( OUString& rStr, const uno::Sequence< i18n::CalendarItem2 >& rMonths )
 {
-    // search for a month' name
-    for ( sal_uInt16 i=1; i <= 12; i++ )
+    const sal_uInt16 nMonths = rMonths.getLength();
+    for (sal_uInt16 i=0; i < nMonths; ++i)
     {
-        OUString aMonthName = rCalendarWrapper.getMonths()[i-1].FullName;
         // long month name?
-        if ( ImplCutMonthName( rStr, aMonthName ) )
-            return i;
+        if ( ImplCutMonthName( rStr, rMonths[i].FullName ) )
+            return i+1;
 
         // short month name?
-        OUString aAbbrevMonthName = rCalendarWrapper.getMonths()[i-1].AbbrevName;
-        if ( ImplCutMonthName( rStr, aAbbrevMonthName ) )
-            return i;
+        if ( ImplCutMonthName( rStr, rMonths[i].AbbrevName ) )
+            return i+1;
+    }
+    return 0;
+}
+
+static sal_uInt16 ImplCutMonthFromString( OUString& rStr, OUString& rCalendarName,
+        const LocaleDataWrapper& rLocaleData, const CalendarWrapper& rCalendarWrapper )
+{
+    const OUString aDefaultCalendarName( rCalendarWrapper.getUniqueID());
+    rCalendarName = aDefaultCalendarName;
+
+    // Search for a month name of the loaded default calendar.
+    const uno::Sequence< i18n::CalendarItem2 > aMonths = rCalendarWrapper.getMonths();
+    sal_uInt16 nMonth = ImplGetMonthFromCalendarItem( rStr, aMonths);
+    if (nMonth > 0)
+        return nMonth;
+
+    // And also possessive genitive and partitive month names.
+    const uno::Sequence< i18n::CalendarItem2 > aGenitiveMonths = rCalendarWrapper.getGenitiveMonths();
+    if (aGenitiveMonths != aMonths)
+    {
+        nMonth = ImplGetMonthFromCalendarItem( rStr, aGenitiveMonths);
+        if (nMonth > 0)
+            return nMonth;
+    }
+    const uno::Sequence< i18n::CalendarItem2 > aPartitiveMonths = rCalendarWrapper.getPartitiveMonths();
+    if (aPartitiveMonths != aMonths)
+    {
+        nMonth = ImplGetMonthFromCalendarItem( rStr, aPartitiveMonths);
+        if (nMonth > 0)
+            return nMonth;
+    }
+
+    // Check if there are more calendars and try them if so, as the long date
+    // format is obtained from the number formatter this is possible (e.g.
+    // ar_DZ "[~hijri] ...")
+    const uno::Sequence< i18n::Calendar2 > aCalendars =  rLocaleData.getAllCalendars();
+    if (aCalendars.getLength() > 1)
+    {
+        for (const auto& rCalendar : aCalendars)
+        {
+            if (rCalendar.Name != aDefaultCalendarName)
+            {
+                rCalendarName = rCalendar.Name;
+
+                nMonth = ImplGetMonthFromCalendarItem( rStr, rCalendar.Months);
+                if (nMonth > 0)
+                    return nMonth;
+
+                if (rCalendar.Months != rCalendar.GenitiveMonths)
+                {
+                    nMonth = ImplGetMonthFromCalendarItem( rStr, rCalendar.GenitiveMonths);
+                    if (nMonth > 0)
+                        return nMonth;
+                }
+
+                if (rCalendar.Months != rCalendar.PartitiveMonths)
+                {
+                    nMonth = ImplGetMonthFromCalendarItem( rStr, rCalendar.PartitiveMonths);
+                    if (nMonth > 0)
+                        return nMonth;
+                }
+
+                rCalendarName = aDefaultCalendarName;
+            }
+        }
     }
 
     return ImplCutNumberFromString( rStr );
@@ -1250,26 +1317,55 @@ bool DateFormatter::TextToDate(const OUString& rStr, Date& rDate, ExtDateFieldFo
 
     if ( eDateOrder == ExtDateFieldFormat::SystemLong )
     {
-        DateOrder eFormat = rLocaleDataWrapper.getLongDateOrder();
+        OUString aCalendarName;
+        LongDateOrder eFormat = rLocaleDataWrapper.getLongDateOrder();
         switch( eFormat )
         {
-            case DateOrder::MDY:
-                nMonth = ImplCutMonthFromString( aStr, rCalendarWrapper );
+            case LongDateOrder::MDY:
+                nMonth = ImplCutMonthFromString( aStr, aCalendarName, rLocaleDataWrapper, rCalendarWrapper );
                 nDay = ImplCutNumberFromString( aStr );
                 nYear  = ImplCutNumberFromString( aStr );
                 break;
-            case DateOrder::DMY:
+            case LongDateOrder::DMY:
                 nDay = ImplCutNumberFromString( aStr );
-                nMonth = ImplCutMonthFromString( aStr, rCalendarWrapper );
+                nMonth = ImplCutMonthFromString( aStr, aCalendarName, rLocaleDataWrapper, rCalendarWrapper );
                 nYear  = ImplCutNumberFromString( aStr );
                 break;
-            case DateOrder::YMD:
+            case LongDateOrder::YDM:
+                nYear  = ImplCutNumberFromString( aStr );
+                nDay = ImplCutNumberFromString( aStr );
+                nMonth = ImplCutMonthFromString( aStr, aCalendarName, rLocaleDataWrapper, rCalendarWrapper );
+                break;
+            case LongDateOrder::YMD:
             default:
                 nYear = ImplCutNumberFromString( aStr );
-                nMonth = ImplCutMonthFromString( aStr, rCalendarWrapper );
+                nMonth = ImplCutMonthFromString( aStr, aCalendarName, rLocaleDataWrapper, rCalendarWrapper );
                 nDay  = ImplCutNumberFromString( aStr );
                 break;
         }
+        if (aCalendarName != "gregorian")
+        {
+            // Calendar widget is Gregorian, convert date.
+            // Need full date.
+            bError = !nDay || !nMonth || !nYear;
+            if (!bError)
+            {
+                CalendarWrapper aCW( rLocaleDataWrapper.getComponentContext());
+                aCW.loadCalendar( aCalendarName, rLocaleDataWrapper.getLoadedLanguageTag().getLocale());
+                aCW.setDateTime(0.5);   // get rid of current time, set some day noon
+                aCW.setValue( i18n::CalendarFieldIndex::DAY_OF_MONTH, nDay);
+                aCW.setValue( i18n::CalendarFieldIndex::MONTH, nMonth - 1);
+                aCW.setValue( i18n::CalendarFieldIndex::YEAR, nYear);
+                bError = !aCW.isValid();
+                if (!bError)
+                {
+                    Date aDate = aCW.getEpochStart() + aCW.getDateTime();
+                    nYear = aDate.GetYear();
+                    nMonth = aDate.GetMonth();
+                    nDay = aDate.GetDay();
+                }
+            }
+        }
     }
     else
     {
@@ -1387,7 +1483,8 @@ namespace
 }
 
 OUString DateFormatter::FormatDate(const Date& rDate, ExtDateFieldFormat eExtFormat,
-                                   const LocaleDataWrapper& rLocaleData, CalendarWrapper& rCalendarWrapper)
+                                   const LocaleDataWrapper& rLocaleData,
+                                   const Formatter::StaticFormatter& rStaticFormatter)
 {
     bool bShowCentury = false;
     switch (eExtFormat)
@@ -1437,7 +1534,16 @@ OUString DateFormatter::FormatDate(const Date& rDate, ExtDateFieldFormat eExtFor
     {
         case ExtDateFieldFormat::SystemLong:
         {
-            return rLocaleData.getLongDate( rDate, rCalendarWrapper, !bShowCentury );
+            SvNumberFormatter* pFormatter = rStaticFormatter;
+            const LanguageTag aFormatterLang( pFormatter->GetLanguageTag());
+            const sal_uInt32 nIndex = pFormatter->GetFormatIndex( NF_DATE_SYSTEM_LONG,
+                    rLocaleData.getLanguageTag().getLanguageType(false));
+            OUString aStr;
+            const Color* pCol;
+            pFormatter->GetOutputString( rDate - pFormatter->GetNullDate(), nIndex, aStr, &pCol);
+            // Reset to what other uses may expect.
+            pFormatter->ChangeIntl( aFormatterLang.getLanguageType(false));
+            return aStr;
         }
         case ExtDateFieldFormat::ShortDDMMYY:
         case ExtDateFieldFormat::ShortDDMMYYYY:
@@ -1482,7 +1588,7 @@ OUString DateFormatter::FormatDate(const Date& rDate, ExtDateFieldFormat eExtFor
 
 OUString DateFormatter::ImplGetDateAsText( const Date& rDate ) const
 {
-    return DateFormatter::FormatDate(rDate, GetExtDateFormat(), ImplGetLocaleDataWrapper(), GetCalendarWrapper());
+    return DateFormatter::FormatDate(rDate, GetExtDateFormat(), ImplGetLocaleDataWrapper(), maStaticFormatter);
 }
 
 static void ImplDateIncrementDay( Date& rDate, bool bUp )
@@ -2036,7 +2142,7 @@ void DateField::DataChanged( const DataChangedEvent& rDCEvt )
     if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) && (rDCEvt.GetFlags() & (AllSettingsFlags::LOCALE|AllSettingsFlags::MISC)) )
     {
         if (rDCEvt.GetFlags() & AllSettingsFlags::LOCALE)
-            ImplGetLocaleDataWrapper().setLanguageTag( GetSettings().GetLanguageTag() );
+            ImplResetLocaleDataWrapper();
         ReformatAll();
     }
 }
@@ -2104,7 +2210,7 @@ void DateBox::DataChanged( const DataChangedEvent& rDCEvt )
 
     if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) && (rDCEvt.GetFlags() & AllSettingsFlags::LOCALE) )
     {
-        ImplGetLocaleDataWrapper().setLanguageTag( GetSettings().GetLanguageTag() );
+        ImplResetLocaleDataWrapper();
         ReformatAll();
     }
 }
@@ -2201,7 +2307,7 @@ namespace weld
     OUString DateFormatter::FormatNumber(int nValue) const
     {
         const LocaleDataWrapper& rLocaleData = Application::GetSettings().GetLocaleDataWrapper();
-        return ::DateFormatter::FormatDate(Date(nValue), m_eFormat, rLocaleData, GetCalendarWrapper());
+        return ::DateFormatter::FormatDate(Date(nValue), m_eFormat, rLocaleData, m_aStaticFormatter);
     }
 
     IMPL_LINK_NOARG(DateFormatter, FormatOutputHdl, LinkParamNone*, bool)
@@ -2240,12 +2346,12 @@ static bool ImplTimeProcessKeyInput( const KeyEvent& rKEvt,
         if ( (nGroup == KEYGROUP_FKEYS) || (nGroup == KEYGROUP_CURSOR) ||
              (nGroup == KEYGROUP_MISC)   ||
              ((cChar >= '0') && (cChar <= '9')) ||
-             string::equals(rLocaleDataWrapper.getTimeSep(), cChar) ||
+             rLocaleDataWrapper.getTimeSep() == OUStringChar(cChar) ||
              (rLocaleDataWrapper.getTimeAM().indexOf(cChar) != -1) ||
              (rLocaleDataWrapper.getTimePM().indexOf(cChar) != -1) ||
              // Accept AM/PM:
              (cChar == 'a') || (cChar == 'A') || (cChar == 'm') || (cChar == 'M') || (cChar == 'p') || (cChar == 'P') ||
-             ((eFormat == TimeFieldFormat::F_SEC_CS) && string::equals(rLocaleDataWrapper.getTime100SecSep(), cChar)) ||
+             ((eFormat == TimeFieldFormat::F_SEC_CS) && rLocaleDataWrapper.getTime100SecSep() == OUStringChar(cChar)) ||
              (bDuration && (cChar == '-')) )
             return false;
         else
@@ -2312,7 +2418,7 @@ bool TimeFormatter::TextToTime(const OUString& rStr, tools::Time& rTime, TimeFie
         // Replace characters above by the separator character
         for (sal_Int32 i = 0; i < aSepStr.getLength(); ++i)
         {
-            if (string::equals(rLocaleDataWrapper.getTimeSep(), aSepStr[i]))
+            if (rLocaleDataWrapper.getTimeSep() == OUStringChar(aSepStr[i]))
                 continue;
             for ( sal_Int32 j = 0; j < aStr.getLength(); j++ )
             {
@@ -2893,7 +2999,7 @@ void TimeField::DataChanged( const DataChangedEvent& rDCEvt )
 
     if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) && (rDCEvt.GetFlags() & AllSettingsFlags::LOCALE) )
     {
-        ImplGetLocaleDataWrapper().setLanguageTag( GetSettings().GetLanguageTag() );
+        ImplResetLocaleDataWrapper();
         ReformatAll();
     }
 }
@@ -3024,7 +3130,7 @@ void TimeBox::DataChanged( const DataChangedEvent& rDCEvt )
 
     if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) && (rDCEvt.GetFlags() & AllSettingsFlags::LOCALE) )
     {
-        ImplGetLocaleDataWrapper().setLanguageTag( GetSettings().GetLanguageTag() );
+        ImplResetLocaleDataWrapper();
         ReformatAll();
     }
 }
