@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
+#include <vcl/builder.hxx>
 #include <vcl/commandevent.hxx>
 #include <vcl/event.hxx>
 #include <vcl/toolkit/lstbox.hxx>
@@ -276,7 +276,7 @@ IMPL_LINK_NOARG(ListBox, ImplPopupModeEndHdl, FloatingWindow*, void)
 
             VclPtr<vcl::Window> xWindow = this;
             Select();
-            if ( xWindow->IsDisposed() )
+            if ( xWindow->isDisposed() )
                 return;
 
             mpImplLB->SetTravelSelect( bTravelSelect );
@@ -483,10 +483,10 @@ void ListBox::DataChanged( const DataChangedEvent& rDCEvt )
 
     if ( mpImplWin )
     {
-        mpImplWin->SetSettings( GetSettings() ); // If not yet set...
-        mpImplWin->ApplySettings(*mpImplWin);
+        mpImplWin->GetOutDev()->SetSettings( GetSettings() ); // If not yet set...
+        mpImplWin->ApplySettings(*mpImplWin->GetOutDev());
 
-        mpBtn->SetSettings( GetSettings() );
+        mpBtn->GetOutDev()->SetSettings( GetSettings() );
         ImplInitDropDownButton( mpBtn );
     }
 
@@ -963,7 +963,7 @@ Image ListBox::GetEntryImage( sal_Int32 nPos ) const
     return Image();
 }
 
-sal_Int32 ListBox::GetEntryPos( const OUString& rStr ) const
+sal_Int32 ListBox::GetEntryPos( std::u16string_view rStr ) const
 {
     if (!mpImplLB)
         return LISTBOX_ENTRY_NOTFOUND;
@@ -1019,7 +1019,7 @@ bool ListBox::IsEntryPosSelected( sal_Int32 nPos ) const
     return mpImplLB->GetEntryList()->IsEntryPosSelected( nPos + mpImplLB->GetEntryList()->GetMRUCount() );
 }
 
-void ListBox::SelectEntry( const OUString& rStr, bool bSelect )
+void ListBox::SelectEntry( std::u16string_view rStr, bool bSelect )
 {
     SelectEntryPos( GetEntryPos( rStr ), bSelect );
 }
@@ -1117,7 +1117,7 @@ tools::Rectangle ListBox::GetBoundingRectangle( sal_Int32 nItem ) const
 {
     tools::Rectangle aRect = mpImplLB->GetMainWindow()->GetBoundingRectangle( nItem );
     tools::Rectangle aOffset = mpImplLB->GetMainWindow()->GetWindowExtentsRelative( static_cast<vcl::Window*>(const_cast<ListBox *>(this)) );
-    aRect.Move( aOffset.TopLeft().X(), aOffset.TopLeft().Y() );
+    aRect.Move( aOffset.Left(), aOffset.Top() );
     return aRect;
 }
 
@@ -1400,22 +1400,20 @@ void ListBox::DumpAsPropertyTree(tools::JsonWriter& rJsonWriter)
     Control::DumpAsPropertyTree(rJsonWriter);
 
     {
-        auto entriesNode = rJsonWriter.startNode("entries");
+        auto entriesNode = rJsonWriter.startArray("entries");
         for (int i = 0; i < GetEntryCount(); ++i)
         {
-            auto entryNode = rJsonWriter.startNode("");
-            rJsonWriter.put("", GetEntry(i));
+            rJsonWriter.putSimpleValue(GetEntry(i));
         }
     }
 
     rJsonWriter.put("selectedCount", GetSelectedEntryCount());
 
     {
-        auto entriesNode = rJsonWriter.startNode("selectedEntries");
+        auto entriesNode = rJsonWriter.startArray("selectedEntries");
         for (int i = 0; i < GetSelectedEntryCount(); ++i)
         {
-            auto entryNode = rJsonWriter.startNode("");
-            rJsonWriter.put("", GetSelectedEntryPos(i));
+            rJsonWriter.putSimpleValue(OUString::number(GetSelectedEntryPos(i)));
         }
     }
 }
