@@ -96,7 +96,7 @@ static bool ImpIsTreeAvailable( Reference< XMultiServiceFactory > const & rXCfgP
     return bAvailable;
 }
 
-void FilterConfigItem::ImpInitTree( const OUString& rSubTree )
+void FilterConfigItem::ImpInitTree( std::u16string_view rSubTree )
 {
     bModified = false;
 
@@ -104,7 +104,7 @@ void FilterConfigItem::ImpInitTree( const OUString& rSubTree )
 
     Reference< XMultiServiceFactory > xCfgProv = theDefaultProvider::get( xContext );
 
-    OUString sTree = "/org.openoffice." + rSubTree;
+    OUString sTree = OUString::Concat("/org.openoffice.") + rSubTree;
     if ( !ImpIsTreeAvailable(xCfgProv, sTree) )
         return;
 
@@ -130,7 +130,7 @@ void FilterConfigItem::ImpInitTree( const OUString& rSubTree )
     }
 }
 
-FilterConfigItem::FilterConfigItem( const OUString& rSubTree )
+FilterConfigItem::FilterConfigItem( std::u16string_view rSubTree )
 {
     ImpInitTree( rSubTree );
 }
@@ -142,7 +142,7 @@ FilterConfigItem::FilterConfigItem( css::uno::Sequence< css::beans::PropertyValu
         aFilterData = *pFilterData;
 }
 
-FilterConfigItem::FilterConfigItem( const OUString& rSubTree,
+FilterConfigItem::FilterConfigItem( std::u16string_view rSubTree,
     css::uno::Sequence< css::beans::PropertyValue > const * pFilterData )
 {
     ImpInitTree( rSubTree );
@@ -378,11 +378,10 @@ void FilterConfigItem::WriteInt32( const OUString& rKey, sal_Int32 nNewValue )
 Reference< XStatusIndicator > FilterConfigItem::GetStatusIndicator() const
 {
     Reference< XStatusIndicator > xStatusIndicator;
-    const OUString sStatusIndicator( "StatusIndicator" );
 
     auto pPropVal = std::find_if(aFilterData.begin(), aFilterData.end(),
-        [&sStatusIndicator](const css::beans::PropertyValue& rPropVal) {
-            return rPropVal.Name == sStatusIndicator; });
+        [](const css::beans::PropertyValue& rPropVal) {
+            return rPropVal.Name == "StatusIndicator"; });
     if (pPropVal != aFilterData.end())
     {
         pPropVal->Value >>= xStatusIndicator;
