@@ -166,24 +166,24 @@ void AddTable(TrueTypeCreator *_this, TrueTypeTable *table)
 
 void RemoveTable(TrueTypeCreator *_this, sal_uInt32 tag)
 {
-    if (listCount(_this->tables))
-    {
-        listToFirst(_this->tables);
-        int done = 0;
-        do {
-            if (static_cast<TrueTypeTable *>(listCurrent(_this->tables))->tag == tag)
+    if (!listCount(_this->tables))
+        return;
+
+    listToFirst(_this->tables);
+    int done = 0;
+    do {
+        if (static_cast<TrueTypeTable *>(listCurrent(_this->tables))->tag == tag)
+        {
+            listRemove(_this->tables);
+        }
+        else
+        {
+            if (listNext(_this->tables))
             {
-                listRemove(_this->tables);
+                done = 1;
             }
-            else
-            {
-                if (listNext(_this->tables))
-                {
-                    done = 1;
-                }
-            }
-        } while (!done);
-    }
+        }
+    } while (!done);
 }
 
 static void ProcessTables(TrueTypeCreator *);
@@ -272,13 +272,12 @@ SFErrCodes StreamToFile(TrueTypeCreator *_this, const char* fname)
     sal_uInt8 *ptr;
     sal_uInt32 length;
     SFErrCodes r;
-    FILE* fd;
 
     if ((r = StreamToMemory(_this, &ptr, &length)) != SFErrCodes::Ok) return r;
     r = SFErrCodes::BadFile;
     if (fname)
     {
-        fd = fopen(fname, "wb");
+        FILE* fd = fopen(fname, "wb");
         if (fd)
         {
             if (fwrite(ptr, 1, length, fd) != length) {
@@ -430,21 +429,21 @@ static void TrueTypeTableDispose_glyf(TrueTypeTable *_this)
 
 static void TrueTypeTableDispose_cmap(TrueTypeTable *_this)
 {
-    if (_this) {
-        table_cmap *t = static_cast<table_cmap *>(_this->data);
-        if (t) {
-            CmapSubTable *s = t->s;
-            if (s) {
-                for (sal_uInt32 i = 0; i < t->m; i++) {
-                    if (s[i].xc) free(s[i].xc);
-                    if (s[i].xg) free(s[i].xg);
-                }
-                free(s);
+    if (!_this)        return;
+
+    table_cmap *t = static_cast<table_cmap *>(_this->data);
+    if (t) {
+        CmapSubTable *s = t->s;
+        if (s) {
+            for (sal_uInt32 i = 0; i < t->m; i++) {
+                if (s[i].xc) free(s[i].xc);
+                if (s[i].xg) free(s[i].xg);
             }
-            free(t);
+            free(s);
         }
-        free(_this);
+        free(t);
     }
+    free(_this);
 }
 
 static void TrueTypeTableDispose_name(TrueTypeTable *_this)
@@ -457,28 +456,28 @@ static void TrueTypeTableDispose_name(TrueTypeTable *_this)
 
 static void TrueTypeTableDispose_post(TrueTypeTable *_this)
 {
-    if (_this) {
-        tdata_post *p = static_cast<tdata_post *>(_this->data);
-        if (p) {
-            if (p->format == 0x00030000) {
-                /* do nothing */
-            } else {
-                SAL_WARN("vcl.fonts", "Unsupported format of a 'post' table: "
-                        << std::setfill('0')
-                        << std::setw(8)
-                        << std::hex
-                        << std::uppercase
-                        << static_cast<int>(p->format) << ".");
-            }
-            free(p);
+    if (!_this)        return;
+
+    tdata_post *p = static_cast<tdata_post *>(_this->data);
+    if (p) {
+        if (p->format == 0x00030000) {
+            /* do nothing */
+        } else {
+            SAL_WARN("vcl.fonts", "Unsupported format of a 'post' table: "
+                    << std::setfill('0')
+                    << std::setw(8)
+                    << std::hex
+                    << std::uppercase
+                    << static_cast<int>(p->format) << ".");
         }
-        free(_this);
+        free(p);
     }
+    free(_this);
 }
 
 /* destructor vtable */
 
-static struct {
+struct {
     sal_uInt32 tag;
     void (*f)(TrueTypeTable *);
 } const vtable1[] =
@@ -804,7 +803,7 @@ static int GetRawData_post(TrueTypeTable *_this, sal_uInt8 **ptr, sal_uInt32 *le
     return ret;
 }
 
-static struct {
+struct {
     sal_uInt32 tag;
     int (*f)(TrueTypeTable *, sal_uInt8 **, sal_uInt32 *, sal_uInt32 *);
 } const vtable2[] =
@@ -1142,7 +1141,7 @@ void cmapAdd(TrueTypeTable *table, sal_uInt32 id, sal_uInt32 c, sal_uInt32 g)
     s[i].n++;
 }
 
-sal_uInt32 glyfAdd(TrueTypeTable *table, GlyphData *glyphdata, TrueTypeFont *fnt)
+sal_uInt32 glyfAdd(TrueTypeTable *table, GlyphData *glyphdata, AbstractTrueTypeFont *fnt)
 {
     list l;
     sal_uInt32 currentID;
@@ -1262,7 +1261,6 @@ static void ProcessTables(TrueTypeCreator *tt)
     listToFirst(glyphlist);
     do {
         GlyphData *gd = static_cast<GlyphData *>(listCurrent(glyphlist));
-        sal_Int16 z;
         glyfLen += gd->nbytes;
         /* XXX if (gd->nbytes & 1) glyfLen++; */
 
@@ -1273,7 +1271,7 @@ static void ProcessTables(TrueTypeCreator *tt)
         /* printf("IDs: %d %d.\n", gd->glyphID, gd->newID); */
 
         if (gd->nbytes != 0) {
-            z = GetInt16(gd->ptr, 2);
+            sal_Int16 z = GetInt16(gd->ptr, 2);
             if (z < xMin) xMin = z;
 
             z = GetInt16(gd->ptr, 4);
