@@ -23,43 +23,69 @@
 #include <unx/freetype_glyphcache.hxx>
 #endif
 
-SalLayoutGlyphs::SalLayoutGlyphs()
-    : m_pImpl(nullptr)
+SalLayoutGlyphs::SalLayoutGlyphs() {}
+
+SalLayoutGlyphs::~SalLayoutGlyphs() {}
+
+SalLayoutGlyphs::SalLayoutGlyphs(SalLayoutGlyphs&& rOther) noexcept
 {
+    std::swap(m_pImpl, rOther.m_pImpl);
+    std::swap(m_pExtraImpls, rOther.m_pExtraImpls);
 }
 
-SalLayoutGlyphs::~SalLayoutGlyphs() { delete m_pImpl; }
-
-SalLayoutGlyphs::SalLayoutGlyphs(const SalLayoutGlyphs& rOther)
-{
-    m_pImpl = rOther.m_pImpl ? rOther.m_pImpl->clone(*this) : nullptr;
-}
-
-SalLayoutGlyphs& SalLayoutGlyphs::operator=(const SalLayoutGlyphs& rOther)
+SalLayoutGlyphs& SalLayoutGlyphs::operator=(SalLayoutGlyphs&& rOther) noexcept
 {
     if (this != &rOther)
     {
-        delete m_pImpl;
-        m_pImpl = rOther.m_pImpl ? rOther.m_pImpl->clone(*this) : nullptr;
+        std::swap(m_pImpl, rOther.m_pImpl);
+        std::swap(m_pExtraImpls, rOther.m_pExtraImpls);
     }
     return *this;
 }
 
-bool SalLayoutGlyphs::IsValid() const { return m_pImpl && m_pImpl->IsValid(); }
+bool SalLayoutGlyphs::IsValid() const
+{
+    if (m_pImpl == nullptr)
+        return false;
+    if (!m_pImpl->IsValid())
+        return false;
+    if (m_pExtraImpls)
+        for (std::unique_ptr<SalLayoutGlyphsImpl> const& impl : *m_pExtraImpls)
+            if (!impl->IsValid())
+                return false;
+    return true;
+}
 
 void SalLayoutGlyphs::Invalidate()
 {
-    if (m_pImpl)
-        m_pImpl->Invalidate();
+    // Invalidating is in fact simply clearing.
+    m_pImpl.reset();
+    m_pExtraImpls.reset();
 }
 
-SalLayoutGlyphsImpl* SalLayoutGlyphsImpl::clone(SalLayoutGlyphs& rGlyphs) const
+SalLayoutGlyphsImpl* SalLayoutGlyphs::Impl(unsigned int nLevel) const
 {
-    SalLayoutGlyphsImpl* pNew = new SalLayoutGlyphsImpl(rGlyphs, *m_rFontInstance);
-    *pNew = *this;
-    return pNew;
+    if (nLevel == 0)
+        return m_pImpl.get();
+    if (m_pExtraImpls != nullptr && nLevel - 1 < m_pExtraImpls->size())
+        return (*m_pExtraImpls)[nLevel - 1].get();
+    return nullptr;
 }
 
+void SalLayoutGlyphs::AppendImpl(SalLayoutGlyphsImpl* pImpl)
+{
+    if (!m_pImpl)
+        m_pImpl.reset(pImpl);
+    else
+    {
+        if (!m_pExtraImpls)
+            m_pExtraImpls.reset(new std::vector<std::unique_ptr<SalLayoutGlyphsImpl>>);
+        m_pExtraImpls->emplace_back(pImpl);
+    }
+}
+
+SalLayoutGlyphsImpl* SalLayoutGlyphsImpl::clone() const { return new SalLayoutGlyphsImpl(*this); }
+
 bool SalLayoutGlyphsImpl::IsValid() const
 {
     if (!m_rFontInstance.is())
@@ -69,10 +95,4 @@ bool SalLayoutGlyphsImpl::IsValid() const
     return true;
 }
 
-void SalLayoutGlyphsImpl::Invalidate()
-{
-    m_rFontInstance.clear();
-    clear();
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
