@@ -8,6 +8,7 @@
  */
 
 #include <vcl/opengl/OpenGLHelper.hxx>
+#include <config_vclplug.h>
 
 #include <osl/file.hxx>
 #include <rtl/bootstrap.hxx>
@@ -25,6 +26,7 @@
 #include <com/sun/star/configuration/theDefaultProvider.hpp>
 
 #include <stdarg.h>
+#include <string_view>
 #include <vector>
 #include <unordered_map>
 
@@ -32,12 +34,12 @@
 #include <vcl/opengl/OpenGLWrapper.hxx>
 #include <vcl/opengl/OpenGLContext.hxx>
 #include <desktop/crashreport.hxx>
-#include <bitmapwriteaccess.hxx>
+#include <bitmap/BitmapWriteAccess.hxx>
 #include <watchdog.hxx>
 #include <vcl/skia/SkiaHelper.hxx>
 #include <vcl/glxtestprocess.hxx>
 
-#if defined UNX && !defined MACOSX && !defined IOS && !defined ANDROID && !defined HAIKU
+#if USING_X11
 #include <opengl/x11/X11DeviceInfo.hxx>
 #elif defined (_WIN32)
 #include <opengl/win/WinDeviceInfo.hxx>
@@ -59,7 +61,7 @@ OUString getShaderFolder()
     return aUrl + "/opengl/";
 }
 
-OString loadShader(const OUString& rFilename)
+OString loadShader(std::u16string_view rFilename)
 {
     OUString aFileURL = getShaderFolder() + rFilename +".glsl";
     osl::File aFile(aFileURL);
@@ -136,16 +138,16 @@ namespace {
     }
 }
 
-static void addPreamble(OString& rShaderSource, const OString& rPreamble)
+static void addPreamble(OString& rShaderSource, std::string_view rPreamble)
 {
-    if (rPreamble.isEmpty())
+    if (rPreamble.empty())
         return;
 
     int nVersionStrStartPos = rShaderSource.indexOf("#version");
 
     if (nVersionStrStartPos == -1)
     {
-        rShaderSource = rPreamble + "\n" + rShaderSource;
+        rShaderSource = OString::Concat(rPreamble) + "\n" + rShaderSource;
     }
     else
     {
@@ -199,7 +201,7 @@ namespace
 
     OString getDeviceInfoString()
     {
-#if defined( SAL_UNX ) && !defined( MACOSX ) && !defined( IOS )&& !defined( ANDROID ) && !defined( HAIKU )
+#if USING_X11
         const X11OpenGLDeviceInfo aInfo;
         return aInfo.GetOS() +
             aInfo.GetOSRelease() +
@@ -221,7 +223,7 @@ namespace
 
     OString getStringDigest( const OUString& rVertexShaderName,
                              const OUString& rFragmentShaderName,
-                             const OString& rPreamble )
+                             std::string_view rPreamble )
     {
         // read shaders source
         OString aVertexShaderSource = getShaderSource( rVertexShaderName );
@@ -301,17 +303,17 @@ namespace
         return false;
     }
 
-    OString createFileName( const OUString& rVertexShaderName,
-                            const OUString& rFragmentShaderName,
-                            const OUString& rGeometryShaderName,
-                            const OString& rDigest )
+    OString createFileName( std::u16string_view rVertexShaderName,
+                            std::u16string_view rFragmentShaderName,
+                            std::u16string_view rGeometryShaderName,
+                            std::string_view rDigest )
     {
         OString aFileName = getCacheFolder() +
             OUStringToOString( rVertexShaderName, RTL_TEXTENCODING_UTF8 ) + "-" +
             OUStringToOString( rFragmentShaderName, RTL_TEXTENCODING_UTF8 ) + "-";
-        if (!rGeometryShaderName.isEmpty())
+        if (!rGeometryShaderName.empty())
             aFileName += OUStringToOString( rGeometryShaderName, RTL_TEXTENCODING_UTF8 ) + "-";
-        aFileName += rDigest + ".bin";
+        aFileName += OString::Concat(rDigest) + ".bin";
         return aFileName;
     }
 
@@ -372,7 +374,7 @@ namespace
 
 OString OpenGLHelper::GetDigest( const OUString& rVertexShaderName,
                                       const OUString& rFragmentShaderName,
-                                      const OString& rPreamble )
+                                      std::string_view rPreamble )
 {
     return getStringDigest(rVertexShaderName, rFragmentShaderName, rPreamble);
 }
@@ -380,8 +382,8 @@ OString OpenGLHelper::GetDigest( const OUString& rVertexShaderName,
 GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
                                 const OUString& rFragmentShaderName,
                                 const OUString& rGeometryShaderName,
-                                const OString& preamble,
-                                const OString& rDigest)
+                                std::string_view preamble,
+                                std::string_view rDigest)
 {
     OpenGLZone aZone;
 
@@ -400,7 +402,7 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
         aGeometryShaderSource = getShaderSource(rGeometryShaderName);
 
     GLint bBinaryResult = GL_FALSE;
-    if (epoxy_has_gl_extension("GL_ARB_get_program_binary") && !rDigest.isEmpty())
+    if (epoxy_has_gl_extension("GL_ARB_get_program_binary") && !rDigest.empty())
     {
         OString aFileName =
                 createFileName(rVertexShaderName, rFragmentShaderName, rGeometryShaderName, rDigest);
@@ -425,7 +427,7 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
     GLint Result = GL_FALSE;
 
     // Compile Vertex Shader
-    if( !preamble.isEmpty())
+    if( !preamble.empty())
         addPreamble( aVertexShaderSource, preamble );
     char const * VertexSourcePointer = aVertexShaderSource.getStr();
     glShaderSource(VertexShaderID, 1, &VertexSourcePointer , nullptr);
@@ -438,7 +440,7 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
                                 rVertexShaderName, true);
 
     // Compile Fragment Shader
-    if( !preamble.isEmpty())
+    if( !preamble.empty())
         addPreamble( aFragmentShaderSource, preamble );
     char const * FragmentSourcePointer = aFragmentShaderSource.getStr();
     glShaderSource(FragmentShaderID, 1, &FragmentSourcePointer , nullptr);
@@ -453,7 +455,7 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
     if (bHasGeometryShader)
     {
         // Compile Geometry Shader
-        if( !preamble.isEmpty())
+        if( !preamble.empty())
             addPreamble( aGeometryShaderSource, preamble );
         char const * GeometrySourcePointer = aGeometryShaderSource.getStr();
         glShaderSource(GeometryShaderID, 1, &GeometrySourcePointer , nullptr);
@@ -472,7 +474,7 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
     if (bHasGeometryShader)
         glAttachShader(ProgramID, GeometryShaderID);
 
-    if (epoxy_has_gl_extension("GL_ARB_get_program_binary") && !rDigest.isEmpty())
+    if (epoxy_has_gl_extension("GL_ARB_get_program_binary") && !rDigest.empty())
     {
         glProgramParameteri(ProgramID, GL_PROGRAM_BINARY_RETRIEVABLE_HINT, GL_TRUE);
         glLinkProgram(ProgramID);
@@ -512,8 +514,8 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
 
 GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
                                 const OUString& rFragmentShaderName,
-                                const OString& preamble,
-                                const OString& rDigest)
+                                std::string_view preamble,
+                                std::string_view rDigest)
 {
     return LoadShaders(rVertexShaderName, rFragmentShaderName, OUString(), preamble, rDigest);
 }
@@ -522,7 +524,7 @@ GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
                                 const OUString& rFragmentShaderName,
                                 const OUString& rGeometryShaderName)
 {
-    return LoadShaders(rVertexShaderName, rFragmentShaderName, rGeometryShaderName, OString(), OString());
+    return LoadShaders(rVertexShaderName, rFragmentShaderName, rGeometryShaderName, std::string_view(), std::string_view());
 }
 
 GLint OpenGLHelper::LoadShaders(const OUString& rVertexShaderName,
@@ -562,8 +564,8 @@ GLenum OpenGLHelper::OptimalBufferFormat()
 BitmapEx OpenGLHelper::ConvertBufferToBitmapEx(const sal_uInt8* const pBuffer, tools::Long nWidth, tools::Long nHeight)
 {
     assert(pBuffer);
-    Bitmap aBitmap( Size(nWidth, nHeight), 24 );
-    AlphaMask aAlpha( Size(nWidth, nHeight) );
+    Bitmap aBitmap(Size(nWidth, nHeight), vcl::PixelFormat::N24_BPP);
+    AlphaMask aAlpha(Size(nWidth, nHeight));
 
     {
         BitmapScopedWriteAccess pWriteAccess( aBitmap );
@@ -761,7 +763,7 @@ bool OpenGLHelper::isDeviceDenylisted()
     {
         OpenGLZone aZone;
 
-#if defined UNX && !defined MACOSX && !defined IOS && !defined ANDROID && !defined HAIKU
+#if USING_X11
         X11OpenGLDeviceInfo aInfo;
         bDenylisted = aInfo.isDeviceBlocked();
         SAL_INFO("vcl.opengl", "denylisted: " << bDenylisted);
@@ -784,12 +786,16 @@ bool OpenGLHelper::isDeviceDenylisted()
     return bDenylisted;
 }
 
-bool OpenGLHelper::supportsVCLOpenGL()
+bool OpenGLHelper::supportsOpenGL()
 {
-    static bool bDisableGL = !!getenv("SAL_DISABLEGL");
-    bool bDenylisted = isDeviceDenylisted();
-
-    return !bDisableGL && !bDenylisted;
+    if( getenv("SAL_DISABLEGL") != nullptr )
+        return false;
+    if( isDeviceDenylisted())
+        return false;
+    if( officecfg::Office::Common::VCL::DisableOpenGL::get())
+        return false;
+    WatchdogThread::start();
+    return true;
 }
 
 namespace
@@ -853,7 +859,7 @@ void OpenGLZone::hardDisable()
     // Disable the OpenGL support
     std::shared_ptr<comphelper::ConfigurationChanges> xChanges(
         comphelper::ConfigurationChanges::create());
-    officecfg::Office::Common::VCL::UseOpenGL::set(false,  xChanges);
+    officecfg::Office::Common::VCL::DisableOpenGL::set(true, xChanges);
     xChanges->commit();
 
     // Force synchronous config write
@@ -884,116 +890,6 @@ const CrashWatchdogTimingsValues& OpenGLZone::getCrashWatchdogTimingsValues()
     return gWatchdogTimings.getWatchdogTimingsValues(eMode);
 }
 
-OpenGLVCLContextZone::OpenGLVCLContextZone()
-{
-    OpenGLContext::makeVCLCurrent();
-}
-
-namespace
-{
-    bool bTempOpenGLDisabled = false;
-}
-
-PreDefaultWinNoOpenGLZone::PreDefaultWinNoOpenGLZone()
-{
-    bTempOpenGLDisabled = true;
-}
-
-PreDefaultWinNoOpenGLZone::~PreDefaultWinNoOpenGLZone()
-{
-    bTempOpenGLDisabled = false;
-}
-
-static void reapGlxTest()
-{
-    // Reap the glxtest child, or it'll stay around as a zombie,
-    // as X11OpenGLDeviceInfo::GetData() will not get called.
-    static bool bTestReaped = false;
-    if(!bTestReaped)
-    {
-        reap_glxtest_process();
-        bTestReaped = true;
-    }
-}
-
-bool OpenGLHelper::isVCLOpenGLEnabled()
-{
-    // Skia always takes precedence if enabled
-    if( SkiaHelper::isVCLSkiaEnabled())
-    {
-        reapGlxTest();
-        return false;
-    }
-
-    /**
-     * The !bSet part should only be called once! Changing the results in the same
-     * run will mix OpenGL and normal rendering.
-     */
-
-    static bool bSet = false;
-    static bool bEnable = false;
-    static bool bForceOpenGL = false;
-
-    // No hardware rendering, so no OpenGL
-    if (Application::IsBitmapRendering())
-        return false;
-
-    //tdf#106155, disable GL while loading certain bitmaps needed for the initial toplevel windows
-    //under raw X (kde) vclplug
-    if (bTempOpenGLDisabled)
-        return false;
-
-    if (bSet)
-    {
-        return bForceOpenGL || bEnable;
-    }
-    /*
-     * There are a number of cases that these environment variables cover:
-     *  * SAL_FORCEGL forces OpenGL independent of any other option
-     *  * SAL_DISABLEGL or a denylisted driver avoid the use of OpenGL if SAL_FORCEGL is not set
-     */
-
-    bSet = true;
-    bForceOpenGL = !!getenv("SAL_FORCEGL") || officecfg::Office::Common::VCL::ForceOpenGL::get();
-
-    bool bRet = false;
-    bool bSupportsVCLOpenGL = supportsVCLOpenGL();
-    // always call supportsVCLOpenGL to de-zombie the glxtest child process on X11
-    if (bForceOpenGL)
-    {
-        bRet = true;
-    }
-    else if (bSupportsVCLOpenGL)
-    {
-        static bool bEnableGLEnv = !!getenv("SAL_ENABLEGL");
-
-        bEnable = bEnableGLEnv;
-
-        if (officecfg::Office::Common::VCL::UseOpenGL::get())
-            bEnable = true;
-
-        // Force disable in safe mode
-        if (Application::IsSafeModeEnabled())
-            bEnable = false;
-
-        bRet = bEnable;
-    }
-
-    if (bRet)
-        WatchdogThread::start();
-    else
-        reapGlxTest();
-
-    CrashReporter::addKeyValue("UseOpenGL", OUString::boolean(bRet), CrashReporter::Write);
-
-    return bRet;
-}
-
-bool OpenGLWrapper::isVCLOpenGLEnabled()
-{
-    return OpenGLHelper::isVCLOpenGLEnabled();
-}
-
 void OpenGLHelper::debugMsgStream(std::ostringstream const &pStream)
 {
     debugMsgPrint(
