@@ -87,6 +87,7 @@ void OutputDevice::DrawHatch( const tools::PolyPolygon& rPolyPoly, const Hatch&
 
     if( !mpGraphics && !AcquireGraphics() )
         return;
+    assert(mpGraphics);
 
     if( mbInitClipRegion )
         InitClipRegion();
@@ -187,7 +188,7 @@ void OutputDevice::DrawHatch( const tools::PolyPolygon& rPolyPoly, const Hatch&
         if( ( rHatch.GetStyle() == HatchStyle::Double ) || ( rHatch.GetStyle() == HatchStyle::Triple ) )
         {
             // Double hatch
-            CalcHatchValues( aRect, nWidth, rHatch.GetAngle() + Degree10(900), aPt1, aPt2, aInc, aEndPt1 );
+            CalcHatchValues( aRect, nWidth, rHatch.GetAngle() + 900_deg10, aPt1, aPt2, aInc, aEndPt1 );
             do
             {
                 DrawHatchLine( tools::Line( aPt1, aPt2 ), rPolyPoly, pPtBuffer.get(), bMtf );
@@ -199,7 +200,7 @@ void OutputDevice::DrawHatch( const tools::PolyPolygon& rPolyPoly, const Hatch&
             if( rHatch.GetStyle() == HatchStyle::Triple )
             {
                 // Triple hatch
-                CalcHatchValues( aRect, nWidth, rHatch.GetAngle() + Degree10(450), aPt1, aPt2, aInc, aEndPt1 );
+                CalcHatchValues( aRect, nWidth, rHatch.GetAngle() + 450_deg10, aPt1, aPt2, aInc, aEndPt1 );
                 do
                 {
                     DrawHatchLine( tools::Line( aPt1, aPt2 ), rPolyPoly, pPtBuffer.get(), bMtf );
@@ -216,15 +217,15 @@ void OutputDevice::CalcHatchValues( const tools::Rectangle& rRect, tools::Long n
                                     Point& rPt1, Point& rPt2, Size& rInc, Point& rEndPt1 )
 {
     Point   aRef;
-    Degree10    nAngle = nAngle10 % Degree10(1800);
+    Degree10    nAngle = nAngle10 % 1800_deg10;
     tools::Long    nOffset = 0;
 
-    if( nAngle > Degree10(900) )
-        nAngle -= Degree10(1800);
+    if( nAngle > 900_deg10 )
+        nAngle -= 1800_deg10;
 
     aRef = ( !IsRefPoint() ? rRect.TopLeft() : GetRefPoint() );
 
-    if( Degree10(0) == nAngle )
+    if( 0_deg10 == nAngle )
     {
         rInc = Size( 0, nDist );
         rPt1 = rRect.TopLeft();
@@ -239,7 +240,7 @@ void OutputDevice::CalcHatchValues( const tools::Rectangle& rRect, tools::Long n
         rPt1.AdjustY( -nOffset );
         rPt2.AdjustY( -nOffset );
     }
-    else if( Degree10(900) == nAngle )
+    else if( 900_deg10 == nAngle )
     {
         rInc = Size( nDist, 0 );
         rPt1 = rRect.TopLeft();
@@ -254,7 +255,7 @@ void OutputDevice::CalcHatchValues( const tools::Rectangle& rRect, tools::Long n
         rPt1.AdjustX( -nOffset );
         rPt2.AdjustX( -nOffset );
     }
-    else if( nAngle >= Degree10(-450) && nAngle <= Degree10(450) )
+    else if( nAngle >= Degree10(-450) && nAngle <= 450_deg10 )
     {
         const double    fAngle = F_PI1800 * std::abs( nAngle.get() );
         const double    fTan = tan( fAngle );
@@ -264,7 +265,7 @@ void OutputDevice::CalcHatchValues( const tools::Rectangle& rRect, tools::Long n
         nDist = FRound( nDist / cos( fAngle ) );
         rInc = Size( 0, nDist );
 
-        if( nAngle > Degree10(0) )
+        if( nAngle > 0_deg10 )
         {
             rPt1 = rRect.TopLeft();
             rPt2 = Point( rRect.Right(), rRect.Top() - nYOff );
@@ -297,7 +298,7 @@ void OutputDevice::CalcHatchValues( const tools::Rectangle& rRect, tools::Long n
         nDist = FRound( nDist / sin( fAngle ) );
         rInc = Size( nDist, 0 );
 
-        if( nAngle > Degree10(0) )
+        if( nAngle > 0_deg10 )
         {
             rPt1 = rRect.TopLeft();
             rPt2 = Point( rRect.Left() - nXOff, rRect.Bottom() );
@@ -404,7 +405,7 @@ void OutputDevice::DrawHatchLine( const tools::Line& rLine, const tools::PolyPol
 void OutputDevice::DrawHatchLine_DrawLine(const Point& rStartPoint, const Point& rEndPoint)
 {
     Point aPt1{ImplLogicToDevicePixel(rStartPoint)}, aPt2{ImplLogicToDevicePixel(rEndPoint)};
-    mpGraphics->DrawLine(aPt1.X(), aPt1.Y(), aPt2.X(), aPt2.Y(), this);
+    mpGraphics->DrawLine(aPt1.X(), aPt1.Y(), aPt2.X(), aPt2.Y(), *this);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
