@@ -30,7 +30,7 @@
 #include <vcl/wrkwin.hxx>
 #include <vcl/event.hxx>
 #include <vcl/toolbox.hxx>
-#include <vcl/floatwin.hxx>
+#include <vcl/toolkit/floatwin.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/IDialogRenderable.hxx>
 
@@ -82,7 +82,7 @@ void FloatingWindow::ImplInitFloating( vcl::Window* pParent, WinBits nStyle )
         if (!(nStyle & WB_NODIALOGCONTROL))
             nStyle |= WB_DIALOGCONTROL;
 
-        if (nStyle & (WB_MOVEABLE | WB_SIZEABLE | WB_ROLLABLE | WB_CLOSEABLE | WB_STANDALONE)
+        if (nStyle & (WB_MOVEABLE | WB_SIZEABLE | WB_CLOSEABLE | WB_STANDALONE)
             && !(nStyle & WB_OWNERDRAWDECORATION))
         {
             WinBits nFloatWinStyle = nStyle;
@@ -228,11 +228,6 @@ void FloatingWindow::dispose()
     SystemWindow::dispose();
 }
 
-Point FloatingWindow::CalcFloatingPosition( vcl::Window* pWindow, const tools::Rectangle& rRect, FloatWinPopupFlags nFlags, sal_uInt16& rArrangeIndex )
-{
-    return ImplCalcPos( pWindow, rRect, nFlags, rArrangeIndex );
-}
-
 Point FloatingWindow::ImplCalcPos(vcl::Window* pWindow,
                                   const tools::Rectangle& rRect, FloatWinPopupFlags nFlags,
                                   sal_uInt16& rArrangeIndex, Point* pLOKTwipsPos)
@@ -490,7 +485,7 @@ Point FloatingWindow::ImplConvertToAbsPos(vcl::Window* pReference, const Point&
     const OutputDevice *pWindowOutDev = pReference->GetOutDev();
 
     // compare coordinates in absolute screen coordinates
-    if( pReference->HasMirroredGraphics()  )
+    if( pWindowOutDev->HasMirroredGraphics()  )
     {
         if(!pReference->IsRTLEnabled() )
             pWindowOutDev->ReMirror( aAbsolute );
@@ -514,7 +509,7 @@ tools::Rectangle FloatingWindow::ImplConvertToAbsPos(vcl::Window* pReference, co
 
     // compare coordinates in absolute screen coordinates
     // Keep in sync with FloatingWindow::ImplFloatHitTest, e.g. fdo#33509
-    if( pReference->HasMirroredGraphics()  )
+    if( pParentWinOutDev->HasMirroredGraphics()  )
     {
         if(!pReference->IsRTLEnabled() )
             pParentWinOutDev->ReMirror(aFloatRect);
@@ -524,6 +519,29 @@ tools::Rectangle FloatingWindow::ImplConvertToAbsPos(vcl::Window* pReference, co
     }
     else
         aFloatRect.SetPos(pReference->OutputToAbsoluteScreenPixel(pReference->ScreenToOutputPixel(rRect.TopLeft())));
+
+    return aFloatRect;
+}
+
+tools::Rectangle FloatingWindow::ImplConvertToRelPos(vcl::Window* pReference, const tools::Rectangle& rRect)
+{
+    tools::Rectangle aFloatRect = rRect;
+
+    const OutputDevice *pParentWinOutDev = pReference->GetOutDev();
+
+    // compare coordinates in absolute screen coordinates
+    // Keep in sync with FloatingWindow::ImplFloatHitTest, e.g. fdo#33509
+    if( pParentWinOutDev->HasMirroredGraphics()  )
+    {
+        aFloatRect = pReference->ImplUnmirroredAbsoluteScreenToOutputPixel(aFloatRect);
+        aFloatRect.SetPos(pReference->OutputToScreenPixel(aFloatRect.TopLeft()));
+
+        if(!pReference->IsRTLEnabled() )
+            pParentWinOutDev->ReMirror(aFloatRect);
+    }
+    else
+        aFloatRect.SetPos(pReference->OutputToScreenPixel(pReference->AbsoluteScreenToOutputPixel(rRect.TopLeft())));
+
     return aFloatRect;
 }
 
@@ -752,9 +770,6 @@ void FloatingWindow::SetTitleType( FloatWinTitleType nTitle )
 
 void FloatingWindow::StartPopupMode( const tools::Rectangle& rRect, FloatWinPopupFlags nFlags )
 {
-    if ( IsRollUp() )
-        RollDown();
-
     // remove title
     mnOldTitle = mnTitle;
     if ( ( mpWindowImpl->mnStyle & WB_POPUP ) && !GetText().isEmpty() )
@@ -796,15 +811,17 @@ void FloatingWindow::StartPopupMode( const tools::Rectangle& rRect, FloatWinPopu
     ImplSVData* pSVData = ImplGetSVData();
     mpNextFloat = pSVData->mpWinData->mpFirstFloat;
     pSVData->mpWinData->mpFirstFloat = this;
-    if (nFlags & FloatWinPopupFlags::GrabFocus)
+    bool bGrabFocus(nFlags & FloatWinPopupFlags::GrabFocus);
+    if (bGrabFocus)
     {
         // force key input even without focus (useful for menus)
         mbGrabFocus = true;
         mxPrevFocusWin = Window::SaveFocus();
         mpWindowImpl->mpFrameData->mbHasFocus = true;
-        GrabFocus();
     }
     Show( true, ShowFlags::NoActivate );
+    if (bGrabFocus)
+        GrabFocus();
 }
 
 void FloatingWindow::StartPopupMode( ToolBox* pBox, FloatWinPopupFlags nFlags )
@@ -812,7 +829,7 @@ void FloatingWindow::StartPopupMode( ToolBox* pBox, FloatWinPopupFlags nFlags )
     mpImplData->mpBox = pBox;
 
     // get selected button
-    sal_uInt16 nItemId = pBox->GetDownItemId();
+    ToolBoxItemId nItemId = pBox->GetDownItemId();
 
     if ( nItemId )
         pBox->ImplFloatControl( true, this );
@@ -934,7 +951,8 @@ void FloatingWindow::AddPopupModeWindow(vcl::Window* pWindow)
     // !!! up-to-now only 1 window and not yet a list
     mpFirstPopupModeWin = pWindow;
 }
-bool FloatingWindow::UpdatePositionData()
+
+bool SystemWindow::UpdatePositionData()
 {
     auto pWin = ImplGetParent();
     if (pWin)
