@@ -168,23 +168,23 @@ void Window::InvertTracking( const tools::Rectangle& rRect, ShowTrackFlags nFlag
 
     if ( nFlags & ShowTrackFlags::TrackWindow )
     {
-        if ( !IsDeviceOutputNecessary() )
+        if ( !GetOutDev()->IsDeviceOutputNecessary() )
             return;
 
         // we need a graphics
-        if ( !mpGraphics )
+        if ( !GetOutDev()->mpGraphics )
         {
             if ( !pOutDev->AcquireGraphics() )
                 return;
         }
 
-        if ( mbInitClipRegion )
-            InitClipRegion();
+        if ( GetOutDev()->mbInitClipRegion )
+            GetOutDev()->InitClipRegion();
 
-        if ( mbOutputClipped )
+        if ( GetOutDev()->mbOutputClipped )
             return;
 
-        pGraphics = mpGraphics;
+        pGraphics = GetOutDev()->mpGraphics;
     }
     else
     {
@@ -192,9 +192,7 @@ void Window::InvertTracking( const tools::Rectangle& rRect, ShowTrackFlags nFlag
 
         if ( nFlags & ShowTrackFlags::Clip )
         {
-            Point aPoint( mnOutOffX, mnOutOffY );
-            vcl::Region aRegion( tools::Rectangle( aPoint,
-                                       Size( mnOutWidth, mnOutHeight ) ) );
+            vcl::Region aRegion( GetOutputRectPixel() );
             ImplClipBoundaries( aRegion, false, false );
             pOutDev->SelectClipRegion( aRegion, pGraphics );
         }
@@ -202,18 +200,18 @@ void Window::InvertTracking( const tools::Rectangle& rRect, ShowTrackFlags nFlag
 
     ShowTrackFlags nStyle = nFlags & ShowTrackFlags::StyleMask;
     if ( nStyle == ShowTrackFlags::Object )
-        pGraphics->Invert( aRect.Left(), aRect.Top(), aRect.GetWidth(), aRect.GetHeight(), SalInvert::TrackFrame, this );
+        pGraphics->Invert( aRect.Left(), aRect.Top(), aRect.GetWidth(), aRect.GetHeight(), SalInvert::TrackFrame, *GetOutDev() );
     else if ( nStyle == ShowTrackFlags::Split )
-        pGraphics->Invert( aRect.Left(), aRect.Top(), aRect.GetWidth(), aRect.GetHeight(), SalInvert::N50, this );
+        pGraphics->Invert( aRect.Left(), aRect.Top(), aRect.GetWidth(), aRect.GetHeight(), SalInvert::N50, *GetOutDev() );
     else
     {
         tools::Long nBorder = 1;
         if ( nStyle == ShowTrackFlags::Big )
             nBorder = 5;
-        pGraphics->Invert( aRect.Left(), aRect.Top(), aRect.GetWidth(), nBorder, SalInvert::N50, this );
-        pGraphics->Invert( aRect.Left(), aRect.Bottom()-nBorder+1, aRect.GetWidth(), nBorder, SalInvert::N50, this );
-        pGraphics->Invert( aRect.Left(), aRect.Top()+nBorder, nBorder, aRect.GetHeight()-(nBorder*2), SalInvert::N50, this );
-        pGraphics->Invert( aRect.Right()-nBorder+1, aRect.Top()+nBorder, nBorder, aRect.GetHeight()-(nBorder*2), SalInvert::N50, this );
+        pGraphics->Invert( aRect.Left(), aRect.Top(), aRect.GetWidth(), nBorder, SalInvert::N50, *GetOutDev() );
+        pGraphics->Invert( aRect.Left(), aRect.Bottom()-nBorder+1, aRect.GetWidth(), nBorder, SalInvert::N50, *GetOutDev() );
+        pGraphics->Invert( aRect.Left(), aRect.Top()+nBorder, nBorder, aRect.GetHeight()-(nBorder*2), SalInvert::N50, *GetOutDev() );
+        pGraphics->Invert( aRect.Right()-nBorder+1, aRect.Top()+nBorder, nBorder, aRect.GetHeight()-(nBorder*2), SalInvert::N50, *GetOutDev() );
     }
 }
 
@@ -227,7 +225,7 @@ IMPL_LINK( Window, ImplTrackTimerHdl, Timer*, pTimer, void )
 
     // create Tracking-Event
     Point           aMousePos( mpWindowImpl->mpFrameData->mnLastMouseX, mpWindowImpl->mpFrameData->mnLastMouseY );
-    if( ImplIsAntiparallel() )
+    if( GetOutDev()->ImplIsAntiparallel() )
     {
         // re-mirror frame pos at pChild
         const OutputDevice *pOutDev = GetOutDev();
@@ -289,7 +287,7 @@ void Window::EndTracking( TrackingEventFlags nFlags )
     // call EndTracking if required
     {
         Point           aMousePos( mpWindowImpl->mpFrameData->mnLastMouseX, mpWindowImpl->mpFrameData->mnLastMouseY );
-        if( ImplIsAntiparallel() )
+        if( GetOutDev()->ImplIsAntiparallel() )
         {
             // re-mirror frame pos at pChild
             const OutputDevice *pOutDev = GetOutDev();
@@ -356,7 +354,7 @@ VclPtr<vcl::Window> Window::SaveFocus()
 
 void Window::EndSaveFocus(const VclPtr<vcl::Window>& xFocusWin)
 {
-    if (xFocusWin && !xFocusWin->IsDisposed())
+    if (xFocusWin && !xFocusWin->isDisposed())
     {
         xFocusWin->GrabFocus();
     }
@@ -466,7 +464,7 @@ void Window::SetControlForeground()
 
 void Window::SetControlForeground(const Color& rColor)
 {
-    if (rColor.GetTransparency())
+    if (rColor.IsTransparent())
     {
         if (mpWindowImpl->mbControlForeground)
         {
@@ -506,7 +504,7 @@ void Window::SetControlBackground()
 
 void Window::SetControlBackground(const Color& rColor)
 {
-    if (rColor.GetTransparency())
+    if (rColor.IsTransparent())
     {
         if (mpWindowImpl->mbControlBackground)
         {
@@ -552,7 +550,7 @@ Size Window::CalcOutputSize( const Size& rWinSz ) const
 
 vcl::Font Window::GetDrawPixelFont(OutputDevice const * pDev) const
 {
-    vcl::Font aFont = GetPointFont(*const_cast<Window*>(this));
+    vcl::Font aFont = GetPointFont(*GetOutDev());
     Size aFontSize = aFont.GetFontSize();
     MapMode aPtMapMode(MapUnit::MapPoint);
     aFontSize = pDev->LogicToPixel( aFontSize, aPtMapMode );
@@ -936,12 +934,12 @@ void Window::ImplSetMouseTransparent( bool bTransparent )
 
 Point Window::ImplOutputToFrame( const Point& rPos )
 {
-    return Point( rPos.X()+mnOutOffX, rPos.Y()+mnOutOffY );
+    return Point( rPos.X()+GetOutDev()->mnOutOffX, rPos.Y()+GetOutDev()->mnOutOffY );
 }
 
 Point Window::ImplFrameToOutput( const Point& rPos )
 {
-    return Point( rPos.X()-mnOutOffX, rPos.Y()-mnOutOffY );
+    return Point( rPos.X()-GetOutDev()->mnOutOffX, rPos.Y()-GetOutDev()->mnOutOffY );
 }
 
 void Window::SetCompoundControl( bool bCompound )
@@ -1326,7 +1324,7 @@ static bool HasParentDockingWindow(const vcl::Window* pWindow)
 
 void Window::queue_resize(StateChangedType eReason)
 {
-    if (IsDisposed())
+    if (isDisposed())
         return;
 
     bool bSomeoneCares = queue_ungrouped_resize(this);
@@ -1367,17 +1365,17 @@ void Window::queue_resize(StateChangedType eReason)
 
 namespace
 {
-    VclAlign toAlign(const OUString &rValue)
+    VclAlign toAlign(std::u16string_view rValue)
     {
         VclAlign eRet = VclAlign::Fill;
 
-        if (rValue == "fill")
+        if (rValue == u"fill")
             eRet = VclAlign::Fill;
-        else if (rValue == "start")
+        else if (rValue == u"start")
             eRet = VclAlign::Start;
-        else if (rValue == "end")
+        else if (rValue == u"end")
             eRet = VclAlign::End;
-        else if (rValue == "center")
+        else if (rValue == u"center")
             eRet = VclAlign::Center;
         return eRet;
     }
@@ -1466,6 +1464,7 @@ bool Window::set_property(const OString &rKey, const OUString &rValue)
         nBits &= ~(WB_LEFT | WB_CENTER | WB_RIGHT);
 
         float f = rValue.toFloat();
+        assert(f == 0.0 || f == 1.0 || f == 0.5);
         if (f == 0.0)
             nBits |= WB_LEFT;
         else if (f == 1.0)
@@ -1495,6 +1494,7 @@ bool Window::set_property(const OString &rKey, const OUString &rValue)
         nBits &= ~(WB_TOP | WB_VCENTER | WB_BOTTOM);
 
         float f = rValue.toFloat();
+        assert(f == 0.0 || f == 1.0 || f == 0.5);
         if (f == 0.0)
             nBits |= WB_TOP;
         else if (f == 1.0)
@@ -1531,9 +1531,15 @@ bool Window::set_property(const OString &rKey, const OUString &rValue)
     else if (rKey == "border-width")
         set_border_width(rValue.toInt32());
     else if (rKey == "margin-start" || rKey == "margin-left")
-        set_margin_left(rValue.toInt32());
+    {
+        assert(rKey == "margin-start" && "margin-left deprecated in favor of margin-start");
+        set_margin_start(rValue.toInt32());
+    }
     else if (rKey == "margin-end" || rKey == "margin-right")
-        set_margin_right(rValue.toInt32());
+    {
+        assert(rKey == "margin-end" && "margin-right deprecated in favor of margin-end");
+        set_margin_end(rValue.toInt32());
+    }
     else if (rKey == "margin-top")
         set_margin_top(rValue.toInt32());
     else if (rKey == "margin-bottom")
@@ -1837,7 +1843,7 @@ sal_Int32 Window::get_border_width() const
     return pWindowImpl->mnBorderWidth;
 }
 
-void Window::set_margin_left(sal_Int32 nWidth)
+void Window::set_margin_start(sal_Int32 nWidth)
 {
     WindowImpl *pWindowImpl = mpWindowImpl->mpBorderWindow ? mpWindowImpl->mpBorderWindow->mpWindowImpl.get() : mpWindowImpl.get();
     if (pWindowImpl->mnMarginLeft != nWidth)
@@ -1847,13 +1853,13 @@ void Window::set_margin_left(sal_Int32 nWidth)
     }
 }
 
-sal_Int32 Window::get_margin_left() const
+sal_Int32 Window::get_margin_start() const
 {
     WindowImpl *pWindowImpl = mpWindowImpl->mpBorderWindow ? mpWindowImpl->mpBorderWindow->mpWindowImpl.get() : mpWindowImpl.get();
     return pWindowImpl->mnMarginLeft;
 }
 
-void Window::set_margin_right(sal_Int32 nWidth)
+void Window::set_margin_end(sal_Int32 nWidth)
 {
     WindowImpl *pWindowImpl = mpWindowImpl->mpBorderWindow ? mpWindowImpl->mpBorderWindow->mpWindowImpl.get() : mpWindowImpl.get();
     if (pWindowImpl->mnMarginRight != nWidth)
@@ -1863,7 +1869,7 @@ void Window::set_margin_right(sal_Int32 nWidth)
     }
 }
 
-sal_Int32 Window::get_margin_right() const
+sal_Int32 Window::get_margin_end() const
 {
     WindowImpl *pWindowImpl = mpWindowImpl->mpBorderWindow ? mpWindowImpl->mpBorderWindow->mpWindowImpl.get() : mpWindowImpl.get();
     return pWindowImpl->mnMarginRight;
@@ -1986,7 +1992,7 @@ const std::vector<VclPtr<FixedText> >& Window::list_mnemonic_labels() const
 
 } /* namespace vcl */
 
-void DrawFocusRect(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
+void InvertFocusRect(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
 {
     const int nBorder = 1;
     rRenderContext.Invert(tools::Rectangle(Point(rRect.Left(), rRect.Top()), Size(rRect.GetWidth(), nBorder)), InvertFlags::N50);
