@@ -44,8 +44,6 @@
 #include <X11/extensions/Xinerama.h>
 #endif
 
-#include <opengl/zone.hxx>
-
 #include <i18nlangtag/languagetag.hxx>
 #include <tools/debug.hxx>
 #include <vcl/svapp.hxx>
@@ -68,8 +66,6 @@
 #include <unx/x11/xrender_peer.hxx>
 #include <unx/glyphcache.hxx>
 
-#include <vcl/opengl/OpenGLHelper.hxx>
-
 #include <poll.h>
 #include <memory>
 #include <vector>
@@ -174,30 +170,6 @@ sal_GetServerVendor( Display *p_display )
     return vendor_unknown;
 }
 
-bool SalDisplay::BestOpenGLVisual(Display* pDisplay, int nScreen, XVisualInfo& rVI)
-{
-    OpenGLZone aZone;
-
-    XVisualInfo* pVI;
-    int aAttrib[] = { GLX_RGBA,
-                      GLX_RED_SIZE, 8,
-                      GLX_GREEN_SIZE, 8,
-                      GLX_BLUE_SIZE, 8,
-                      GLX_DEPTH_SIZE, 24,
-                      GLX_STENCIL_SIZE, 8,
-                      None };
-
-    pVI = glXChooseVisual( pDisplay, nScreen, aAttrib );
-    if( !pVI )
-        return false;
-
-    rVI = *pVI;
-    XFree( pVI );
-
-    CHECK_GL_ERROR();
-    return true;
-}
-
 bool SalDisplay::BestVisual( Display     *pDisplay,
                              int          nScreen,
                              XVisualInfo &rVI )
@@ -211,11 +183,6 @@ bool SalDisplay::BestVisual( Display     *pDisplay,
     if( nVID && sal_GetVisualInfo( pDisplay, nVID, rVI ) )
         return rVI.visualid == nDefVID;
 
-// TODO SKIA
-    bool bUseOpenGL = OpenGLHelper::isVCLOpenGLEnabled();
-    if (bUseOpenGL && BestOpenGLVisual(pDisplay, nScreen, rVI))
-        return rVI.visualid == nDefVID;
-
     XVisualInfo aVI;
     aVI.screen = nScreen;
     // get all visuals
@@ -1835,6 +1802,9 @@ Cursor SalDisplay::GetPointer( PointerStyle ePointerStyle )
         case PointerStyle::ShowWhitespace:
             MAKE_CURSOR( showwhitespace_ );
             break;
+        case PointerStyle::FatCross:
+            MAKE_CURSOR( fatcross_ );
+            break;
 
         default:
             OSL_FAIL("pointer not implemented");
@@ -1937,7 +1907,7 @@ void SalX11Display::Yield()
     GetX11SalData()->ResetXErrorOccurred();
 }
 
-bool SalX11Display::Dispatch( XEvent *pEvent )
+void SalX11Display::Dispatch( XEvent *pEvent )
 {
     SalI18N_InputMethod* const pInputMethod =
         pXLib_ ? pXLib_->GetInputMethod() : nullptr;
@@ -1960,7 +1930,7 @@ bool SalX11Display::Dispatch( XEvent *pEvent )
             }
         }
         if( pInputMethod->FilterEvent( pEvent, aFrameWindow ) )
-            return false;
+            return;
     }
 
     SalInstance* pInstance = GetSalData()->m_pInstance;
@@ -1985,7 +1955,7 @@ bool SalX11Display::Dispatch( XEvent *pEvent )
                     {
                         for (auto pSalFrame : m_aFrames )
                              pSalFrame->CallCallback( SalEvent::SettingsChanged, nullptr );
-                        return false;
+                        return;
                     }
                 }
             }
@@ -2011,7 +1981,7 @@ bool SalX11Display::Dispatch( XEvent *pEvent )
                 && GetKbdExtension()->GetEventBase() == pEvent->type )
             {
                 GetKbdExtension()->Dispatch( pEvent );
-                return true;
+                return;
             }
             break;
     }
@@ -2026,11 +1996,13 @@ bool SalX11Display::Dispatch( XEvent *pEvent )
             || pFrame->GetForeignParent() == aDispatchWindow
             )
         {
-            return pFrame->Dispatch( pEvent );
+            pFrame->Dispatch( pEvent );
+            return;
         }
         if( pEvent->type == ConfigureNotify && pEvent->xconfigure.window == pFrame->GetStackingWindow() )
         {
-            return pFrame->Dispatch( pEvent );
+            pFrame->Dispatch( pEvent );
+            return;
         }
     }
 
@@ -2039,8 +2011,6 @@ bool SalX11Display::Dispatch( XEvent *pEvent )
 
     // is this perhaps a root window that changed size ?
     processRandREvent( pEvent );
-
-    return false;
 }
 
 #ifdef DBG_UTIL
@@ -2385,9 +2355,9 @@ bool SalDisplay::XIfEventWithTimeout( XEvent* o_pEvent, XPointer i_pPredicateDat
     return bRet;
 }
 
-SalVisual::SalVisual():
-    eRGBMode_(SalRGB::RGB), nRedShift_(0), nGreenShift_(0), nBlueShift_(0), nRedBits_(0), nGreenBits_(0),
-    nBlueBits_(0)
+SalVisual::SalVisual()
+    : eRGBMode_(SalRGB::RGB), nRedShift_(0), nGreenShift_(0), nBlueShift_(0)
+    , nRedBits_(0), nGreenBits_(0), nBlueBits_(0)
 {
     visual = nullptr;
 }
@@ -2396,7 +2366,12 @@ SalVisual::SalVisual( const XVisualInfo* pXVI )
 {
     *static_cast<XVisualInfo*>(this) = *pXVI;
     if( GetClass() != TrueColor )
+    {
+        eRGBMode_ = SalRGB::RGB;
+        nRedShift_ = nGreenShift_ = nBlueShift_ = 0;
+        nRedBits_ = nGreenBits_ = nBlueBits_ = 0;
         return;
+    }
 
     nRedShift_      = sal_Shift( red_mask );
     nGreenShift_    = sal_Shift( green_mask );
@@ -2463,7 +2438,7 @@ SalVisual::SalVisual( const XVisualInfo* pXVI )
 Color SalVisual::GetTCColor( Pixel nPixel ) const
 {
     if( SALCOLOR == eRGBMode_ )
-        return static_cast<Color>(nPixel);
+        return Color(ColorTransparency, nPixel);
 
     if( SALCOLORREVERSE == eRGBMode_ )
         return Color( (nPixel & 0x0000FF),
@@ -2748,7 +2723,7 @@ Color SalColormap::GetColor( Pixel nPixel ) const
     if( !m_hColormap )
     {
         SAL_WARN("vcl", "SalColormap::GetColor() !m_hColormap");
-        return nPixel;
+        return Color(ColorTransparency, nPixel);
     }
 
     // DirectColor, StaticColor, StaticGray, GrayScale
@@ -2824,7 +2799,7 @@ Pixel SalColormap::GetPixel( Color nColor ) const
                     {
                         XColor aInversColor;
 
-                        Color nInversColor = sal_uInt32(nColor) ^ 0xFFFFFF;
+                        Color nInversColor(ColorTransparency, sal_uInt32(nColor) ^ 0xFFFFFF);
 
                         GetXPixel( aInversColor,
                                    nInversColor.GetRed(),
