@@ -43,11 +43,11 @@ void CPDManager::onNameAcquired (GDBusConnection *connection,
                                  gpointer user_data)
 {
     gchar* contents;
-    GDBusNodeInfo *introspection_data;
-
     // Get Interface for introspection
-    g_file_get_contents (FRONTEND_INTERFACE, &contents, nullptr, nullptr);
-    introspection_data = g_dbus_node_info_new_for_xml (contents, nullptr);
+    if (!g_file_get_contents (FRONTEND_INTERFACE, &contents, nullptr, nullptr))
+        return;
+
+    GDBusNodeInfo *introspection_data = g_dbus_node_info_new_for_xml (contents, nullptr);
 
     g_dbus_connection_register_object (connection,
                                        "/org/libreoffice/PrintDialog",
@@ -63,28 +63,29 @@ void CPDManager::onNameAcquired (GDBusConnection *connection,
     std::vector<std::pair<std::string, gchar*>> backends = current->getTempBackends();
     for (auto const& backend : backends)
     {
-        GDBusProxy *proxy;
         // Get Interface for introspection
-        g_file_get_contents (BACKEND_INTERFACE, &contents, nullptr, nullptr);
-        introspection_data = g_dbus_node_info_new_for_xml (contents, nullptr);
-        proxy = g_dbus_proxy_new_sync (connection,
-                                       G_DBUS_PROXY_FLAGS_NONE,
-                                       introspection_data->interfaces[0],
-                                       backend.first.c_str(),
-                                       backend.second,
-                                       "org.openprinting.PrintBackend",
-                                       nullptr,
-                                       nullptr);
-        g_free(backend.second);
-        g_assert (proxy != nullptr);
-        g_dbus_proxy_call(proxy, "ActivateBackend",
-                          nullptr,
-                          G_DBUS_CALL_FLAGS_NONE,
-                          -1, nullptr, nullptr, nullptr);
+        if (g_file_get_contents(BACKEND_INTERFACE, &contents, nullptr, nullptr))
+        {
+            introspection_data = g_dbus_node_info_new_for_xml (contents, nullptr);
+            GDBusProxy *proxy = g_dbus_proxy_new_sync (connection,
+                                           G_DBUS_PROXY_FLAGS_NONE,
+                                           introspection_data->interfaces[0],
+                                           backend.first.c_str(),
+                                           backend.second,
+                                           "org.openprinting.PrintBackend",
+                                           nullptr,
+                                           nullptr);
+            g_assert (proxy != nullptr);
+            g_dbus_proxy_call(proxy, "ActivateBackend",
+                              nullptr,
+                              G_DBUS_CALL_FLAGS_NONE,
+                              -1, nullptr, nullptr, nullptr);
 
-        g_free(contents);
-        g_object_unref(proxy);
-        g_dbus_node_info_unref(introspection_data);
+            g_free(contents);
+            g_object_unref(proxy);
+            g_dbus_node_info_unref(introspection_data);
+        }
+        g_free(backend.second);
     }
 }
 
@@ -108,24 +109,24 @@ void CPDManager::printerAdded (GDBusConnection *connection,
     proxy = current->getProxy(sender_name);
     if (proxy == nullptr) {
         gchar* contents;
-        GDBusNodeInfo *introspection_data;
 
         // Get Interface for introspection
-        g_file_get_contents ("/usr/share/dbus-1/interfaces/org.openprinting.Backend.xml", &contents, nullptr, nullptr);
-        introspection_data = g_dbus_node_info_new_for_xml (contents, nullptr);
-        proxy = g_dbus_proxy_new_sync (connection,
-                                       G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
-                                       introspection_data->interfaces[0],
-                                       sender_name,
-                                       object_path,
-                                       interface_name,
-                                       nullptr,
-                                       nullptr);
+        if (g_file_get_contents ("/usr/share/dbus-1/interfaces/org.openprinting.Backend.xml", &contents, nullptr, nullptr)) {
+            GDBusNodeInfo *introspection_data = g_dbus_node_info_new_for_xml (contents, nullptr);
+            proxy = g_dbus_proxy_new_sync (connection,
+                                           G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+                                           introspection_data->interfaces[0],
+                                           sender_name,
+                                           object_path,
+                                           interface_name,
+                                           nullptr,
+                                           nullptr);
 
-        g_free(contents);
-        g_dbus_node_info_unref(introspection_data);
-        std::pair<std::string, GDBusProxy *> new_backend (sender_name, proxy);
-        current->addBackend(new_backend);
+            g_free(contents);
+            g_dbus_node_info_unref(introspection_data);
+            std::pair<std::string, GDBusProxy *> new_backend (sender_name, proxy);
+            current->addBackend(new_backend);
+        }
     }
     CPDPrinter *pDest = static_cast<CPDPrinter *>(malloc(sizeof(CPDPrinter)));
     pDest->backend = proxy;
@@ -258,9 +259,11 @@ CPDManager* CPDManager::tryLoadCPD()
                 gchar* contents;
                 std::stringstream filepath;
                 filepath << BACKEND_DIR << '/' << filename;
-                g_file_get_contents(filepath.str().c_str(), &contents, nullptr, nullptr);
-                std::pair<std::string, gchar*> new_tbackend (filename, contents);
-                pManager->addTempBackend(new_tbackend);
+                if (g_file_get_contents(filepath.str().c_str(), &contents, nullptr, nullptr))
+                {
+                    std::pair<std::string, gchar*> new_tbackend (filename, contents);
+                    pManager->addTempBackend(new_tbackend);
+                }
             }
             g_dir_close(dir);
         }
