@@ -36,7 +36,6 @@
 #include <tools/stream.hxx>
 #include <tools/zcodec.hxx>
 #include <o3tl/safeint.hxx>
-#include <osl/mutex.hxx>
 #include <osl/file.hxx>
 #include <osl/process.h>
 #include <osl/thread.h>
@@ -48,6 +47,7 @@
 
 #include <com/sun/star/lang/Locale.hpp>
 
+#include <mutex>
 #include <unordered_map>
 
 #ifdef ENABLE_CUPS
@@ -56,7 +56,7 @@
 
 #include <config_dbus.h>
 #include <config_gio.h>
-#include <boost/functional/hash.hpp>
+#include <o3tl/hash_combine.hxx>
 
 namespace psp
 {
@@ -78,9 +78,9 @@ namespace psp
             size_t operator()(const css::lang::Locale& rLocale) const
             {
                 std::size_t seed = 0;
-                boost::hash_combine(seed, rLocale.Language.hashCode());
-                boost::hash_combine(seed, rLocale.Country.hashCode());
-                boost::hash_combine(seed, rLocale.Variant.hashCode());
+                o3tl::hash_combine(seed, rLocale.Language.hashCode());
+                o3tl::hash_combine(seed, rLocale.Country.hashCode());
+                o3tl::hash_combine(seed, rLocale.Variant.hashCode());
                 return seed;
             }
         };
@@ -245,7 +245,7 @@ namespace psp
     {
     public:
         std::vector< std::unique_ptr<PPDParser> > aAllParsers;
-        std::unique_ptr<std::unordered_map< OUString, OUString >> pAllPPDFiles;
+        std::optional<std::unordered_map< OUString, OUString >> xAllPPDFiles;
     };
 }
 
@@ -417,7 +417,7 @@ void PPDParser::scanPPDDir( const OUString& rDir )
                         {
                             if( aFileName.endsWithIgnoreAsciiCaseAsciiL( rSuffix.pSuffix, rSuffix.nSuffixLen ) )
                             {
-                                (*rPPDCache.pAllPPDFiles)[ aFileName.copy( 0, aFileName.getLength() - rSuffix.nSuffixLen ) ] = aPPDFile.PathToFileName();
+                                (*rPPDCache.xAllPPDFiles)[ aFileName.copy( 0, aFileName.getLength() - rSuffix.nSuffixLen ) ] = aPPDFile.PathToFileName();
                                 break;
                             }
                         }
@@ -435,10 +435,10 @@ void PPDParser::scanPPDDir( const OUString& rDir )
 
 void PPDParser::initPPDFiles(PPDCache &rPPDCache)
 {
-    if( rPPDCache.pAllPPDFiles )
+    if( rPPDCache.xAllPPDFiles )
         return;
 
-    rPPDCache.pAllPPDFiles.reset(new std::unordered_map< OUString, OUString >);
+    rPPDCache.xAllPPDFiles.emplace();
 
     // check installation directories
     std::vector< OUString > aPathList;
@@ -448,7 +448,7 @@ void PPDParser::initPPDFiles(PPDCache &rPPDCache)
         INetURLObject aPPDDir( path, INetProtocol::File, INetURLObject::EncodeMechanism::All );
         scanPPDDir( aPPDDir.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
     }
-    if( rPPDCache.pAllPPDFiles->find( OUString( "SGENPRT" ) ) != rPPDCache.pAllPPDFiles->end() )
+    if( rPPDCache.xAllPPDFiles->find( OUString( "SGENPRT" ) ) != rPPDCache.xAllPPDFiles->end() )
         return;
 
     // last try: search in directory of executable (mainly for setup)
@@ -461,8 +461,8 @@ void PPDParser::initPPDFiles(PPDCache &rPPDCache)
                 << aDir.GetMainURL(INetURLObject::DecodeMechanism::NONE));
         scanPPDDir( aDir.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
         SAL_INFO("vcl.unx.print", "SGENPRT "
-                << (rPPDCache.pAllPPDFiles->find("SGENPRT") ==
-                    rPPDCache.pAllPPDFiles->end() ? "not found" : "found"));
+                << (rPPDCache.xAllPPDFiles->find("SGENPRT") ==
+                    rPPDCache.xAllPPDFiles->end() ? "not found" : "found"));
     }
 }
 
@@ -488,23 +488,23 @@ OUString PPDParser::getPPDFile( const OUString& rFile )
                 aBase = aBase.copy( nLastIndex+1 );
             do
             {
-                it = rPPDCache.pAllPPDFiles->find( aBase );
+                it = rPPDCache.xAllPPDFiles->find( aBase );
                 nLastIndex = aBase.lastIndexOf( '.' );
                 if( nLastIndex > 0 )
                     aBase = aBase.copy( 0, nLastIndex );
-            } while( it == rPPDCache.pAllPPDFiles->end() && nLastIndex > 0 );
+            } while( it == rPPDCache.xAllPPDFiles->end() && nLastIndex > 0 );
 
-            if( it == rPPDCache.pAllPPDFiles->end() && bRetry )
+            if( it == rPPDCache.xAllPPDFiles->end() && bRetry )
             {
                 // a new file ? rehash
-                rPPDCache.pAllPPDFiles.reset();
+                rPPDCache.xAllPPDFiles.reset();
                 bRetry = false;
                 // note this is optimized for office start where
                 // no new files occur and initPPDFiles is called only once
             }
-        } while( ! rPPDCache.pAllPPDFiles );
+        } while( ! rPPDCache.xAllPPDFiles );
 
-        if( it != rPPDCache.pAllPPDFiles->end() )
+        if( it != rPPDCache.xAllPPDFiles->end() )
             aStream.Open( it->second );
     }
 
@@ -531,8 +531,8 @@ OUString PPDParser::getPPDFile( const OUString& rFile )
 
 const PPDParser* PPDParser::getParser( const OUString& rFile )
 {
-    static ::osl::Mutex aMutex;
-    ::osl::Guard< ::osl::Mutex > aGuard( aMutex );
+    static std::recursive_mutex aMutex;
+    std::lock_guard aGuard( aMutex );
 
     OUString aFile = rFile;
     if( !rFile.startsWith( "CUPS:" ) && !rFile.startsWith( "CPD:" ) )
@@ -720,14 +720,11 @@ PPDParser::PPDParser( const OUString& rFile ) :
                 if (aCurLine.matchIgnoreAsciiCase("*include:"))
                 {
                     aCurLine = aCurLine.copy(9);
-                    aCurLine = comphelper::string::stripStart(aCurLine, ' ');
-                    aCurLine = comphelper::string::stripEnd(aCurLine, ' ');
-                    aCurLine = comphelper::string::stripStart(aCurLine, '\t');
-                    aCurLine = comphelper::string::stripEnd(aCurLine, '\t');
+                    aCurLine = comphelper::string::strip(aCurLine, ' ');
+                    aCurLine = comphelper::string::strip(aCurLine, '\t');
                     aCurLine = comphelper::string::stripEnd(aCurLine, '\r');
                     aCurLine = comphelper::string::stripEnd(aCurLine, '\n');
-                    aCurLine = comphelper::string::stripStart(aCurLine, '"');
-                    aCurLine = comphelper::string::stripEnd(aCurLine, '"');
+                    aCurLine = comphelper::string::strip(aCurLine, '"');
                     aStream.Close();
                     aStream.Open(getPPDFile(OStringToOUString(aCurLine, m_aFileEncoding)));
                     continue;
@@ -1091,7 +1088,8 @@ void PPDParser::parse( ::std::vector< OString >& rLines )
         nPos = aCurrentLine.indexOf(':');
         if( nPos != -1 )
         {
-            aOption = OStringToOUString( aCurrentLine.copy( 1, nPos-1 ), RTL_TEXTENCODING_MS_1252 );
+            aOption = OStringToOUString(
+                aCurrentLine.subView( 1, nPos-1 ), RTL_TEXTENCODING_MS_1252 );
             aOption = GetCommandLineToken( 1, aOption );
             sal_Int32 nTransPos = aOption.indexOf( '/' );
             if( nTransPos != -1 )
@@ -1143,7 +1141,7 @@ void PPDParser::parse( ::std::vector< OString >& rLines )
                 nTransPos = aLine.indexOf('"');
                 if (nTransPos == -1)
                     nTransPos = aLine.getLength();
-                aValue = OStringToOUString(aLine.copy(0, nTransPos), RTL_TEXTENCODING_MS_1252);
+                aValue = OStringToOUString(aLine.subView(0, nTransPos), RTL_TEXTENCODING_MS_1252);
                 // after the second doublequote can follow a / and a translation
                 if (nTransPos < aLine.getLength() - 2)
                 {
@@ -1173,7 +1171,7 @@ void PPDParser::parse( ::std::vector< OString >& rLines )
                 nTransPos = aLine.indexOf('/');
                 if (nTransPos == -1)
                     nTransPos = aLine.getLength();
-                aValue = OStringToOUString(aLine.copy(0, nTransPos), RTL_TEXTENCODING_MS_1252);
+                aValue = OStringToOUString(aLine.subView(0, nTransPos), RTL_TEXTENCODING_MS_1252);
                 if (nTransPos+1 < aLine.getLength())
                     aValueTranslation = handleTranslation( aLine.copy( nTransPos+1 ), bIsGlobalizedLine );
                 eType = eString;
@@ -1235,7 +1233,7 @@ void PPDParser::parse( ::std::vector< OString >& rLines )
         if (aLine.startsWith("*Default"))
         {
             SAL_INFO("vcl.unx.print", "Found a default: '" << aLine << "'");
-            OUString aKey(OStringToOUString(aLine.copy(8), RTL_TEXTENCODING_MS_1252));
+            OUString aKey(OStringToOUString(aLine.subView(8), RTL_TEXTENCODING_MS_1252));
             sal_Int32 nPos = aKey.indexOf( ':' );
             if( nPos != -1 )
             {
@@ -1272,7 +1270,7 @@ void PPDParser::parse( ::std::vector< OString >& rLines )
     }
 }
 
-void PPDParser::parseOpenUI(const OString& rLine, const OString& rPPDGroup)
+void PPDParser::parseOpenUI(const OString& rLine, std::string_view rPPDGroup)
 {
     OUString aTranslation;
     OString aKey = rLine;
@@ -1403,7 +1401,7 @@ OUString PPDParser::getDefaultPaperDimension() const
 }
 
 bool PPDParser::getMargins(
-                           const OUString& rPaperName,
+                           std::u16string_view rPaperName,
                            int& rLeft, int& rRight,
                            int& rUpper, int& rLower ) const
 {
@@ -1439,7 +1437,7 @@ bool PPDParser::getMargins(
 }
 
 bool PPDParser::getPaperDimension(
-                                  const OUString& rPaperName,
+                                  std::u16string_view rPaperName,
                                   int& rWidth, int& rHeight ) const
 {
     if( ! m_pPaperDimensions )
@@ -1916,11 +1914,12 @@ void PPDContext::rebuildFromStreamBuffer(const std::vector<char> &rBuffer)
         sal_Int32 nPos = aLine.indexOf(':');
         if( nPos != -1 )
         {
-            const PPDKey* pKey = m_pParser->getKey( OStringToOUString( aLine.copy( 0, nPos ), RTL_TEXTENCODING_MS_1252 ) );
+            const PPDKey* pKey = m_pParser->getKey( OStringToOUString( aLine.subView( 0, nPos ), RTL_TEXTENCODING_MS_1252 ) );
             if( pKey )
             {
                 const PPDValue* pValue = nullptr;
-                OUString aOption(OStringToOUString(aLine.copy(nPos+1), RTL_TEXTENCODING_MS_1252));
+                OUString aOption(
+                    OStringToOUString(aLine.subView(nPos+1), RTL_TEXTENCODING_MS_1252));
                 if (aOption != "*nil")
                     pValue = pKey->getValue( aOption );
                 m_aCurrentValues[ pKey ] = pValue;
