@@ -50,6 +50,7 @@
 #include <algorithm>
 #include <set>
 #include <string.h>
+#include <string_view>
 
 #include "SalGtkFilePicker.hxx"
 
@@ -72,7 +73,9 @@ void SalGtkFilePicker::InitialMapping()
     if (!mbPreviewState )
     {
         gtk_widget_hide( m_pPreview );
+#if !GTK_CHECK_VERSION(4, 0, 0)
         gtk_file_chooser_set_preview_widget_active( GTK_FILE_CHOOSER( m_pDialog ), false);
+#endif
     }
     gtk_widget_set_size_request (m_pPreview, -1, -1);
 }
@@ -107,7 +110,6 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
     for( i = 0; i < LIST_LAST; i++ )
     {
         m_pHBoxs[i] = nullptr;
-        m_pAligns[i] = nullptr;
         m_pLists[i] = nullptr;
         m_pListLabels[i] = nullptr;
         mbListVisibility[i] = false;
@@ -115,29 +117,33 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
 
     OUString aFilePickerTitle = getResString( FILE_PICKER_TITLE_OPEN );
 
-    m_pDialog = gtk_file_chooser_dialog_new(
-            OUStringToOString( aFilePickerTitle, RTL_TEXTENCODING_UTF8 ).getStr(),
-            nullptr,
-            GTK_FILE_CHOOSER_ACTION_OPEN,
-            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-            nullptr );
-
+    m_pDialog = GTK_WIDGET(g_object_new(GTK_TYPE_FILE_CHOOSER_DIALOG,
+                                        "title", OUStringToOString(aFilePickerTitle, RTL_TEXTENCODING_UTF8).getStr(),
+                                        "action", GTK_FILE_CHOOSER_ACTION_OPEN,
+                                        nullptr));
     gtk_dialog_set_default_response( GTK_DIALOG (m_pDialog), GTK_RESPONSE_ACCEPT );
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
 #if ENABLE_GIO
     gtk_file_chooser_set_local_only( GTK_FILE_CHOOSER( m_pDialog ), false );
 #endif
+#endif
+
     gtk_file_chooser_set_select_multiple( GTK_FILE_CHOOSER( m_pDialog ), false );
 
-    m_pVBox = gtk_vbox_new( false, 0 );
+    m_pVBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
     // We don't want clickable items to have a huge hit-area
-    GtkWidget *pHBox = gtk_hbox_new( false, 0 );
-    GtkWidget *pThinVBox = gtk_vbox_new( false, 0 );
+    GtkWidget *pHBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    GtkWidget *pThinVBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_box_pack_end (GTK_BOX( m_pVBox ), pHBox, false, false, 0);
     gtk_box_pack_start (GTK_BOX( pHBox ), pThinVBox, false, false, 0);
+#else
+    gtk_box_append(GTK_BOX(m_pVBox), pHBox);
+    gtk_box_prepend(GTK_BOX(m_pVBox), pThinVBox);
+#endif
     gtk_widget_show( pHBox );
     gtk_widget_show( pThinVBox );
 
@@ -167,14 +173,16 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
             break;
         }
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
         gtk_box_pack_end( GTK_BOX( pThinVBox ), m_pToggles[i], false, false, 0 );
+#else
+        gtk_box_append(GTK_BOX(pThinVBox), m_pToggles[i]);
+#endif
     }
 
     for( i = 0; i < LIST_LAST; i++ )
     {
-        m_pHBoxs[i] = gtk_hbox_new( false, 0 );
-
-        m_pAligns[i] = gtk_alignment_new(0, 0, 0, 1);
+        m_pHBoxs[i] = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
         GtkListStore *pListStores[ LIST_LAST ];
         pListStores[i] = gtk_list_store_new (1, G_TYPE_STRING);
@@ -205,34 +213,54 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
                 break;
         }
 
-        gtk_container_add( GTK_CONTAINER( m_pAligns[i]), m_pLists[i] );
-        gtk_box_pack_end( GTK_BOX( m_pHBoxs[i] ), m_pAligns[i], false, false, 0 );
+#if !GTK_CHECK_VERSION(4, 0, 0)
+        gtk_box_pack_end( GTK_BOX( m_pHBoxs[i] ), m_pLists[i], false, false, 0 );
         gtk_box_pack_end( GTK_BOX( m_pHBoxs[i] ), m_pListLabels[i], false, false, 0 );
+#else
+        gtk_box_append(GTK_BOX(m_pHBoxs[i]), m_pLists[i]);
+        gtk_box_append(GTK_BOX(m_pHBoxs[i]), m_pListLabels[i]);
+#endif
         gtk_label_set_mnemonic_widget( GTK_LABEL(m_pListLabels[i]), m_pLists[i] );
         gtk_box_set_spacing( GTK_BOX( m_pHBoxs[i] ), 12 );
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
         gtk_box_pack_end( GTK_BOX( m_pVBox ), m_pHBoxs[i], false, false, 0 );
+#else
+        gtk_box_append(GTK_BOX(m_pVBox), m_pHBoxs[i]);
+#endif
     }
 
     aLabel = getResString( FILE_PICKER_FILE_TYPE );
     m_pFilterExpander = gtk_expander_new_with_mnemonic(
         OUStringToOString( aLabel, RTL_TEXTENCODING_UTF8 ).getStr());
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_box_pack_end( GTK_BOX( m_pVBox ), m_pFilterExpander, false, true, 0 );
+#else
+    gtk_box_append(GTK_BOX(m_pVBox), m_pFilterExpander);
+#endif
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     GtkWidget *scrolled_window = gtk_scrolled_window_new (nullptr, nullptr);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-        GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
         GTK_SHADOW_IN);
+#else
+    GtkWidget *scrolled_window = gtk_scrolled_window_new();
+    gtk_scrolled_window_set_has_frame(GTK_SCROLLED_WINDOW(scrolled_window), true);
+#endif
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
+        GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_container_add (GTK_CONTAINER (m_pFilterExpander), scrolled_window);
+#else
+    gtk_expander_set_child(GTK_EXPANDER(m_pFilterExpander), scrolled_window);
+#endif
     gtk_widget_show (scrolled_window);
 
     m_pFilterStore = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_STRING,
         G_TYPE_STRING, G_TYPE_STRING);
     m_pFilterView = gtk_tree_view_new_with_model (GTK_TREE_MODEL(m_pFilterStore));
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(m_pFilterView), false);
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW(m_pFilterView), true);
 
     GtkCellRenderer *cell = nullptr;
 
@@ -246,13 +274,21 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
         gtk_tree_view_append_column (GTK_TREE_VIEW(m_pFilterView), column);
     }
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_container_add (GTK_CONTAINER (scrolled_window), m_pFilterView);
+#else
+    gtk_scrolled_window_set_child(GTK_SCROLLED_WINDOW(scrolled_window), m_pFilterView);
+#endif
     gtk_widget_show (m_pFilterView);
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_file_chooser_set_extra_widget( GTK_FILE_CHOOSER( m_pDialog ), m_pVBox );
+#endif
 
     m_pPreview = gtk_image_new();
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_file_chooser_set_preview_widget( GTK_FILE_CHOOSER( m_pDialog ), m_pPreview );
+#endif
 
     g_signal_connect( G_OBJECT( m_pToggles[PREVIEW] ), "toggled",
                       G_CALLBACK( preview_toggled_cb ), this );
@@ -279,7 +315,9 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
     gtk_widget_set_size_request (m_pFilterView, -1, height);
     gtk_widget_set_size_request (m_pPreview, 1, height);
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_file_chooser_set_preview_widget_active( GTK_FILE_CHOOSER( m_pDialog ), true);
+#endif
 }
 
 // XFilePickerNotifier
@@ -411,37 +449,6 @@ shrinkFilterName( const OUString &rFilterName, bool bAllowNoStar = false )
     return aRealName;
 }
 
-static void
-dialog_remove_buttons(GtkWidget *pActionArea)
-{
-    GtkContainer *pContainer = GTK_CONTAINER( pActionArea );
-
-    g_return_if_fail( pContainer != nullptr );
-
-    GList *pChildren = gtk_container_get_children( pContainer );
-
-    for( GList *p = pChildren; p; p = p->next )
-    {
-        GtkWidget *pWidget = GTK_WIDGET( p->data );
-        if ( GTK_IS_BUTTON( pWidget ) )
-            gtk_widget_destroy( pWidget );
-    }
-
-    g_list_free( pChildren );
-}
-
-static void
-dialog_remove_buttons( GtkDialog *pDialog )
-{
-    g_return_if_fail( GTK_IS_DIALOG( pDialog ) );
-
-    GtkWidget *pHeaderBar = gtk_dialog_get_header_bar(pDialog);
-    if( pHeaderBar != nullptr )
-        dialog_remove_buttons( pHeaderBar );
-    else
-        dialog_remove_buttons(gtk_dialog_get_action_area(pDialog));
-}
-
 namespace {
 
     struct FilterTitleMatch
@@ -725,9 +732,14 @@ uno::Sequence<OUString> SAL_CALL SalGtkFilePicker::getSelectedFiles()
 
     OSL_ASSERT( m_pDialog != nullptr );
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     GSList* pPathList = gtk_file_chooser_get_uris( GTK_FILE_CHOOSER(m_pDialog) );
-
     int nCount = g_slist_length( pPathList );
+#else
+    GListModel* pPathList = gtk_file_chooser_get_files(GTK_FILE_CHOOSER(m_pDialog));
+    int nCount = g_list_model_get_n_items(pPathList);
+#endif
+
     int nIndex = 0;
 
     // get the current action setting
@@ -737,9 +749,16 @@ uno::Sequence<OUString> SAL_CALL SalGtkFilePicker::getSelectedFiles()
     uno::Sequence< OUString > aSelectedFiles(nCount);
 
     // Convert to OOo
+#if !GTK_CHECK_VERSION(4, 0, 0)
     for( GSList *pElem = pPathList; pElem; pElem = pElem->next)
     {
         gchar *pURI = static_cast<gchar*>(pElem->data);
+#else
+    while (gpointer pElem = g_list_model_get_item(pPathList, nIndex))
+    {
+        gchar *pURI = g_file_get_uri(static_cast<GFile*>(pElem));
+#endif
+
         aSelectedFiles[ nIndex ] = uritounicode(pURI);
 
         if( GTK_FILE_CHOOSER_ACTION_SAVE == eAction )
@@ -858,7 +877,11 @@ uno::Sequence<OUString> SAL_CALL SalGtkFilePicker::getSelectedFiles()
         g_free( pURI );
     }
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     g_slist_free( pPathList );
+#else
+    g_object_unref(pPathList);
+#endif
 
     return aSelectedFiles;
 }
@@ -886,13 +909,23 @@ sal_Int16 SAL_CALL SalGtkFilePicker::execute()
     if ( !m_aCurrentFilter.isEmpty() )
         SetCurFilter(m_aCurrentFilter);
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     mnHID_FolderChange =
         g_signal_connect( GTK_FILE_CHOOSER( m_pDialog ), "current-folder-changed",
             G_CALLBACK( folder_changed_cb ), static_cast<gpointer>(this) );
+#else
+    // no replacement in 4-0 that I can see :-(
+    mnHID_FolderChange = 0;
+#endif
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
     mnHID_SelectionChange =
         g_signal_connect( GTK_FILE_CHOOSER( m_pDialog ), "selection-changed",
             G_CALLBACK( selection_changed_cb ), static_cast<gpointer>(this) );
+#else
+    // no replacement in 4-0 that I can see :-(
+    mnHID_SelectionChange = 0;
+#endif
 
     int btn = GTK_RESPONSE_NO;
 
@@ -912,8 +945,7 @@ sal_Int16 SAL_CALL SalGtkFilePicker::execute()
     }
     if (pParent)
         gtk_window_set_transient_for(GTK_WINDOW(m_pDialog), pParent);
-    RunDialog* pRunDialog = new RunDialog(m_pDialog, xToolkit, xDesktop);
-    uno::Reference < awt::XTopWindowListener > xLifeCycle(pRunDialog);
+    rtl::Reference<RunDialog> pRunDialog = new RunDialog(m_pDialog, xToolkit, xDesktop);
     while( GTK_RESPONSE_NO == btn )
     {
         btn = GTK_RESPONSE_YES; // we don't want to repeat unless user clicks NO for file save.
@@ -1000,11 +1032,14 @@ sal_Int16 SAL_CALL SalGtkFilePicker::execute()
                                 OUStringToOString(getResString(FILE_PICKER_TITLE_SAVE ),
                                 RTL_TEXTENCODING_UTF8 ).getStr() );
                             gtk_window_set_transient_for(GTK_WINDOW(dlg), GTK_WINDOW(m_pDialog));
-                            RunDialog* pAnotherDialog = new RunDialog(dlg, xToolkit, xDesktop);
-                            uno::Reference < awt::XTopWindowListener > xAnotherLifeCycle(pAnotherDialog);
+                            rtl::Reference<RunDialog> pAnotherDialog = new RunDialog(dlg, xToolkit, xDesktop);
                             btn = pAnotherDialog->run();
 
-                            gtk_widget_destroy( dlg );
+#if !GTK_CHECK_VERSION(4, 0, 0)
+                            gtk_widget_destroy(dlg);
+#else
+                            gtk_window_destroy(GTK_WINDOW(dlg));
+#endif
                         }
                         g_free (gFileName);
 
@@ -1047,12 +1082,12 @@ sal_Int16 SAL_CALL SalGtkFilePicker::execute()
 // cf. offapi/com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.idl
 GtkWidget *SalGtkFilePicker::getWidget( sal_Int16 nControlId, GType *pType )
 {
-    GType      tType = GTK_TYPE_TOGGLE_BUTTON; //prevent warning by initializing
+    GType      tType = GTK_TYPE_CHECK_BUTTON; //prevent warning by initializing
     GtkWidget *pWidget = nullptr;
 
 #define MAP_TOGGLE( elem ) \
         case ExtendedFilePickerElementIds::CHECKBOX_##elem: \
-            pWidget = m_pToggles[elem]; tType = GTK_TYPE_TOGGLE_BUTTON; \
+            pWidget = m_pToggles[elem]; tType = GTK_TYPE_CHECK_BUTTON; \
             break
 #define MAP_BUTTON( elem ) \
         case ExtendedFilePickerElementIds::PUSHBUTTON_##elem: \
@@ -1102,11 +1137,13 @@ GtkWidget *SalGtkFilePicker::getWidget( sal_Int16 nControlId, GType *pType )
 static void HackWidthToFirst(GtkComboBox *pWidget)
 {
     GtkRequisition requisition;
+#if !GTK_CHECK_VERSION(4, 0, 0)
     gtk_widget_size_request(GTK_WIDGET(pWidget), &requisition);
+#endif
     gtk_widget_set_size_request(GTK_WIDGET(pWidget), requisition.width, -1);
 }
 
-static void ComboBoxAppendText(GtkComboBox *pCombo, const OUString &rStr)
+static void ComboBoxAppendText(GtkComboBox *pCombo, std::u16string_view rStr)
 {
   GtkTreeIter aIter;
   GtkListStore *pStore = GTK_LIST_STORE(gtk_combo_box_get_model(pCombo));
@@ -1253,11 +1290,15 @@ void SAL_CALL SalGtkFilePicker::setValue( sal_Int16 nControlId, sal_Int16 nContr
 
     if( !( pWidget = getWidget( nControlId, &tType ) ) )
         SAL_WARN( "vcl.gtk", "enable unknown control " << nControlId);
-    else if( tType == GTK_TYPE_TOGGLE_BUTTON )
+    else if( tType == GTK_TYPE_CHECK_BUTTON)
     {
         bool bChecked = false;
         rValue >>= bChecked;
-        gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( pWidget ), bChecked );
+#if GTK_CHECK_VERSION(4, 0, 0)
+        gtk_check_button_set_active(GTK_CHECK_BUTTON(pWidget), bChecked);
+#else
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pWidget), bChecked);
+#endif
     }
     else if( tType == GTK_TYPE_COMBO_BOX )
         HandleSetListValue(GTK_COMBO_BOX(pWidget), nControlAction, rValue);
@@ -1280,8 +1321,14 @@ uno::Any SAL_CALL SalGtkFilePicker::getValue( sal_Int16 nControlId, sal_Int16 nC
 
     if( !( pWidget = getWidget( nControlId, &tType ) ) )
         SAL_WARN( "vcl.gtk", "enable unknown control " << nControlId);
-    else if( tType == GTK_TYPE_TOGGLE_BUTTON )
-        aRetval <<= bool( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( pWidget ) ) );
+    else if( tType == GTK_TYPE_CHECK_BUTTON)
+    {
+#if GTK_CHECK_VERSION(4, 0, 0)
+        aRetval <<= bool(gtk_check_button_get_active(GTK_CHECK_BUTTON(pWidget)));
+#else
+        aRetval <<= bool(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pWidget)));
+#endif
+    }
     else if( tType == GTK_TYPE_COMBO_BOX )
         aRetval = HandleGetListValue(GTK_COMBO_BOX(pWidget), nControlAction);
     else
@@ -1329,20 +1376,7 @@ void SAL_CALL SalGtkFilePicker::setLabel( sal_Int16 nControlId, const OUString&
     }
 
     OString aTxt = OUStringToOString( rLabel.replace('~', '_'), RTL_TEXTENCODING_UTF8 );
-    if (nControlId == ExtendedFilePickerElementIds::PUSHBUTTON_PLAY)
-    {
-#ifdef GTK_STOCK_MEDIA_PLAY
-        if (msPlayLabel.isEmpty())
-            msPlayLabel = rLabel;
-        if (msPlayLabel == rLabel)
-            gtk_button_set_label(GTK_BUTTON(pWidget), GTK_STOCK_MEDIA_PLAY);
-        else
-            gtk_button_set_label(GTK_BUTTON(pWidget), GTK_STOCK_MEDIA_STOP);
-#else
-        gtk_button_set_label(GTK_BUTTON(pWidget), aTxt.getStr());
-#endif
-    }
-    else if( tType == GTK_TYPE_TOGGLE_BUTTON || tType == GTK_TYPE_BUTTON || tType == GTK_TYPE_LABEL )
+    if( tType == GTK_TYPE_CHECK_BUTTON || tType == GTK_TYPE_BUTTON || tType == GTK_TYPE_LABEL )
         g_object_set( pWidget, "label", aTxt.getStr(),
                       "use_underline", true, nullptr );
     else
@@ -1361,7 +1395,7 @@ OUString SAL_CALL SalGtkFilePicker::getLabel( sal_Int16 nControlId )
 
     if( !( pWidget = getWidget( nControlId, &tType ) ) )
         SAL_WARN( "vcl.gtk", "Get label on unknown control " << nControlId);
-    else if( tType == GTK_TYPE_TOGGLE_BUTTON || tType == GTK_TYPE_BUTTON || tType == GTK_TYPE_LABEL )
+    else if( tType == GTK_TYPE_CHECK_BUTTON || tType == GTK_TYPE_BUTTON || tType == GTK_TYPE_LABEL )
         aTxt = gtk_button_get_label( GTK_BUTTON( pWidget ) );
     else
         SAL_WARN( "vcl.gtk", "Can't get label on list");
@@ -1480,6 +1514,7 @@ void SalGtkFilePicker::selection_changed_cb( GtkFileChooser *, SalGtkFilePicker
 
 void SalGtkFilePicker::update_preview_cb( GtkFileChooser *file_chooser, SalGtkFilePicker* pobjFP )
 {
+#if !GTK_CHECK_VERSION(4, 0, 0)
     bool have_preview = false;
 
     GtkWidget* preview = pobjFP->m_pPreview;
@@ -1504,6 +1539,10 @@ void SalGtkFilePicker::update_preview_cb( GtkFileChooser *file_chooser, SalGtkFi
 
     if( filename )
         g_free( filename );
+#else
+    (void)file_chooser;
+    (void)pobjFP;
+#endif
 }
 
 sal_Bool SAL_CALL SalGtkFilePicker::setShowState( sal_Bool bShowState )
@@ -1597,7 +1636,9 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
     }
 
     GtkFileChooserAction eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-    const gchar *first_button_text = GTK_STOCK_OPEN;
+    OString sOpen = getOpenText();
+    OString sSave = getSaveText();
+    const gchar *first_button_text = sOpen.getStr();
 
     SolarMutexGuard g;
 
@@ -1607,22 +1648,22 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
     {
         case FILEOPEN_SIMPLE:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             break;
         case FILESAVE_SIMPLE:
             eAction = GTK_FILE_CHOOSER_ACTION_SAVE;
-            first_button_text = GTK_STOCK_SAVE;
+            first_button_text = sSave.getStr();
                 break;
         case FILESAVE_AUTOEXTENSION_PASSWORD:
             eAction = GTK_FILE_CHOOSER_ACTION_SAVE;
-            first_button_text = GTK_STOCK_SAVE;
+            first_button_text = sSave.getStr();
             mbToggleVisibility[PASSWORD] = true;
             mbToggleVisibility[GPGENCRYPTION] = true;
             // TODO
             break;
         case FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS:
             eAction = GTK_FILE_CHOOSER_ACTION_SAVE;
-            first_button_text = GTK_STOCK_SAVE;
+            first_button_text = sSave.getStr();
             mbToggleVisibility[PASSWORD] = true;
             mbToggleVisibility[GPGENCRYPTION] = true;
             mbToggleVisibility[FILTEROPTIONS] = true;
@@ -1630,19 +1671,19 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
                 break;
         case FILESAVE_AUTOEXTENSION_SELECTION:
             eAction = GTK_FILE_CHOOSER_ACTION_SAVE; // SELECT_FOLDER ?
-            first_button_text = GTK_STOCK_SAVE;
+            first_button_text = sSave.getStr();
             mbToggleVisibility[SELECTION] = true;
             // TODO
                 break;
         case FILESAVE_AUTOEXTENSION_TEMPLATE:
             eAction = GTK_FILE_CHOOSER_ACTION_SAVE;
-            first_button_text = GTK_STOCK_SAVE;
+            first_button_text = sSave.getStr();
             mbListVisibility[TEMPLATE] = true;
             // TODO
                 break;
         case FILEOPEN_LINK_PREVIEW_IMAGE_TEMPLATE:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbToggleVisibility[LINK] = true;
             mbToggleVisibility[PREVIEW] = true;
             mbListVisibility[IMAGE_TEMPLATE] = true;
@@ -1650,7 +1691,7 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
                 break;
         case FILEOPEN_LINK_PREVIEW_IMAGE_ANCHOR:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbToggleVisibility[LINK] = true;
             mbToggleVisibility[PREVIEW] = true;
             mbListVisibility[IMAGE_ANCHOR] = true;
@@ -1658,38 +1699,38 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
                 break;
         case FILEOPEN_PLAY:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbButtonVisibility[PLAY] = true;
             // TODO
                 break;
         case FILEOPEN_LINK_PLAY:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbToggleVisibility[LINK] = true;
             mbButtonVisibility[PLAY] = true;
             // TODO
                 break;
         case FILEOPEN_READONLY_VERSION:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbToggleVisibility[READONLY] = true;
             mbListVisibility[VERSION] = true;
             break;
         case FILEOPEN_LINK_PREVIEW:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbToggleVisibility[LINK] = true;
             mbToggleVisibility[PREVIEW] = true;
             // TODO
                 break;
         case FILESAVE_AUTOEXTENSION:
             eAction = GTK_FILE_CHOOSER_ACTION_SAVE;
-            first_button_text = GTK_STOCK_SAVE;
+            first_button_text = sSave.getStr();
             // TODO
                 break;
         case FILEOPEN_PREVIEW:
             eAction = GTK_FILE_CHOOSER_ACTION_OPEN;
-            first_button_text = GTK_STOCK_OPEN;
+            first_button_text = sOpen.getStr();
             mbToggleVisibility[PREVIEW] = true;
             // TODO
                 break;
@@ -1708,18 +1749,15 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
     }
 
     gtk_file_chooser_set_action( GTK_FILE_CHOOSER( m_pDialog ), eAction);
-    dialog_remove_buttons( GTK_DIALOG( m_pDialog ) );
-    gtk_dialog_add_button( GTK_DIALOG( m_pDialog ), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL );
+    gtk_dialog_add_button(GTK_DIALOG( m_pDialog ),
+                          getCancelText().getStr(),
+                          GTK_RESPONSE_CANCEL);
     for( int nTVIndex = 0; nTVIndex < BUTTON_LAST; nTVIndex++ )
     {
         if( mbButtonVisibility[nTVIndex] )
         {
-#ifdef GTK_STOCK_MEDIA_PLAY
-            m_pButtons[ nTVIndex ] = gtk_dialog_add_button( GTK_DIALOG( m_pDialog ), GTK_STOCK_MEDIA_PLAY, 1 );
-#else
             OString aPlay = OUStringToOString( getResString( PUSHBUTTON_PLAY ), RTL_TEXTENCODING_UTF8 );
             m_pButtons[ nTVIndex ] = gtk_dialog_add_button( GTK_DIALOG( m_pDialog ), aPlay.getStr(), 1 );
-#endif
         }
     }
     gtk_dialog_add_button( GTK_DIALOG( m_pDialog ), first_button_text, GTK_RESPONSE_ACCEPT );
@@ -1740,7 +1778,6 @@ void SAL_CALL SalGtkFilePicker::initialize( const uno::Sequence<uno::Any>& aArgu
             gtk_widget_set_sensitive( m_pLists[ nTVIndex ], false );
             gtk_widget_show( m_pLists[ nTVIndex ] );
             gtk_widget_show( m_pListLabels[ nTVIndex ] );
-            gtk_widget_show( m_pAligns[ nTVIndex ] );
             gtk_widget_show( m_pHBoxs[ nTVIndex ] );
         }
     }
@@ -1767,6 +1804,7 @@ void SAL_CALL SalGtkFilePicker::cancel()
 
 void SalGtkFilePicker::SetCurFilter( const OUString& rFilter )
 {
+#if !GTK_CHECK_VERSION(4, 0, 0)
     // Get all the filters already added
     GSList *filters = gtk_file_chooser_list_filters ( GTK_FILE_CHOOSER( m_pDialog ) );
     bool bFound = false;
@@ -1787,8 +1825,12 @@ void SalGtkFilePicker::SetCurFilter( const OUString& rFilter )
     }
 
     g_slist_free( filters );
+#else
+    (void)rFilter;
+#endif
 }
 
+#if !GTK_CHECK_VERSION(4, 0, 0)
 extern "C"
 {
 static gboolean
@@ -1816,6 +1858,7 @@ case_insensitive_filter (const GtkFileFilterInfo *filter_info, gpointer data)
     return bRetval;
 }
 }
+#endif
 
 GtkFileFilter* SalGtkFilePicker::implAddFilter( const OUString& rFilter, const OUString& rType )
 {
@@ -1845,10 +1888,12 @@ GtkFileFilter* SalGtkFilePicker::implAddFilter( const OUString& rFilter, const O
                 if (!aTokens.isEmpty())
                     aTokens.append(",");
                 aTokens.append(aToken);
+#if !GTK_CHECK_VERSION(4, 0, 0)
                 gtk_file_filter_add_custom (filter, GTK_FILE_FILTER_URI,
                     case_insensitive_filter,
                     g_strdup( OUStringToOString(aToken, RTL_TEXTENCODING_UTF8).getStr() ),
                     g_free );
+#endif
 
                 SAL_INFO( "vcl.gtk", "fustering with " << aToken );
             }
@@ -1962,6 +2007,7 @@ void SalGtkFilePicker::SetFilters()
 
 SalGtkFilePicker::~SalGtkFilePicker()
 {
+#if !GTK_CHECK_VERSION(4, 0, 0)
     SolarMutexGuard g;
 
     int i;
@@ -1972,13 +2018,14 @@ SalGtkFilePicker::~SalGtkFilePicker()
     for( i = 0; i < LIST_LAST; i++ )
     {
         gtk_widget_destroy( m_pListLabels[i] );
-        gtk_widget_destroy( m_pAligns[i] ); //m_pAligns[i] owns m_pLists[i]
+        gtk_widget_destroy( m_pLists[i] );
         gtk_widget_destroy( m_pHBoxs[i] );
     }
 
     m_pFilterVector.reset();
 
     gtk_widget_destroy( m_pVBox );
+#endif
 }
 
 uno::Reference< ui::dialogs::XFilePicker2 >
