@@ -28,16 +28,14 @@
 #include <tools/debug.hxx>
 #include <tools/time.hxx>
 #include <comphelper/solarmutex.hxx>
+#include <comphelper/windowserrorstring.hxx>
 #include <o3tl/char16_t2wchar_t.hxx>
 
 #include <vcl/inputtypes.hxx>
-#include <vcl/opengl/OpenGLHelper.hxx>
 #include <vcl/opengl/OpenGLContext.hxx>
 #include <vcl/timer.hxx>
 #include <vclpluginapi.h>
 
-#include <opengl/salbmp.hxx>
-#include <opengl/win/gdiimpl.hxx>
 #include <win/wincomp.hxx>
 #include <win/salids.hrc>
 #include <win/saldata.hxx>
@@ -76,25 +74,6 @@
 
 #include <postwin.h>
 
-void SalAbort( const OUString& rErrorText, bool )
-{
-    ImplFreeSalGDI();
-
-    if ( rErrorText.isEmpty() )
-    {
-        // make sure crash reporter is triggered
-        RaiseException( 0, EXCEPTION_NONCONTINUABLE, 0, nullptr );
-        FatalAppExitW( 0, L"Application Error" );
-    }
-    else
-    {
-        CrashReporter::addKeyValue("AbortMessage", rErrorText, CrashReporter::Write);
-        // make sure crash reporter is triggered
-        RaiseException( 0, EXCEPTION_NONCONTINUABLE, 0, nullptr );
-        FatalAppExitW( 0, o3tl::toW(rErrorText.getStr()) );
-    }
-}
-
 static LRESULT CALLBACK SalComWndProcW( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lParam );
 
 class SalYieldMutex : public comphelper::SolarMutex
@@ -158,6 +137,7 @@ void SalYieldMutex::doAcquire( sal_uInt32 nLockCount )
             // wait for SalYieldMutex::release() to set the condition
             osl::Condition::Result res = m_condition.wait();
             assert(osl::Condition::Result::result_ok == res);
+            (void) res;
         }
         while ( true );
     }
@@ -429,45 +409,39 @@ static LRESULT ImplSalDispatchMessage( const MSG* pMsg )
     return lResult;
 }
 
-bool ImplSalYield( bool bWait, bool bHandleAllCurrentEvents )
+// probably can't be static, because of SalTimer friend? (static gives C4211)
+bool ImplSalYield(const bool bWait, const bool bHandleAllCurrentEvents)
 {
+    // used to abort further message processing on tick count wraps
     static sal_uInt32 nLastTicks = 0;
-    MSG aMsg;
-    bool bWasMsg = false, bOneEvent = false, bWasTimeoutMsg = false;
-    ImplSVData *const pSVData = ImplGetSVData();
-    WinSalTimer* pTimer = static_cast<WinSalTimer*>( pSVData->maSchedCtx.mpSalTimer );
-    const bool bNoYieldLock = (GetSalData()->mpInstance->m_nNoYieldLock > 0);
 
-    assert( !bNoYieldLock );
-    if ( bNoYieldLock )
+    // we should never yield in m_nNoYieldLock mode!
+    const bool bNoYieldLock = (GetSalData()->mpInstance->m_nNoYieldLock > 0);
+    assert(!bNoYieldLock);
+    if (bNoYieldLock)
         return false;
 
-    sal_uInt32 nCurTicks = 0;
-    if ( bHandleAllCurrentEvents )
-        nCurTicks = GetTickCount();
+    MSG aMsg;
+    bool bWasMsg = false, bWasTimeoutMsg = false;
+    WinSalTimer* pTimer = static_cast<WinSalTimer*>(ImplGetSVData()->maSchedCtx.mpSalTimer);
+
+    sal_uInt32 nCurTicks = GetTickCount();
 
-    bool bHadNewerEvent = false;
     do
     {
-        bOneEvent = PeekMessageW( &aMsg, nullptr, 0, 0, PM_REMOVE );
-        if ( bOneEvent )
-        {
-            bWasMsg = true;
-            TranslateMessage( &aMsg );
-            LRESULT nRet = ImplSalDispatchMessage( &aMsg );
+        if (!PeekMessageW(&aMsg, nullptr, 0, 0, PM_REMOVE))
+            break;
 
-            if ( !bWasTimeoutMsg )
-                bWasTimeoutMsg = (SAL_MSG_TIMER_CALLBACK == aMsg.message)
-                    && static_cast<bool>( nRet );
+        bWasMsg = true;
+        TranslateMessage(&aMsg);
+        LRESULT nRet = ImplSalDispatchMessage(&aMsg);
 
-            if ( bHandleAllCurrentEvents
-                    && !bHadNewerEvent && aMsg.time > nCurTicks
-                    && (nLastTicks <= nCurTicks || aMsg.time < nLastTicks) )
-                bHadNewerEvent = true;
-            bOneEvent = !bHadNewerEvent;
-        }
+        bWasTimeoutMsg |= (SAL_MSG_TIMER_CALLBACK == aMsg.message) && static_cast<bool>(nRet);
 
-        if ( !(bHandleAllCurrentEvents && bOneEvent) )
+        if (!bHandleAllCurrentEvents)
+            break;
+
+        if ((aMsg.time > nCurTicks) && (nLastTicks <= nCurTicks || aMsg.time < nLastTicks))
             break;
     }
     while( true );
@@ -482,20 +456,30 @@ bool ImplSalYield( bool bWait, bool bHandleAllCurrentEvents )
         bWasMsg = true;
     }
 
-    if ( bHandleAllCurrentEvents )
-        nLastTicks = nCurTicks;
+    nLastTicks = nCurTicks;
 
     if ( bWait && !bWasMsg )
     {
-        if ( GetMessageW( &aMsg, nullptr, 0, 0 ) )
+        switch (GetMessageW(&aMsg, nullptr, 0, 0))
         {
-            bWasMsg = true;
-            TranslateMessage( &aMsg );
-            ImplSalDispatchMessage( &aMsg );
+            case -1:
+                SAL_WARN("vcl.schedule", "GetMessageW failed: " << WindowsErrorString(GetLastError()));
+                // should we std::abort() / SalAbort here?
+                break;
+            case 0:
+                SAL_INFO("vcl.schedule", "GetMessageW received WM_QUIT while waiting");
+                break;
+            default:
+                bWasMsg = true;
+                TranslateMessage(&aMsg);
+                ImplSalDispatchMessage(&aMsg);
+                break;
         }
     }
 
-    // we're back in the main loop after resize or move
+    // If we enabled ForceRealTimer mode skipping our direct timeout processing,
+    // mainly because some Windows API call spawns its own nested message loop,
+    // switch back to our own processing (like after window resize or move)
     if ( pTimer )
         pTimer->SetForceRealTimer( false );
 
@@ -681,116 +665,8 @@ LRESULT CALLBACK SalComWndProcW( HWND hWnd, UINT nMsg, WPARAM wParam, LPARAM lPa
     return nRet;
 }
 
-namespace {
-
-struct MsgRange
-{
-    UINT nStart;
-    UINT nEnd;
-};
-
-}
-
-static std::vector<MsgRange> GetOtherRanges( VclInputFlags nType )
-{
-    assert( nType != VCL_INPUT_ANY );
-
-    // this array must be kept sorted!
-    const UINT nExcludeMsgIds[] =
-    {
-        0,
-
-        WM_MOVE, // 3
-        WM_SIZE, // 5
-        WM_PAINT, // 15
-        WM_KEYDOWN, // 256
-        WM_TIMER, // 275
-
-        WM_MOUSEFIRST, // 512
-        513,
-        514,
-        515,
-        516,
-        517,
-        518,
-        519,
-        520,
-        WM_MOUSELAST, // 521
-
-        SAL_MSG_POSTMOVE, // WM_USER+136
-        SAL_MSG_POSTCALLSIZE, // WM_USER+137
-
-        SAL_MSG_TIMER_CALLBACK, // WM_USER+162
-
-        UINT_MAX
-    };
-    const unsigned MAX_EXCL = SAL_N_ELEMENTS( nExcludeMsgIds );
-
-    bool aExcludeMsgList[ MAX_EXCL ] = { false, };
-    std::vector<MsgRange> aResult;
-
-    // set the excluded values
-    if ( !(nType & VclInputFlags::MOUSE) )
-    {
-        for ( unsigned i = 0; nExcludeMsgIds[ 6 + i ] <= WM_MOUSELAST; ++i )
-            aExcludeMsgList[ 6 + i ] = true;
-    }
-
-    if ( !(nType & VclInputFlags::KEYBOARD) )
-        aExcludeMsgList[ 4 ] = true;
-
-    if ( !(nType & VclInputFlags::PAINT) )
-    {
-        aExcludeMsgList[ 1 ] = true;
-        aExcludeMsgList[ 2 ] = true;
-        aExcludeMsgList[ 3 ] = true;
-        aExcludeMsgList[ 16 ] = true;
-        aExcludeMsgList[ 17 ] = true;
-    }
-
-    if ( !(nType & VclInputFlags::TIMER) )
-    {
-        aExcludeMsgList[ 5 ]  = true;
-        aExcludeMsgList[ 18 ]  = true;
-    }
-
-    // build the message ranges to check
-    MsgRange aRange = { 0, 0 };
-    bool doEnd = true;
-    for ( unsigned i = 1; i < MAX_EXCL; ++i )
-    {
-        if ( aExcludeMsgList[ i ] )
-        {
-            if ( !doEnd )
-            {
-                if ( nExcludeMsgIds[ i ] == aRange.nStart )
-                    ++aRange.nStart;
-                else
-                    doEnd = true;
-            }
-            if ( doEnd )
-            {
-                aRange.nEnd = nExcludeMsgIds[ i ] - 1;
-                aResult.push_back( aRange );
-                doEnd = false;
-                aRange.nStart = aRange.nEnd + 2;
-            }
-        }
-    }
-
-    if ( aRange.nStart != UINT_MAX )
-    {
-        aRange.nEnd = UINT_MAX;
-        aResult.push_back( aRange );
-    }
-
-    return aResult;
-}
-
 bool WinSalInstance::AnyInput( VclInputFlags nType )
 {
-    MSG aMsg;
-
     if ( nType & VclInputFlags::TIMER )
     {
         const WinSalTimer* pTimer = static_cast<WinSalTimer*>( ImplGetSVData()->maSchedCtx.mpSalTimer );
@@ -798,81 +674,40 @@ bool WinSalInstance::AnyInput( VclInputFlags nType )
             return true;
     }
 
+    // Note: Do not use PeekMessage(), despite the name it may dispatch events,
+    // even with PM_NOREMOVE specified, which may lead to unwanted recursion.
+
     if ( (nType & VCL_INPUT_ANY) == VCL_INPUT_ANY )
     {
         // revert bugfix for #108919# which never reported timeouts when called from the timer handler
         // which made the application completely unresponsive during background formatting
-        if ( PeekMessageW( &aMsg, nullptr, 0, 0, PM_NOREMOVE | PM_NOYIELD ) )
+        if ( GetQueueStatus( QS_ALLEVENTS ))
             return true;
     }
     else
     {
-        const bool bCheck_KEYBOARD (nType & VclInputFlags::KEYBOARD);
-        const bool bCheck_OTHER    (nType & VclInputFlags::OTHER);
+        UINT flags = 0;
 
-        // If there is a modifier key event, it counts as OTHER
-        // Previously we were simply ignoring these events...
-        if ( bCheck_KEYBOARD || bCheck_OTHER )
-        {
-            if ( PeekMessageW( &aMsg, nullptr, WM_KEYDOWN, WM_KEYDOWN,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-            {
-                const bool bIsModifier = ( (aMsg.wParam == VK_SHIFT) ||
-                    (aMsg.wParam == VK_CONTROL) || (aMsg.wParam == VK_MENU) );
-                if ( bCheck_KEYBOARD && !bIsModifier )
-                    return true;
-                if ( bCheck_OTHER && bIsModifier )
-                    return true;
-            }
-        }
-
-        // Other checks for all messages not excluded.
-        // The less we exclude, the less ranges have to be checked!
-        if ( bCheck_OTHER )
-        {
-            // TIMER and KEYBOARD are already handled, so always exclude them!
-            VclInputFlags nOtherType = nType &
-                ~VclInputFlags(VclInputFlags::KEYBOARD | VclInputFlags::TIMER);
-
-            std::vector<MsgRange> aMsgRangeList( GetOtherRanges( nOtherType ) );
-            for ( MsgRange const & aRange : aMsgRangeList )
-                if ( PeekMessageW( &aMsg, nullptr, aRange.nStart,
-                                   aRange.nEnd, PM_NOREMOVE | PM_NOYIELD ) )
-                    return true;
-
-            // MOUSE and PAINT already handled, so skip further checks
-            return false;
-        }
+        // This code previously considered modifier keys as OTHER,
+        // but that makes this hard to do without PeekMessage,
+        // is inconsistent with the X11 backend, and I see no good reason.
+        if ( nType & VclInputFlags::KEYBOARD )
+            flags |= QS_KEY;
 
         if ( nType & VclInputFlags::MOUSE )
-        {
-            if ( PeekMessageW( &aMsg, nullptr, WM_MOUSEFIRST, WM_MOUSELAST,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-                return true;
-        }
+            flags |= QS_MOUSE;
 
         if ( nType & VclInputFlags::PAINT )
-        {
-            if ( PeekMessageW( &aMsg, nullptr, WM_PAINT, WM_PAINT,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-                return true;
+            flags |= QS_PAINT;
 
-            if ( PeekMessageW( &aMsg, nullptr, WM_SIZE, WM_SIZE,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-                return true;
+        if ( nType & VclInputFlags::TIMER )
+            flags |= QS_TIMER;
 
-            if ( PeekMessageW( &aMsg, nullptr, SAL_MSG_POSTCALLSIZE, SAL_MSG_POSTCALLSIZE,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-                return true;
+        if( nType & VclInputFlags::OTHER )
+            flags |= QS_ALLEVENTS & ~QS_KEY & ~QS_MOUSE & ~QS_PAINT & ~QS_TIMER;
 
-            if ( PeekMessageW( &aMsg, nullptr, WM_MOVE, WM_MOVE,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-                return true;
-
-            if ( PeekMessageW( &aMsg, nullptr, SAL_MSG_POSTMOVE, SAL_MSG_POSTMOVE,
-                                  PM_NOREMOVE | PM_NOYIELD ) )
-                return true;
-        }
+        if( GetQueueStatus( flags ))
+            return true;
     }
 
     return false;
@@ -997,9 +832,6 @@ std::shared_ptr<SalBitmap> WinSalInstance::CreateSalBitmap()
         return std::make_shared<SkiaSalBitmap>();
     else
 #endif
-    if (OpenGLHelper::isVCLOpenGLEnabled())
-        return std::make_shared<OpenGLSalBitmap>();
-    else
         return std::make_shared<WinSalBitmap>();
 }
 
@@ -1076,7 +908,7 @@ OUString WinSalInstance::getOSVersion()
                                 + OUString::number(vi2.dwMinorVersion));
                 aVer.append(" ");
                 if (vi2.szCSDVersion[0])
-                    aVer.append(o3tl::toU(vi2.szCSDVersion)).append(" ");
+                    aVer.append(OUString::Concat(o3tl::toU(vi2.szCSDVersion)) + " ");
                 aVer.append("Build " + OUString::number(vi2.dwBuildNumber));
                 bHaveVerFromRtlGetVersion = true;
             }
@@ -1099,4 +931,9 @@ std::shared_ptr<vcl::BackendCapabilities> WinSalInstance::GetBackendCapabilities
     return pBackendCapabilities;
 }
 
+void WinSalInstance::BeforeAbort(const OUString&, bool)
+{
+    ImplFreeSalGDI();
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
