@@ -37,7 +37,6 @@
 #include <osl/module.h>
 #include <o3tl/char16_t2wchar_t.hxx>
 
-#include <opengl/win/gdiimpl.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 
@@ -45,6 +44,7 @@
 #include <win/salgdi.h>
 #include <win/saldata.hxx>
 #include <win/scoped_gdi.hxx>
+#include <win/wingdiimpl.hxx>
 
 #include <uxtheme.h>
 #include <vssym32.h>
@@ -437,10 +437,10 @@ static void impl_drawAeroToolbar( HDC hDC, RECT rc, bool bHorizontal )
 {
     if ( rc.top == 0 && bHorizontal )
     {
-        const long GRADIENT_HEIGHT = 32;
+        const int GRADIENT_HEIGHT = 32;
 
-        long gradient_break = rc.top;
-        long gradient_bottom = rc.bottom - 1;
+        LONG gradient_break = rc.top;
+        LONG gradient_bottom = rc.bottom - 1;
         GRADIENT_RECT g_rect[1] = { { 0, 1 } };
 
         // very slow gradient at the top (if we have space for that)
@@ -478,7 +478,7 @@ static void impl_drawAeroToolbar( HDC hDC, RECT rc, bool bHorizontal )
         // when done for the vertical ones too
         if ( bHorizontal )
         {
-            long from_x, from_y, to_x, to_y;
+            LONG from_x, from_y, to_x, to_y;
 
             from_x = rc.left;
             to_x = rc.right;
@@ -1008,7 +1008,7 @@ static bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         if( vsAPI.GetThemeBackgroundContentRect( hTheme, hDC, PP_BAR, iState, &rc, &aProgressRect) != S_OK )
             return false;
 
-        long nProgressWidth = aValue.getNumericVal();
+        tools::Long nProgressWidth = aValue.getNumericVal();
         nProgressWidth *= (aProgressRect.right - aProgressRect.left);
         nProgressWidth /= (rc.right - rc.left);
         if( AllSettings::GetLayoutRTL() )
@@ -1028,13 +1028,13 @@ static bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
         RECT aTRect = rc;
         if( nPart == ControlPart::TrackHorzArea )
         {
-            long nH = aTrackRect.GetHeight();
+            tools::Long nH = aTrackRect.GetHeight();
             aTRect.top += (rc.bottom - rc.top - nH)/2;
             aTRect.bottom = aTRect.top + nH;
         }
         else
         {
-            long nW = aTrackRect.GetWidth();
+            tools::Long nW = aTrackRect.GetWidth();
             aTRect.left += (rc.right - rc.left - nW)/2;
             aTRect.right = aTRect.left + nW;
         }
@@ -1138,7 +1138,7 @@ static bool ImplDrawNativeControl( HDC hDC, HTHEME hTheme, RECT rc,
                 tools::Rectangle aRect( ImplGetThemeRect( hTheme, hDC,
                     MENU_POPUPSEPARATOR, 0, tools::Rectangle( rc.left, rc.top, rc.right, rc.bottom ) ) );
                 // center the separator inside the passed rectangle
-                long nDY = ((rc.bottom - rc.top + 1) - aRect.GetHeight()) / 2;
+                auto const nDY = ((rc.bottom - rc.top + 1) - aRect.GetHeight()) / 2;
                 rc.top += nDY;
                 rc.bottom = rc.top+aRect.GetHeight()-1;
                 return ImplDrawTheme( hTheme, hDC, MENU_POPUPSEPARATOR, 0, rc, aCaption );
@@ -1425,7 +1425,7 @@ bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
             aNonClientMetrics.cbSize = sizeof( aNonClientMetrics );
             if ( SystemParametersInfoW( SPI_GETNONCLIENTMETRICS, sizeof( aNonClientMetrics ), &aNonClientMetrics, 0 ) )
             {
-                long nFontHeight = aNonClientMetrics.lfMessageFont.lfHeight;
+                LONG nFontHeight = aNonClientMetrics.lfMessageFont.lfHeight;
                 if( nFontHeight < 0 )
                     nFontHeight = -nFontHeight;
 
@@ -1478,7 +1478,7 @@ bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
             tools::Rectangle aThumbRect = ImplGetThemeRect( hTheme, hDC, iPart, iState, tools::Rectangle() );
             if( nPart == ControlPart::ThumbHorz )
             {
-                long nW = aThumbRect.GetWidth();
+                tools::Long nW = aThumbRect.GetWidth();
                 tools::Rectangle aRect( rControlRegion );
                 aRect.SetRight( aRect.Left() + nW - 1 );
                 rNativeContentRegion = aRect;
@@ -1486,7 +1486,7 @@ bool WinSalGraphics::getNativeControlRegion(  ControlType nType,
             }
             else
             {
-                long nH = aThumbRect.GetHeight();
+                tools::Long nH = aThumbRect.GetHeight();
                 tools::Rectangle aRect( rControlRegion );
                 aRect.SetBottom( aRect.Top() + nH - 1 );
                 rNativeContentRegion = aRect;
