@@ -44,6 +44,7 @@
 #include <comphelper/sequence.hxx>
 #include <comphelper/propertyvalue.hxx>
 #include <comphelper/string.hxx>
+#include <regex>
 
 using namespace com::sun::star;
 
@@ -56,7 +57,7 @@ static beans::PropertyValue lcl_makePropVal(PropertyIds nNameID, T const & aValu
     return {getPropertyName(nNameID), 0, uno::makeAny(aValue), beans::PropertyState_DIRECT_VALUE};
 }
 
-static sal_Int32 lcl_findProperty( const uno::Sequence< beans::PropertyValue >& aProps, const OUString& sName )
+static sal_Int32 lcl_findProperty( const uno::Sequence< beans::PropertyValue >& aProps, std::u16string_view sName )
 {
     sal_Int32 i = 0;
     sal_Int32 nLen = aProps.getLength( );
@@ -160,15 +161,14 @@ uno::Sequence<beans::PropertyValue> ListLevel::GetProperties(bool bDefaults)
     return aLevelProps;
 }
 
-static bool IgnoreForCharStyle(const OUString& aStr, const bool bIsSymbol)
+static bool IgnoreForCharStyle(std::u16string_view aStr, const bool bIsSymbol)
 {
     //Names found in PropertyIds.cxx, Lines 56-396
-    return (aStr=="Adjust" || aStr=="IndentAt" || aStr=="FirstLineIndent"
-            || aStr=="FirstLineOffset" || aStr=="LeftMargin"
-            || aStr=="CharInteropGrabBag" || aStr=="ParaInteropGrabBag" ||
+    return (aStr==u"Adjust" || aStr==u"IndentAt" || aStr==u"FirstLineIndent"
+            || aStr==u"FirstLineOffset" || aStr==u"LeftMargin"
             // We need font names when they are different for the bullet and for the text.
             // But leave symbols alone, we only want to keep the font style for letters and numbers.
-            (bIsSymbol && aStr=="CharFontName")
+            || (bIsSymbol && aStr==u"CharFontName")
         );
 }
 uno::Sequence< beans::PropertyValue > ListLevel::GetCharStyleProperties( )
@@ -269,7 +269,7 @@ uno::Sequence<beans::PropertyValue> ListLevel::GetLevelProperties(bool bDefaults
     }
 
     std::optional<PropertyMap::Property> aPropFont = getProperty(PROP_CHAR_FONT_NAME);
-    if(aPropFont && !isOutlineNumbering())
+    if (aPropFont)
         aNumberingProperties.emplace_back( getPropertyName(PROP_BULLET_FONT_NAME), 0, aPropFont->second, beans::PropertyState_DIRECT_VALUE );
 
     return comphelper::containerToSequence(aNumberingProperties);
@@ -414,7 +414,7 @@ ListDef::~ListDef( )
 {
 }
 
-OUString ListDef::GetStyleName(sal_Int32 const nId,
+const OUString & ListDef::GetStyleName(sal_Int32 const nId,
     uno::Reference<container::XNameContainer> const& xStyles)
 {
     if (xStyles.is())
@@ -677,18 +677,19 @@ void ListsManager::lcl_attribute( Id nName, Value& rVal )
     {
         case NS_ooxml::LN_CT_LevelText_val:
         {
-            //this strings contains the definition of the level
-            //the level number is marked as %n
-            //these numbers can be mixed randomly together with separators pre- and suffixes
-            //the Writer supports only a number of upper levels to show, separators is always a dot
-            //and each level can have a prefix and a suffix
             if(pCurrentLvl)
             {
                 //if the BulletChar is a soft-hyphen (0xad)
                 //replace it with a hard-hyphen (0x2d)
                 //-> this fixes missing hyphen export in PDF etc.
                 // see tdf#101626
-                pCurrentLvl->SetBulletChar( rVal.getString().replace( 0xad, 0x2d ) );
+                std::string sLevelText = rVal.getString().replace(0xad, 0x2d).toUtf8().getStr();
+
+                // DOCX level-text contains levels definition in format "%1.%2.%3"
+                // we need to convert it to LO internal representation: "%1%.%2%.%3%"
+                static const std::regex aTokenRegex("(%\\d)");
+                sLevelText = std::regex_replace(sLevelText, aTokenRegex, "$1%");
+                pCurrentLvl->SetBulletChar( OUString::fromUtf8(sLevelText) );
             }
         }
         break;
