@@ -16,6 +16,11 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
+#include <sal/config.h>
+
+#include <string_view>
+
 #include "PropertyMap.hxx"
 #include "TagLogger.hxx"
 #include <ooxml/resourceids.hxx>
@@ -316,7 +321,7 @@ void PropertyMap::dumpXml() const
                     TagLogger::getInstance().attribute( "floatValue", aFloat );
 
                     rPropPair.second.getValue() >>= auInt;
-                    TagLogger::getInstance().attribute( "stringValue", OUString() );
+                    TagLogger::getInstance().attribute( "stringValue", std::u16string_view() );
                 }
                 catch ( ... )
                 {
@@ -407,6 +412,7 @@ SectionPropertyMap::SectionPropertyMap( bool bIsFirstSection )
     , m_nBreakType( -1 )
     , m_nLeftMargin( 2540 )  // page left margin,  default 1 inch = 1440 twip -> 2540 1/100 mm
     , m_nRightMargin( 2540 ) // page right margin,  default 1 inch = 1440 twip -> 2540 1/100 mm
+    , m_nGutterMargin(0)
     , m_nTopMargin( 2540 )
     , m_nBottomMargin( 2540 )
     , m_nHeaderTop( 1270 )    // 720 twip
@@ -419,6 +425,8 @@ SectionPropertyMap::SectionPropertyMap( bool bIsFirstSection )
     , m_nLnc(NS_ooxml::LN_Value_ST_LineNumberRestart_newPage)
     , m_ndxaLnn( 0 )
     , m_nLnnMin( 0 )
+    , m_bDynamicHeightTop( true )
+    , m_bDynamicHeightBottom( true )
     , m_bDefaultHeaderLinkToPrevious( true )
     , m_bEvenPageHeaderLinkToPrevious( true )
     , m_bFirstPageHeaderLinkToPrevious( true )
@@ -614,10 +622,10 @@ void SectionPropertyMap::ApplyBorderToPageStyles( DomainMapper_Impl& rDM_Impl,
                 nLineWidth = m_oBorderLines[nBorder]->LineWidth;
             if ( xFirst.is() )
                 SetBorderDistance( xFirst, aMarginIds[nBorder], aBorderDistanceIds[nBorder],
-                    m_nBorderDistances[nBorder], eOffsetFrom, nLineWidth );
+                    m_nBorderDistances[nBorder], eOffsetFrom, nLineWidth, rDM_Impl );
             if ( xSecond.is() )
                 SetBorderDistance( xSecond, aMarginIds[nBorder], aBorderDistanceIds[nBorder],
-                    m_nBorderDistances[nBorder], eOffsetFrom, nLineWidth );
+                    m_nBorderDistances[nBorder], eOffsetFrom, nLineWidth, rDM_Impl );
         }
     }
 
@@ -649,7 +657,8 @@ void SectionPropertyMap::SetBorderDistance( const uno::Reference< beans::XProper
                                             PropertyIds eDistId,
                                             sal_Int32 nDistance,
                                             BorderOffsetFrom eOffsetFrom,
-                                            sal_uInt32 nLineWidth )
+                                            sal_uInt32 nLineWidth,
+                                            DomainMapper_Impl& rDM_Impl )
 {
     if (!xStyle.is())
         return;
@@ -661,6 +670,25 @@ void SectionPropertyMap::SetBorderDistance( const uno::Reference< beans::XProper
     editeng::BorderDistanceFromWord(eOffsetFrom == BorderOffsetFrom::Edge, nMargin, nDistance,
                                     nLineWidth);
 
+    if (eOffsetFrom == BorderOffsetFrom::Edge)
+    {
+        uno::Any aGutterMargin = xStyle->getPropertyValue( "GutterMargin" );
+        sal_Int32 nGutterMargin = 0;
+        aGutterMargin >>= nGutterMargin;
+
+        if (eMarginId == PROP_LEFT_MARGIN && !rDM_Impl.GetSettingsTable()->GetGutterAtTop())
+        {
+            nMargin -= nGutterMargin;
+            nDistance += nGutterMargin;
+        }
+
+        if (eMarginId == PROP_TOP_MARGIN && rDM_Impl.GetSettingsTable()->GetGutterAtTop())
+        {
+            nMargin -= nGutterMargin;
+            nDistance += nGutterMargin;
+        }
+    }
+
     // Change the margins with the border distance
     uno::Reference< beans::XMultiPropertySet > xMultiSet( xStyle, uno::UNO_QUERY_THROW );
     uno::Sequence<OUString> aProperties { sMarginName, sBorderDistanceName };
@@ -677,7 +705,7 @@ void SectionPropertyMap::DontBalanceTextColumns()
     }
     catch ( const uno::Exception& )
     {
-        OSL_FAIL( "Exception in SectionPropertyMap::DontBalanceTextColumns" );
+        TOOLS_WARN_EXCEPTION( "writerfilter", "SectionPropertyMap::DontBalanceTextColumns" );
     }
 }
 
@@ -792,7 +820,7 @@ uno::Reference< text::XTextColumns > SectionPropertyMap::ApplyColumnProperties(
     }
     catch ( const uno::Exception& )
     {
-        OSL_FAIL( "Exception in SectionPropertyMap::ApplyColumnProperties" );
+        TOOLS_WARN_EXCEPTION( "writerfilter", "SectionPropertyMap::ApplyColumnProperties" );
     }
     return xColumns;
 }
@@ -956,28 +984,25 @@ void SectionPropertyMap::PrepareHeaderFooterProperties( bool bFirstPage )
     bool bCopyFirstToFollow = bFirstPage && m_bTitlePage && m_aFollowPageStyle.is();
 
     sal_Int32 nTopMargin = m_nTopMargin;
-    sal_Int32 nHeaderTop = m_nHeaderTop;
+    sal_Int32 nHeaderHeight = m_nHeaderTop;
     if ( HasHeader( bFirstPage ) )
     {
-        nTopMargin = nHeaderTop;
-        if ( m_nTopMargin > 0 && m_nTopMargin > nHeaderTop )
-            nHeaderTop = m_nTopMargin - nHeaderTop;
-        else
-            nHeaderTop = 0;
+        nTopMargin = m_nHeaderTop;
+        nHeaderHeight = m_nTopMargin - m_nHeaderTop;
 
         // minimum header height 1mm
-        if ( nHeaderTop < MIN_HEAD_FOOT_HEIGHT )
-            nHeaderTop = MIN_HEAD_FOOT_HEIGHT;
+        if ( nHeaderHeight < MIN_HEAD_FOOT_HEIGHT )
+            nHeaderHeight = MIN_HEAD_FOOT_HEIGHT;
     }
 
+    Insert(PROP_HEADER_IS_DYNAMIC_HEIGHT, uno::makeAny(m_bDynamicHeightTop));
+    Insert(PROP_HEADER_DYNAMIC_SPACING, uno::makeAny(m_bDynamicHeightTop));
+    Insert(PROP_HEADER_BODY_DISTANCE, uno::makeAny(nHeaderHeight - MIN_HEAD_FOOT_HEIGHT));
+    Insert(PROP_HEADER_HEIGHT, uno::makeAny(nHeaderHeight));
+    // looks like PROP_HEADER_HEIGHT = height of the header + space between the header, and the body
 
-    if ( m_nTopMargin >= 0 ) //fixed height header -> see WW8Par6.hxx
+    if ( m_bDynamicHeightTop ) //fixed height header -> see WW8Par6.hxx
     {
-        Insert( PROP_HEADER_IS_DYNAMIC_HEIGHT, uno::makeAny( true ) );
-        Insert( PROP_HEADER_DYNAMIC_SPACING, uno::makeAny( true ) );
-        Insert( PROP_HEADER_BODY_DISTANCE, uno::makeAny( nHeaderTop - MIN_HEAD_FOOT_HEIGHT ) );// ULSpace.Top()
-        Insert( PROP_HEADER_HEIGHT, uno::makeAny( nHeaderTop ) );
-
         if (bCopyFirstToFollow && HasHeader(/*bFirstPage=*/true))
         {
             m_aFollowPageStyle->setPropertyValue("HeaderDynamicSpacing",
@@ -986,36 +1011,25 @@ void SectionPropertyMap::PrepareHeaderFooterProperties( bool bFirstPage )
                                                  getProperty(PROP_HEADER_HEIGHT)->second);
         }
     }
-    else
-    {
-        //todo: old filter fakes a frame into the header/footer to support overlapping
-        //current setting is completely wrong!
-        Insert( PROP_HEADER_HEIGHT, uno::makeAny( nHeaderTop ) );
-        Insert( PROP_HEADER_BODY_DISTANCE, uno::makeAny( m_nTopMargin - nHeaderTop ) );
-        Insert( PROP_HEADER_IS_DYNAMIC_HEIGHT, uno::makeAny( false ) );
-        Insert( PROP_HEADER_DYNAMIC_SPACING, uno::makeAny( false ) );
-    }
 
     sal_Int32 nBottomMargin = m_nBottomMargin;
-    sal_Int32 nHeaderBottom = m_nHeaderBottom;
+    sal_Int32 nFooterHeight = m_nHeaderBottom;
     if ( HasFooter( bFirstPage ) )
     {
-        nBottomMargin = nHeaderBottom;
-        if ( m_nBottomMargin > 0 && m_nBottomMargin > nHeaderBottom )
-            nHeaderBottom = m_nBottomMargin - nHeaderBottom;
-        else
-            nHeaderBottom = 0;
-        if ( nHeaderBottom < MIN_HEAD_FOOT_HEIGHT )
-            nHeaderBottom = MIN_HEAD_FOOT_HEIGHT;
+        nBottomMargin = m_nHeaderBottom;
+        nFooterHeight = m_nBottomMargin - m_nHeaderBottom;
+
+        // minimum footer height 1mm
+        if ( nFooterHeight < MIN_HEAD_FOOT_HEIGHT )
+            nFooterHeight = MIN_HEAD_FOOT_HEIGHT;
     }
 
-    if ( m_nBottomMargin >= 0 ) //fixed height footer -> see WW8Par6.hxx
+    Insert(PROP_FOOTER_IS_DYNAMIC_HEIGHT, uno::makeAny(m_bDynamicHeightBottom));
+    Insert(PROP_FOOTER_DYNAMIC_SPACING, uno::makeAny(m_bDynamicHeightBottom));
+    Insert(PROP_FOOTER_BODY_DISTANCE, uno::makeAny(nFooterHeight - MIN_HEAD_FOOT_HEIGHT));
+    Insert(PROP_FOOTER_HEIGHT, uno::makeAny(nFooterHeight));
+    if (m_bDynamicHeightBottom) //fixed height footer -> see WW8Par6.hxx
     {
-        Insert( PROP_FOOTER_IS_DYNAMIC_HEIGHT, uno::makeAny( true ) );
-        Insert( PROP_FOOTER_DYNAMIC_SPACING, uno::makeAny( true ) );
-        Insert( PROP_FOOTER_BODY_DISTANCE, uno::makeAny( nHeaderBottom - MIN_HEAD_FOOT_HEIGHT ) );
-        Insert( PROP_FOOTER_HEIGHT, uno::makeAny( nHeaderBottom ) );
-
         if (bCopyFirstToFollow && HasFooter(/*bFirstPage=*/true))
         {
             m_aFollowPageStyle->setPropertyValue("FooterDynamicSpacing",
@@ -1024,15 +1038,6 @@ void SectionPropertyMap::PrepareHeaderFooterProperties( bool bFirstPage )
                                                  getProperty(PROP_FOOTER_HEIGHT)->second);
         }
     }
-    else
-    {
-        //todo: old filter fakes a frame into the header/footer to support overlapping
-        //current setting is completely wrong!
-        Insert( PROP_FOOTER_IS_DYNAMIC_HEIGHT, uno::makeAny( false ) );
-        Insert( PROP_FOOTER_DYNAMIC_SPACING, uno::makeAny( false ) );
-        Insert( PROP_FOOTER_HEIGHT, uno::makeAny( m_nBottomMargin - nHeaderBottom ) );
-        Insert( PROP_FOOTER_BODY_DISTANCE, uno::makeAny( nHeaderBottom ) );
-    }
 
     //now set the top/bottom margin for the follow page style
     Insert( PROP_TOP_MARGIN, uno::makeAny( std::max<sal_Int32>(nTopMargin, 0) ) );
@@ -1061,6 +1066,7 @@ void SectionPropertyMap::HandleMarginsHeaderFooter( bool bFirstPage, DomainMappe
 {
     Insert( PROP_LEFT_MARGIN, uno::makeAny( m_nLeftMargin ) );
     Insert( PROP_RIGHT_MARGIN, uno::makeAny( m_nRightMargin ) );
+    Insert(PROP_GUTTER_MARGIN, uno::makeAny(m_nGutterMargin));
 
     if ( rDM_Impl.m_oBackgroundColor )
         Insert( PROP_BACK_COLOR, uno::makeAny( *rDM_Impl.m_oBackgroundColor ) );
@@ -1107,10 +1113,20 @@ void SectionPropertyMap::HandleMarginsHeaderFooter( bool bFirstPage, DomainMappe
     */
     CopyLastHeaderFooter( bFirstPage, rDM_Impl );
     PrepareHeaderFooterProperties( bFirstPage );
+
+    // tdf#119952: If top/bottom margin was negative during docx import,
+    // then the header/footer and the body could be on top of each other
+    // writer is unable to display both of them in the same position, but can be simulated
+    // by moving the header/footer text into a flyframe anchored to the header/footer,
+    // leaving an empty dummy header/footer.
+    rDM_Impl.ConvertHeaderFooterToTextFrame(m_bDynamicHeightTop, m_bDynamicHeightBottom);
 }
 
 bool SectionPropertyMap::FloatingTableConversion( const DomainMapper_Impl& rDM_Impl, FloatingTableInfo& rInfo )
 {
+    // always convert non-floating tables to floating ones in footnotes and endnotes
+    if ( rInfo.m_bConvertToFloatingInFootnote )
+        return true;
     // This is OOXML version of the code deciding if the table needs to be
     // in a floating frame.
     // For ww8 code, see SwWW8ImplReader::FloatingTableConversion in
@@ -1136,26 +1152,26 @@ bool SectionPropertyMap::FloatingTableConversion( const DomainMapper_Impl& rDM_I
         nTableWidth *= nTextAreaWidth / 100.0;
     }
     sal_Int32 nLeftMargin = 0;
-    if ( rInfo.getPropertyValue( "LeftMargin" ) >>= nLeftMargin )
+    if ( rInfo.getPropertyValue( u"LeftMargin" ) >>= nLeftMargin )
         nTableWidth += nLeftMargin;
     sal_Int32 nRightMargin = 0;
-    if ( rInfo.getPropertyValue( "RightMargin" ) >>= nRightMargin )
+    if ( rInfo.getPropertyValue( u"RightMargin" ) >>= nRightMargin )
         nTableWidth += nRightMargin;
 
-    sal_Int16 nHoriOrientRelation = rInfo.getPropertyValue( "HoriOrientRelation" ).get<sal_Int16>();
-    sal_Int16 nVertOrientRelation = rInfo.getPropertyValue( "VertOrientRelation" ).get<sal_Int16>();
+    sal_Int16 nHoriOrientRelation = rInfo.getPropertyValue( u"HoriOrientRelation" ).get<sal_Int16>();
+    sal_Int16 nVertOrientRelation = rInfo.getPropertyValue( u"VertOrientRelation" ).get<sal_Int16>();
     if ( nHoriOrientRelation == text::RelOrientation::PAGE_FRAME && nVertOrientRelation == text::RelOrientation::PAGE_FRAME )
     {
-        sal_Int16 nHoriOrient = rInfo.getPropertyValue( "HoriOrient" ).get<sal_Int16>();
-        sal_Int16 nVertOrient = rInfo.getPropertyValue( "VertOrient" ).get<sal_Int16>();
+        sal_Int16 nHoriOrient = rInfo.getPropertyValue( u"HoriOrient" ).get<sal_Int16>();
+        sal_Int16 nVertOrient = rInfo.getPropertyValue( u"VertOrient" ).get<sal_Int16>();
         if ( nHoriOrient == text::HoriOrientation::NONE && nVertOrient == text::VertOrientation::NONE )
         {
             // Anchor position is relative to the page horizontally and vertically as well and is an absolute position.
             // The more close we are to the left edge, the less likely there will be any wrapping.
             // The more close we are to the bottom, the more likely the table will span over to the next page
             // So if we're in the bottom left quarter, don't do any conversion.
-            sal_Int32 nHoriOrientPosition = rInfo.getPropertyValue( "HoriOrientPosition" ).get<sal_Int32>();
-            sal_Int32 nVertOrientPosition = rInfo.getPropertyValue( "VertOrientPosition" ).get<sal_Int32>();
+            sal_Int32 nHoriOrientPosition = rInfo.getPropertyValue( u"HoriOrientPosition" ).get<sal_Int32>();
+            sal_Int32 nVertOrientPosition = rInfo.getPropertyValue( u"VertOrientPosition" ).get<sal_Int32>();
             sal_Int32 nPageHeight = getProperty( PROP_HEIGHT )->second.get<sal_Int32>();
             if ( nHoriOrientPosition < (nPageWidth / 2) && nVertOrientPosition >( nPageHeight / 2 ) )
                 return false;
@@ -1245,6 +1261,10 @@ void SectionPropertyMap::HandleIncreasedAnchoredObjectSpacing(DomainMapper_Impl&
         sal_Int32 nOpaqueCount = 0;
         for (const auto& rAnchored : rAnchor.m_aAnchoredObjects)
         {
+            // Ignore inline objects stored only for redlining.
+            if (rAnchored.m_xRedlineForInline)
+                continue;
+
             uno::Reference<beans::XPropertySet> xShape(rAnchored.m_xAnchoredObject, uno::UNO_QUERY);
             if (!xShape.is())
             {
@@ -1361,13 +1381,16 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
 
     // Text area width is known at the end of a section: decide if tables should be converted or not.
     std::vector<FloatingTableInfo>& rPendingFloatingTables = rDM_Impl.m_aPendingFloatingTables;
-    uno::Reference<text::XTextAppendAndConvert> xBodyText( rDM_Impl.GetBodyText(), uno::UNO_QUERY );
     for ( FloatingTableInfo & rInfo : rPendingFloatingTables )
     {
         rInfo.m_nBreakType = m_nBreakType;
         if ( FloatingTableConversion( rDM_Impl, rInfo ) )
         {
-            std::vector<css::uno::Any> aFramedRedlines = rDM_Impl.aFramedRedlines;
+            uno::Reference<text::XTextAppendAndConvert> xBodyText(
+                            rInfo.m_bConvertToFloatingInFootnote
+                                ? rInfo.m_xStart->getText()
+                                : rDM_Impl.GetBodyText(), uno::UNO_QUERY );
+            std::deque<css::uno::Any> aFramedRedlines = rDM_Impl.m_aStoredRedlines[StoredRedlines::FRAME];
             try
             {
                 // convert redline ranges to cursor movement and character length
@@ -1708,7 +1731,7 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
         }
 
         sal_Int32 nCharWidth = 423; //240 twip/ 12 pt
-        const StyleSheetEntryPtr pEntry = rDM_Impl.GetStyleSheetTable()->FindStyleSheetByConvertedStyleName( "Standard" );
+        const StyleSheetEntryPtr pEntry = rDM_Impl.GetStyleSheetTable()->FindStyleSheetByConvertedStyleName( u"Standard" );
         if ( pEntry )
         {
             std::optional< PropertyMap::Property > pPropHeight = pEntry->pProperties->getProperty( PROP_CHAR_HEIGHT_ASIAN );
@@ -1849,7 +1872,7 @@ void SectionPropertyMap::CloseSectionGroup( DomainMapper_Impl& rDM_Impl )
         }
         catch ( const uno::Exception& )
         {
-            OSL_FAIL( "Exception in SectionPropertyMap::CloseSectionGroup" );
+            TOOLS_WARN_EXCEPTION( "writerfilter", "SectionPropertyMap::CloseSectionGroup" );
         }
     }
 
@@ -1999,7 +2022,7 @@ void SectionPropertyMap::ApplyProperties_( const uno::Reference< beans::XPropert
         }
         catch ( const uno::Exception& )
         {
-            OSL_FAIL( "Exception in SectionPropertyMap::ApplyProperties_" );
+            TOOLS_WARN_EXCEPTION( "writerfilter", "SectionPropertyMap::ApplyProperties_" );
         }
     }
     for ( size_t i = 0; i < vNames.size(); ++i )
@@ -2011,7 +2034,7 @@ void SectionPropertyMap::ApplyProperties_( const uno::Reference< beans::XPropert
         }
         catch ( const uno::Exception& )
         {
-            OSL_FAIL( "Exception in SectionPropertyMap::ApplyProperties_" );
+            TOOLS_WARN_EXCEPTION( "writerfilter", "SectionPropertyMap::ApplyProperties_" );
         }
     }
 }
