@@ -31,11 +31,13 @@ WpftDrawFilterTest::WpftDrawFilterTest()
 void WpftDrawFilterTest::test()
 {
     const writerperfect::test::WpftOptionalMap_t aMWAWOptional{
+        { "Canvas_2.hqx", REQUIRE_MWAW_VERSION(0, 3, 17) },
         { "ClarisDraw.hqx", REQUIRE_MWAW_VERSION(0, 3, 5) },
         { "CorelPainter_3_win.rif", REQUIRE_MWAW_VERSION(0, 3, 15) },
         { "CorelPainter_10", REQUIRE_MWAW_VERSION(0, 3, 15) },
         { "CricketDraw_1.0.hqx", REQUIRE_MWAW_VERSION(0, 3, 8) },
         { "CricketDraw_1.1.hqx", REQUIRE_MWAW_VERSION(0, 3, 8) },
+        { "DrawingTable_1.hqx", REQUIRE_MWAW_VERSION(0, 3, 17) },
         { "FreeHand_1.0.hqx", REQUIRE_MWAW_VERSION(0, 3, 8) },
         { "FreeHand_2.0.hqx", REQUIRE_MWAW_VERSION(0, 3, 8) },
         { "MacDraft_1.0.hqx", REQUIRE_MWAW_VERSION(0, 3, 5) },
@@ -49,23 +51,24 @@ void WpftDrawFilterTest::test()
         { "Draw_3.1.sda", REQUIRE_STAROFFICE_VERSION(0, 0, 1) },
     };
 
-    doTest("com.sun.star.comp.Draw.CDRImportFilter", "/writerperfect/qa/unit/data/draw/libcdr/");
+    doTest("com.sun.star.comp.Draw.CDRImportFilter", u"/writerperfect/qa/unit/data/draw/libcdr/");
     doTest("com.sun.star.comp.Draw.CMXImportFilter",
-           "/writerperfect/qa/unit/data/draw/libcdr-cmx/");
+           u"/writerperfect/qa/unit/data/draw/libcdr-cmx/");
     doTest("com.sun.star.comp.Draw.FreehandImportFilter",
-           "/writerperfect/qa/unit/data/draw/libfreehand/");
+           u"/writerperfect/qa/unit/data/draw/libfreehand/");
     doTest("com.sun.star.comp.Draw.MSPUBImportFilter",
-           "/writerperfect/qa/unit/data/draw/libmspub/");
+           u"/writerperfect/qa/unit/data/draw/libmspub/");
     doTest("com.sun.star.comp.Draw.MWAWDrawImportFilter",
-           "/writerperfect/qa/unit/data/draw/libmwaw/", aMWAWOptional);
+           u"/writerperfect/qa/unit/data/draw/libmwaw/", aMWAWOptional);
     doTest("com.sun.star.comp.Draw.VisioImportFilter",
-           "/writerperfect/qa/unit/data/draw/libvisio/");
-    doTest("com.sun.star.comp.Draw.WPGImportFilter", "/writerperfect/qa/unit/data/draw/libwpg/");
+           u"/writerperfect/qa/unit/data/draw/libvisio/");
+    doTest("com.sun.star.comp.Draw.WPGImportFilter", u"/writerperfect/qa/unit/data/draw/libwpg/");
     doTest("org.libreoffice.comp.Draw.PageMakerImportFilter",
-           "/writerperfect/qa/unit/data/draw/libpagemaker/");
+           u"/writerperfect/qa/unit/data/draw/libpagemaker/");
     doTest("org.libreoffice.comp.Draw.StarOfficeDrawImportFilter",
-           "/writerperfect/qa/unit/data/draw/libstaroffice/", aStarOfficeOptional);
-    doTest("org.libreoffice.comp.Draw.ZMFImportFilter", "/writerperfect/qa/unit/data/draw/libzmf/");
+           u"/writerperfect/qa/unit/data/draw/libstaroffice/", aStarOfficeOptional);
+    doTest("org.libreoffice.comp.Draw.ZMFImportFilter",
+           u"/writerperfect/qa/unit/data/draw/libzmf/");
 }
 
 CPPUNIT_TEST_SUITE_REGISTRATION(WpftDrawFilterTest);
