@@ -27,6 +27,7 @@
 #include <climits>
 #include <limits>
 #include <memory>
+#include <string_view>
 #include <unordered_map>
 #include <vector>
 
@@ -86,11 +87,11 @@ OUString lcl_normalizeSubStreamPath(const OUString& rPath)
 
 namespace
 {
-OUString concatPath(const OUString& lhs, const OUString& rhs)
+OUString concatPath(std::u16string_view lhs, const OUString& rhs)
 {
-    if (lhs.isEmpty())
+    if (lhs.empty())
         return rhs;
-    return lhs + "/" + rhs;
+    return OUString::Concat(lhs) + "/" + rhs;
 }
 
 struct OLEStreamData
@@ -142,7 +143,7 @@ struct OLEStorageImpl
     tools::SvRef<SotStorageStream> const& getStream(std::size_t nId);
 
 private:
-    void traverse(const tools::SvRef<SotStorage>& rStorage, const OUString& rPath);
+    void traverse(const tools::SvRef<SotStorage>& rStorage, std::u16string_view rPath);
 
     tools::SvRef<SotStorageStream> createStream(const OUString& rPath);
 
@@ -177,7 +178,7 @@ void OLEStorageImpl::initialize(std::unique_ptr<SvStream> pStream)
 
     mxRootStorage = new SotStorage(pStream.release(), true);
 
-    traverse(mxRootStorage, "");
+    traverse(mxRootStorage, u"");
 
     mbInitialized = true;
 }
@@ -209,7 +210,7 @@ tools::SvRef<SotStorageStream> const& OLEStorageImpl::getStream(const std::size_
     return maStreams[nId].stream;
 }
 
-void OLEStorageImpl::traverse(const tools::SvRef<SotStorage>& rStorage, const OUString& rPath)
+void OLEStorageImpl::traverse(const tools::SvRef<SotStorage>& rStorage, std::u16string_view rPath)
 {
     SvStorageInfoList infos;
 
@@ -623,7 +624,7 @@ bool WPXSvInputStreamImpl::existsSubStream(const char* const name)
     PositionHolder pos(mxSeekable);
     mxSeekable->seek(0);
 
-    const OUString aName(OStringToOUString(OString(name), RTL_TEXTENCODING_UTF8));
+    const OUString aName(OStringToOUString(std::string_view(name), RTL_TEXTENCODING_UTF8));
 
     if (isOLE())
     {
@@ -653,7 +654,7 @@ librevenge::RVNGInputStream* WPXSvInputStreamImpl::getSubStreamByName(const char
     PositionHolder pos(mxSeekable);
     mxSeekable->seek(0);
 
-    const OUString aName(OStringToOUString(OString(name), RTL_TEXTENCODING_UTF8));
+    const OUString aName(OStringToOUString(std::string_view(name), RTL_TEXTENCODING_UTF8));
 
     if (isOLE())
     {
@@ -775,14 +776,11 @@ bool WPXSvInputStreamImpl::isZip()
 
         try
         {
-            Sequence<Any> aArgs(1);
-            aArgs[0] <<= mxStream;
-
             const Reference<XComponentContext> xContext(comphelper::getProcessComponentContext(),
                                                         UNO_SET_THROW);
             const Reference<packages::zip::XZipFileAccess2> xZip(
                 xContext->getServiceManager()->createInstanceWithArgumentsAndContext(
-                    "com.sun.star.packages.zip.ZipFileAccess", aArgs, xContext),
+                    "com.sun.star.packages.zip.ZipFileAccess", { Any(mxStream) }, xContext),
                 UNO_QUERY_THROW);
             mpZipStorage.reset(new ZipStorageImpl(xZip));
         }
