@@ -386,8 +386,6 @@ namespace xmloff
 
     void OPropertyExport::exportRelativeTargetLocation(const OUString& _sPropertyName,CCAFlags _nProperty,bool _bAddType)
     {
-        DBG_CHECK_PROPERTY( _sPropertyName, OUString );
-
         Any aAny = m_xProps->getPropertyValue(_sPropertyName);
 
         OUString sTargetLocation;
@@ -402,6 +400,11 @@ namespace xmloff
             auto sURL = aAny.get<OUString>();
             sTargetLocation = m_rContext.getGlobalContext().AddEmbeddedObject(sURL);
         }
+        else
+        {
+            SAL_WARN("xmloff.forms", "OPropertyExport::exportRelativeTargetLocation: "
+                "Value of " << _sPropertyName << " not found!");
+        }
 
         if (!sTargetLocation.isEmpty())
         {
@@ -544,7 +547,7 @@ namespace xmloff
                 aBuffer.append(getINT64(_rValue));
                 break;
             case TypeClass_UNSIGNED_HYPER:
-                aBuffer.append(OUString::number(_rValue.get<sal_uInt64>()));
+                aBuffer.append(static_cast<sal_Int64>(_rValue.get<sal_uInt64>()));
                 break;
             case TypeClass_ENUM:
             {
