@@ -129,12 +129,10 @@ lcl_initDocumentProperties(SvXMLImport & rImport,
         uno::Reference<xml::dom::XSAXDocumentBuilder2> const& xDocBuilder,
         uno::Reference<document::XDocumentProperties> const& xDocProps)
 {
-    uno::Sequence< uno::Any > aSeq(1);
-    aSeq[0] <<= xDocBuilder->getDocument();
     uno::Reference< lang::XInitialization > const xInit(xDocProps,
         uno::UNO_QUERY_THROW);
     try {
-        xInit->initialize(aSeq);
+        xInit->initialize({ uno::Any(xDocBuilder->getDocument()) });
         rImport.SetStatistics(xDocProps->getDocumentStatistics());
         // convert all URLs from relative to absolute
         xDocProps->setTemplateURL(rImport.GetAbsoluteReference(
@@ -167,7 +165,7 @@ lcl_initGenerator(SvXMLImport & rImport,
         xPath->registerNS(GetXMLToken(XML_NP_META), GetXMLToken(XML_N_META));
 
         uno::Reference< xml::xpath::XXPathObject > const xObj(
-            xPath->eval(xDoc.get(), "string(/office:document-meta/office:meta/meta:generator)"),
+            xPath->eval(xDoc, "string(/office:document-meta/office:meta/meta:generator)"),
             uno::UNO_SET_THROW);
         OUString const value(xObj->getString());
         SvXMLMetaDocumentContext::setBuildId(value, rImport.getImportInfo());
@@ -244,15 +242,14 @@ void SvXMLMetaDocumentContext::setBuildId(OUString const& i_rBuildId, const uno:
             if ( nEnd != -1 )
             {
                 OUStringBuffer sBuffer(
-                    i_rBuildId.copy( nBegin+1, nEnd-nBegin-1 ) );
-                const OUString sBuildCompare(
-                     "$Build-"  );
+                    i_rBuildId.subView( nBegin+1, nEnd-nBegin-1 ) );
+                static const OUStringLiteral sBuildCompare(
+                     u"$Build-"  );
                 nBegin = i_rBuildId.indexOf( sBuildCompare, nEnd );
                 if ( nBegin != -1 )
                 {
                     sBuffer.append( '$' );
-                    sBuffer.append( std::u16string_view(i_rBuildId).substr(
-                        nBegin + sBuildCompare.getLength()) );
+                    sBuffer.append( i_rBuildId.subView(nBegin + sBuildCompare.getLength()) );
                     sBuildId = sBuffer.makeStringAndClear();
                 }
             }
@@ -306,7 +303,7 @@ void SvXMLMetaDocumentContext::setBuildId(OUString const& i_rBuildId, const uno:
     {
         if( xImportInfo.is() )
         {
-            const OUString aPropName("BuildId");
+            static const OUStringLiteral aPropName(u"BuildId");
             uno::Reference< beans::XPropertySetInfo > xSetInfo(
                 xImportInfo->getPropertySetInfo());
             if( xSetInfo.is() && xSetInfo->hasPropertyByName( aPropName ) )
