@@ -40,7 +40,7 @@ using namespace ::com::sun::star::xml::sax;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star;
 
-const char XMLN_VERSIONSLIST[] = "VersionList.xml";
+constexpr OUStringLiteral XMLN_VERSIONSLIST = u"VersionList.xml";
 
 XMLVersionListExport::XMLVersionListExport(
     const css::uno::Reference< css::uno::XComponentContext >& rContext,
@@ -108,7 +108,7 @@ XMLVersionListImport::XMLVersionListImport(
 {
 }
 
-XMLVersionListImport::~XMLVersionListImport() throw()
+XMLVersionListImport::~XMLVersionListImport() noexcept
 {}
 
 SvXMLImportContext *XMLVersionListImport::CreateFastContext( sal_Int32 nElement,
@@ -325,7 +325,7 @@ void SAL_CALL XMLVersionListPersistence::store( const uno::Reference< embed::XSt
 
         Reference< io::XOutputStream > xOut = xVerStream->getOutputStream();
         if ( !xOut.is() )
-            throw uno::RuntimeException(); // the stream was successfully opened for writing already
+            throw uno::RuntimeException("The stream was successfully opened for writing already!");
 
         xWriter->setOutputStream(xOut);
 
