@@ -273,7 +273,7 @@ SvXMLNumFmtExport::~SvXMLNumFmtExport()
 
 //  helper methods
 
-static OUString lcl_CreateStyleName( sal_Int32 nKey, sal_Int32 nPart, bool bDefPart, const OUString& rPrefix )
+static OUString lcl_CreateStyleName( sal_Int32 nKey, sal_Int32 nPart, bool bDefPart, std::u16string_view rPrefix )
 {
     OUStringBuffer aFmtName(10);
     aFmtName.append( rPrefix );
@@ -313,7 +313,7 @@ void SvXMLNumFmtExport::AddLanguageAttr_Impl( LanguageType nLang )
 
 //  methods to write individual elements within a format
 
-void SvXMLNumFmtExport::AddToTextElement_Impl( const OUString& rString )
+void SvXMLNumFmtExport::AddToTextElement_Impl( std::u16string_view rString )
 {
     //  append to sTextContent, write element in FinishTextElement_Impl
     //  to avoid several text elements following each other
@@ -899,7 +899,7 @@ bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
         //  text before currency symbol
         if ( nPos > 0 )
         {
-            AddToTextElement_Impl( rString.copy( 0, nPos ) );
+            AddToTextElement_Impl( rString.subView( 0, nPos ) );
         }
         //  currency symbol (empty string -> default)
         WriteCurrencyElement_Impl( "", "" );
@@ -908,7 +908,7 @@ bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
         //  text after currency symbol
         if ( nCont < nLength )
         {
-            AddToTextElement_Impl( rString.copy( nCont, nLength-nCont ) );
+            AddToTextElement_Impl( rString.subView( nCont, nLength-nCont ) );
         }
     }
     else
@@ -1268,6 +1268,8 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
         sal_Int32 nMinDecimals = nPrecision;
         OUString sCurrExt;
         OUString aCalendar;
+        bool bImplicitOtherCalendar = false;
+        bool bExplicitCalendar = false;
         sal_uInt16 nPos = 0;
         bool bEnd = false;
         while (!bEnd)
@@ -1336,7 +1338,10 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                 case NF_KEY_R:
                 case NF_KEY_RR:
                     if (aCalendar.isEmpty())
+                    {
                         aCalendar = lcl_GetDefaultCalendar( pFormatter, nLang );
+                        bImplicitOtherCalendar = true;
+                    }
                     break;
             }
             ++nPos;
@@ -1579,7 +1584,10 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
 
                 case NF_SYMBOLTYPE_CALENDAR:
                     if ( pElemStr )
+                    {
                         aCalendar = *pElemStr;
+                        bExplicitCalendar = true;
+                    }
                     break;
 
                 // date elements:
@@ -1615,7 +1623,8 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                         if ( nElemType == NF_KEY_NNNN )
                         {
                             //  write additional text element for separator
-                            pLocaleData->setLanguageTag( LanguageTag( nLang ) );
+                            pLocaleData.reset( new LocaleDataWrapper( pFormatter->GetComponentContext(),
+                                LanguageTag( nLang ) ) );
                             AddToTextElement_Impl( pLocaleData->getLongDateDayOfWeekSep() );
                         }
                     }
@@ -1640,10 +1649,16 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
                 case NF_KEY_R:      //! R acts as EE, no attribute available
                     {
                         //! distinguish EE and R
-                        //  calendar attribute for E and EE and R is set in first loop
+                        // Calendar attribute for E and EE and R is set in
+                        // first loop. If set and not an explicit calendar and
+                        // YY or YYYY is encountered, switch temporarily to
+                        // Gregorian.
                         bool bLong = ( nElemType == NF_KEY_YYYY || nElemType == NF_KEY_EEC ||
                                             nElemType == NF_KEY_R );
-                        WriteYearElement_Impl( aCalendar, ( bSystemDate ? bLongSysDate : bLong ) );
+                        WriteYearElement_Impl(
+                                ((bImplicitOtherCalendar && !bExplicitCalendar
+                                  && (nElemType == NF_KEY_YY || nElemType == NF_KEY_YYYY)) ? "gregorian" : aCalendar),
+                                (bSystemDate ? bLongSysDate : bLong));
                         bAnyContent = true;
                     }
                     break;
