@@ -43,6 +43,7 @@
 #include <xmloff/languagetagodf.hxx>
 
 #include <memory>
+#include <string_view>
 #include <vector>
 
 using namespace ::com::sun::star;
@@ -77,7 +78,7 @@ public:
 
     SvNumberFormatter*      GetNumberFormatter() const  { return pFormatter; }
     const LocaleDataWrapper&    GetLocaleData( LanguageType nLang );
-    sal_uInt32              GetKeyForName( const OUString& rName );
+    sal_uInt32              GetKeyForName( std::u16string_view rName );
     void                    AddKey( sal_uInt32 nKey, const OUString& rName, bool bRemoveAfterUse );
     void                    SetUsed( sal_uInt32 nKey );
     void                    RemoveVolatileFormats();
@@ -292,7 +293,7 @@ SvXMLNumImpData::SvXMLNumImpData(
     SAL_WARN_IF( !rxContext.is(), "xmloff", "got no service manager" );
 }
 
-sal_uInt32 SvXMLNumImpData::GetKeyForName( const OUString& rName )
+sal_uInt32 SvXMLNumImpData::GetKeyForName( std::u16string_view rName )
 {
     for (const auto& rObj : m_NameEntries)
     {
@@ -364,12 +365,10 @@ void SvXMLNumImpData::RemoveVolatileFormats()
 
 const LocaleDataWrapper& SvXMLNumImpData::GetLocaleData( LanguageType nLang )
 {
-    if ( !pLocaleData )
+    if ( !pLocaleData || pLocaleData->getLanguageTag() != LanguageTag(nLang) )
         pLocaleData = std::make_unique<LocaleDataWrapper>(
                pFormatter ? pFormatter->GetComponentContext() : m_xContext,
             LanguageTag( nLang ) );
-    else
-        pLocaleData->setLanguageTag( LanguageTag( nLang ) );
     return *pLocaleData;
 }
 
@@ -421,12 +420,11 @@ SvXMLNumFmtPropContext::SvXMLNumFmtPropContext( SvXMLImport& rImport,
 {
     for( auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ) )
     {
-        OUString sValue = aIter.toString();
         switch ( aIter.getToken())
         {
             case XML_ELEMENT(FO, XML_COLOR):
             case XML_ELEMENT(FO_COMPAT, XML_COLOR):
-                bColSet = ::sax::Converter::convertColor( m_nColor, sValue );
+                bColSet = ::sax::Converter::convertColor( m_nColor, aIter.toString() );
                 break;
             default:
                 XMLOFF_WARN_UNKNOWN("xmloff", aIter);
@@ -456,10 +454,9 @@ SvXMLNumFmtEmbeddedTextContext::SvXMLNumFmtEmbeddedTextContext( SvXMLImport& rIm
 
     for( auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ) )
     {
-        OUString sValue = aIter.toString();
         if ( aIter.getToken() == XML_ELEMENT(NUMBER, XML_POSITION) )
         {
-            if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+            if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                 nTextPosition = nAttrVal;
         }
         else
@@ -655,11 +652,10 @@ SvXMLNumFmtElementContext::SvXMLNumFmtElementContext( SvXMLImport& rImport,
 
     for( auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ) )
     {
-        OUString sValue = aIter.toString();
         switch (aIter.getToken())
         {
             case XML_ELEMENT(NUMBER, XML_DECIMAL_PLACES):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                 {
                     // fdo#58539 & gnome#627420: limit number of digits during import
                     aNumInfo.nDecimals = std::min<sal_Int32>(nAttrVal, NF_MAX_FORMAT_SYMBOLS);
@@ -667,61 +663,61 @@ SvXMLNumFmtElementContext::SvXMLNumFmtElementContext( SvXMLImport& rImport,
                 break;
             case XML_ELEMENT(LO_EXT, XML_MIN_DECIMAL_PLACES):
             case XML_ELEMENT(NUMBER, XML_MIN_DECIMAL_PLACES):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nMinDecimalDigits = nAttrVal;
                 break;
             case XML_ELEMENT(NUMBER, XML_MIN_INTEGER_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nInteger = nAttrVal;
                 break;
             case XML_ELEMENT(NUMBER, XML_GROUPING):
-                if (::sax::Converter::convertBool( bAttrBool, sValue ))
+                if (::sax::Converter::convertBool( bAttrBool, aIter.toView() ))
                     aNumInfo.bGrouping = bAttrBool;
                 break;
             case XML_ELEMENT(NUMBER, XML_DISPLAY_FACTOR):
-                if (::sax::Converter::convertDouble( fAttrDouble, sValue ))
+                if (::sax::Converter::convertDouble( fAttrDouble, aIter.toView() ))
                     aNumInfo.fDisplayFactor = fAttrDouble;
                 break;
             case XML_ELEMENT(NUMBER, XML_DECIMAL_REPLACEMENT):
-                if ( sValue == " " )
+                if ( aIter.toView() == " " )
                 {
                     aNumInfo.bDecAlign = true; // space replacement for "?"
                     bVarDecimals = true;
                 }
                 else
-                    if ( sValue.isEmpty() )
+                    if ( aIter.isEmpty() )
                         bVarDecimals = true;   // empty replacement string: variable decimals
                     else                                // all other strings
                         aNumInfo.bDecReplace = true;    // decimal replacement with dashes
                 break;
             case XML_ELEMENT(NUMBER, XML_MIN_EXPONENT_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nExpDigits = std::min<sal_Int32>(nAttrVal, NF_MAX_FORMAT_SYMBOLS);
                 break;
             case XML_ELEMENT(NUMBER, XML_EXPONENT_INTERVAL):
             case XML_ELEMENT(LO_EXT, XML_EXPONENT_INTERVAL):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nExpInterval = nAttrVal;
                 break;
             case XML_ELEMENT(NUMBER, XML_FORCED_EXPONENT_SIGN):
             case XML_ELEMENT(LO_EXT, XML_FORCED_EXPONENT_SIGN):
-                if (::sax::Converter::convertBool( bAttrBool, sValue ))
+                if (::sax::Converter::convertBool( bAttrBool, aIter.toView() ))
                     aNumInfo.bExpSign = bAttrBool;
                 break;
             case XML_ELEMENT(NUMBER, XML_MIN_NUMERATOR_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nMinNumerDigits = nAttrVal;
                 break;
             case XML_ELEMENT(NUMBER, XML_MIN_DENOMINATOR_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nMinDenomDigits = nAttrVal;
                 break;
             case XML_ELEMENT(LO_EXT, XML_MAX_NUMERATOR_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 1 ))  // at least one '#'
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 1 ))  // at least one '#'
                     aNumInfo.nMaxNumerDigits = nAttrVal;
                 break;
             case XML_ELEMENT(NUMBER, XML_DENOMINATOR_VALUE):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 1 )) // 0 is not valid
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 1 )) // 0 is not valid
                 {
                     aNumInfo.nFracDenominator = nAttrVal;
                     bIsMaxDenominator = false;
@@ -729,7 +725,7 @@ SvXMLNumFmtElementContext::SvXMLNumFmtElementContext( SvXMLImport& rImport,
                 break;
             case XML_ELEMENT(NUMBER, XML_MAX_DENOMINATOR_VALUE):  // part of ODF 1.3
             case XML_ELEMENT(LO_EXT, XML_MAX_DENOMINATOR_VALUE):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 1 ) && aNumInfo.nFracDenominator <= 0)
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 1 ) && aNumInfo.nFracDenominator <= 0)
                 {   // if denominator value not yet defined
                     aNumInfo.nFracDenominator = nAttrVal;
                     bIsMaxDenominator = true;
@@ -737,39 +733,39 @@ SvXMLNumFmtElementContext::SvXMLNumFmtElementContext( SvXMLImport& rImport,
                 break;
             case XML_ELEMENT(LO_EXT, XML_ZEROS_NUMERATOR_DIGITS):
             case XML_ELEMENT(NUMBER, XML_ZEROS_NUMERATOR_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nZerosNumerDigits = nAttrVal;
                 break;
             case XML_ELEMENT(NUMBER, XML_ZEROS_DENOMINATOR_DIGITS):
             case XML_ELEMENT(LO_EXT, XML_ZEROS_DENOMINATOR_DIGITS):
-                if (::sax::Converter::convertNumber( nAttrVal, sValue, 0 ))
+                if (::sax::Converter::convertNumber( nAttrVal, aIter.toView(), 0 ))
                     aNumInfo.nZerosDenomDigits = nAttrVal;
                  break;
             case XML_ELEMENT(NUMBER, XML_INTEGER_FRACTION_DELIMITER):
             case XML_ELEMENT(LO_EXT, XML_INTEGER_FRACTION_DELIMITER):
-                aNumInfo.aIntegerFractionDelimiter = sValue;
+                aNumInfo.aIntegerFractionDelimiter = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_RFC_LANGUAGE_TAG):
-                aLanguageTagODF.maRfcLanguageTag = sValue;
+                aLanguageTagODF.maRfcLanguageTag = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_LANGUAGE):
-                aLanguageTagODF.maLanguage = sValue;
+                aLanguageTagODF.maLanguage = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_SCRIPT):
-                aLanguageTagODF.maScript = sValue;
+                aLanguageTagODF.maScript = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_COUNTRY):
-                aLanguageTagODF.maCountry = sValue;
+                aLanguageTagODF.maCountry = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_STYLE):
-                SvXMLUnitConverter::convertEnum( bLong, sValue, aStyleValueMap );
+                SvXMLUnitConverter::convertEnum( bLong, aIter.toView(), aStyleValueMap );
                 break;
             case XML_ELEMENT(NUMBER, XML_TEXTUAL):
-                if (::sax::Converter::convertBool( bAttrBool, sValue ))
+                if (::sax::Converter::convertBool( bAttrBool, aIter.toView() ))
                     bTextual = bAttrBool;
                 break;
             case XML_ELEMENT(NUMBER, XML_CALENDAR):
-                sCalendar = sValue;
+                sCalendar = aIter.toString();
                 break;
             default:
                 XMLOFF_WARN_UNKNOWN("xmloff", aIter);
@@ -931,24 +927,17 @@ void SvXMLNumFmtElementContext::endFastElement(sal_Int32 )
                 // Do not replace for default calendar.
                 // Also replace Y by E if we're switching to the secondary
                 // calendar of a locale if it is known to implicitly use E.
-                bool bImplicitEC = (!sCalendar.isEmpty() &&
-                        rParent.GetLocaleData().doesSecondaryCalendarUseEC( sCalendar));
-                if (bImplicitEC || (!sCalendar.isEmpty() && rParent.HasEra()))
+                rParent.UpdateCalendar( sCalendar);
+                const SvXMLNumFormatContext::ImplicitCalendar eCal = rParent.GetImplicitCalendarState();
+                if (eCal == SvXMLNumFormatContext::ImplicitCalendar::SECONDARY
+                        || eCal == SvXMLNumFormatContext::ImplicitCalendar::SECONDARY_FROM_OTHER)
                 {
-                    // If E or EE is the first format keyword, passing
-                    // bImplicitEC=true suppresses the superfluous calendar
-                    // modifier for this format. This does not help for
-                    // something like [~cal]DD/MM/EE but so far only YMD order
-                    // is used with such calendars. Live with the modifier if
-                    // other keywords precede this.
-                    rParent.UpdateCalendar( sCalendar, bImplicitEC);
                     rParent.AddNfKeyword(
                             sal::static_int_cast< sal_uInt16 >(
                                 bEffLong ? NF_KEY_EEC : NF_KEY_EC ) );
                 }
                 else
                 {
-                    rParent.UpdateCalendar( sCalendar );
                     rParent.AddNfKeyword(
                             sal::static_int_cast< sal_uInt16 >(
                                 bEffLong ? NF_KEY_YYYY : NF_KEY_YY ) );
@@ -964,11 +953,26 @@ void SvXMLNumFmtElementContext::endFastElement(sal_Int32 )
             //  HasEra flag is set
             break;
         case SvXMLStyleTokens::DayOfWeek:
-            rParent.UpdateCalendar( sCalendar );
 //! I18N doesn't provide SYSTEM or extended date information yet
-            rParent.AddNfKeyword(
-                sal::static_int_cast< sal_uInt16 >(
-                    bEffLong ? NF_KEY_NNNN : NF_KEY_NN ) );
+            {
+                // Implicit secondary calendar uses A keyword, default and
+                // explicit calendar N keyword.
+                rParent.UpdateCalendar( sCalendar);
+                const SvXMLNumFormatContext::ImplicitCalendar eCal = rParent.GetImplicitCalendarState();
+                if (eCal == SvXMLNumFormatContext::ImplicitCalendar::SECONDARY
+                        || eCal == SvXMLNumFormatContext::ImplicitCalendar::SECONDARY_FROM_OTHER)
+                {
+                    rParent.AddNfKeyword(
+                            sal::static_int_cast< sal_uInt16 >(
+                                bEffLong ? NF_KEY_AAAA : NF_KEY_AAA ) );
+                }
+                else
+                {
+                    rParent.AddNfKeyword(
+                            sal::static_int_cast< sal_uInt16 >(
+                                bEffLong ? NF_KEY_NNNN : NF_KEY_NN ) );
+                }
+            }
             break;
         case SvXMLStyleTokens::WeekOfYear:
             rParent.UpdateCalendar( sCalendar );
@@ -1066,9 +1070,9 @@ void SvXMLNumFmtElementContext::endFastElement(sal_Int32 )
                 rParent.AddNumber( aNumInfo );      // simple number
 
                 if ( aNumInfo.bExpSign )
-                    rParent.AddToCode( "E+" );
+                    rParent.AddToCode( u"E+" );
                 else
-                    rParent.AddToCode( "E" );
+                    rParent.AddToCode( u"E" );
                 for (sal_Int32 i=0; i<aNumInfo.nExpDigits; i++)
                 {
                     rParent.AddToCode( '0' );
@@ -1119,6 +1123,7 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
     aMyConditions(),
     nType( nNewType ),
     nKey(-1),
+    eImplicitCalendar(ImplicitCalendar::DEFAULT),
     nFormatLang( LANGUAGE_SYSTEM ),
     bAutoOrder( false ),
     bFromSystem( false ),
@@ -1127,7 +1132,6 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
     bAutoInt( false ),
     bHasExtraText( false ),
     bHasLongDoW( false ),
-    bHasEra( false ),
     bHasDateTime( false ),
     bRemoveAfterUse( false ),
     eDateDOW( XML_DEA_NONE ),
@@ -1146,59 +1150,58 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
 
     for( auto &aIter : sax_fastparser::castToFastAttributeList( xAttrList ) )
     {
-        OUString sValue = aIter.toString();
         switch (aIter.getToken())
         {
         //  attributes for a style
             case XML_ELEMENT(STYLE, XML_NAME):
                 break;
             case XML_ELEMENT(NUMBER, XML_RFC_LANGUAGE_TAG):
-                aLanguageTagODF.maRfcLanguageTag = sValue;
+                aLanguageTagODF.maRfcLanguageTag = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_LANGUAGE):
-                aLanguageTagODF.maLanguage = sValue;
+                aLanguageTagODF.maLanguage = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_SCRIPT):
-                aLanguageTagODF.maScript = sValue;
+                aLanguageTagODF.maScript = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_COUNTRY):
-                aLanguageTagODF.maCountry = sValue;
+                aLanguageTagODF.maCountry = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_TITLE):
-                sFormatTitle = sValue;
+                sFormatTitle = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_AUTOMATIC_ORDER):
-                if (::sax::Converter::convertBool( bAttrBool, sValue ))
+                if (::sax::Converter::convertBool( bAttrBool, aIter.toView() ))
                     bAutoOrder = bAttrBool;
                 break;
             case XML_ELEMENT(NUMBER, XML_FORMAT_SOURCE):
-                SvXMLUnitConverter::convertEnum( bFromSystem, sValue, aFormatSourceMap );
+                SvXMLUnitConverter::convertEnum( bFromSystem, aIter.toView(), aFormatSourceMap );
                 break;
             case XML_ELEMENT(NUMBER, XML_TRUNCATE_ON_OVERFLOW):
-                if (::sax::Converter::convertBool( bAttrBool, sValue ))
+                if (::sax::Converter::convertBool( bAttrBool, aIter.toView() ))
                     bTruncate = bAttrBool;
                 break;
             case XML_ELEMENT(STYLE, XML_VOLATILE):
                 //  volatile formats can be removed after importing
                 //  if not used in other styles
-                if (::sax::Converter::convertBool( bAttrBool, sValue ))
+                if (::sax::Converter::convertBool( bAttrBool, aIter.toView() ))
                     bRemoveAfterUse = bAttrBool;
                 break;
             case XML_ELEMENT(NUMBER, XML_TRANSLITERATION_FORMAT):
-                aNatNumAttr.Format = sValue;
+                aNatNumAttr.Format = aIter.toString();
                 break;
             case XML_ELEMENT(LO_EXT, XML_TRANSLITERATION_SPELLOUT):
             case XML_ELEMENT(NUMBER, XML_TRANSLITERATION_SPELLOUT):
-                aSpellout = sValue;
+                aSpellout = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_TRANSLITERATION_LANGUAGE):
-                aNatNumAttr.Locale.Language = sValue;
+                aNatNumAttr.Locale.Language = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_TRANSLITERATION_COUNTRY):
-                aNatNumAttr.Locale.Country = sValue;
+                aNatNumAttr.Locale.Country = aIter.toString();
                 break;
             case XML_ELEMENT(NUMBER, XML_TRANSLITERATION_STYLE):
-                aNatNumAttr.Style = sValue;
+                aNatNumAttr.Style = aIter.toString();
                 break;
             default:
                 XMLOFF_WARN_UNKNOWN("xmloff", aIter);
@@ -1216,7 +1219,7 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
         return;
 
     LanguageTag aLanguageTag( OUString(), aNatNumAttr.Locale.Language,
-                OUString(), aNatNumAttr.Locale.Country);
+                std::u16string_view(), aNatNumAttr.Locale.Country);
     aNatNumAttr.Locale = aLanguageTag.getLocale( false);
 
     // NatNum12 spell out formula (cardinal, ordinal, ordinal-feminine etc.)
@@ -1256,6 +1259,7 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
     aMyConditions(),
     nType( SvXMLStylesTokens::NUMBER_STYLE ),
     nKey(nTempKey),
+    eImplicitCalendar(ImplicitCalendar::DEFAULT),
     nFormatLang( nLang ),
     bAutoOrder( false ),
     bFromSystem( false ),
@@ -1264,7 +1268,6 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
     bAutoInt( false ),
     bHasExtraText( false ),
     bHasLongDoW( false ),
-    bHasEra( false ),
     bHasDateTime( false ),
     bRemoveAfterUse( false ),
     eDateDOW( XML_DEA_NONE ),
@@ -1276,7 +1279,7 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
     eDateSecs( XML_DEA_NONE ),
     bDateNoDefault( false )
 {
-    SetAttribute(XML_NAMESPACE_STYLE, GetXMLToken(XML_NAME), rName);
+    SetAttribute(XML_ELEMENT(STYLE, XML_NAME), rName);
 }
 
 SvXMLNumFormatContext::~SvXMLNumFormatContext()
@@ -1624,7 +1627,7 @@ void SvXMLNumFormatContext::AddToCode( sal_Unicode c )
     bHasExtraText = true;
 }
 
-void SvXMLNumFormatContext::AddToCode( const OUString& rString )
+void SvXMLNumFormatContext::AddToCode( std::u16string_view rString )
 {
     aFormatCode.append( rString );
     bHasExtraText = true;
@@ -1762,7 +1765,7 @@ void SvXMLNumFormatContext::AddNumber( const SvXMLNumberInfo& rInfo )
         }
     }
 
-    aFormatCode.append( aNumStr.makeStringAndClear() );
+    aFormatCode.append( aNumStr );
 
     if ( ( rInfo.bDecReplace || rInfo.nMinDecimalDigits < rInfo.nDecimals ) && nPrec )     // add decimal replacement (dashes)
     {
@@ -1835,9 +1838,9 @@ void SvXMLNumFormatContext::AddCurrency( const OUString& rContent, LanguageType
                 //  remove both quotes from aFormatCode
                 OUString aOld = aFormatCode.makeStringAndClear();
                 if ( nFirst > 0 )
-                    aFormatCode.append( aOld.copy( 0, nFirst ) );
+                    aFormatCode.append( aOld.subView( 0, nFirst ) );
                 if ( nLength > nFirst + 2 )
-                    aFormatCode.append( aOld.copy( nFirst + 1, nLength - nFirst - 2 ) );
+                    aFormatCode.append( aOld.subView( nFirst + 1, nLength - nFirst - 2 ) );
             }
         }
     }
@@ -1852,7 +1855,7 @@ void SvXMLNumFormatContext::AddCurrency( const OUString& rContent, LanguageType
         if ( nLang != LANGUAGE_SYSTEM )
         {
             //  '-' sign and language code in hex:
-            aFormatCode.append("-").append(OUString(OUString::number(sal_uInt16(nLang), 16)).toAsciiUpperCase());
+            aFormatCode.append("-" + OUString(OUString::number(sal_uInt16(nLang), 16)).toAsciiUpperCase());
         }
 
         aFormatCode.append( ']' );    // end of "new" currency symbol
@@ -1865,9 +1868,6 @@ void SvXMLNumFormatContext::AddNfKeyword( sal_uInt16 nIndex )
     if (!pFormatter)
         return;
 
-    if ( nIndex == NF_KEY_G || nIndex == NF_KEY_GG || nIndex == NF_KEY_GGG )
-        bHasEra = true;
-
     if ( nIndex == NF_KEY_NNNN )
     {
         nIndex = NF_KEY_NNN;
@@ -1883,7 +1883,7 @@ void SvXMLNumFormatContext::AddNfKeyword( sal_uInt16 nIndex )
         if ( !bTruncate && !bHasDateTime )
         {
             //  with truncate-on-overflow = false, add "[]" to first time part
-            aFormatCode.append("[").append(sKeyword).append("]");
+            aFormatCode.append("[" + sKeyword + "]");
         }
         else
         {
@@ -2009,7 +2009,7 @@ void SvXMLNumFormatContext::AddCondition( const sal_Int32 nIndex )
                 sRealCond = sRealCond.replaceAt( nPos, 1, rDecSep );
             }
         }
-        aConditions.append("[").append(sRealCond).append("]");
+        aConditions.append("[" + sRealCond + "]");
     }
 
     const SvNumberformat* pFormat = pFormatter->GetEntry(l_nKey);
@@ -2049,17 +2049,69 @@ void SvXMLNumFormatContext::AddColor( Color const nColor )
     }
 }
 
-void SvXMLNumFormatContext::UpdateCalendar( const OUString& rNewCalendar, bool bImplicitSecondaryCalendarEC )
+void SvXMLNumFormatContext::UpdateCalendar( const OUString& rNewCalendar )
 {
     if ( rNewCalendar != sCalendar )
     {
-        sCalendar = rNewCalendar;
-        if ( !sCalendar.isEmpty() && !bImplicitSecondaryCalendarEC )
+        if (rNewCalendar.isEmpty() || rNewCalendar == aImplicitCalendar[0])
         {
-            aFormatCode.append( "[~" );            // intro for calendar code
-            aFormatCode.append( sCalendar );
-            aFormatCode.append( ']' );    // end of calendar code
+            eImplicitCalendar = (eImplicitCalendar == ImplicitCalendar::OTHER ?
+                    ImplicitCalendar::DEFAULT_FROM_OTHER : ImplicitCalendar::DEFAULT);
         }
+        else if (aImplicitCalendar[0].isEmpty() && rNewCalendar == GetLocaleData().getDefaultCalendar()->Name)
+        {
+            eImplicitCalendar = (eImplicitCalendar == ImplicitCalendar::OTHER ?
+                    ImplicitCalendar::DEFAULT_FROM_OTHER : ImplicitCalendar::DEFAULT);
+            aImplicitCalendar[0] = rNewCalendar;
+        }
+        else if (rNewCalendar == aImplicitCalendar[1])
+        {
+            eImplicitCalendar = (eImplicitCalendar == ImplicitCalendar::OTHER ?
+                    ImplicitCalendar::SECONDARY_FROM_OTHER : ImplicitCalendar::SECONDARY);
+        }
+        else if (aImplicitCalendar[1].isEmpty() && GetLocaleData().doesSecondaryCalendarUseEC( rNewCalendar))
+        {
+            eImplicitCalendar = (eImplicitCalendar == ImplicitCalendar::OTHER ?
+                    ImplicitCalendar::SECONDARY_FROM_OTHER : ImplicitCalendar::SECONDARY);
+            aImplicitCalendar[1] = rNewCalendar;
+        }
+        else
+        {
+            eImplicitCalendar = ImplicitCalendar::OTHER;
+        }
+
+        if (eImplicitCalendar != ImplicitCalendar::DEFAULT && eImplicitCalendar != ImplicitCalendar::SECONDARY)
+        {
+            // A switch from empty default calendar to named default calendar or
+            // vice versa is not a switch.
+            bool bSameDefault = false;
+            if (sCalendar.isEmpty() || rNewCalendar.isEmpty())
+            {
+                // As both are not equal, only one can be empty here, the other
+                // can not.
+                const OUString& rDefaultCalendar = GetLocaleData().getDefaultCalendar()->Name;
+                // So if one is the named default calendar the other is the
+                // empty default calendar.
+                bSameDefault = (rNewCalendar == rDefaultCalendar || sCalendar == rDefaultCalendar);
+            }
+            if (!bSameDefault)
+            {
+                aFormatCode.append( "[~" );   // intro for calendar code
+                if (rNewCalendar.isEmpty())
+                {
+                    // Empty calendar name here means switching to default calendar
+                    // from a different calendar. Needs to be explicitly stated in
+                    // format code.
+                    aFormatCode.append( GetLocaleData().getDefaultCalendar()->Name );
+                }
+                else
+                {
+                    aFormatCode.append( rNewCalendar );
+                }
+                aFormatCode.append( ']' );    // end of calendar code
+            }
+        }
+        sCalendar = rNewCalendar;
     }
 }
 
