@@ -53,14 +53,12 @@ using ::com::sun::star::container::XIndexReplace;
 XMLIndexTemplateContext::XMLIndexTemplateContext(
     SvXMLImport& rImport,
     Reference<XPropertySet> & rPropSet,
-    sal_uInt16 nPrfx,
-    const OUString& rLocalName,
     const SvXMLEnumMapEntry<sal_uInt16>* pLevelNameMap,
     enum XMLTokenEnum eLevelAttrName,
     const char** pLevelStylePropMap,
     const bool* pAllowedTokenTypes,
     bool bT )
-:   SvXMLImportContext(rImport, nPrfx, rLocalName)
+:   SvXMLImportContext(rImport)
 ,   pOutlineLevelNameMap(pLevelNameMap)
 ,   eOutlineLevelAttrName(eLevelAttrName)
 ,   pOutlineLevelStylePropMap(pLevelStylePropMap)
@@ -97,44 +95,30 @@ void XMLIndexTemplateContext::addTemplateEntry(
 }
 
 
-void XMLIndexTemplateContext::StartElement(
-        const Reference<XAttributeList> & xAttrList)
+void XMLIndexTemplateContext::startFastElement(
+    sal_Int32 /*nElement*/,
+    const css::uno::Reference< css::xml::sax::XFastAttributeList >& xAttrList )
 {
     // process two attributes: style-name, outline-level
-    sal_Int16 nLength = xAttrList->getLength();
-    for(sal_Int16 nAttr = 0; nAttr < nLength; nAttr++)
+    for( auto& aIter : sax_fastparser::castToFastAttributeList(xAttrList) )
     {
-        OUString sLocalName;
-        sal_uInt16 nPrefix = GetImport().GetNamespaceMap().
-            GetKeyByAttrName( xAttrList->getNameByIndex(nAttr),
-                              &sLocalName );
-        if (XML_NAMESPACE_TEXT == nPrefix)
+        if(aIter.getToken() == XML_ELEMENT(TEXT, XML_STYLE_NAME))
         {
-            if ( IsXMLToken( sLocalName, XML_STYLE_NAME ) )
+            // style name
+            sStyleName = aIter.toString();
+            bStyleNameOK = true;
+        }
+        else if (aIter.getToken() == XML_ELEMENT(TEXT, eOutlineLevelAttrName))
+        {
+            // we have an attr name! Then see if we have the attr, too.
+            // outline level
+            sal_uInt16 nTmp;
+            if (SvXMLUnitConverter::convertEnum(nTmp, aIter.toView(), pOutlineLevelNameMap))
             {
-                // style name
-                sStyleName = xAttrList->getValueByIndex(nAttr);
-                bStyleNameOK = true;
+                nOutlineLevel = nTmp;
+                bOutlineLevelOK = true;
             }
-            else if (eOutlineLevelAttrName != XML_TOKEN_INVALID)
-            {
-                // we have an attr name! Then see if we have the attr, too.
-                if (IsXMLToken(sLocalName, eOutlineLevelAttrName))
-                {
-                    // outline level
-                    sal_uInt16 nTmp;
-                    if (SvXMLUnitConverter::convertEnum(
-                        nTmp, xAttrList->getValueByIndex(nAttr),
-                        pOutlineLevelNameMap))
-                    {
-                        nOutlineLevel = nTmp;
-                        bOutlineLevelOK = true;
-                    }
-                    // else: illegal value -> ignore
-                }
-                // else: unknown attribute -> ignore
-            }
-            // else: we don't care about outline-level -> ignore
+            // else: illegal value -> ignore
         }
         // else: attribute not in text namespace -> ignore
     }
@@ -214,17 +198,16 @@ SvXMLEnumMapEntry<TemplateTokenType> const aTemplateTokenTypeMap[] =
     { XML_TOKEN_INVALID, TemplateTokenType(0) }
 };
 
-SvXMLImportContextRef XMLIndexTemplateContext::CreateChildContext(
-    sal_uInt16 nPrefix,
-    const OUString& rLocalName,
-    const Reference<XAttributeList> & /*xAttrList*/ )
+css::uno::Reference< css::xml::sax::XFastContextHandler > XMLIndexTemplateContext::createFastChildContext(
+    sal_Int32 nElement,
+    const css::uno::Reference< css::xml::sax::XFastAttributeList >& )
 {
     SvXMLImportContext* pContext = nullptr;
 
-    if (XML_NAMESPACE_TEXT == nPrefix || XML_NAMESPACE_LO_EXT == nPrefix)
+    if (IsTokenInNamespace(nElement, XML_NAMESPACE_TEXT) || IsTokenInNamespace(nElement, XML_NAMESPACE_LO_EXT))
     {
         TemplateTokenType nToken;
-        if (SvXMLUnitConverter::convertEnum(nToken, rLocalName,
+        if (SvXMLUnitConverter::convertEnum(nToken, SvXMLImport::getNameFromToken(nElement),
                                             aTemplateTokenTypeMap))
         {
             // can this index accept this kind of token?
@@ -234,46 +217,42 @@ SvXMLImportContextRef XMLIndexTemplateContext::CreateChildContext(
                 {
                     case XML_TOK_INDEX_TYPE_ENTRY_TEXT:
                         pContext = new XMLIndexSimpleEntryContext(
-                            GetImport(), "TokenEntryText", *this,
-                            nPrefix, rLocalName);
+                            GetImport(), "TokenEntryText", *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_PAGE_NUMBER:
                         pContext = new XMLIndexSimpleEntryContext(
-                            GetImport(), "TokenPageNumber", *this,
-                            nPrefix, rLocalName);
+                            GetImport(), "TokenPageNumber", *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_LINK_START:
                         pContext = new XMLIndexSimpleEntryContext(
-                            GetImport(), "TokenHyperlinkStart", *this,
-                            nPrefix, rLocalName);
+                            GetImport(), "TokenHyperlinkStart", *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_LINK_END:
                         pContext = new XMLIndexSimpleEntryContext(
-                            GetImport(), "TokenHyperlinkEnd", *this,
-                            nPrefix, rLocalName);
+                            GetImport(), "TokenHyperlinkEnd", *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_TEXT:
                         pContext = new XMLIndexSpanEntryContext(
-                            GetImport(), *this, nPrefix, rLocalName);
+                            GetImport(), *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_TAB_STOP:
                         pContext = new XMLIndexTabStopEntryContext(
-                            GetImport(), *this, nPrefix, rLocalName);
+                            GetImport(), *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_BIBLIOGRAPHY:
                         pContext = new XMLIndexBibliographyEntryContext(
-                            GetImport(), *this, nPrefix, rLocalName);
+                            GetImport(), *this);
                         break;
 
                     case XML_TOK_INDEX_TYPE_CHAPTER:
                         pContext = new XMLIndexChapterInfoEntryContext(
-                            GetImport(), *this, nPrefix, rLocalName, bTOC );
+                            GetImport(), *this, bTOC );
                         break;
 
                     default:
