@@ -480,7 +480,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
     SAL_WARN_IF(!bInit, "xmlsecurity.comp", "Error initializing security context!");
 
     if (!bInit)
-        return uno::Sequence<security::DocumentSignatureInformation>(0);
+        return {};
 
     if (!rxStorage.is())
     {
@@ -507,7 +507,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
     }
 
     if (!xInputStream.is() && aStreamHelper.nStorageFormat != embed::StorageFormats::OFOPXML)
-        return Sequence< css::security::DocumentSignatureInformation >(0);
+        return {};
 
 
     XMLSignatureHelper& rSignatureHelper = aSignatureManager.getSignatureHelper();
@@ -575,7 +575,7 @@ DocumentDigitalSignatures::ImplVerifySignatures(
             // collide, or PGPKeyID format might change - can't we
             // keep the xCert itself in rInfo?
             rSigInfo.Signer = xGpgSecEnv->getCertificate(
-                rInfo.ouGpgKeyID, xmlsecurity::numericStringToBigInteger(""));
+                rInfo.ouGpgKeyID, xmlsecurity::numericStringToBigInteger(u""));
             rSigInfo.CertificateStatus = xGpgSecEnv->verifyCertificate(
                 rSigInfo.Signer, Sequence<Reference<css::security::XCertificate>>());
         }
@@ -663,12 +663,12 @@ sal_Bool DocumentDigitalSignatures::isAuthorTrusted(
     }
     OUString sSerialNum = xmlsecurity::bigIntegerToNumericString(xAuthor->getSerialNumber());
 
-    Sequence< SvtSecurityOptions::Certificate > aTrustedAuthors = SvtSecurityOptions().GetTrustedAuthors();
+    std::vector< SvtSecurityOptions::Certificate > aTrustedAuthors = SvtSecurityOptions().GetTrustedAuthors();
 
     return std::any_of(aTrustedAuthors.begin(), aTrustedAuthors.end(),
         [&xAuthor, &sSerialNum](const SvtSecurityOptions::Certificate& rAuthor) {
-            return xmlsecurity::EqualDistinguishedNames(rAuthor[0], xAuthor->getIssuerName())
-                && ( rAuthor[1] == sSerialNum );
+            return xmlsecurity::EqualDistinguishedNames(rAuthor.SubjectName, xAuthor->getIssuerName())
+                && ( rAuthor.SerialNumber == sSerialNum );
         });
 }
 
@@ -772,20 +772,16 @@ void DocumentDigitalSignatures::addAuthorToTrustedSources(
 {
     SvtSecurityOptions aSecOpts;
 
-    SvtSecurityOptions::Certificate aNewCert( 3 );
-    aNewCert[ 0 ] = Author->getIssuerName();
-    aNewCert[ 1 ] = xmlsecurity::bigIntegerToNumericString( Author->getSerialNumber() );
+    SvtSecurityOptions::Certificate aNewCert;
+    aNewCert.SubjectName = Author->getIssuerName();
+    aNewCert.SerialNumber = xmlsecurity::bigIntegerToNumericString( Author->getSerialNumber() );
 
     OUStringBuffer aStrBuffer;
     ::comphelper::Base64::encode(aStrBuffer, Author->getEncoded());
-    aNewCert[ 2 ] = aStrBuffer.makeStringAndClear();
-
-
-    Sequence< SvtSecurityOptions::Certificate > aTrustedAuthors = aSecOpts.GetTrustedAuthors();
-    sal_Int32 nCnt = aTrustedAuthors.getLength();
-    aTrustedAuthors.realloc( nCnt + 1 );
-    aTrustedAuthors[ nCnt ] = aNewCert;
+    aNewCert.RawData = aStrBuffer.makeStringAndClear();
 
+    std::vector< SvtSecurityOptions::Certificate > aTrustedAuthors = aSecOpts.GetTrustedAuthors();
+    aTrustedAuthors.push_back( aNewCert );
     aSecOpts.SetTrustedAuthors( aTrustedAuthors );
 }
 
