@@ -293,8 +293,7 @@ return cppu::supportsService(this, serviceName);
 
 /* XServiceInfo */
 Sequence< OUString > SAL_CALL XMLSignature_MSCryptImpl::getSupportedServiceNames() {
-    Sequence<OUString> seqServiceNames { "com.sun.star.xml.crypto.XMLSignature" };
-    return seqServiceNames ;
+    return { "com.sun.star.xml.crypto.XMLSignature" };
 }
 
 extern "C" SAL_DLLPUBLIC_EXPORT uno::XInterface*
